/* Generated by Cython 0.20.1 on Mon Jun 23 19:17:59 2014 */

#define PY_SSIZE_T_CLEAN
#ifndef CYTHON_USE_PYLONG_INTERNALS
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 0
#else
#include "pyconfig.h"
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 1
#else
#define CYTHON_USE_PYLONG_INTERNALS 0
#endif
#endif
#endif
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#define CYTHON_ABI "0_20_1"
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if CYTHON_COMPILING_IN_PYPY
#define Py_OptimizeFlag 0
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_As_int(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_TPFLAGS_HAVE_VERSION_TAG 0
#endif
#if PY_VERSION_HEX < 0x02060000 && !defined(Py_TPFLAGS_IS_ABSTRACT)
  #define Py_TPFLAGS_IS_ABSTRACT 0
#endif
#if PY_VERSION_HEX < 0x030400a1 && !defined(Py_TPFLAGS_HAVE_FINALIZE)
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ? \
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#define __Pyx_PyString_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj) || \
                                         PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  /* Initialize NaN. The sign is irrelevant, an exponent with all bits 1 and
   a nonzero mantissa means NaN. If the first bit in the mantissa is 1, it is
   a quiet NaN. */
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__axon___objects
#define __PYX_HAVE_API__axon___objects
#include "string.h"
#include "stdio.h"
#include "datetime.h"
#include "math.h"
#include "floatobject.h"
#include "utils.h"
#include "bytesobject.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (    \
    (sizeof(type) < sizeof(Py_ssize_t))  ||             \
    (sizeof(type) > sizeof(Py_ssize_t) &&               \
          likely(v < (type)PY_SSIZE_T_MAX ||            \
                 v == (type)PY_SSIZE_T_MAX)  &&         \
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||       \
                                v == (type)PY_SSIZE_T_MIN)))  ||  \
    (sizeof(type) == sizeof(Py_ssize_t) &&              \
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||        \
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromUString(s)  __Pyx_PyObject_FromString((char*)s)
#define __Pyx_PyBytes_FromUString(s)   __Pyx_PyBytes_FromString((char*)s)
#define __Pyx_PyByteArray_FromUString(s)   __Pyx_PyByteArray_FromString((char*)s)
#define __Pyx_PyStr_FromUString(s)     __Pyx_PyStr_FromString((char*)s)
#define __Pyx_PyUnicode_FromUString(s) __Pyx_PyUnicode_FromString((char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return u_end - u - 1;
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    if (strcmp(PyBytes_AsString(default_encoding), "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        const char* default_encoding_c = PyBytes_AS_STRING(default_encoding);
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (ascii_chars_u == NULL) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (ascii_chars_b == NULL || strncmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
    }
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    default_encoding_c = PyBytes_AS_STRING(default_encoding);
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(sys);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "_objects.pxd",
  "_objects.py",
  "datetime.pxd",
};

/*--- Type declarations ---*/
struct UndefinedObject;
struct ReadonlyDict;
struct ReadonlyList;
struct __pyx_obj_4axon_8_objects_NamedValue;
struct Attribute;
struct __pyx_obj_4axon_8_objects_Attrs;
struct EmptyObject;
struct SequenceObject;
struct MappingObject;
struct ElementObject;
struct InstanceObject;
struct __pyx_obj_4axon_8_objects_Builder;
struct __pyx_obj_4axon_8_objects_SafeBuilder;
struct __pyx_obj_4axon_8_objects_StrictBuilder;
struct __pyx_obj_4axon_8_objects_MixedBuilder;
struct GenericBuilderObject;
struct SimpleBuilder;
struct __pyx_obj_4axon_8_objects_StringReader;
struct __pyx_obj_4axon_8_objects_StringWriter;
struct TimeZoneUTCObject;
struct __pyx_defaults;
typedef struct __pyx_defaults __pyx_defaults;

/* "axon/_objects.pxd":142
 * 
 * 
 * ctypedef PyObject* PyObjectPtr             # <<<<<<<<<<<<<<
 * 
 * cdef public unicode empty_name
 */
typedef PyObject *__pyx_t_4axon_8_objects_PyObjectPtr;
struct __pyx_defaults {
  PyObject *__pyx_arg_name;
};

/* "axon/_objects.pxd":193
 * 
 * @cython.final
 * cdef public class Undefined[object UndefinedObject, type UndefinedType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct UndefinedObject {
  PyObject_HEAD
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) UndefinedType;

/* "axon/_objects.pxd":200
 * #
 * @cython.final
 * cdef public class rdict(dict)[object ReadonlyDict, type ReadonlyDictType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct ReadonlyDict {
  PyDictObject __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ReadonlyDictType;

/* "axon/_objects.pxd":207
 * #
 * @cython.final
 * cdef public class rlist(list)[object ReadonlyList, type ReadonlyListType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct ReadonlyList {
  PyListObject __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ReadonlyListType;

/* "axon/_objects.pxd":213
 * cdef public rlist c_empty_list
 * 
 * cdef class NamedValue:             # <<<<<<<<<<<<<<
 *     cdef public object __name__
 *     cdef public object __value__
 */
struct __pyx_obj_4axon_8_objects_NamedValue {
  PyObject_HEAD
  PyObject *__name__;
  PyObject *__value__;
};


/* "axon/_objects.pxd":223
 * #
 * @cython.final
 * cdef public class Attribute[type AttributeType, object Attribute]:             # <<<<<<<<<<<<<<
 *     cdef public unicode name
 *     cdef public object value
 */
struct Attribute {
  PyObject_HEAD
  PyObject *name;
  PyObject *value;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) AttributeType;

/* "axon/_objects.pxd":232
 * cdef public Attribute c_new_attribute(unicode name, object value)
 * 
 * cdef class Attrs(object):             # <<<<<<<<<<<<<<
 *     #
 *     cdef public dict mapping
 */
struct __pyx_obj_4axon_8_objects_Attrs {
  PyObject_HEAD
  PyObject *mapping;
};


/* "axon/_objects.pxd":244
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Empty[type EmptyType, object EmptyObject]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 * 
 */
struct EmptyObject {
  PyObject_HEAD
  PyObject *name;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) EmptyType;

/* "axon/_objects.pxd":252
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Sequence[object SequenceObject, type SequenceType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public list sequence
 */
struct SequenceObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SequenceType;

/* "axon/_objects.pxd":262
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Mapping[object MappingObject, type MappingType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public dict mapping
 */
struct MappingObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) MappingType;

/* "axon/_objects.pxd":272
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Element[object ElementObject, type ElementType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public dict mapping
 */
struct ElementObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *mapping;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ElementType;

/* "axon/_objects.pxd":282
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Instance[object InstanceObject, type InstanceType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public tuple sequence
 */
struct InstanceObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) InstanceType;

/* "axon/_objects.pxd":308
 * cdef public dict c_factory_dict
 * 
 * cdef class Builder:             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */
struct __pyx_obj_4axon_8_objects_Builder {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_Builder *__pyx_vtab;
};


/* "axon/_objects.pxd":315
 *     cdef public object create_empty(self, object)
 * 
 * cdef class SafeBuilder(Builder):             # <<<<<<<<<<<<<<
 *     @cython.locals(o=Mapping)
 *     cdef public object create_mapping(self, object, dict)
 */
struct __pyx_obj_4axon_8_objects_SafeBuilder {
  struct __pyx_obj_4axon_8_objects_Builder __pyx_base;
};


/* "axon/_objects.pxd":327
 *     cdef public object create_empty(self, object)
 * 
 * cdef class StrictBuilder(Builder):             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */
struct __pyx_obj_4axon_8_objects_StrictBuilder {
  struct __pyx_obj_4axon_8_objects_Builder __pyx_base;
};


/* "axon/_objects.pxd":334
 *     cdef public object create_empty(self, object)
 * 
 * cdef class MixedBuilder(Builder):             # <<<<<<<<<<<<<<
 *     cdef SafeBuilder builder
 *     cdef public object create_mapping(self, object, dict)
 */
struct __pyx_obj_4axon_8_objects_MixedBuilder {
  struct __pyx_obj_4axon_8_objects_Builder __pyx_base;
  struct __pyx_obj_4axon_8_objects_SafeBuilder *builder;
};


/* "axon/_objects.pxd":342
 *     cdef public object create_empty(self, object)
 * 
 * cdef public class GenericBuilder(Builder)[object GenericBuilderObject, type GenericBuilderType]:             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */
struct GenericBuilderObject {
  struct __pyx_obj_4axon_8_objects_Builder __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) GenericBuilderType;

/* "axon/_objects.pxd":367
 * cdef dict tz_dict = {}
 * 
 * cdef public class SimpleBuilder[type SimpleBuilderType, object SimpleBuilder]:             # <<<<<<<<<<<<<<
 * 
 *     @cython.locals(n=int, i=int, buf=cython.p_char, num_buffer=bytes)
 */
struct SimpleBuilder {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_SimpleBuilder *__pyx_vtab;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleBuilderType;

/* "axon/_objects.pxd":392
 * 
 * @cython.final
 * cdef class StringReader:             # <<<<<<<<<<<<<<
 *     cdef unicode buffer
 *     cdef int pos
 */
struct __pyx_obj_4axon_8_objects_StringReader {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_StringReader *__pyx_vtab;
  PyObject *buffer;
  int pos;
  int n;
};


/* "axon/_objects.pxd":404
 * 
 * @cython.final
 * cdef class StringWriter:             # <<<<<<<<<<<<<<
 * 
 *     cdef list blocks
 */
struct __pyx_obj_4axon_8_objects_StringWriter {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_StringWriter *__pyx_vtab;
  PyObject *blocks;
  PyObject *items;
  int n;
};


/* "axon/_objects.pxd":418
 * cdef object timezone_cls
 * 
 * cdef public class timezone(tzinfo)[object TimeZoneUTCObject, type TimeZoneUTCType]:             # <<<<<<<<<<<<<<
 *     """Fixed offset in minutes east from UTC."""
 * 
 */
struct TimeZoneUTCObject {
  PyDateTime_TZInfo __pyx_base;
  PyObject *offset;
  PyObject *name;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) TimeZoneUTCType;


/* "axon/_objects.py":820
 *         c_factory_dict[name] = factory_func
 * 
 * class Builder:             # <<<<<<<<<<<<<<
 *     def create_sequence(self, name, sequence):
 *         return None
 */

struct __pyx_vtabstruct_4axon_8_objects_Builder {
  PyObject *(*create_mapping)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *);
  PyObject *(*create_element)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *);
  PyObject *(*create_sequence)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *);
  PyObject *(*create_instance)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *);
  PyObject *(*create_empty)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_8_objects_Builder *__pyx_vtabptr_4axon_8_objects_Builder;


/* "axon/_objects.py":836
 *         return None
 * 
 * class SafeBuilder(Builder):             # <<<<<<<<<<<<<<
 *     #
 *     def create_mapping(self, name, mapping):
 */

struct __pyx_vtabstruct_4axon_8_objects_SafeBuilder {
  struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_base;
};
static struct __pyx_vtabstruct_4axon_8_objects_SafeBuilder *__pyx_vtabptr_4axon_8_objects_SafeBuilder;


/* "axon/_objects.py":869
 *         return e
 * 
 * class StrictBuilder(Builder):             # <<<<<<<<<<<<<<
 * 
 *     #def __init__(self):
 */

struct __pyx_vtabstruct_4axon_8_objects_StrictBuilder {
  struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_base;
};
static struct __pyx_vtabstruct_4axon_8_objects_StrictBuilder *__pyx_vtabptr_4axon_8_objects_StrictBuilder;


/* "axon/_objects.py":909
 *             return handler()
 * 
 * class MixedBuilder(Builder):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
 */

struct __pyx_vtabstruct_4axon_8_objects_MixedBuilder {
  struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_base;
};
static struct __pyx_vtabstruct_4axon_8_objects_MixedBuilder *__pyx_vtabptr_4axon_8_objects_MixedBuilder;

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) GenericBuilderType;

/* "axon/_objects.py":949
 *             return handler()
 * 
 * class GenericBuilder(Builder):             # <<<<<<<<<<<<<<
 * 
 *     def create_mapping(self, name, mapping):
 */

struct __pyx_vtabstruct_4axon_8_objects_GenericBuilder {
  struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_base;
};
static struct __pyx_vtabstruct_4axon_8_objects_GenericBuilder *__pyx_vtabptr_4axon_8_objects_GenericBuilder;

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleBuilderType;

/* "axon/_objects.py":988
 * 
 * 
 * class SimpleBuilder:             # <<<<<<<<<<<<<<
 * 
 *     def create_int(self, text):
 */

struct __pyx_vtabstruct_4axon_8_objects_SimpleBuilder {
  PyObject *(*create_int)(struct SimpleBuilder *, PyObject *);
  PyObject *(*create_float)(struct SimpleBuilder *, PyObject *);
  PyObject *(*create_decimal)(struct SimpleBuilder *, PyObject *);
  PyObject *(*create_time)(struct SimpleBuilder *, int, int, int, int, PyObject *);
  PyObject *(*create_timedelta)(struct SimpleBuilder *, int, int, int);
  PyObject *(*create_date)(struct SimpleBuilder *, int, int, int);
  PyObject *(*create_datetime)(struct SimpleBuilder *, int, int, int, int, int, int, int, PyObject *);
  PyObject *(*create_tzinfo)(struct SimpleBuilder *, int);
  PyObject *(*create_inf)(struct SimpleBuilder *);
  PyObject *(*create_ninf)(struct SimpleBuilder *);
  PyObject *(*create_nan)(struct SimpleBuilder *);
  PyObject *(*create_decimal_inf)(struct SimpleBuilder *);
  PyObject *(*create_decimal_ninf)(struct SimpleBuilder *);
  PyObject *(*create_decimal_nan)(struct SimpleBuilder *);
  PyObject *(*create_binary)(struct SimpleBuilder *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_8_objects_SimpleBuilder *__pyx_vtabptr_4axon_8_objects_SimpleBuilder;
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_int(struct SimpleBuilder *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_float(struct SimpleBuilder *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal(struct SimpleBuilder *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_time(struct SimpleBuilder *, int, int, int, int, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_timedelta(struct SimpleBuilder *, int, int, int);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_date(struct SimpleBuilder *, int, int, int);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_datetime(struct SimpleBuilder *, int, int, int, int, int, int, int, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_tzinfo(struct SimpleBuilder *, int);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_inf(struct SimpleBuilder *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_ninf(struct SimpleBuilder *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_nan(struct SimpleBuilder *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_inf(struct SimpleBuilder *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_ninf(struct SimpleBuilder *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_nan(struct SimpleBuilder *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_binary(struct SimpleBuilder *, PyObject *);


/* "axon/_objects.py":1057
 *         return decodebytes(text.encode('ascii'))
 * 
 * class StringReader:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, text):
 */

struct __pyx_vtabstruct_4axon_8_objects_StringReader {
  PyObject *(*readline)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4axon_8_objects_StringReader *__pyx_vtabptr_4axon_8_objects_StringReader;
static PyObject *__pyx_f_4axon_8_objects_12StringReader_readline(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_4axon_8_objects_12StringReader_close(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);


/* "axon/_objects.py":1115
 * 
 * 
 * class StringWriter:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
 */

struct __pyx_vtabstruct_4axon_8_objects_StringWriter {
  PyObject *(*write)(struct __pyx_obj_4axon_8_objects_StringWriter *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getvalue)(struct __pyx_obj_4axon_8_objects_StringWriter *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_4axon_8_objects_StringWriter *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4axon_8_objects_StringWriter *__pyx_vtabptr_4axon_8_objects_StringWriter;
static PyObject *__pyx_f_4axon_8_objects_12StringWriter_write(struct __pyx_obj_4axon_8_objects_StringWriter *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_4axon_8_objects_12StringWriter_getvalue(struct __pyx_obj_4axon_8_objects_StringWriter *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_4axon_8_objects_12StringWriter_close(struct __pyx_obj_4axon_8_objects_StringWriter *, int __pyx_skip_dispatch);
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_XDECREF_SET(r, v) do {                            \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_XDECREF(tmp);                              \
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {                             \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_DECREF(tmp);                               \
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name); /*proto*/

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw); /*proto*/
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name); /*proto*/

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *); /*proto*/

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type); /*proto*/

#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value); /*proto*/

static CYTHON_INLINE int __Pyx_PyDict_Contains(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

#define __Pyx_CyFunction_USED 1
#include <structmember.h>
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f) \
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f) \
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f) \
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g) \
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
    PyObject *func_dict;
    PyObject *func_weakreflist;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj; /* No-args super() class cell */
    void *defaults;
    int defaults_pyobjects;
    int flags;
    PyObject *defaults_tuple;   /* Const defaults tuple */
    PyObject *defaults_kwdict;  /* Const kwonly defaults dict */
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations; /* function annotations dict */
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code) \
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __Pyx_CyFunction_init(void);

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void); /*proto*/

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected); /*proto*/

static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_dealloc);

static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

static int __Pyx_SetVtable(PyObject *dict, void *vtable); /*proto*/

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name); /*proto*/

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb); /*proto*/
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb); /*proto*/

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static PyObject *__Pyx_GetNameInClass(PyObject *nmspace, PyObject *name); /*proto*/

static double __Pyx__PyObject_AsDouble(PyObject* obj); /* proto */
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj) \
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) : \
 likely(PyInt_CheckExact(obj)) ? \
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj) \
((likely(PyFloat_CheckExact(obj))) ? \
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level); /*proto*/

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

static int __Pyx_check_binary_version(void);

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig); /*proto*/

static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig); /*proto*/

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyObject *__Pyx_ImportModule(const char *name); /*proto*/

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);  /*proto*/

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'cython' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.unicode' */

/* Module declarations from 'cpython.bytes' */

/* Module declarations from 'cpython.long' */

/* Module declarations from 'datetime' */

/* Module declarations from 'cpython.datetime' */
static PyTypeObject *__pyx_ptype_7cpython_8datetime_date = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_time = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_datetime = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_timedelta = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_tzinfo = 0;
static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_date_new(int, int, int); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_new(int, int, int, int, PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_new(int, int, int, int, int, int, int, PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timedelta_new(int, int, int); /*proto*/

/* Module declarations from 'axon._objects' */
static PyTypeObject *__pyx_ptype_4axon_8_objects_Undefined = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_rdict = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_rlist = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_NamedValue = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Attribute = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Attrs = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Empty = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Sequence = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Mapping = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Element = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Instance = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Builder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_SafeBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_StrictBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_MixedBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_GenericBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_SimpleBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_StringReader = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_StringWriter = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_timezone = 0;
static PyObject *__pyx_v_4axon_8_objects__decimal2str = 0;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_8_objects_empty_name;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_8_objects_c_undescore;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_8_objects_c_undefined;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_8_objects_name_cache;
static PyObject *__pyx_v_4axon_8_objects_c_str_type = 0;
__PYX_EXTERN_C DL_EXPORT(struct ReadonlyDict) *__pyx_v_4axon_8_objects_c_empty_dict;
__PYX_EXTERN_C DL_EXPORT(struct ReadonlyList) *__pyx_v_4axon_8_objects_c_empty_list;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_8_objects_c_factory_dict;
static PyObject *__pyx_v_4axon_8_objects_c_builder_dict = 0;
static PyObject *__pyx_v_4axon_8_objects__str2decimal = 0;
static PyObject *__pyx_v_4axon_8_objects__inf = 0;
static PyObject *__pyx_v_4axon_8_objects__ninf = 0;
static PyObject *__pyx_v_4axon_8_objects__nan = 0;
static PyObject *__pyx_v_4axon_8_objects__decimal_inf = 0;
static PyObject *__pyx_v_4axon_8_objects__decimal_ninf = 0;
static PyObject *__pyx_v_4axon_8_objects__decimal_nan = 0;
static PyObject *__pyx_v_4axon_8_objects_tz_dict = 0;
static PyObject *__pyx_v_4axon_8_objects_timezone_cls = 0;
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_dict(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_list(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_tuple(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_unicode(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_name(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_named(PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_new_attribute(PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
__PYX_EXTERN_C DL_EXPORT(struct Attribute) *__pyx_f_4axon_8_objects_c_new_attribute(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_new_attrs(PyObject *); /*proto*/
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_f_4axon_8_objects_c_new_sequence(PyObject *, PyObject *); /*proto*/
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_f_4axon_8_objects_c_new_mapping(PyObject *, PyObject *); /*proto*/
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_f_4axon_8_objects_c_new_element(PyObject *, PyObject *, PyObject *); /*proto*/
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_f_4axon_8_objects_c_new_instance(PyObject *, PyObject *, PyObject *); /*proto*/
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_f_4axon_8_objects_c_new_empty(PyObject *); /*proto*/
static CYTHON_INLINE struct __pyx_obj_4axon_8_objects_Builder *__pyx_f_4axon_8_objects_c_get_builder(PyObject *); /*proto*/
static struct __pyx_obj_4axon_8_objects_Builder *__pyx_f_4axon_8_objects_get_builder(PyObject *, int __pyx_skip_dispatch); /*proto*/
#define __Pyx_MODULE_NAME "axon._objects"
int __pyx_module_is_main_axon___objects = 0;

/* Implementation of 'axon._objects' */
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_property;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_pf_4axon_8_objects_9Undefined___repr__(CYTHON_UNUSED struct UndefinedObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_9Undefined_2__str__(CYTHON_UNUSED struct UndefinedObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_isundef(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_2_error_readonly(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_4_error_empty_mapping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_6_error_empty_sequence(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8_error_invalid_name(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_10clear_all_names(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_12as_unicode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_14as_list(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_16as_dict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_18as_tuple(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o); /* proto */
static int __pyx_pf_4axon_8_objects_5rdict___setitem__(struct ReadonlyDict *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_key, CYTHON_UNUSED PyObject *__pyx_v_item); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5rdict_2setdefault(struct ReadonlyDict *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_key, CYTHON_UNUSED PyObject *__pyx_v_default); /* proto */
static int __pyx_pf_4axon_8_objects_5rdict_4__delitem__(struct ReadonlyDict *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5rdict_6__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_op); /* proto */
static int __pyx_pf_4axon_8_objects_5rlist___setitem__(struct ReadonlyList *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_index, CYTHON_UNUSED PyObject *__pyx_v_item); /* proto */
static int __pyx_pf_4axon_8_objects_5rlist_2__delitem__(struct ReadonlyList *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5rlist_4__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_op); /* proto */
static int __pyx_pf_4axon_8_objects_10NamedValue___init__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_2__getitem__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static int __pyx_pf_4axon_8_objects_10NamedValue_4__setitem__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_6__getattr__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_8__isinstancecheck__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_cls, PyObject *__pyx_v_inst); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_8__name_____get__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_10NamedValue_8__name___2__set__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_10NamedValue_8__name___4__del__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_9__value_____get__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_10NamedValue_9__value___2__set__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_10NamedValue_9__value___4__del__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_20named(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_9Attribute___init__(struct Attribute *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_9Attribute_2__getitem__(struct Attribute *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_9Attribute_4__repr__(struct Attribute *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_9Attribute_4name___get__(struct Attribute *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_9Attribute_4name_2__set__(struct Attribute *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_9Attribute_4name_4__del__(struct Attribute *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_9Attribute_5value___get__(struct Attribute *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_9Attribute_5value_2__set__(struct Attribute *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_9Attribute_5value_4__del__(struct Attribute *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_22new_attribute(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Attrs___getattr__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Attrs_2__getitem__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Attrs_4__repr__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Attrs_7mapping___get__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_5Attrs_7mapping_2__set__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_5Attrs_7mapping_4__del__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_mapping(CYTHON_UNUSED struct EmptyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_2sequence(CYTHON_UNUSED struct EmptyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_4a(CYTHON_UNUSED struct EmptyObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_5Empty_6__init__(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_sequences); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_8__repr__(struct EmptyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_10as_mapping(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_mapping); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_12as_sequence(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_14as_element(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_16as_instance(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_5Empty_4name___get__(struct EmptyObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_5Empty_4name_2__set__(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_5Empty_4name_4__del__(struct EmptyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_mapping(CYTHON_UNUSED struct SequenceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_2a(CYTHON_UNUSED struct SequenceObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8Sequence_4__init__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_6__getitem__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static int __pyx_pf_4axon_8_objects_8Sequence_8__setitem__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_10__repr__(struct SequenceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_12as_mapping(CYTHON_UNUSED struct SequenceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_14as_sequence(struct SequenceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_16as_element(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_mapping); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_18as_instance(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_mapping); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_4name___get__(struct SequenceObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8Sequence_4name_2__set__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_8Sequence_4name_4__del__(struct SequenceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Sequence_8sequence___get__(struct SequenceObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8Sequence_8sequence_2__set__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_8Sequence_8sequence_4__del__(struct SequenceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_sequence(CYTHON_UNUSED struct MappingObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_2a(struct MappingObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_7Mapping_4__init__(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_6get(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_8set(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_10update(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_map); /* proto */
static int __pyx_pf_4axon_8_objects_7Mapping_12__contains__(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_14__repr__(struct MappingObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_16as_mapping(struct MappingObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_18as_sequence(CYTHON_UNUSED struct MappingObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_20as_element(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_22as_instance(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_4name___get__(struct MappingObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_7Mapping_4name_2__set__(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_7Mapping_4name_4__del__(struct MappingObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Mapping_7mapping___get__(struct MappingObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_7Mapping_7mapping_2__set__(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_7Mapping_7mapping_4__del__(struct MappingObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_a(struct ElementObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_2__init__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_4__getitem__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_6__setitem__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_8__contains__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_10get(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_12set(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_14update(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_map); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_16append(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_sub); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_18extend(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_subs); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_20__repr__(struct ElementObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_22as_mapping(CYTHON_UNUSED struct ElementObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_24as_sequence(CYTHON_UNUSED struct ElementObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_26as_element(struct ElementObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_28as_instance(struct ElementObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_4name___get__(struct ElementObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_4name_2__set__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_4name_4__del__(struct ElementObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_7mapping___get__(struct ElementObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_7mapping_2__set__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_7mapping_4__del__(struct ElementObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7Element_8sequence___get__(struct ElementObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_8sequence_2__set__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_7Element_8sequence_4__del__(struct ElementObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_a(struct InstanceObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8Instance_2__init__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_4__getitem__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static int __pyx_pf_4axon_8_objects_8Instance_6__setitem__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_8get(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_10set(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_12update(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_map); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_14append(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_sub); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_16extend(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_subs); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_18__repr__(struct InstanceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_20as_mapping(CYTHON_UNUSED struct InstanceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_22as_sequence(CYTHON_UNUSED struct InstanceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_24as_element(struct InstanceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_26as_instance(struct InstanceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_4name___get__(struct InstanceObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8Instance_4name_2__set__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_8Instance_4name_4__del__(struct InstanceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_8sequence___get__(struct InstanceObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8Instance_8sequence_2__set__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_8Instance_8sequence_4__del__(struct InstanceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8Instance_7mapping___get__(struct InstanceObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8Instance_7mapping_2__set__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_8Instance_7mapping_4__del__(struct InstanceObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_24sequence(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_26mapping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_28element(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_30instance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_32empty(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_34reset_factory(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7factory_2__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_7factory__factory(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_factory_func, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_36factory(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_factory_func); /* proto */
static int __pyx_pf_4axon_8_objects_12MixedBuilder___init__(struct __pyx_obj_4axon_8_objects_MixedBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_38register_builder(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode, PyObject *__pyx_v_builder); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_40get_builder(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode); /* proto */
static int __pyx_pf_4axon_8_objects_12StringReader___init__(struct __pyx_obj_4axon_8_objects_StringReader *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_12StringReader_2readline(struct __pyx_obj_4axon_8_objects_StringReader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_12StringReader_4close(struct __pyx_obj_4axon_8_objects_StringReader *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_12StringWriter___init__(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_12StringWriter_2write(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_12StringWriter_4getvalue(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_12StringWriter_6close(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8timezone___init__(struct TimeZoneUTCObject *__pyx_v_self, PyObject *__pyx_v_offset, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8timezone_2utcoffset(struct TimeZoneUTCObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8timezone_4tzname(struct TimeZoneUTCObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8timezone_6dst(CYTHON_UNUSED struct TimeZoneUTCObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8timezone_8__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_op); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8timezone_10__str__(struct TimeZoneUTCObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8timezone_12__repr__(struct TimeZoneUTCObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8timezone_6offset___get__(struct TimeZoneUTCObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8timezone_6offset_2__set__(struct TimeZoneUTCObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_8timezone_6offset_4__del__(struct TimeZoneUTCObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_8_objects_8timezone_4name___get__(struct TimeZoneUTCObject *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_8_objects_8timezone_4name_2__set__(struct TimeZoneUTCObject *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_8_objects_8timezone_4name_4__del__(struct TimeZoneUTCObject *__pyx_v_self); /* proto */
static PyObject *__pyx_tp_new_4axon_8_objects_Undefined(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_rdict(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_rlist(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_NamedValue(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_Attribute(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_Attrs(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_Empty(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_Sequence(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_Mapping(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_Element(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_Instance(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_Builder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_SafeBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_StrictBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_MixedBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_GenericBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_SimpleBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_StringReader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_StringWriter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_8_objects_timezone(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static char __pyx_k_[] = "?";
static char __pyx_k_a[] = "a";
static char __pyx_k_o[] = "o";
static char __pyx_k__2[] = "\077\077";
static char __pyx_k__6[] = ":";
static char __pyx_k__7[] = ")";
static char __pyx_k__8[] = ", ";
static char __pyx_k_eq[] = "__eq__";
static char __pyx_k_NaN[] = "NaN";
static char __pyx_k__17[] = "";
static char __pyx_k__18[] = "-";
static char __pyx_k__19[] = "+";
static char __pyx_k__22[] = "*";
static char __pyx_k__33[] = "_";
static char __pyx_k_get[] = "get";
static char __pyx_k_inf[] = "_inf";
static char __pyx_k_key[] = "key";
static char __pyx_k_nan[] = "_nan";
static char __pyx_k_val[] = "val";
static char __pyx_k_days[] = "days";
static char __pyx_k_main[] = "__main__";
static char __pyx_k_mode[] = "mode";
static char __pyx_k_name[] = "name";
static char __pyx_k_ninf[] = "_ninf";
static char __pyx_k_safe[] = "safe";
static char __pyx_k_self[] = "self";
static char __pyx_k_test[] = "__test__";
static char __pyx_k_text[] = "text";
static char __pyx_k_empty[] = "empty(";
static char __pyx_k_error[] = "error";
static char __pyx_k_inf_2[] = "inf";
static char __pyx_k_inf_3[] = "-inf";
static char __pyx_k_mixed[] = "mixed";
static char __pyx_k_nan_2[] = "nan";
static char __pyx_k_range[] = "range";
static char __pyx_k_undef[] = "undef";
static char __pyx_k_value[] = "value";
static char __pyx_k_append[] = "append";
static char __pyx_k_base64[] = "base64";
static char __pyx_k_divmod[] = "divmod";
static char __pyx_k_errors[] = "errors";
static char __pyx_k_extend[] = "extend";
static char __pyx_k_import[] = "__import__";
static char __pyx_k_offset[] = "offset";
static char __pyx_k_strict[] = "strict";
static char __pyx_k_tzname[] = "tzname";
static char __pyx_k_update[] = "update";
static char __pyx_k_as_dict[] = "as_dict";
static char __pyx_k_as_list[] = "as_list";
static char __pyx_k_builder[] = "builder";
static char __pyx_k_decimal[] = "_decimal";
static char __pyx_k_default[] = "default";
static char __pyx_k_element[] = "element(";
static char __pyx_k_empty_2[] = "empty";
static char __pyx_k_factory[] = "_factory";
static char __pyx_k_isundef[] = "isundef";
static char __pyx_k_mapping[] = "mapping";
static char __pyx_k_minutes[] = "minutes";
static char __pyx_k_seconds[] = "seconds";
static char __pyx_k_tz_dict[] = "tz_dict";
static char __pyx_k_value_2[] = "__value__";
static char __pyx_k_Infinity[] = "Infinity";
static char __pyx_k_KeyError[] = "KeyError";
static char __pyx_k_as_tuple[] = "as_tuple";
static char __pyx_k_builtins[] = "builtins";
static char __pyx_k_cdecimal[] = "cdecimal";
static char __pyx_k_datetime[] = "datetime";
static char __pyx_k_instance[] = "instance(";
static char __pyx_k_property[] = "property";
static char __pyx_k_pyx_capi[] = "__pyx_capi__";
static char __pyx_k_sequence[] = "sequence";
static char __pyx_k_str_type[] = "str_type";
static char __pyx_k_timezone[] = "timezone";
static char __pyx_k_TypeError[] = "TypeError";
static char __pyx_k_UTC_s_02d[] = "UTC%s%02d";
static char __pyx_k_decimal_2[] = "decimal";
static char __pyx_k_element_2[] = "element";
static char __pyx_k_factory_2[] = "factory";
static char __pyx_k_mapping_2[] = "mapping(";
static char __pyx_k_sequences[] = "sequences";
static char __pyx_k_timedelta[] = "timedelta";
static char __pyx_k_IndexError[] = "IndexError";
static char __pyx_k_Infinity_2[] = "-Infinity";
static char __pyx_k_as_unicode[] = "as_unicode";
static char __pyx_k_axon_types[] = "axon.types";
static char __pyx_k_c_str_type[] = "c_str_type";
static char __pyx_k_empty_name[] = "empty_name";
static char __pyx_k_getcontext[] = "getcontext";
static char __pyx_k_instance_2[] = "instance";
static char __pyx_k_name_cache[] = "name_cache";
static char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static char __pyx_k_sequence_2[] = "sequence(";
static char __pyx_k_timezone_r[] = "timezone(%r)";
static char __pyx_k_axon_errors[] = "axon.errors";
static char __pyx_k_c_undefined[] = "c_undefined";
static char __pyx_k_c_undescore[] = "c_undescore";
static char __pyx_k_decimal2str[] = "_decimal2str";
static char __pyx_k_decimal_inf[] = "_decimal_inf";
static char __pyx_k_decimal_nan[] = "_decimal_nan";
static char __pyx_k_decodebytes[] = "decodebytes";
static char __pyx_k_encodebytes[] = "encodebytes";
static char __pyx_k_str2decimal[] = "_str2decimal";
static char __pyx_k_c_empty_dict[] = "c_empty_dict";
static char __pyx_k_c_empty_list[] = "c_empty_list";
static char __pyx_k_decimal_ninf[] = "_decimal_ninf";
static char __pyx_k_decodestring[] = "decodestring";
static char __pyx_k_encodestring[] = "encodestring";
static char __pyx_k_factory_func[] = "factory_func";
static char __pyx_k_timezone_cls[] = "timezone_cls";
static char __pyx_k_timezone_r_s[] = "timezone(%r, %s)";
static char __pyx_k_UTC_s_02d_02d[] = "UTC%s%02d:%02d";
static char __pyx_k_axon__objects[] = "axon._objects";
static char __pyx_k_reset_factory[] = "reset_factory";
static char __pyx_k_to_eng_string[] = "to_eng_string";
static char __pyx_k_AttributeError[] = "AttributeError";
static char __pyx_k_Invalid_name_r[] = "Invalid name: %r";
static char __pyx_k_c_builder_dict[] = "c_builder_dict";
static char __pyx_k_c_factory_dict[] = "c_factory_dict";
static char __pyx_k_create_decimal[] = "create_decimal";
static char __pyx_k_error_readonly[] = "_error_readonly";
static char __pyx_k_clear_all_names[] = "clear_all_names";
static char __pyx_k_register_builder[] = "register_builder";
static char __pyx_k_Index_out_of_range[] = "Index out of range";
static char __pyx_k_error_invalid_name[] = "_error_invalid_name";
static char __pyx_k_error_empty_mapping[] = "_error_empty_mapping";
static char __pyx_k_error_empty_sequence[] = "_error_empty_sequence";
static char __pyx_k_default_decimal_context[] = "default_decimal_context";
static char __pyx_k_factory_locals__factory[] = "factory.<locals>._factory";
static char __pyx_k_The_type_of_r_is_not_rdict[] = "The type of %r is not rdict";
static char __pyx_k_The_type_of_r_is_not_rlist[] = "The type of %r is not rlist";
static char __pyx_k_Users_sz_repos_pyaxon_lib_axon[] = "/Users/sz/repos/pyaxon/lib/axon/_objects.py";
static char __pyx_k_Element_Sequence_convertion_isn[] = "Element->Sequence convertion isn't available";
static char __pyx_k_Instance_Mapping_convertion_isn[] = "Instance->Mapping convertion isn't available";
static char __pyx_k_Mapping_Sequence_convertion_isn[] = "Mapping->Sequence convertion isn't available";
static char __pyx_k_Sequence_Mapping_convertion_isn[] = "Sequence->Mapping convertion isn't available";
static char __pyx_k_Element_Mapping_convertion_isn_t[] = "Element->Mapping convertion isn't available";
static char __pyx_k_Instance_Sequence_convertion_isn[] = "Instance->Sequence convertion isn't available";
static char __pyx_k_Invalid_type_expected_tzinfo_ins[] = "Invalid type: expected `tzinfo` instance";
static char __pyx_k_Object_r_contains_an_empty_mappi[] = "Object %r contains an empty mapping";
static char __pyx_k_Object_r_contains_an_empty_seque[] = "Object %r contains an empty sequence";
static char __pyx_k_Readonly_object_type_r_don_t_sup[] = "Readonly object type %r don't support assigning items or attributes";
static char __pyx_k_This_object_r_is_not_unicode_com[] = "This object %r is not unicode compatible";
static char __pyx_k_This_type_of_comparison_is_not_s[] = "This type of comparison is not supported";
static PyObject *__pyx_kp_u_;
static PyObject *__pyx_n_s_AttributeError;
static PyObject *__pyx_kp_u_Element_Mapping_convertion_isn_t;
static PyObject *__pyx_kp_u_Element_Sequence_convertion_isn;
static PyObject *__pyx_n_s_IndexError;
static PyObject *__pyx_kp_u_Index_out_of_range;
static PyObject *__pyx_n_u_Infinity;
static PyObject *__pyx_kp_u_Infinity_2;
static PyObject *__pyx_kp_u_Instance_Mapping_convertion_isn;
static PyObject *__pyx_kp_u_Instance_Sequence_convertion_isn;
static PyObject *__pyx_kp_u_Invalid_name_r;
static PyObject *__pyx_kp_u_Invalid_type_expected_tzinfo_ins;
static PyObject *__pyx_n_s_KeyError;
static PyObject *__pyx_kp_u_Mapping_Sequence_convertion_isn;
static PyObject *__pyx_n_u_NaN;
static PyObject *__pyx_kp_u_Object_r_contains_an_empty_mappi;
static PyObject *__pyx_kp_u_Object_r_contains_an_empty_seque;
static PyObject *__pyx_kp_u_Readonly_object_type_r_don_t_sup;
static PyObject *__pyx_kp_u_Sequence_Mapping_convertion_isn;
static PyObject *__pyx_kp_u_The_type_of_r_is_not_rdict;
static PyObject *__pyx_kp_u_The_type_of_r_is_not_rlist;
static PyObject *__pyx_kp_s_This_object_r_is_not_unicode_com;
static PyObject *__pyx_kp_u_This_type_of_comparison_is_not_s;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_kp_u_UTC_s_02d;
static PyObject *__pyx_kp_u_UTC_s_02d_02d;
static PyObject *__pyx_kp_s_Users_sz_repos_pyaxon_lib_axon;
static PyObject *__pyx_kp_s__17;
static PyObject *__pyx_kp_u__17;
static PyObject *__pyx_kp_u__18;
static PyObject *__pyx_kp_u__19;
static PyObject *__pyx_kp_u__2;
static PyObject *__pyx_n_s__22;
static PyObject *__pyx_n_u__33;
static PyObject *__pyx_kp_u__6;
static PyObject *__pyx_kp_u__7;
static PyObject *__pyx_kp_u__8;
static PyObject *__pyx_n_s_a;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_as_dict;
static PyObject *__pyx_n_s_as_list;
static PyObject *__pyx_n_s_as_tuple;
static PyObject *__pyx_n_s_as_unicode;
static PyObject *__pyx_n_s_axon__objects;
static PyObject *__pyx_n_s_axon_errors;
static PyObject *__pyx_n_s_axon_types;
static PyObject *__pyx_n_s_base64;
static PyObject *__pyx_n_s_builder;
static PyObject *__pyx_n_s_builtins;
static PyObject *__pyx_n_s_c_builder_dict;
static PyObject *__pyx_n_s_c_empty_dict;
static PyObject *__pyx_n_s_c_empty_list;
static PyObject *__pyx_n_s_c_factory_dict;
static PyObject *__pyx_n_s_c_str_type;
static PyObject *__pyx_n_s_c_undefined;
static PyObject *__pyx_n_s_c_undescore;
static PyObject *__pyx_n_s_cdecimal;
static PyObject *__pyx_n_s_clear_all_names;
static PyObject *__pyx_n_s_create_decimal;
static PyObject *__pyx_n_s_datetime;
static PyObject *__pyx_n_s_days;
static PyObject *__pyx_n_s_decimal;
static PyObject *__pyx_n_s_decimal2str;
static PyObject *__pyx_n_s_decimal_2;
static PyObject *__pyx_n_s_decimal_inf;
static PyObject *__pyx_n_s_decimal_nan;
static PyObject *__pyx_n_s_decimal_ninf;
static PyObject *__pyx_n_s_decodebytes;
static PyObject *__pyx_n_s_decodestring;
static PyObject *__pyx_n_s_default;
static PyObject *__pyx_n_s_default_decimal_context;
static PyObject *__pyx_n_s_divmod;
static PyObject *__pyx_kp_u_element;
static PyObject *__pyx_n_s_element_2;
static PyObject *__pyx_kp_u_empty;
static PyObject *__pyx_n_s_empty_2;
static PyObject *__pyx_n_s_empty_name;
static PyObject *__pyx_n_s_encodebytes;
static PyObject *__pyx_n_s_encodestring;
static PyObject *__pyx_n_s_eq;
static PyObject *__pyx_n_s_error;
static PyObject *__pyx_n_s_error_empty_mapping;
static PyObject *__pyx_n_s_error_empty_sequence;
static PyObject *__pyx_n_s_error_invalid_name;
static PyObject *__pyx_n_s_error_readonly;
static PyObject *__pyx_n_s_errors;
static PyObject *__pyx_n_s_extend;
static PyObject *__pyx_n_s_factory;
static PyObject *__pyx_n_s_factory_2;
static PyObject *__pyx_n_s_factory_func;
static PyObject *__pyx_n_s_factory_locals__factory;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_getcontext;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_inf;
static PyObject *__pyx_n_u_inf_2;
static PyObject *__pyx_kp_u_inf_3;
static PyObject *__pyx_kp_u_instance;
static PyObject *__pyx_n_s_instance_2;
static PyObject *__pyx_n_s_isundef;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_mapping;
static PyObject *__pyx_kp_u_mapping_2;
static PyObject *__pyx_n_s_minutes;
static PyObject *__pyx_n_u_mixed;
static PyObject *__pyx_n_s_mode;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_cache;
static PyObject *__pyx_n_s_nan;
static PyObject *__pyx_n_u_nan_2;
static PyObject *__pyx_n_s_ninf;
static PyObject *__pyx_n_s_o;
static PyObject *__pyx_n_s_offset;
static PyObject *__pyx_n_s_property;
static PyObject *__pyx_n_s_pyx_capi;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_register_builder;
static PyObject *__pyx_n_s_reset_factory;
static PyObject *__pyx_n_u_safe;
static PyObject *__pyx_n_s_seconds;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_sequence;
static PyObject *__pyx_kp_u_sequence_2;
static PyObject *__pyx_n_s_sequences;
static PyObject *__pyx_n_s_str2decimal;
static PyObject *__pyx_n_s_str_type;
static PyObject *__pyx_n_u_strict;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_text;
static PyObject *__pyx_n_s_timedelta;
static PyObject *__pyx_n_s_timezone;
static PyObject *__pyx_n_s_timezone_cls;
static PyObject *__pyx_kp_u_timezone_r;
static PyObject *__pyx_kp_u_timezone_r_s;
static PyObject *__pyx_n_s_to_eng_string;
static PyObject *__pyx_n_s_tz_dict;
static PyObject *__pyx_n_s_tzname;
static PyObject *__pyx_n_s_undef;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_val;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_value_2;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_24;
static PyObject *__pyx_int_60;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__40;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_codeobj__16;
static PyObject *__pyx_codeobj__24;
static PyObject *__pyx_codeobj__26;
static PyObject *__pyx_codeobj__28;
static PyObject *__pyx_codeobj__30;
static PyObject *__pyx_codeobj__32;
static PyObject *__pyx_codeobj__35;
static PyObject *__pyx_codeobj__37;
static PyObject *__pyx_codeobj__39;
static PyObject *__pyx_codeobj__41;
static PyObject *__pyx_codeobj__43;
static PyObject *__pyx_codeobj__45;
static PyObject *__pyx_codeobj__48;
static PyObject *__pyx_codeobj__51;
static PyObject *__pyx_codeobj__54;
static PyObject *__pyx_codeobj__56;
static PyObject *__pyx_codeobj__58;
static PyObject *__pyx_codeobj__60;
static PyObject *__pyx_codeobj__63;
PyObject *__pyx_v_4axon_8_objects_empty_name = 0;
PyObject *__pyx_v_4axon_8_objects_c_undescore = 0;
PyObject *__pyx_v_4axon_8_objects_c_undefined = 0;
PyObject *__pyx_v_4axon_8_objects_name_cache = 0;
struct ReadonlyDict *__pyx_v_4axon_8_objects_c_empty_dict = 0;
struct ReadonlyList *__pyx_v_4axon_8_objects_c_empty_list = 0;
PyObject *__pyx_v_4axon_8_objects_c_factory_dict = 0;

/* "axon/_objects.py":90
 * 
 * class Undefined:
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '?'
 *     def __str__(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_9Undefined_1__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_9Undefined_1__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Undefined___repr__(((struct UndefinedObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_9Undefined___repr__(CYTHON_UNUSED struct UndefinedObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":91
 * class Undefined:
 *     def __repr__(self):
 *         return '?'             # <<<<<<<<<<<<<<
 *     def __str__(self):
 *         return '??'
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u_);
  __pyx_r = __pyx_kp_u_;
  goto __pyx_L0;

  /* "axon/_objects.py":90
 * 
 * class Undefined:
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '?'
 *     def __str__(self):
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":92
 *     def __repr__(self):
 *         return '?'
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '??'
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_9Undefined_3__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_9Undefined_3__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Undefined_2__str__(((struct UndefinedObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_9Undefined_2__str__(CYTHON_UNUSED struct UndefinedObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "axon/_objects.py":93
 *         return '?'
 *     def __str__(self):
 *         return '??'             # <<<<<<<<<<<<<<
 * 
 * def isundef(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__2);
  __pyx_r = __pyx_kp_u__2;
  goto __pyx_L0;

  /* "axon/_objects.py":92
 *     def __repr__(self):
 *         return '?'
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '??'
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":95
 *         return '??'
 * 
 * def isundef(o):             # <<<<<<<<<<<<<<
 *     return type(o) is Undefined
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_1isundef(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_1isundef = {__Pyx_NAMESTR("isundef"), (PyCFunction)__pyx_pw_4axon_8_objects_1isundef, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_1isundef(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isundef (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_isundef(__pyx_self, ((PyObject *)__pyx_v_o));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_isundef(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isundef", 0);

  /* "axon/_objects.py":96
 * 
 * def isundef(o):
 *     return type(o) is Undefined             # <<<<<<<<<<<<<<
 * 
 * c_undefined = Undefined()
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_o)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Undefined)));
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":95
 *         return '??'
 * 
 * def isundef(o):             # <<<<<<<<<<<<<<
 *     return type(o) is Undefined
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.isundef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":101
 * undef = c_undefined
 * 
 * def _error_readonly(self):             # <<<<<<<<<<<<<<
 *     return AttributeError(
 *         'Readonly object type %r don\'t support assigning items or attributes' \
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_3_error_readonly(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_3_error_readonly = {__Pyx_NAMESTR("_error_readonly"), (PyCFunction)__pyx_pw_4axon_8_objects_3_error_readonly, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_3_error_readonly(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_error_readonly (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_2_error_readonly(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_2_error_readonly(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_error_readonly", 0);

  /* "axon/_objects.py":102
 * 
 * def _error_readonly(self):
 *     return AttributeError(             # <<<<<<<<<<<<<<
 *         'Readonly object type %r don\'t support assigning items or attributes' \
 *         % type(self))
 */
  __Pyx_XDECREF(__pyx_r);

  /* "axon/_objects.py":104
 *     return AttributeError(
 *         'Readonly object type %r don\'t support assigning items or attributes' \
 *         % type(self))             # <<<<<<<<<<<<<<
 * 
 * def _error_empty_mapping(self):
 */
  __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Readonly_object_type_r_don_t_sup, ((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":102
 * 
 * def _error_readonly(self):
 *     return AttributeError(             # <<<<<<<<<<<<<<
 *         'Readonly object type %r don\'t support assigning items or attributes' \
 *         % type(self))
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_AttributeError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":101
 * undef = c_undefined
 * 
 * def _error_readonly(self):             # <<<<<<<<<<<<<<
 *     return AttributeError(
 *         'Readonly object type %r don\'t support assigning items or attributes' \
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects._error_readonly", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":106
 *         % type(self))
 * 
 * def _error_empty_mapping(self):             # <<<<<<<<<<<<<<
 *     return KeyError(
 *         'Object %r contains an empty mapping' \
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5_error_empty_mapping(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_5_error_empty_mapping = {__Pyx_NAMESTR("_error_empty_mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_5_error_empty_mapping, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_5_error_empty_mapping(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_error_empty_mapping (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_4_error_empty_mapping(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_4_error_empty_mapping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_error_empty_mapping", 0);

  /* "axon/_objects.py":107
 * 
 * def _error_empty_mapping(self):
 *     return KeyError(             # <<<<<<<<<<<<<<
 *         'Object %r contains an empty mapping' \
 *         % type(self))
 */
  __Pyx_XDECREF(__pyx_r);

  /* "axon/_objects.py":109
 *     return KeyError(
 *         'Object %r contains an empty mapping' \
 *         % type(self))             # <<<<<<<<<<<<<<
 * 
 * def _error_empty_sequence(self):
 */
  __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Object_r_contains_an_empty_mappi, ((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":107
 * 
 * def _error_empty_mapping(self):
 *     return KeyError(             # <<<<<<<<<<<<<<
 *         'Object %r contains an empty mapping' \
 *         % type(self))
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":106
 *         % type(self))
 * 
 * def _error_empty_mapping(self):             # <<<<<<<<<<<<<<
 *     return KeyError(
 *         'Object %r contains an empty mapping' \
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects._error_empty_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":111
 *         % type(self))
 * 
 * def _error_empty_sequence(self):             # <<<<<<<<<<<<<<
 *     return KeyError(
 *         'Object %r contains an empty sequence' \
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7_error_empty_sequence(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_7_error_empty_sequence = {__Pyx_NAMESTR("_error_empty_sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_7_error_empty_sequence, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_7_error_empty_sequence(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_error_empty_sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_6_error_empty_sequence(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_6_error_empty_sequence(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_error_empty_sequence", 0);

  /* "axon/_objects.py":112
 * 
 * def _error_empty_sequence(self):
 *     return KeyError(             # <<<<<<<<<<<<<<
 *         'Object %r contains an empty sequence' \
 *         % type(self))
 */
  __Pyx_XDECREF(__pyx_r);

  /* "axon/_objects.py":114
 *     return KeyError(
 *         'Object %r contains an empty sequence' \
 *         % type(self))             # <<<<<<<<<<<<<<
 * 
 * def _error_invalid_name(name):
 */
  __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Object_r_contains_an_empty_seque, ((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":112
 * 
 * def _error_empty_sequence(self):
 *     return KeyError(             # <<<<<<<<<<<<<<
 *         'Object %r contains an empty sequence' \
 *         % type(self))
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":111
 *         % type(self))
 * 
 * def _error_empty_sequence(self):             # <<<<<<<<<<<<<<
 *     return KeyError(
 *         'Object %r contains an empty sequence' \
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects._error_empty_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":116
 *         % type(self))
 * 
 * def _error_invalid_name(name):             # <<<<<<<<<<<<<<
 *     return KeyError('Invalid name: %r' % type(name))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_9_error_invalid_name(PyObject *__pyx_self, PyObject *__pyx_v_name); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_9_error_invalid_name = {__Pyx_NAMESTR("_error_invalid_name"), (PyCFunction)__pyx_pw_4axon_8_objects_9_error_invalid_name, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_9_error_invalid_name(PyObject *__pyx_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_error_invalid_name (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8_error_invalid_name(__pyx_self, ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8_error_invalid_name(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_error_invalid_name", 0);

  /* "axon/_objects.py":117
 * 
 * def _error_invalid_name(name):
 *     return KeyError('Invalid name: %r' % type(name))             # <<<<<<<<<<<<<<
 * 
 * #####################################################
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Invalid_name_r, ((PyObject *)Py_TYPE(__pyx_v_name))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":116
 *         % type(self))
 * 
 * def _error_invalid_name(name):             # <<<<<<<<<<<<<<
 *     return KeyError('Invalid name: %r' % type(name))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects._error_invalid_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":128
 * name_cache = {None: empty_name, c_undescore: c_undescore}
 * 
 * def clear_all_names():             # <<<<<<<<<<<<<<
 *     name_cache = {}
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_11clear_all_names(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_11clear_all_names = {__Pyx_NAMESTR("clear_all_names"), (PyCFunction)__pyx_pw_4axon_8_objects_11clear_all_names, METH_NOARGS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_11clear_all_names(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear_all_names (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10clear_all_names(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_10clear_all_names(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED PyObject *__pyx_v_name_cache = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clear_all_names", 0);

  /* "axon/_objects.py":129
 * 
 * def clear_all_names():
 *     name_cache = {}             # <<<<<<<<<<<<<<
 * 
 * def as_unicode(o):
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name_cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":128
 * name_cache = {None: empty_name, c_undescore: c_undescore}
 * 
 * def clear_all_names():             # <<<<<<<<<<<<<<
 *     name_cache = {}
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.clear_all_names", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name_cache);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":131
 *     name_cache = {}
 * 
 * def as_unicode(o):             # <<<<<<<<<<<<<<
 *     return c_as_unicode(o)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_13as_unicode(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_13as_unicode = {__Pyx_NAMESTR("as_unicode"), (PyCFunction)__pyx_pw_4axon_8_objects_13as_unicode, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_13as_unicode(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_unicode (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_12as_unicode(__pyx_self, ((PyObject *)__pyx_v_o));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_12as_unicode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_unicode", 0);

  /* "axon/_objects.py":132
 * 
 * def as_unicode(o):
 *     return c_as_unicode(o)             # <<<<<<<<<<<<<<
 * 
 * def as_list(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":131
 *     name_cache = {}
 * 
 * def as_unicode(o):             # <<<<<<<<<<<<<<
 *     return c_as_unicode(o)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.as_unicode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":134
 *     return c_as_unicode(o)
 * 
 * def as_list(o):             # <<<<<<<<<<<<<<
 *     return c_as_list(o)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_15as_list(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_15as_list = {__Pyx_NAMESTR("as_list"), (PyCFunction)__pyx_pw_4axon_8_objects_15as_list, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_15as_list(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_list (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_14as_list(__pyx_self, ((PyObject *)__pyx_v_o));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_14as_list(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_list", 0);

  /* "axon/_objects.py":135
 * 
 * def as_list(o):
 *     return c_as_list(o)             # <<<<<<<<<<<<<<
 * 
 * def as_dict(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":134
 *     return c_as_unicode(o)
 * 
 * def as_list(o):             # <<<<<<<<<<<<<<
 *     return c_as_list(o)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.as_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":137
 *     return c_as_list(o)
 * 
 * def as_dict(o):             # <<<<<<<<<<<<<<
 *     return c_as_dict(o)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_17as_dict(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_17as_dict = {__Pyx_NAMESTR("as_dict"), (PyCFunction)__pyx_pw_4axon_8_objects_17as_dict, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_17as_dict(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_dict (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_16as_dict(__pyx_self, ((PyObject *)__pyx_v_o));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_16as_dict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_dict", 0);

  /* "axon/_objects.py":138
 * 
 * def as_dict(o):
 *     return c_as_dict(o)             # <<<<<<<<<<<<<<
 * 
 * def as_tuple(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":137
 *     return c_as_list(o)
 * 
 * def as_dict(o):             # <<<<<<<<<<<<<<
 *     return c_as_dict(o)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.as_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":140
 *     return c_as_dict(o)
 * 
 * def as_tuple(o):             # <<<<<<<<<<<<<<
 *     return c_as_tuple(o)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_19as_tuple(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_19as_tuple = {__Pyx_NAMESTR("as_tuple"), (PyCFunction)__pyx_pw_4axon_8_objects_19as_tuple, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_19as_tuple(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_tuple (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_18as_tuple(__pyx_self, ((PyObject *)__pyx_v_o));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_18as_tuple(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_tuple", 0);

  /* "axon/_objects.py":141
 * 
 * def as_tuple(o):
 *     return c_as_tuple(o)             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_tuple(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":140
 *     return c_as_dict(o)
 * 
 * def as_tuple(o):             # <<<<<<<<<<<<<<
 *     return c_as_tuple(o)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.as_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":148
 * class rdict(dict):
 *     #
 *     def __setitem__(self, key, item):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5rdict_1__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_item); /*proto*/
static int __pyx_pw_4axon_8_objects_5rdict_1__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_item) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5rdict___setitem__(((struct ReadonlyDict *)__pyx_v_self), ((PyObject *)__pyx_v_key), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5rdict___setitem__(struct ReadonlyDict *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_key, CYTHON_UNUSED PyObject *__pyx_v_item) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "axon/_objects.py":149
 *     #
 *     def __setitem__(self, key, item):
 *         raise _error_readonly(self)             # <<<<<<<<<<<<<<
 *     #
 *     def setdefault(self, key, default):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error_readonly); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":148
 * class rdict(dict):
 *     #
 *     def __setitem__(self, key, item):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.rdict.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":151
 *         raise _error_readonly(self)
 *     #
 *     def setdefault(self, key, default):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5rdict_3setdefault(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5rdict_3setdefault(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_key = 0;
  CYTHON_UNUSED PyObject *__pyx_v_default = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setdefault (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_default,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_default)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setdefault", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setdefault") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_key = values[0];
    __pyx_v_default = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setdefault", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.rdict.setdefault", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_5rdict_2setdefault(((struct ReadonlyDict *)__pyx_v_self), __pyx_v_key, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5rdict_2setdefault(struct ReadonlyDict *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_key, CYTHON_UNUSED PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setdefault", 0);

  /* "axon/_objects.py":152
 *     #
 *     def setdefault(self, key, default):
 *         raise _error_readonly(self)             # <<<<<<<<<<<<<<
 *     #
 *     def __delitem__(self, key):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error_readonly); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":151
 *         raise _error_readonly(self)
 *     #
 *     def setdefault(self, key, default):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.rdict.setdefault", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":154
 *         raise _error_readonly(self)
 *     #
 *     def __delitem__(self, key):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5rdict_5__delitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_4axon_8_objects_5rdict_5__delitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__delitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5rdict_4__delitem__(((struct ReadonlyDict *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5rdict_4__delitem__(struct ReadonlyDict *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_key) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__delitem__", 0);

  /* "axon/_objects.py":155
 *     #
 *     def __delitem__(self, key):
 *         raise _error_readonly(self)             # <<<<<<<<<<<<<<
 *     #
 *     def __richcmp__(self, other, op):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error_readonly); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":154
 *         raise _error_readonly(self)
 *     #
 *     def __delitem__(self, key):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.rdict.__delitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":157
 *         raise _error_readonly(self)
 *     #
 *     def __richcmp__(self, other, op):             # <<<<<<<<<<<<<<
 *         if type(self) is rdict:
 *             if op == 2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5rdict_7__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_arg_op); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5rdict_7__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_arg_op) {
  PyObject *__pyx_v_op = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__richcmp__ (wrapper)", 0);
  __pyx_v_op = __Pyx_PyInt_From_int(__pyx_arg_op); if (unlikely(!__pyx_v_op)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __Pyx_GOTREF(__pyx_v_op);
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.rdict.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_5rdict_6__richcmp__(((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_other), ((PyObject *)__pyx_v_op));

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5rdict_6__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_op) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__richcmp__", 0);

  /* "axon/_objects.py":158
 *     #
 *     def __richcmp__(self, other, op):
 *         if type(self) is rdict:             # <<<<<<<<<<<<<<
 *             if op == 2:
 *                 return dict.__eq__(self, other)
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_self)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_rdict)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.py":159
 *     def __richcmp__(self, other, op):
 *         if type(self) is rdict:
 *             if op == 2:             # <<<<<<<<<<<<<<
 *                 return dict.__eq__(self, other)
 *             elif op == 3:
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_op, __pyx_int_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "axon/_objects.py":160
 *         if type(self) is rdict:
 *             if op == 2:
 *                 return dict.__eq__(self, other)             # <<<<<<<<<<<<<<
 *             elif op == 3:
 *                 return not dict.__eq__(self, other)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)((PyObject*)(&PyDict_Type))), __pyx_n_s_eq); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      __Pyx_INCREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L0;
    }

    /* "axon/_objects.py":161
 *             if op == 2:
 *                 return dict.__eq__(self, other)
 *             elif op == 3:             # <<<<<<<<<<<<<<
 *                 return not dict.__eq__(self, other)
 *             raise TypeError('This type of comparison is not supported')
 */
    __pyx_t_5 = PyObject_RichCompare(__pyx_v_op, __pyx_int_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {

      /* "axon/_objects.py":162
 *                 return dict.__eq__(self, other)
 *             elif op == 3:
 *                 return not dict.__eq__(self, other)             # <<<<<<<<<<<<<<
 *             raise TypeError('This type of comparison is not supported')
 *         else:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)((PyObject*)(&PyDict_Type))), __pyx_n_s_eq); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      __Pyx_INCREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;
    }

    /* "axon/_objects.py":163
 *             elif op == 3:
 *                 return not dict.__eq__(self, other)
 *             raise TypeError('This type of comparison is not supported')             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError('The type of %r is not rdict' % type(self))
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  /*else*/ {

    /* "axon/_objects.py":165
 *             raise TypeError('This type of comparison is not supported')
 *         else:
 *             raise TypeError('The type of %r is not rdict' % type(self))             # <<<<<<<<<<<<<<
 *     #
 * #
 */
    __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_The_type_of_r_is_not_rdict, ((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_objects.py":157
 *         raise _error_readonly(self)
 *     #
 *     def __richcmp__(self, other, op):             # <<<<<<<<<<<<<<
 *         if type(self) is rdict:
 *             if op == 2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._objects.rdict.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":172
 * class rlist(list):
 *     #
 *     def __setitem__(self, index, item):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5rlist_1__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_item); /*proto*/
static int __pyx_pw_4axon_8_objects_5rlist_1__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_item) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5rlist___setitem__(((struct ReadonlyList *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5rlist___setitem__(struct ReadonlyList *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_index, CYTHON_UNUSED PyObject *__pyx_v_item) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "axon/_objects.py":173
 *     #
 *     def __setitem__(self, index, item):
 *         raise _error_readonly(self)             # <<<<<<<<<<<<<<
 *     #
 *     def append(self, item):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error_readonly); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":172
 * class rlist(list):
 *     #
 *     def __setitem__(self, index, item):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.rlist.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":175
 *         raise _error_readonly(self)
 *     #
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

int __pyx_f_4axon_8_objects_5rlist_append(struct ReadonlyList *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_item) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 0);

  /* "axon/_objects.py":176
 *     #
 *     def append(self, item):
 *         raise _error_readonly(self)             # <<<<<<<<<<<<<<
 *     #
 *     def extend(self, items):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error_readonly); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 176; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 176; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 176; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 176; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":175
 *         raise _error_readonly(self)
 *     #
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.rlist.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":178
 *         raise _error_readonly(self)
 *     #
 *     def extend(self, items):             # <<<<<<<<<<<<<<
 *         self._error_readonly(self)
 *     #
 */

int __pyx_f_4axon_8_objects_5rlist_extend(struct ReadonlyList *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_items) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 0);

  /* "axon/_objects.py":179
 *     #
 *     def extend(self, items):
 *         self._error_readonly(self)             # <<<<<<<<<<<<<<
 *     #
 *     def __delitem__(self, index):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_error_readonly); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":178
 *         raise _error_readonly(self)
 *     #
 *     def extend(self, items):             # <<<<<<<<<<<<<<
 *         self._error_readonly(self)
 *     #
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.rlist.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":181
 *         self._error_readonly(self)
 *     #
 *     def __delitem__(self, index):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5rlist_3__delitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static int __pyx_pw_4axon_8_objects_5rlist_3__delitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__delitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5rlist_2__delitem__(((struct ReadonlyList *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5rlist_2__delitem__(struct ReadonlyList *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_index) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__delitem__", 0);

  /* "axon/_objects.py":182
 *     #
 *     def __delitem__(self, index):
 *         raise _error_readonly(self)             # <<<<<<<<<<<<<<
 *     #
 *     def __richcmp__(self, other, op):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error_readonly); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":181
 *         self._error_readonly(self)
 *     #
 *     def __delitem__(self, index):             # <<<<<<<<<<<<<<
 *         raise _error_readonly(self)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.rlist.__delitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":184
 *         raise _error_readonly(self)
 *     #
 *     def __richcmp__(self, other, op):             # <<<<<<<<<<<<<<
 *         if type(self) is rlist:
 *             if op == 2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5rlist_5__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_arg_op); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5rlist_5__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_arg_op) {
  PyObject *__pyx_v_op = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__richcmp__ (wrapper)", 0);
  __pyx_v_op = __Pyx_PyInt_From_int(__pyx_arg_op); if (unlikely(!__pyx_v_op)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __Pyx_GOTREF(__pyx_v_op);
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.rlist.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_5rlist_4__richcmp__(((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_other), ((PyObject *)__pyx_v_op));

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5rlist_4__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_op) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__richcmp__", 0);

  /* "axon/_objects.py":185
 *     #
 *     def __richcmp__(self, other, op):
 *         if type(self) is rlist:             # <<<<<<<<<<<<<<
 *             if op == 2:
 *                 return list.__eq__(self, other)
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_self)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_rlist)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.py":186
 *     def __richcmp__(self, other, op):
 *         if type(self) is rlist:
 *             if op == 2:             # <<<<<<<<<<<<<<
 *                 return list.__eq__(self, other)
 *             elif op == 3:
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_op, __pyx_int_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "axon/_objects.py":187
 *         if type(self) is rlist:
 *             if op == 2:
 *                 return list.__eq__(self, other)             # <<<<<<<<<<<<<<
 *             elif op == 3:
 *                 return not list.__eq__(self, other)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)((PyObject*)(&PyList_Type))), __pyx_n_s_eq); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      __Pyx_INCREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L0;
    }

    /* "axon/_objects.py":188
 *             if op == 2:
 *                 return list.__eq__(self, other)
 *             elif op == 3:             # <<<<<<<<<<<<<<
 *                 return not list.__eq__(self, other)
 *             raise TypeError('This type of comparison is not supported')
 */
    __pyx_t_5 = PyObject_RichCompare(__pyx_v_op, __pyx_int_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {

      /* "axon/_objects.py":189
 *                 return list.__eq__(self, other)
 *             elif op == 3:
 *                 return not list.__eq__(self, other)             # <<<<<<<<<<<<<<
 *             raise TypeError('This type of comparison is not supported')
 *         else:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)((PyObject*)(&PyList_Type))), __pyx_n_s_eq); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      __Pyx_INCREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;
    }

    /* "axon/_objects.py":190
 *             elif op == 3:
 *                 return not list.__eq__(self, other)
 *             raise TypeError('This type of comparison is not supported')             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError('The type of %r is not rlist' % type(self))
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  /*else*/ {

    /* "axon/_objects.py":192
 *             raise TypeError('This type of comparison is not supported')
 *         else:
 *             raise TypeError('The type of %r is not rlist' % type(self))             # <<<<<<<<<<<<<<
 * 
 * c_empty_dict = rdict({})
 */
    __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_The_type_of_r_is_not_rlist, ((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 192; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 192; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 192; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 192; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_objects.py":184
 *         raise _error_readonly(self)
 *     #
 *     def __richcmp__(self, other, op):             # <<<<<<<<<<<<<<
 *         if type(self) is rlist:
 *             if op == 2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._objects.rlist.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":236
 * class NamedValue:
 *     #
 *     def __init__(self, name, value):             # <<<<<<<<<<<<<<
 *         self.__name__ = value
 *         self.__value__ = value
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_10NamedValue_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_10NamedValue_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_value = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 236; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 236; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_name = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 236; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.NamedValue.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue___init__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self), __pyx_v_name, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_10NamedValue___init__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":237
 *     #
 *     def __init__(self, name, value):
 *         self.__name__ = value             # <<<<<<<<<<<<<<
 *         self.__value__ = value
 *     #
 */
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->__name__);
  __Pyx_DECREF(__pyx_v_self->__name__);
  __pyx_v_self->__name__ = __pyx_v_value;

  /* "axon/_objects.py":238
 *     def __init__(self, name, value):
 *         self.__name__ = value
 *         self.__value__ = value             # <<<<<<<<<<<<<<
 *     #
 *     def __getitem__(self, index):
 */
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->__value__);
  __Pyx_DECREF(__pyx_v_self->__value__);
  __pyx_v_self->__value__ = __pyx_v_value;

  /* "axon/_objects.py":236
 * class NamedValue:
 *     #
 *     def __init__(self, name, value):             # <<<<<<<<<<<<<<
 *         self.__name__ = value
 *         self.__value__ = value
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":240
 *         self.__value__ = value
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         return self.__value__[index]
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_3__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_3__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_2__getitem__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_2__getitem__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "axon/_objects.py":241
 *     #
 *     def __getitem__(self, index):
 *         return self.__value__[index]             # <<<<<<<<<<<<<<
 *     #
 *     def __setitem__(self, index, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_self->__value__, __pyx_v_index); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 241; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":240
 *         self.__value__ = value
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         return self.__value__[index]
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.NamedValue.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":243
 *         return self.__value__[index]
 *     #
 *     def __setitem__(self, index, value):             # <<<<<<<<<<<<<<
 *         self.__value__[index] = value
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_10NamedValue_5__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_10NamedValue_5__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_4__setitem__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_10NamedValue_4__setitem__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "axon/_objects.py":244
 *     #
 *     def __setitem__(self, index, value):
 *         self.__value__[index] = value             # <<<<<<<<<<<<<<
 *     #
 *     def __getattr__(self, name):
 */
  if (unlikely(PyObject_SetItem(__pyx_v_self->__value__, __pyx_v_index, __pyx_v_value) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 244; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":243
 *         return self.__value__[index]
 *     #
 *     def __setitem__(self, index, value):             # <<<<<<<<<<<<<<
 *         self.__value__[index] = value
 *     #
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.NamedValue.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":246
 *         self.__value__[index] = value
 *     #
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         return getattr(self.__value__, name)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_7__getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_7__getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_6__getattr__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_6__getattr__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "axon/_objects.py":247
 *     #
 *     def __getattr__(self, name):
 *         return getattr(self.__value__, name)             # <<<<<<<<<<<<<<
 *     #
 *     def __isinstancecheck__(cls, inst):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->__value__;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr(__pyx_t_1, __pyx_v_name); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":246
 *         self.__value__[index] = value
 *     #
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         return getattr(self.__value__, name)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.NamedValue.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":249
 *         return getattr(self.__value__, name)
 *     #
 *     def __isinstancecheck__(cls, inst):             # <<<<<<<<<<<<<<
 *         return isinstance(inst.__value__, cls)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_9__isinstancecheck__(PyObject *__pyx_v_cls, PyObject *__pyx_v_inst); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_9__isinstancecheck__(PyObject *__pyx_v_cls, PyObject *__pyx_v_inst) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__isinstancecheck__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_8__isinstancecheck__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_cls), ((PyObject *)__pyx_v_inst));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_8__isinstancecheck__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_cls, PyObject *__pyx_v_inst) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__isinstancecheck__", 0);

  /* "axon/_objects.py":250
 *     #
 *     def __isinstancecheck__(cls, inst):
 *         return isinstance(inst.__value__, cls)             # <<<<<<<<<<<<<<
 *     #
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_inst, __pyx_n_s_value_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_t_1, ((PyObject *)__pyx_v_cls)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":249
 *         return getattr(self.__value__, name)
 *     #
 *     def __isinstancecheck__(cls, inst):             # <<<<<<<<<<<<<<
 *         return isinstance(inst.__value__, cls)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.NamedValue.__isinstancecheck__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":214
 * 
 * cdef class NamedValue:
 *     cdef public object __name__             # <<<<<<<<<<<<<<
 *     cdef public object __value__
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_8__name___1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_8__name___1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_8__name_____get__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_8__name_____get__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__name__);
  __pyx_r = __pyx_v_self->__name__;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_10NamedValue_8__name___3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_10NamedValue_8__name___3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_8__name___2__set__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_10NamedValue_8__name___2__set__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->__name__);
  __Pyx_DECREF(__pyx_v_self->__name__);
  __pyx_v_self->__name__ = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_10NamedValue_8__name___5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_10NamedValue_8__name___5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_8__name___4__del__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_10NamedValue_8__name___4__del__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__name__);
  __Pyx_DECREF(__pyx_v_self->__name__);
  __pyx_v_self->__name__ = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":215
 * cdef class NamedValue:
 *     cdef public object __name__
 *     cdef public object __value__             # <<<<<<<<<<<<<<
 * 
 * cpdef named(name, value)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_9__value___1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_10NamedValue_9__value___1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_9__value_____get__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_10NamedValue_9__value_____get__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__value__);
  __pyx_r = __pyx_v_self->__value__;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_10NamedValue_9__value___3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_10NamedValue_9__value___3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_9__value___2__set__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_10NamedValue_9__value___2__set__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->__value__);
  __Pyx_DECREF(__pyx_v_self->__value__);
  __pyx_v_self->__value__ = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_10NamedValue_9__value___5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_10NamedValue_9__value___5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_10NamedValue_9__value___4__del__(((struct __pyx_obj_4axon_8_objects_NamedValue *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_10NamedValue_9__value___4__del__(struct __pyx_obj_4axon_8_objects_NamedValue *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__value__);
  __Pyx_DECREF(__pyx_v_self->__value__);
  __pyx_v_self->__value__ = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":253
 *     #
 * 
 * def named(name, value):             # <<<<<<<<<<<<<<
 *     return NamedValue(name, value)
 * 
 */

static PyObject *__pyx_pw_4axon_8_objects_21named(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_named(PyObject *__pyx_v_name, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("named", 0);

  /* "axon/_objects.py":254
 * 
 * def named(name, value):
 *     return NamedValue(name, value)             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 254; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_INCREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_NamedValue)), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 254; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":253
 *     #
 * 
 * def named(name, value):             # <<<<<<<<<<<<<<
 *     return NamedValue(name, value)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.named", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_21named(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_21named(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_value = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("named (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("named", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "named") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_name = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("named", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.named", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_20named(__pyx_self, __pyx_v_name, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_20named(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("named", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_named(__pyx_v_name, __pyx_v_value, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.named", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":261
 * class Attribute:
 *     #
 *     def __init__(self, name, value):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.value = value
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_9Attribute_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_9Attribute_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_value = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_name = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Attribute.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute___init__(((struct Attribute *)__pyx_v_self), __pyx_v_name, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_9Attribute___init__(struct Attribute *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":262
 *     #
 *     def __init__(self, name, value):
 *         self.name = c_as_name(name)             # <<<<<<<<<<<<<<
 *         self.value = value
 *     #
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":263
 *     def __init__(self, name, value):
 *         self.name = c_as_name(name)
 *         self.value = value             # <<<<<<<<<<<<<<
 *     #
 *     def __getitem__(self, index):
 */
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = __pyx_v_value;

  /* "axon/_objects.py":261
 * class Attribute:
 *     #
 *     def __init__(self, name, value):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.value = value
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Attribute.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":265
 *         self.value = value
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         if index == 0:
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_9Attribute_3__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_9Attribute_3__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute_2__getitem__(((struct Attribute *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_9Attribute_2__getitem__(struct Attribute *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "axon/_objects.py":266
 *     #
 *     def __getitem__(self, index):
 *         if index == 0:             # <<<<<<<<<<<<<<
 *             return self.name
 *         elif index == 1:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_index, __pyx_int_0, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.py":267
 *     def __getitem__(self, index):
 *         if index == 0:
 *             return self.name             # <<<<<<<<<<<<<<
 *         elif index == 1:
 *             return self.value
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->name);
    __pyx_r = __pyx_v_self->name;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":268
 *         if index == 0:
 *             return self.name
 *         elif index == 1:             # <<<<<<<<<<<<<<
 *             return self.value
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_index, __pyx_int_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.py":269
 *             return self.name
 *         elif index == 1:
 *             return self.value             # <<<<<<<<<<<<<<
 *         else:
 *             raise IndexError('Index out of range')
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->value);
    __pyx_r = __pyx_v_self->value;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":271
 *             return self.value
 *         else:
 *             raise IndexError('Index out of range')             # <<<<<<<<<<<<<<
 *     #
 *     def __repr__(self):
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_IndexError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_objects.py":265
 *         self.value = value
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         if index == 0:
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Attribute.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":273
 *             raise IndexError('Index out of range')
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name + ':' + repr(self.value)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_9Attribute_5__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_9Attribute_5__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute_4__repr__(((struct Attribute *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_9Attribute_4__repr__(struct Attribute *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":274
 *     #
 *     def __repr__(self):
 *         return self.name + ':' + repr(self.value)             # <<<<<<<<<<<<<<
 *     #
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_self->name, __pyx_kp_u__6); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_v_self->value;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Repr(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":273
 *             raise IndexError('Index out of range')
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name + ':' + repr(self.value)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Attribute.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":224
 * @cython.final
 * cdef public class Attribute[type AttributeType, object Attribute]:
 *     cdef public unicode name             # <<<<<<<<<<<<<<
 *     cdef public object value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_9Attribute_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_9Attribute_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute_4name___get__(((struct Attribute *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_9Attribute_4name___get__(struct Attribute *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_9Attribute_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_9Attribute_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute_4name_2__set__(((struct Attribute *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_9Attribute_4name_2__set__(struct Attribute *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 224; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Attribute.name.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_9Attribute_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_9Attribute_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute_4name_4__del__(((struct Attribute *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_9Attribute_4name_4__del__(struct Attribute *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":225
 * cdef public class Attribute[type AttributeType, object Attribute]:
 *     cdef public unicode name
 *     cdef public object value             # <<<<<<<<<<<<<<
 * 
 * @cython.locals(a=Attribute)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_9Attribute_5value_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_9Attribute_5value_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute_5value___get__(((struct Attribute *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_9Attribute_5value___get__(struct Attribute *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->value);
  __pyx_r = __pyx_v_self->value;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_9Attribute_5value_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_9Attribute_5value_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute_5value_2__set__(((struct Attribute *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_9Attribute_5value_2__set__(struct Attribute *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_9Attribute_5value_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_9Attribute_5value_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_9Attribute_5value_4__del__(((struct Attribute *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_9Attribute_5value_4__del__(struct Attribute *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":278
 * 
 * 
 * def new_attribute(name, value):             # <<<<<<<<<<<<<<
 *     a = Attribute.__new__(Attribute)
 *     a.name = c_as_unicode(name)
 */

static PyObject *__pyx_pw_4axon_8_objects_23new_attribute(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_new_attribute(PyObject *__pyx_v_name, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  struct Attribute *__pyx_v_a = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("new_attribute", 0);

  /* "axon/_objects.py":279
 * 
 * def new_attribute(name, value):
 *     a = Attribute.__new__(Attribute)             # <<<<<<<<<<<<<<
 *     a.name = c_as_unicode(name)
 *     a.value = value
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Attribute(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Attribute)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Attribute)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_a = ((struct Attribute *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":280
 * def new_attribute(name, value):
 *     a = Attribute.__new__(Attribute)
 *     a.name = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *     a.value = value
 *     return a
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_a->name);
  __Pyx_DECREF(__pyx_v_a->name);
  __pyx_v_a->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":281
 *     a = Attribute.__new__(Attribute)
 *     a.name = c_as_unicode(name)
 *     a.value = value             # <<<<<<<<<<<<<<
 *     return a
 * 
 */
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_a->value);
  __Pyx_DECREF(__pyx_v_a->value);
  __pyx_v_a->value = __pyx_v_value;

  /* "axon/_objects.py":282
 *     a.name = c_as_unicode(name)
 *     a.value = value
 *     return a             # <<<<<<<<<<<<<<
 * 
 * def c_new_attribute(name, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_a));
  __pyx_r = ((PyObject *)__pyx_v_a);
  goto __pyx_L0;

  /* "axon/_objects.py":278
 * 
 * 
 * def new_attribute(name, value):             # <<<<<<<<<<<<<<
 *     a = Attribute.__new__(Attribute)
 *     a.name = c_as_unicode(name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.new_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_a);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_23new_attribute(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_23new_attribute(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_value = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new_attribute (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("new_attribute", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "new_attribute") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_name = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("new_attribute", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.new_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_22new_attribute(__pyx_self, __pyx_v_name, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_22new_attribute(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("new_attribute", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_new_attribute(__pyx_v_name, __pyx_v_value, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.new_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":284
 *     return a
 * 
 * def c_new_attribute(name, value):             # <<<<<<<<<<<<<<
 *     a = Attribute.__new__(Attribute)
 *     a.name = name
 */

struct Attribute *__pyx_f_4axon_8_objects_c_new_attribute(PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_a = NULL;
  struct Attribute *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_attribute", 0);

  /* "axon/_objects.py":285
 * 
 * def c_new_attribute(name, value):
 *     a = Attribute.__new__(Attribute)             # <<<<<<<<<<<<<<
 *     a.name = name
 *     a.value = value
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Attribute(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Attribute)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_a = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":286
 * def c_new_attribute(name, value):
 *     a = Attribute.__new__(Attribute)
 *     a.name = name             # <<<<<<<<<<<<<<
 *     a.value = value
 *     return a
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_a, __pyx_n_s_name, __pyx_v_name) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 286; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":287
 *     a = Attribute.__new__(Attribute)
 *     a.name = name
 *     a.value = value             # <<<<<<<<<<<<<<
 *     return a
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_a, __pyx_n_s_value, __pyx_v_value) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 287; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":288
 *     a.name = name
 *     a.value = value
 *     return a             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (!(likely(((__pyx_v_a) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_a, __pyx_ptype_4axon_8_objects_Attribute))))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 288; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_a);
  __pyx_r = ((struct Attribute *)__pyx_v_a);
  goto __pyx_L0;

  /* "axon/_objects.py":284
 *     return a
 * 
 * def c_new_attribute(name, value):             # <<<<<<<<<<<<<<
 *     a = Attribute.__new__(Attribute)
 *     a.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_new_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_a);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":296
 * class Attrs(object):
 *     #
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         return self.mapping[name]
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Attrs_1__getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Attrs_1__getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Attrs___getattr__(((struct __pyx_obj_4axon_8_objects_Attrs *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Attrs___getattr__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "axon/_objects.py":297
 *     #
 *     def __getattr__(self, name):
 *         return self.mapping[name]             # <<<<<<<<<<<<<<
 *     #
 *     def __getitem__(self, name):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->mapping, __pyx_v_name); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":296
 * class Attrs(object):
 *     #
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         return self.mapping[name]
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Attrs.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":299
 *         return self.mapping[name]
 *     #
 *     def __getitem__(self, name):             # <<<<<<<<<<<<<<
 *         return self.mapping[name]
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Attrs_3__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Attrs_3__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Attrs_2__getitem__(((struct __pyx_obj_4axon_8_objects_Attrs *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Attrs_2__getitem__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "axon/_objects.py":300
 *     #
 *     def __getitem__(self, name):
 *         return self.mapping[name]             # <<<<<<<<<<<<<<
 *     #
 *     #def __setattr__(self, name, value):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 300; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->mapping, __pyx_v_name); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 300; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":299
 *         return self.mapping[name]
 *     #
 *     def __getitem__(self, name):             # <<<<<<<<<<<<<<
 *         return self.mapping[name]
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Attrs.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":305
 *     #    self.mapping[name] = value
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.mapping)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Attrs_5__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Attrs_5__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Attrs_4__repr__(((struct __pyx_obj_4axon_8_objects_Attrs *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Attrs_4__repr__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":306
 *     #
 *     def __repr__(self):
 *         return repr(self.mapping)             # <<<<<<<<<<<<<<
 * 
 * def new_attrs(mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->mapping;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Repr(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":305
 *     #    self.mapping[name] = value
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.mapping)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Attrs.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":234
 * cdef class Attrs(object):
 *     #
 *     cdef public dict mapping             # <<<<<<<<<<<<<<
 * 
 * @cython.locals(attrs=Attrs)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Attrs_7mapping_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Attrs_7mapping_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Attrs_7mapping___get__(((struct __pyx_obj_4axon_8_objects_Attrs *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Attrs_7mapping___get__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->mapping);
  __pyx_r = __pyx_v_self->mapping;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5Attrs_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_5Attrs_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Attrs_7mapping_2__set__(((struct __pyx_obj_4axon_8_objects_Attrs *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5Attrs_7mapping_2__set__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Attrs.mapping.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5Attrs_7mapping_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_5Attrs_7mapping_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Attrs_7mapping_4__del__(((struct __pyx_obj_4axon_8_objects_Attrs *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5Attrs_7mapping_4__del__(struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":308
 *         return repr(self.mapping)
 * 
 * def new_attrs(mapping):             # <<<<<<<<<<<<<<
 *     attrs = Attrs.__new__(Attrs)
 *     attrs.mapping = mapping
 */

static PyObject *__pyx_f_4axon_8_objects_new_attrs(PyObject *__pyx_v_mapping) {
  struct __pyx_obj_4axon_8_objects_Attrs *__pyx_v_attrs = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("new_attrs", 0);

  /* "axon/_objects.py":309
 * 
 * def new_attrs(mapping):
 *     attrs = Attrs.__new__(Attrs)             # <<<<<<<<<<<<<<
 *     attrs.mapping = mapping
 *     return attrs
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Attrs(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Attrs)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 309; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Attrs)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 309; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_attrs = ((struct __pyx_obj_4axon_8_objects_Attrs *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":310
 * def new_attrs(mapping):
 *     attrs = Attrs.__new__(Attrs)
 *     attrs.mapping = mapping             # <<<<<<<<<<<<<<
 *     return attrs
 * 
 */
  __Pyx_INCREF(__pyx_v_mapping);
  __Pyx_GIVEREF(__pyx_v_mapping);
  __Pyx_GOTREF(__pyx_v_attrs->mapping);
  __Pyx_DECREF(__pyx_v_attrs->mapping);
  __pyx_v_attrs->mapping = __pyx_v_mapping;

  /* "axon/_objects.py":311
 *     attrs = Attrs.__new__(Attrs)
 *     attrs.mapping = mapping
 *     return attrs             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_attrs));
  __pyx_r = ((PyObject *)__pyx_v_attrs);
  goto __pyx_L0;

  /* "axon/_objects.py":308
 *         return repr(self.mapping)
 * 
 * def new_attrs(mapping):             # <<<<<<<<<<<<<<
 *     attrs = Attrs.__new__(Attrs)
 *     attrs.mapping = mapping
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.new_attrs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_attrs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":334
 *     '''
 *     @property
 *     def mapping(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_1mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_1mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mapping (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_mapping(((struct EmptyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_mapping(CYTHON_UNUSED struct EmptyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mapping", 0);

  /* "axon/_objects.py":335
 *     @property
 *     def mapping(self):
 *         return None             # <<<<<<<<<<<<<<
 *     #
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":334
 *     '''
 *     @property
 *     def mapping(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":338
 *     #
 *     @property
 *     def sequence(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_3sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_3sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_2sequence(((struct EmptyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_2sequence(CYTHON_UNUSED struct EmptyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence", 0);

  /* "axon/_objects.py":339
 *     @property
 *     def sequence(self):
 *         return None             # <<<<<<<<<<<<<<
 *     #
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":338
 *     #
 *     @property
 *     def sequence(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":342
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(c_empty_dict)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_5a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_5a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("a (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_4a(((struct EmptyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_4a(CYTHON_UNUSED struct EmptyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("a", 0);

  /* "axon/_objects.py":343
 *     @property
 *     def a(self):
 *         return new_attrs(c_empty_dict)             # <<<<<<<<<<<<<<
 *     #
 *     def __init__(self, name, sequences=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_v_4axon_8_objects_c_empty_dict);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_new_attrs(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":342
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(c_empty_dict)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Empty.a", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":345
 *         return new_attrs(c_empty_dict)
 *     #
 *     def __init__(self, name, sequences=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5Empty_7__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_5Empty_7__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  CYTHON_UNUSED PyObject *__pyx_v_sequences = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_sequences,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequences);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 345; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_sequences = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 345; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Empty.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_6__init__(((struct EmptyObject *)__pyx_v_self), __pyx_v_name, __pyx_v_sequences);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5Empty_6__init__(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_sequences) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":346
 *     #
 *     def __init__(self, name, sequences=None):
 *         self.name = c_as_name(name)             # <<<<<<<<<<<<<<
 *     #
 * #     def __richcmp__(self, other, op):
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":345
 *         return new_attrs(c_empty_dict)
 *     #
 *     def __init__(self, name, sequences=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *     #
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Empty.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":359
 * #             raise TypeError('This type of comparison is not supported')
 * #     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'empty(' + repr(self.name) + ')'
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_9__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_9__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_8__repr__(((struct EmptyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_8__repr__(struct EmptyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":360
 * #     #
 *     def __repr__(self):
 *         return 'empty(' + repr(self.name) + ')'             # <<<<<<<<<<<<<<
 *     #
 *     def as_mapping(self, mapping=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Repr(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_empty, __pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u__7); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":359
 * #             raise TypeError('This type of comparison is not supported')
 * #     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'empty(' + repr(self.name) + ')'
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Empty.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":362
 *         return 'empty(' + repr(self.name) + ')'
 *     #
 *     def as_mapping(self, mapping=None):             # <<<<<<<<<<<<<<
 *         return c_new_mapping(self.name, c_as_dict(mapping))
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_11as_mapping(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_11as_mapping(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_mapping = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_mapping (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mapping,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "as_mapping") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_mapping = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("as_mapping", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Empty.as_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_10as_mapping(((struct EmptyObject *)__pyx_v_self), __pyx_v_mapping);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_10as_mapping(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_mapping", 0);

  /* "axon/_objects.py":363
 *     #
 *     def as_mapping(self, mapping=None):
 *         return c_new_mapping(self.name, c_as_dict(mapping))             # <<<<<<<<<<<<<<
 *     #
 *     def as_sequence(self, sequence=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_new_mapping(__pyx_t_1, ((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":362
 *         return 'empty(' + repr(self.name) + ')'
 *     #
 *     def as_mapping(self, mapping=None):             # <<<<<<<<<<<<<<
 *         return c_new_mapping(self.name, c_as_dict(mapping))
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Empty.as_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":365
 *         return c_new_mapping(self.name, c_as_dict(mapping))
 *     #
 *     def as_sequence(self, sequence=None):             # <<<<<<<<<<<<<<
 *         return c_new_sequence(self.name, c_as_list(sequence))
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_13as_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_13as_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_sequence (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "as_sequence") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 365; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("as_sequence", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 365; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Empty.as_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_12as_sequence(((struct EmptyObject *)__pyx_v_self), __pyx_v_sequence);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_12as_sequence(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_sequence", 0);

  /* "axon/_objects.py":366
 *     #
 *     def as_sequence(self, sequence=None):
 *         return c_new_sequence(self.name, c_as_list(sequence))             # <<<<<<<<<<<<<<
 *     #
 *     def as_element(self, mapping=None, sequence=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 366; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_new_sequence(__pyx_t_1, ((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 366; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":365
 *         return c_new_mapping(self.name, c_as_dict(mapping))
 *     #
 *     def as_sequence(self, sequence=None):             # <<<<<<<<<<<<<<
 *         return c_new_sequence(self.name, c_as_list(sequence))
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Empty.as_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":368
 *         return c_new_sequence(self.name, c_as_list(sequence))
 *     #
 *     def as_element(self, mapping=None, sequence=None):             # <<<<<<<<<<<<<<
 *         return c_new_element(self.name, c_as_dict(mapping), c_as_list(sequence))
 *             #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_15as_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_15as_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_mapping = 0;
  PyObject *__pyx_v_sequence = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_element (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mapping,&__pyx_n_s_sequence,0};
    PyObject* values[2] = {0,0};
    values[0] = ((PyObject *)Py_None);
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping);
          if (value) { values[0] = value; kw_args--; }
        }
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "as_element") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 368; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_mapping = values[0];
    __pyx_v_sequence = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("as_element", 0, 0, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 368; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Empty.as_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_14as_element(((struct EmptyObject *)__pyx_v_self), __pyx_v_mapping, __pyx_v_sequence);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_14as_element(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_element", 0);

  /* "axon/_objects.py":369
 *     #
 *     def as_element(self, mapping=None, sequence=None):
 *         return c_new_element(self.name, c_as_dict(mapping), c_as_list(sequence))             # <<<<<<<<<<<<<<
 *             #
 *     def as_instance(self, sequence=None, mapping=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_element(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":368
 *         return c_new_sequence(self.name, c_as_list(sequence))
 *     #
 *     def as_element(self, mapping=None, sequence=None):             # <<<<<<<<<<<<<<
 *         return c_new_element(self.name, c_as_dict(mapping), c_as_list(sequence))
 *             #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.Empty.as_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":371
 *         return c_new_element(self.name, c_as_dict(mapping), c_as_list(sequence))
 *             #
 *     def as_instance(self, sequence=None, mapping=None):             # <<<<<<<<<<<<<<
 *         return c_new_instance(self.name, c_as_tuple(sequence), c_as_dict(mapping))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_17as_instance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_17as_instance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_mapping = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_instance (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,&__pyx_n_s_mapping,0};
    PyObject* values[2] = {0,0};
    values[0] = ((PyObject *)Py_None);
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[0] = value; kw_args--; }
        }
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "as_instance") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 371; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = values[0];
    __pyx_v_mapping = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("as_instance", 0, 0, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 371; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Empty.as_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_16as_instance(((struct EmptyObject *)__pyx_v_self), __pyx_v_sequence, __pyx_v_mapping);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_16as_instance(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_instance", 0);

  /* "axon/_objects.py":372
 *             #
 *     def as_instance(self, sequence=None, mapping=None):
 *         return c_new_instance(self.name, c_as_tuple(sequence), c_as_dict(mapping))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_tuple(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_instance(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":371
 *         return c_new_element(self.name, c_as_dict(mapping), c_as_list(sequence))
 *             #
 *     def as_instance(self, sequence=None, mapping=None):             # <<<<<<<<<<<<<<
 *         return c_new_instance(self.name, c_as_tuple(sequence), c_as_dict(mapping))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.Empty.as_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":245
 * @cython.final
 * cdef public class Empty[type EmptyType, object EmptyObject]:
 *     cdef public object name             # <<<<<<<<<<<<<<
 * 
 * #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_5Empty_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_5Empty_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_4name___get__(((struct EmptyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_5Empty_4name___get__(struct EmptyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5Empty_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_5Empty_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_4name_2__set__(((struct EmptyObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5Empty_4name_2__set__(struct EmptyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_5Empty_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_5Empty_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_5Empty_4name_4__del__(((struct EmptyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_5Empty_4name_4__del__(struct EmptyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":398
 *     #
 *     @property
 *     def mapping(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_1mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_1mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mapping (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_mapping(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_mapping(CYTHON_UNUSED struct SequenceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mapping", 0);

  /* "axon/_objects.py":399
 *     @property
 *     def mapping(self):
 *         return None             # <<<<<<<<<<<<<<
 *     #
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":398
 *     #
 *     @property
 *     def mapping(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":402
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(c_empty_dict)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_3a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_3a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("a (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_2a(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_2a(CYTHON_UNUSED struct SequenceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("a", 0);

  /* "axon/_objects.py":403
 *     @property
 *     def a(self):
 *         return new_attrs(c_empty_dict)             # <<<<<<<<<<<<<<
 *     #
 *     def __init__(self, name, sequence=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_v_4axon_8_objects_c_empty_dict);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_new_attrs(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 403; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":402
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(c_empty_dict)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Sequence.a", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":405
 *         return new_attrs(c_empty_dict)
 *     #
 *     def __init__(self, name, sequence=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.sequence = c_as_list(sequence)
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Sequence_5__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_8Sequence_5__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sequence = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_sequence,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 405; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_sequence = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 405; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Sequence.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_4__init__(((struct SequenceObject *)__pyx_v_self), __pyx_v_name, __pyx_v_sequence);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Sequence_4__init__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":406
 *     #
 *     def __init__(self, name, sequence=None):
 *         self.name = c_as_name(name)             # <<<<<<<<<<<<<<
 *         self.sequence = c_as_list(sequence)
 *     #
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":407
 *     def __init__(self, name, sequence=None):
 *         self.name = c_as_name(name)
 *         self.sequence = c_as_list(sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def __getitem__(self, index):
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 407; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":405
 *         return new_attrs(c_empty_dict)
 *     #
 *     def __init__(self, name, sequence=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.sequence = c_as_list(sequence)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Sequence.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":409
 *         self.sequence = c_as_list(sequence)
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         return self.sequence[index]
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_7__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_7__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_6__getitem__(((struct SequenceObject *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_6__getitem__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "axon/_objects.py":410
 *     #
 *     def __getitem__(self, index):
 *         return self.sequence[index]             # <<<<<<<<<<<<<<
 *     #
 *     def __setitem__(self, index, val):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PyObject_GetItem(__pyx_v_self->sequence, __pyx_v_index); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":409
 *         self.sequence = c_as_list(sequence)
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         return self.sequence[index]
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Sequence.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":412
 *         return self.sequence[index]
 *     #
 *     def __setitem__(self, index, val):             # <<<<<<<<<<<<<<
 *         self.sequence[index] = val
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Sequence_9__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val); /*proto*/
static int __pyx_pw_4axon_8_objects_8Sequence_9__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_8__setitem__(((struct SequenceObject *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_val));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Sequence_8__setitem__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "axon/_objects.py":413
 *     #
 *     def __setitem__(self, index, val):
 *         self.sequence[index] = val             # <<<<<<<<<<<<<<
 *     #
 * #     def __richcmp__(self, other, op):
 */
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyObject_SetItem(__pyx_v_self->sequence, __pyx_v_index, __pyx_v_val) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":412
 *         return self.sequence[index]
 *     #
 *     def __setitem__(self, index, val):             # <<<<<<<<<<<<<<
 *         self.sequence[index] = val
 *     #
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Sequence.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":429
 * #                 'Types %r and %r are not comparable at all' % (type(self), type(other)))
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'sequence(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.sequence) if x]) + ')'
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_11__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_11__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_10__repr__(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_10__repr__(struct SequenceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":430
 *     #
 *     def __repr__(self):
 *         return 'sequence(' + \             # <<<<<<<<<<<<<<
 *                 ', '.join([repr(x) for x in (self.name, self.sequence) if x]) + ')'
 *     #
 */
  __Pyx_XDECREF(__pyx_r);

  /* "axon/_objects.py":431
 *     def __repr__(self):
 *         return 'sequence(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.sequence) if x]) + ')'             # <<<<<<<<<<<<<<
 *     #
 *     def as_mapping(self):
 */
  { /* enter inner scope */
    PyObject *__pyx_7genexpr__pyx_v_x = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_self->name);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->name);
    __Pyx_GIVEREF(__pyx_v_self->name);
    __Pyx_INCREF(__pyx_v_self->sequence);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->sequence);
    __Pyx_GIVEREF(__pyx_v_self->sequence);
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_4 >= 2) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      #endif
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_x, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_7genexpr__pyx_v_x); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      if (__pyx_t_5) {
        __pyx_t_2 = PyObject_Repr(__pyx_7genexpr__pyx_v_x); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L8;
      }
      __pyx_L8:;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x);
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x);
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__8, __pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":430
 *     #
 *     def __repr__(self):
 *         return 'sequence(' + \             # <<<<<<<<<<<<<<
 *                 ', '.join([repr(x) for x in (self.name, self.sequence) if x]) + ')'
 *     #
 */
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_sequence_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":431
 *     def __repr__(self):
 *         return 'sequence(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.sequence) if x]) + ')'             # <<<<<<<<<<<<<<
 *     #
 *     def as_mapping(self):
 */
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u__7); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 431; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":429
 * #                 'Types %r and %r are not comparable at all' % (type(self), type(other)))
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'sequence(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.sequence) if x]) + ')'
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Sequence.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":433
 *                 ', '.join([repr(x) for x in (self.name, self.sequence) if x]) + ')'
 *     #
 *     def as_mapping(self):             # <<<<<<<<<<<<<<
 *         raise error("Sequence->Mapping convertion isn't available")
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_13as_mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_13as_mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_mapping (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_12as_mapping(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_12as_mapping(CYTHON_UNUSED struct SequenceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_mapping", 0);

  /* "axon/_objects.py":434
 *     #
 *     def as_mapping(self):
 *         raise error("Sequence->Mapping convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_sequence(self):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":433
 *                 ', '.join([repr(x) for x in (self.name, self.sequence) if x]) + ')'
 *     #
 *     def as_mapping(self):             # <<<<<<<<<<<<<<
 *         raise error("Sequence->Mapping convertion isn't available")
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Sequence.as_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":436
 *         raise error("Sequence->Mapping convertion isn't available")
 *     #
 *     def as_sequence(self):             # <<<<<<<<<<<<<<
 *         return self
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_15as_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_15as_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_14as_sequence(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_14as_sequence(struct SequenceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_sequence", 0);

  /* "axon/_objects.py":437
 *     #
 *     def as_sequence(self):
 *         return self             # <<<<<<<<<<<<<<
 *     #
 *     def as_element(self, mapping=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "axon/_objects.py":436
 *         raise error("Sequence->Mapping convertion isn't available")
 *     #
 *     def as_sequence(self):             # <<<<<<<<<<<<<<
 *         return self
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":439
 *         return self
 *     #
 *     def as_element(self, mapping=None):             # <<<<<<<<<<<<<<
 *         return c_new_element(self.name, c_as_dict(mapping), self.sequence)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_17as_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_17as_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_mapping = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_element (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mapping,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "as_element") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 439; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_mapping = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("as_element", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 439; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Sequence.as_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_16as_element(((struct SequenceObject *)__pyx_v_self), __pyx_v_mapping);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_16as_element(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_element", 0);

  /* "axon/_objects.py":440
 *     #
 *     def as_element(self, mapping=None):
 *         return c_new_element(self.name, c_as_dict(mapping), self.sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def as_instance(self, mapping=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 440; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_v_self->sequence;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_element(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 440; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":439
 *         return self
 *     #
 *     def as_element(self, mapping=None):             # <<<<<<<<<<<<<<
 *         return c_new_element(self.name, c_as_dict(mapping), self.sequence)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.Sequence.as_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":442
 *         return c_new_element(self.name, c_as_dict(mapping), self.sequence)
 *     #
 *     def as_instance(self, mapping=None):             # <<<<<<<<<<<<<<
 *         return c_new_instance(self.name, tuple(self.sequence), c_as_dict(mapping))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_19as_instance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_19as_instance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_mapping = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_instance (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mapping,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "as_instance") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 442; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_mapping = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("as_instance", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 442; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Sequence.as_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_18as_instance(((struct SequenceObject *)__pyx_v_self), __pyx_v_mapping);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_18as_instance(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_instance", 0);

  /* "axon/_objects.py":443
 *     #
 *     def as_instance(self, mapping=None):
 *         return c_new_instance(self.name, tuple(self.sequence), c_as_dict(mapping))             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_2 = PyList_AsTuple(__pyx_v_self->sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_instance(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":442
 *         return c_new_element(self.name, c_as_dict(mapping), self.sequence)
 *     #
 *     def as_instance(self, mapping=None):             # <<<<<<<<<<<<<<
 *         return c_new_instance(self.name, tuple(self.sequence), c_as_dict(mapping))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.Sequence.as_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":253
 * @cython.final
 * cdef public class Sequence[object SequenceObject, type SequenceType]:
 *     cdef public object name             # <<<<<<<<<<<<<<
 *     cdef public list sequence
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_4name___get__(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_4name___get__(struct SequenceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Sequence_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_8Sequence_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_4name_2__set__(((struct SequenceObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Sequence_4name_2__set__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Sequence_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_8Sequence_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_4name_4__del__(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Sequence_4name_4__del__(struct SequenceObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":254
 * cdef public class Sequence[object SequenceObject, type SequenceType]:
 *     cdef public object name
 *     cdef public list sequence             # <<<<<<<<<<<<<<
 *     #
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_8sequence_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Sequence_8sequence_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_8sequence___get__(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Sequence_8sequence___get__(struct SequenceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __pyx_r = __pyx_v_self->sequence;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Sequence_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_8Sequence_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_8sequence_2__set__(((struct SequenceObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Sequence_8sequence_2__set__(struct SequenceObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 254; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Sequence.sequence.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Sequence_8sequence_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_8Sequence_8sequence_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Sequence_8sequence_4__del__(((struct SequenceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Sequence_8sequence_4__del__(struct SequenceObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":467
 *     #
 *     @property
 *     def sequence(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_1sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_1sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_sequence(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_sequence(CYTHON_UNUSED struct MappingObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence", 0);

  /* "axon/_objects.py":468
 *     @property
 *     def sequence(self):
 *         return None             # <<<<<<<<<<<<<<
 *     #
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":467
 *     #
 *     @property
 *     def sequence(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":471
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_3a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_3a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("a (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_2a(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_2a(struct MappingObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("a", 0);

  /* "axon/_objects.py":472
 *     @property
 *     def a(self):
 *         return new_attrs(self.mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def __init__(self, name, mapping=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->mapping;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_new_attrs(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 472; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":471
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Mapping.a", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":474
 *         return new_attrs(self.mapping)
 *     #
 *     def __init__(self, name, mapping=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.mapping = c_as_dict(mapping)
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Mapping_5__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_7Mapping_5__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_mapping = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_mapping,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_mapping = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Mapping.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_4__init__(((struct MappingObject *)__pyx_v_self), __pyx_v_name, __pyx_v_mapping);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Mapping_4__init__(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":475
 *     #
 *     def __init__(self, name, mapping=None):
 *         self.name = c_as_name(name)             # <<<<<<<<<<<<<<
 *         self.mapping = c_as_dict(mapping)
 *     #
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":476
 *     def __init__(self, name, mapping=None):
 *         self.name = c_as_name(name)
 *         self.mapping = c_as_dict(mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def get(self, name, default=None):
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":474
 *         return new_attrs(self.mapping)
 *     #
 *     def __init__(self, name, mapping=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.mapping = c_as_dict(mapping)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Mapping.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":478
 *         self.mapping = c_as_dict(mapping)
 *     #
 *     def get(self, name, default=None):             # <<<<<<<<<<<<<<
 *         return self.mapping.get(name, default)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_7get(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_7get(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_default = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_default,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_default = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Mapping.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_6get(((struct MappingObject *)__pyx_v_self), __pyx_v_name, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_6get(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 0);

  /* "axon/_objects.py":479
 *     #
 *     def get(self, name, default=None):
 *         return self.mapping.get(name, default)             # <<<<<<<<<<<<<<
 *     #
 *     def set(self, name, val):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->mapping, __pyx_v_name, __pyx_v_default); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":478
 *         self.mapping = c_as_dict(mapping)
 *     #
 *     def get(self, name, default=None):             # <<<<<<<<<<<<<<
 *         return self.mapping.get(name, default)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Mapping.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":481
 *         return self.mapping.get(name, default)
 *     #
 *     def set(self, name, val):             # <<<<<<<<<<<<<<
 *         self.mapping[name] = val
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_9set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_9set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_val = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_val,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_val)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_name = values[0];
    __pyx_v_val = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Mapping.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_8set(((struct MappingObject *)__pyx_v_self), __pyx_v_name, __pyx_v_val);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_8set(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 0);

  /* "axon/_objects.py":482
 *     #
 *     def set(self, name, val):
 *         self.mapping[name] = val             # <<<<<<<<<<<<<<
 *     #
 *     def update(self, map):
 */
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 482; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyDict_SetItem(__pyx_v_self->mapping, __pyx_v_name, __pyx_v_val) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 482; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":481
 *         return self.mapping.get(name, default)
 *     #
 *     def set(self, name, val):             # <<<<<<<<<<<<<<
 *         self.mapping[name] = val
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Mapping.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":484
 *         self.mapping[name] = val
 *     #
 *     def update(self, map):             # <<<<<<<<<<<<<<
 *         self.mapping.update(map)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_11update(PyObject *__pyx_v_self, PyObject *__pyx_v_map); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_11update(PyObject *__pyx_v_self, PyObject *__pyx_v_map) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("update (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_10update(((struct MappingObject *)__pyx_v_self), ((PyObject *)__pyx_v_map));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_10update(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_map) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 0);

  /* "axon/_objects.py":485
 *     #
 *     def update(self, map):
 *         self.mapping.update(map)             # <<<<<<<<<<<<<<
 *     #
 *     def __contains__(self, name):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->mapping, __pyx_n_s_update); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_map);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_map);
  __Pyx_GIVEREF(__pyx_v_map);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":484
 *         self.mapping[name] = val
 *     #
 *     def update(self, map):             # <<<<<<<<<<<<<<
 *         self.mapping.update(map)
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Mapping.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":487
 *         self.mapping.update(map)
 *     #
 *     def __contains__(self, name):             # <<<<<<<<<<<<<<
 *         return name in self.mapping
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Mapping_13__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static int __pyx_pw_4axon_8_objects_7Mapping_13__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_12__contains__(((struct MappingObject *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Mapping_12__contains__(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__contains__", 0);

  /* "axon/_objects.py":488
 *     #
 *     def __contains__(self, name):
 *         return name in self.mapping             # <<<<<<<<<<<<<<
 *     #
 * #     def __richcmp__(self, other, op):
 */
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 488; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = (__Pyx_PyDict_Contains(__pyx_v_name, __pyx_v_self->mapping, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 488; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "axon/_objects.py":487
 *         self.mapping.update(map)
 *     #
 *     def __contains__(self, name):             # <<<<<<<<<<<<<<
 *         return name in self.mapping
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Mapping.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":504
 * #                 'Types %r and %r are not comparable at all' % (type(self), type(other)))
 * #     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return  'mapping(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.mapping) if x]) + ')'
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_15__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_15__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_14__repr__(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_14__repr__(struct MappingObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":505
 * #     #
 *     def __repr__(self):
 *         return  'mapping(' + \             # <<<<<<<<<<<<<<
 *                 ', '.join([repr(x) for x in (self.name, self.mapping) if x]) + ')'
 *     #
 */
  __Pyx_XDECREF(__pyx_r);

  /* "axon/_objects.py":506
 *     def __repr__(self):
 *         return  'mapping(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.mapping) if x]) + ')'             # <<<<<<<<<<<<<<
 *     #
 *     def as_mapping(self):
 */
  { /* enter inner scope */
    PyObject *__pyx_8genexpr1__pyx_v_x = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_self->name);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->name);
    __Pyx_GIVEREF(__pyx_v_self->name);
    __Pyx_INCREF(__pyx_v_self->mapping);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->mapping);
    __Pyx_GIVEREF(__pyx_v_self->mapping);
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_4 >= 2) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      #endif
      __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_x, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_8genexpr1__pyx_v_x); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      if (__pyx_t_5) {
        __pyx_t_2 = PyObject_Repr(__pyx_8genexpr1__pyx_v_x); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L8;
      }
      __pyx_L8:;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_x);
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_x);
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__8, __pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":505
 * #     #
 *     def __repr__(self):
 *         return  'mapping(' + \             # <<<<<<<<<<<<<<
 *                 ', '.join([repr(x) for x in (self.name, self.mapping) if x]) + ')'
 *     #
 */
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_mapping_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":506
 *     def __repr__(self):
 *         return  'mapping(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.mapping) if x]) + ')'             # <<<<<<<<<<<<<<
 *     #
 *     def as_mapping(self):
 */
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u__7); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":504
 * #                 'Types %r and %r are not comparable at all' % (type(self), type(other)))
 * #     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return  'mapping(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.mapping) if x]) + ')'
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Mapping.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":508
 *                 ', '.join([repr(x) for x in (self.name, self.mapping) if x]) + ')'
 *     #
 *     def as_mapping(self):             # <<<<<<<<<<<<<<
 *         return self
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_17as_mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_17as_mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_mapping (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_16as_mapping(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_16as_mapping(struct MappingObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_mapping", 0);

  /* "axon/_objects.py":509
 *     #
 *     def as_mapping(self):
 *         return self             # <<<<<<<<<<<<<<
 *     #
 *     def as_sequence(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "axon/_objects.py":508
 *                 ', '.join([repr(x) for x in (self.name, self.mapping) if x]) + ')'
 *     #
 *     def as_mapping(self):             # <<<<<<<<<<<<<<
 *         return self
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":511
 *         return self
 *     #
 *     def as_sequence(self):             # <<<<<<<<<<<<<<
 *         raise error("Mapping->Sequence convertion isn't available")
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_19as_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_19as_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_18as_sequence(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_18as_sequence(CYTHON_UNUSED struct MappingObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_sequence", 0);

  /* "axon/_objects.py":512
 *     #
 *     def as_sequence(self):
 *         raise error("Mapping->Sequence convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_element(self, sequence=None):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":511
 *         return self
 *     #
 *     def as_sequence(self):             # <<<<<<<<<<<<<<
 *         raise error("Mapping->Sequence convertion isn't available")
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Mapping.as_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":514
 *         raise error("Mapping->Sequence convertion isn't available")
 *     #
 *     def as_element(self, sequence=None):             # <<<<<<<<<<<<<<
 *         return c_new_element(self.name, self.mapping, c_as_list(sequence))
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_21as_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_21as_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_element (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "as_element") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("as_element", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Mapping.as_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_20as_element(((struct MappingObject *)__pyx_v_self), __pyx_v_sequence);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_20as_element(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_element", 0);

  /* "axon/_objects.py":515
 *     #
 *     def as_element(self, sequence=None):
 *         return c_new_element(self.name, self.mapping, c_as_list(sequence))             # <<<<<<<<<<<<<<
 *     #
 *     def as_instance(self, sequence=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_v_self->mapping;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 515; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_element(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 515; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":514
 *         raise error("Mapping->Sequence convertion isn't available")
 *     #
 *     def as_element(self, sequence=None):             # <<<<<<<<<<<<<<
 *         return c_new_element(self.name, self.mapping, c_as_list(sequence))
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.Mapping.as_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":517
 *         return c_new_element(self.name, self.mapping, c_as_list(sequence))
 *     #
 *     def as_instance(self, sequence=None):             # <<<<<<<<<<<<<<
 *         return c_new_instance(self.name, c_as_tuple(sequence), self.mapping)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_23as_instance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_23as_instance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sequence = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_instance (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sequence,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "as_instance") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sequence = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("as_instance", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Mapping.as_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_22as_instance(((struct MappingObject *)__pyx_v_self), __pyx_v_sequence);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_22as_instance(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_instance", 0);

  /* "axon/_objects.py":518
 *     #
 *     def as_instance(self, sequence=None):
 *         return c_new_instance(self.name, c_as_tuple(sequence), self.mapping)             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_tuple(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 518; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_v_self->mapping;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_instance(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 518; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":517
 *         return c_new_element(self.name, self.mapping, c_as_list(sequence))
 *     #
 *     def as_instance(self, sequence=None):             # <<<<<<<<<<<<<<
 *         return c_new_instance(self.name, c_as_tuple(sequence), self.mapping)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.Mapping.as_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":263
 * @cython.final
 * cdef public class Mapping[object MappingObject, type MappingType]:
 *     cdef public object name             # <<<<<<<<<<<<<<
 *     cdef public dict mapping
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_4name___get__(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_4name___get__(struct MappingObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Mapping_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_7Mapping_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_4name_2__set__(((struct MappingObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Mapping_4name_2__set__(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Mapping_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_7Mapping_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_4name_4__del__(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Mapping_4name_4__del__(struct MappingObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":264
 * cdef public class Mapping[object MappingObject, type MappingType]:
 *     cdef public object name
 *     cdef public dict mapping             # <<<<<<<<<<<<<<
 *     #
 * #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_7mapping_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Mapping_7mapping_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_7mapping___get__(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Mapping_7mapping___get__(struct MappingObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->mapping);
  __pyx_r = __pyx_v_self->mapping;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Mapping_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_7Mapping_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_7mapping_2__set__(((struct MappingObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Mapping_7mapping_2__set__(struct MappingObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Mapping.mapping.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Mapping_7mapping_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_7Mapping_7mapping_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Mapping_7mapping_4__del__(((struct MappingObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Mapping_7mapping_4__del__(struct MappingObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":543
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_1a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_1a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("a (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_a(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_a(struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("a", 0);

  /* "axon/_objects.py":544
 *     @property
 *     def a(self):
 *         return new_attrs(self.mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def __init__(self, name, mapping, sequence=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->mapping;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_new_attrs(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 544; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":543
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Element.a", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":546
 *         return new_attrs(self.mapping)
 *     #
 *     def __init__(self, name, mapping, sequence=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.mapping = c_as_dict(mapping)
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_mapping = 0;
  PyObject *__pyx_v_sequence = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_mapping,&__pyx_n_s_sequence,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 546; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 546; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_mapping = values[1];
    __pyx_v_sequence = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 546; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Element.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_2__init__(((struct ElementObject *)__pyx_v_self), __pyx_v_name, __pyx_v_mapping, __pyx_v_sequence);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_2__init__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":547
 *     #
 *     def __init__(self, name, mapping, sequence=None):
 *         self.name = c_as_name(name)             # <<<<<<<<<<<<<<
 *         self.mapping = c_as_dict(mapping)
 *         self.sequence = c_as_list(sequence)
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":548
 *     def __init__(self, name, mapping, sequence=None):
 *         self.name = c_as_name(name)
 *         self.mapping = c_as_dict(mapping)             # <<<<<<<<<<<<<<
 *         self.sequence = c_as_list(sequence)
 *     #
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":549
 *         self.name = c_as_name(name)
 *         self.mapping = c_as_dict(mapping)
 *         self.sequence = c_as_list(sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def __getitem__(self, index):
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 549; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":546
 *         return new_attrs(self.mapping)
 *     #
 *     def __init__(self, name, mapping, sequence=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.mapping = c_as_dict(mapping)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Element.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":551
 *         self.sequence = c_as_list(sequence)
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         return self.sequence[index]
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_4__getitem__(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_4__getitem__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "axon/_objects.py":552
 *     #
 *     def __getitem__(self, index):
 *         return self.sequence[index]             # <<<<<<<<<<<<<<
 *     #
 *     def __setitem__(self, index, val):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PyObject_GetItem(__pyx_v_self->sequence, __pyx_v_index); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":551
 *         self.sequence = c_as_list(sequence)
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         return self.sequence[index]
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Element.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":554
 *         return self.sequence[index]
 *     #
 *     def __setitem__(self, index, val):             # <<<<<<<<<<<<<<
 *         self.sequence[index] = val
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_7__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_7__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_6__setitem__(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_val));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_6__setitem__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "axon/_objects.py":555
 *     #
 *     def __setitem__(self, index, val):
 *         self.sequence[index] = val             # <<<<<<<<<<<<<<
 *     #
 *     def __contains__(self, name):
 */
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyObject_SetItem(__pyx_v_self->sequence, __pyx_v_index, __pyx_v_val) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":554
 *         return self.sequence[index]
 *     #
 *     def __setitem__(self, index, val):             # <<<<<<<<<<<<<<
 *         self.sequence[index] = val
 *     #
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Element.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":557
 *         self.sequence[index] = val
 *     #
 *     def __contains__(self, name):             # <<<<<<<<<<<<<<
 *         return name in self.mapping
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_9__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_9__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_8__contains__(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_8__contains__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__contains__", 0);

  /* "axon/_objects.py":558
 *     #
 *     def __contains__(self, name):
 *         return name in self.mapping             # <<<<<<<<<<<<<<
 *     #
 *     def get(self, name, default=None):
 */
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = (__Pyx_PyDict_Contains(__pyx_v_name, __pyx_v_self->mapping, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "axon/_objects.py":557
 *         self.sequence[index] = val
 *     #
 *     def __contains__(self, name):             # <<<<<<<<<<<<<<
 *         return name in self.mapping
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Element.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":560
 *         return name in self.mapping
 *     #
 *     def get(self, name, default=None):             # <<<<<<<<<<<<<<
 *         return self.mapping.get(name, default)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_11get(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_11get(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_default = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_default,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_default = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Element.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_10get(((struct ElementObject *)__pyx_v_self), __pyx_v_name, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_10get(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 0);

  /* "axon/_objects.py":561
 *     #
 *     def get(self, name, default=None):
 *         return self.mapping.get(name, default)             # <<<<<<<<<<<<<<
 *     #
 *     def set(self, name, val):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 561; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->mapping, __pyx_v_name, __pyx_v_default); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 561; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":560
 *         return name in self.mapping
 *     #
 *     def get(self, name, default=None):             # <<<<<<<<<<<<<<
 *         return self.mapping.get(name, default)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Element.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":563
 *         return self.mapping.get(name, default)
 *     #
 *     def set(self, name, val):             # <<<<<<<<<<<<<<
 *         self.mapping[name] = val
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_13set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_13set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_val = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_val,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_val)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 563; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 563; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_name = values[0];
    __pyx_v_val = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 563; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Element.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_12set(((struct ElementObject *)__pyx_v_self), __pyx_v_name, __pyx_v_val);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_12set(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 0);

  /* "axon/_objects.py":564
 *     #
 *     def set(self, name, val):
 *         self.mapping[name] = val             # <<<<<<<<<<<<<<
 *     #
 *     def update(self, map):
 */
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 564; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyDict_SetItem(__pyx_v_self->mapping, __pyx_v_name, __pyx_v_val) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 564; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":563
 *         return self.mapping.get(name, default)
 *     #
 *     def set(self, name, val):             # <<<<<<<<<<<<<<
 *         self.mapping[name] = val
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Element.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":566
 *         self.mapping[name] = val
 *     #
 *     def update(self, map):             # <<<<<<<<<<<<<<
 *         self.mapping.update(map)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_15update(PyObject *__pyx_v_self, PyObject *__pyx_v_map); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_15update(PyObject *__pyx_v_self, PyObject *__pyx_v_map) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("update (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_14update(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_map));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_14update(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_map) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 0);

  /* "axon/_objects.py":567
 *     #
 *     def update(self, map):
 *         self.mapping.update(map)             # <<<<<<<<<<<<<<
 *     #
 *     def append(self, sub):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->mapping, __pyx_n_s_update); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 567; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 567; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_map);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_map);
  __Pyx_GIVEREF(__pyx_v_map);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 567; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":566
 *         self.mapping[name] = val
 *     #
 *     def update(self, map):             # <<<<<<<<<<<<<<
 *         self.mapping.update(map)
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Element.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":569
 *         self.mapping.update(map)
 *     #
 *     def append(self, sub):             # <<<<<<<<<<<<<<
 *         self.sequence.append(sub)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_17append(PyObject *__pyx_v_self, PyObject *__pyx_v_sub); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_17append(PyObject *__pyx_v_self, PyObject *__pyx_v_sub) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_16append(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_sub));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_16append(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_sub) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 0);

  /* "axon/_objects.py":570
 *     #
 *     def append(self, sub):
 *         self.sequence.append(sub)             # <<<<<<<<<<<<<<
 *     #
 *     def extend(self, subs):
 */
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 570; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyList_Append(__pyx_v_self->sequence, __pyx_v_sub); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 570; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":569
 *         self.mapping.update(map)
 *     #
 *     def append(self, sub):             # <<<<<<<<<<<<<<
 *         self.sequence.append(sub)
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Element.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":572
 *         self.sequence.append(sub)
 *     #
 *     def extend(self, subs):             # <<<<<<<<<<<<<<
 *         self.sequence.extend(subs)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_19extend(PyObject *__pyx_v_self, PyObject *__pyx_v_subs); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_19extend(PyObject *__pyx_v_self, PyObject *__pyx_v_subs) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extend (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_18extend(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_subs));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_18extend(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_subs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 0);

  /* "axon/_objects.py":573
 *     #
 *     def extend(self, subs):
 *         self.sequence.extend(subs)             # <<<<<<<<<<<<<<
 *     #
 *     def __repr__(self):
 */
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "extend");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 573; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyList_Extend(__pyx_v_self->sequence, __pyx_v_subs); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 573; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":572
 *         self.sequence.append(sub)
 *     #
 *     def extend(self, subs):             # <<<<<<<<<<<<<<
 *         self.sequence.extend(subs)
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Element.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":575
 *         self.sequence.extend(subs)
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return  'element(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.mapping, self.sequence) if x]) + ')'
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_21__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_21__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_20__repr__(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_20__repr__(struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":576
 *     #
 *     def __repr__(self):
 *         return  'element(' + \             # <<<<<<<<<<<<<<
 *                 ', '.join([repr(x) for x in (self.name, self.mapping, self.sequence) if x]) + ')'
 *     #
 */
  __Pyx_XDECREF(__pyx_r);

  /* "axon/_objects.py":577
 *     def __repr__(self):
 *         return  'element(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.mapping, self.sequence) if x]) + ')'             # <<<<<<<<<<<<<<
 *     #
 * #     def __richcmp__(self, other, op):
 */
  { /* enter inner scope */
    PyObject *__pyx_8genexpr2__pyx_v_x = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_self->name);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->name);
    __Pyx_GIVEREF(__pyx_v_self->name);
    __Pyx_INCREF(__pyx_v_self->mapping);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->mapping);
    __Pyx_GIVEREF(__pyx_v_self->mapping);
    __Pyx_INCREF(__pyx_v_self->sequence);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_self->sequence);
    __Pyx_GIVEREF(__pyx_v_self->sequence);
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_4 >= 3) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      #endif
      __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_x, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_8genexpr2__pyx_v_x); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      if (__pyx_t_5) {
        __pyx_t_2 = PyObject_Repr(__pyx_8genexpr2__pyx_v_x); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L8;
      }
      __pyx_L8:;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_x);
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_x);
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__8, __pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":576
 *     #
 *     def __repr__(self):
 *         return  'element(' + \             # <<<<<<<<<<<<<<
 *                 ', '.join([repr(x) for x in (self.name, self.mapping, self.sequence) if x]) + ')'
 *     #
 */
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_element, __pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":577
 *     def __repr__(self):
 *         return  'element(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.mapping, self.sequence) if x]) + ')'             # <<<<<<<<<<<<<<
 *     #
 * #     def __richcmp__(self, other, op):
 */
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u__7); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":575
 *         self.sequence.extend(subs)
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return  'element(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.mapping, self.sequence) if x]) + ')'
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Element.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":595
 * #                 'Types %r and %r are not comparable at all' % (type(self), type(other)))
 *     #
 *     def as_mapping(self):             # <<<<<<<<<<<<<<
 *         raise error("Element->Mapping convertion isn't available")
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_23as_mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_23as_mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_mapping (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_22as_mapping(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_22as_mapping(CYTHON_UNUSED struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_mapping", 0);

  /* "axon/_objects.py":596
 *     #
 *     def as_mapping(self):
 *         raise error("Element->Mapping convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_sequence(self):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 596; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 596; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 596; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":595
 * #                 'Types %r and %r are not comparable at all' % (type(self), type(other)))
 *     #
 *     def as_mapping(self):             # <<<<<<<<<<<<<<
 *         raise error("Element->Mapping convertion isn't available")
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Element.as_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":598
 *         raise error("Element->Mapping convertion isn't available")
 *     #
 *     def as_sequence(self):             # <<<<<<<<<<<<<<
 *         raise error("Element->Sequence convertion isn't available")
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_25as_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_25as_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_24as_sequence(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_24as_sequence(CYTHON_UNUSED struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_sequence", 0);

  /* "axon/_objects.py":599
 *     #
 *     def as_sequence(self):
 *         raise error("Element->Sequence convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_element(self):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 599; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 599; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 599; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":598
 *         raise error("Element->Mapping convertion isn't available")
 *     #
 *     def as_sequence(self):             # <<<<<<<<<<<<<<
 *         raise error("Element->Sequence convertion isn't available")
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Element.as_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":601
 *         raise error("Element->Sequence convertion isn't available")
 *     #
 *     def as_element(self):             # <<<<<<<<<<<<<<
 *         return self
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_27as_element(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_27as_element(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_element (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_26as_element(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_26as_element(struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_element", 0);

  /* "axon/_objects.py":602
 *     #
 *     def as_element(self):
 *         return self             # <<<<<<<<<<<<<<
 *     #
 *     def as_instance(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "axon/_objects.py":601
 *         raise error("Element->Sequence convertion isn't available")
 *     #
 *     def as_element(self):             # <<<<<<<<<<<<<<
 *         return self
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":604
 *         return self
 *     #
 *     def as_instance(self):             # <<<<<<<<<<<<<<
 *         return c_new_instance(self.name, tuple(self.sequence), self.mapping)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_29as_instance(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_29as_instance(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_instance (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_28as_instance(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_28as_instance(struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_instance", 0);

  /* "axon/_objects.py":605
 *     #
 *     def as_instance(self):
 *         return c_new_instance(self.name, tuple(self.sequence), self.mapping)             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 605; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_2 = PyList_AsTuple(__pyx_v_self->sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 605; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_v_self->mapping;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_instance(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 605; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":604
 *         return self
 *     #
 *     def as_instance(self):             # <<<<<<<<<<<<<<
 *         return c_new_instance(self.name, tuple(self.sequence), self.mapping)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.Element.as_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":273
 * @cython.final
 * cdef public class Element[object ElementObject, type ElementType]:
 *     cdef public object name             # <<<<<<<<<<<<<<
 *     cdef public dict mapping
 *     cdef public list sequence
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_4name___get__(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_4name___get__(struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_4name_2__set__(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_4name_2__set__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_4name_4__del__(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_4name_4__del__(struct ElementObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":274
 * cdef public class Element[object ElementObject, type ElementType]:
 *     cdef public object name
 *     cdef public dict mapping             # <<<<<<<<<<<<<<
 *     cdef public list sequence
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_7mapping_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_7mapping_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_7mapping___get__(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_7mapping___get__(struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->mapping);
  __pyx_r = __pyx_v_self->mapping;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_7mapping_2__set__(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_7mapping_2__set__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Element.mapping.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_7mapping_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_7mapping_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_7mapping_4__del__(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_7mapping_4__del__(struct ElementObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":275
 *     cdef public object name
 *     cdef public dict mapping
 *     cdef public list sequence             # <<<<<<<<<<<<<<
 *     #
 * #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7Element_8sequence_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_7Element_8sequence_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_8sequence___get__(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7Element_8sequence___get__(struct ElementObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __pyx_r = __pyx_v_self->sequence;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_8sequence_2__set__(((struct ElementObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_8sequence_2__set__(struct ElementObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Element.sequence.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_7Element_8sequence_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_7Element_8sequence_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_7Element_8sequence_4__del__(((struct ElementObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_7Element_8sequence_4__del__(struct ElementObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":629
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_1a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_1a(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("a (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_a(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_a(struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("a", 0);

  /* "axon/_objects.py":630
 *     @property
 *     def a(self):
 *         return new_attrs(self.mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def __init__(self, name, sequence=None, mapping=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->mapping;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_new_attrs(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 630; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":629
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Instance.a", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":632
 *         return new_attrs(self.mapping)
 *     #
 *     def __init__(self, name, sequence=None, mapping=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.sequence = c_as_tuple(sequence)
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Instance_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_8Instance_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_mapping = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_sequence,&__pyx_n_s_mapping,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 632; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_sequence = values[1];
    __pyx_v_mapping = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 632; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Instance.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_2__init__(((struct InstanceObject *)__pyx_v_self), __pyx_v_name, __pyx_v_sequence, __pyx_v_mapping);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Instance_2__init__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":633
 *     #
 *     def __init__(self, name, sequence=None, mapping=None):
 *         self.name = c_as_name(name)             # <<<<<<<<<<<<<<
 *         self.sequence = c_as_tuple(sequence)
 *         self.mapping = c_as_dict(mapping)
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 633; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":634
 *     def __init__(self, name, sequence=None, mapping=None):
 *         self.name = c_as_name(name)
 *         self.sequence = c_as_tuple(sequence)             # <<<<<<<<<<<<<<
 *         self.mapping = c_as_dict(mapping)
 *     #
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_tuple(__pyx_v_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":635
 *         self.name = c_as_name(name)
 *         self.sequence = c_as_tuple(sequence)
 *         self.mapping = c_as_dict(mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def __getitem__(self, index):
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":632
 *         return new_attrs(self.mapping)
 *     #
 *     def __init__(self, name, sequence=None, mapping=None):             # <<<<<<<<<<<<<<
 *         self.name = c_as_name(name)
 *         self.sequence = c_as_tuple(sequence)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Instance.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":637
 *         self.mapping = c_as_dict(mapping)
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         return self.sequence[index]
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_4__getitem__(((struct InstanceObject *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_4__getitem__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "axon/_objects.py":638
 *     #
 *     def __getitem__(self, index):
 *         return self.sequence[index]             # <<<<<<<<<<<<<<
 *     #
 *     def __setitem__(self, index, val):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PyObject_GetItem(__pyx_v_self->sequence, __pyx_v_index); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":637
 *         self.mapping = c_as_dict(mapping)
 *     #
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         return self.sequence[index]
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Instance.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":640
 *         return self.sequence[index]
 *     #
 *     def __setitem__(self, index, val):             # <<<<<<<<<<<<<<
 *         self.sequence[index] = val
 *     #
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Instance_7__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val); /*proto*/
static int __pyx_pw_4axon_8_objects_8Instance_7__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_6__setitem__(((struct InstanceObject *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_val));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Instance_6__setitem__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "axon/_objects.py":641
 *     #
 *     def __setitem__(self, index, val):
 *         self.sequence[index] = val             # <<<<<<<<<<<<<<
 *     #
 *     def get(self, name, default=None):
 */
  if (unlikely(__pyx_v_self->sequence == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyObject_SetItem(__pyx_v_self->sequence, __pyx_v_index, __pyx_v_val) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":640
 *         return self.sequence[index]
 *     #
 *     def __setitem__(self, index, val):             # <<<<<<<<<<<<<<
 *         self.sequence[index] = val
 *     #
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Instance.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":643
 *         self.sequence[index] = val
 *     #
 *     def get(self, name, default=None):             # <<<<<<<<<<<<<<
 *         return self.mapping.get(name, default)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_9get(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_9get(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_default = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_default,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 643; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_default = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 643; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Instance.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_8get(((struct InstanceObject *)__pyx_v_self), __pyx_v_name, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_8get(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 0);

  /* "axon/_objects.py":644
 *     #
 *     def get(self, name, default=None):
 *         return self.mapping.get(name, default)             # <<<<<<<<<<<<<<
 *     #
 *     def set(self, name, val):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 644; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->mapping, __pyx_v_name, __pyx_v_default); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 644; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":643
 *         self.sequence[index] = val
 *     #
 *     def get(self, name, default=None):             # <<<<<<<<<<<<<<
 *         return self.mapping.get(name, default)
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Instance.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":646
 *         return self.mapping.get(name, default)
 *     #
 *     def set(self, name, val):             # <<<<<<<<<<<<<<
 *         self.mapping[name] = val
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_11set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_11set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_val = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_val,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_val)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 646; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 646; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_name = values[0];
    __pyx_v_val = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 646; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.Instance.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_10set(((struct InstanceObject *)__pyx_v_self), __pyx_v_name, __pyx_v_val);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_10set(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 0);

  /* "axon/_objects.py":647
 *     #
 *     def set(self, name, val):
 *         self.mapping[name] = val             # <<<<<<<<<<<<<<
 *     #
 *     def update(self, map):
 */
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 647; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyDict_SetItem(__pyx_v_self->mapping, __pyx_v_name, __pyx_v_val) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 647; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":646
 *         return self.mapping.get(name, default)
 *     #
 *     def set(self, name, val):             # <<<<<<<<<<<<<<
 *         self.mapping[name] = val
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.Instance.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":649
 *         self.mapping[name] = val
 *     #
 *     def update(self, map):             # <<<<<<<<<<<<<<
 *         self.mapping.update(map)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_13update(PyObject *__pyx_v_self, PyObject *__pyx_v_map); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_13update(PyObject *__pyx_v_self, PyObject *__pyx_v_map) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("update (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_12update(((struct InstanceObject *)__pyx_v_self), ((PyObject *)__pyx_v_map));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_12update(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_map) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 0);

  /* "axon/_objects.py":650
 *     #
 *     def update(self, map):
 *         self.mapping.update(map)             # <<<<<<<<<<<<<<
 *     #
 *     def append(self, sub):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->mapping, __pyx_n_s_update); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_map);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_map);
  __Pyx_GIVEREF(__pyx_v_map);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":649
 *         self.mapping[name] = val
 *     #
 *     def update(self, map):             # <<<<<<<<<<<<<<
 *         self.mapping.update(map)
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Instance.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":652
 *         self.mapping.update(map)
 *     #
 *     def append(self, sub):             # <<<<<<<<<<<<<<
 *         self.sequence.append(sub)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_15append(PyObject *__pyx_v_self, PyObject *__pyx_v_sub); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_15append(PyObject *__pyx_v_self, PyObject *__pyx_v_sub) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_14append(((struct InstanceObject *)__pyx_v_self), ((PyObject *)__pyx_v_sub));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_14append(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_sub) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 0);

  /* "axon/_objects.py":653
 *     #
 *     def append(self, sub):
 *         self.sequence.append(sub)             # <<<<<<<<<<<<<<
 *     #
 *     def extend(self, subs):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sequence, __pyx_n_s_append); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 653; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 653; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_sub);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_sub);
  __Pyx_GIVEREF(__pyx_v_sub);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 653; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":652
 *         self.mapping.update(map)
 *     #
 *     def append(self, sub):             # <<<<<<<<<<<<<<
 *         self.sequence.append(sub)
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Instance.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":655
 *         self.sequence.append(sub)
 *     #
 *     def extend(self, subs):             # <<<<<<<<<<<<<<
 *         self.sequence.extend(subs)
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_17extend(PyObject *__pyx_v_self, PyObject *__pyx_v_subs); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_17extend(PyObject *__pyx_v_self, PyObject *__pyx_v_subs) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extend (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_16extend(((struct InstanceObject *)__pyx_v_self), ((PyObject *)__pyx_v_subs));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_16extend(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_subs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 0);

  /* "axon/_objects.py":656
 *     #
 *     def extend(self, subs):
 *         self.sequence.extend(subs)             # <<<<<<<<<<<<<<
 *     #
 *     def __repr__(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sequence, __pyx_n_s_extend); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 656; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 656; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_subs);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_subs);
  __Pyx_GIVEREF(__pyx_v_subs);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 656; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":655
 *         self.sequence.append(sub)
 *     #
 *     def extend(self, subs):             # <<<<<<<<<<<<<<
 *         self.sequence.extend(subs)
 *     #
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Instance.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":658
 *         self.sequence.extend(subs)
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return  'instance(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.sequence, self.mapping) if x]) + ')'
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_19__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_19__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_18__repr__(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_18__repr__(struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":659
 *     #
 *     def __repr__(self):
 *         return  'instance(' + \             # <<<<<<<<<<<<<<
 *                 ', '.join([repr(x) for x in (self.name, self.sequence, self.mapping) if x]) + ')'
 *     #
 */
  __Pyx_XDECREF(__pyx_r);

  /* "axon/_objects.py":660
 *     def __repr__(self):
 *         return  'instance(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.sequence, self.mapping) if x]) + ')'             # <<<<<<<<<<<<<<
 *     #
 * #     def __richcmp__(self, other, op):
 */
  { /* enter inner scope */
    PyObject *__pyx_8genexpr3__pyx_v_x = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_self->name);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->name);
    __Pyx_GIVEREF(__pyx_v_self->name);
    __Pyx_INCREF(__pyx_v_self->sequence);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->sequence);
    __Pyx_GIVEREF(__pyx_v_self->sequence);
    __Pyx_INCREF(__pyx_v_self->mapping);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_self->mapping);
    __Pyx_GIVEREF(__pyx_v_self->mapping);
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_4 >= 3) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      #endif
      __Pyx_XDECREF_SET(__pyx_8genexpr3__pyx_v_x, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_8genexpr3__pyx_v_x); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
      if (__pyx_t_5) {
        __pyx_t_2 = PyObject_Repr(__pyx_8genexpr3__pyx_v_x); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L8;
      }
      __pyx_L8:;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_x);
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_x);
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__8, __pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":659
 *     #
 *     def __repr__(self):
 *         return  'instance(' + \             # <<<<<<<<<<<<<<
 *                 ', '.join([repr(x) for x in (self.name, self.sequence, self.mapping) if x]) + ')'
 *     #
 */
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_instance, __pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 659; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.py":660
 *     def __repr__(self):
 *         return  'instance(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.sequence, self.mapping) if x]) + ')'             # <<<<<<<<<<<<<<
 *     #
 * #     def __richcmp__(self, other, op):
 */
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u__7); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":658
 *         self.sequence.extend(subs)
 *     #
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return  'instance(' + \
 *                 ', '.join([repr(x) for x in (self.name, self.sequence, self.mapping) if x]) + ')'
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.Instance.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":680
 * #                 'Types %r and %r are not comparable at all' % (type(self), type(other)))
 *     #
 *     def as_mapping(self):             # <<<<<<<<<<<<<<
 *         raise error("Instance->Mapping convertion isn't available")
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_21as_mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_21as_mapping(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_mapping (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_20as_mapping(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_20as_mapping(CYTHON_UNUSED struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_mapping", 0);

  /* "axon/_objects.py":681
 *     #
 *     def as_mapping(self):
 *         raise error("Instance->Mapping convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_sequence(self):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":680
 * #                 'Types %r and %r are not comparable at all' % (type(self), type(other)))
 *     #
 *     def as_mapping(self):             # <<<<<<<<<<<<<<
 *         raise error("Instance->Mapping convertion isn't available")
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Instance.as_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":683
 *         raise error("Instance->Mapping convertion isn't available")
 *     #
 *     def as_sequence(self):             # <<<<<<<<<<<<<<
 *         raise error("Instance->Sequence convertion isn't available")
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_23as_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_23as_sequence(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_22as_sequence(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_22as_sequence(CYTHON_UNUSED struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_sequence", 0);

  /* "axon/_objects.py":684
 *     #
 *     def as_sequence(self):
 *         raise error("Instance->Sequence convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_element(self):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_error); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  {__pyx_filename = __pyx_f[1]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":683
 *         raise error("Instance->Mapping convertion isn't available")
 *     #
 *     def as_sequence(self):             # <<<<<<<<<<<<<<
 *         raise error("Instance->Sequence convertion isn't available")
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.Instance.as_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":686
 *         raise error("Instance->Sequence convertion isn't available")
 *     #
 *     def as_element(self):             # <<<<<<<<<<<<<<
 *         return c_new_element(self.name, self.mapping, list(self.sequence))
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_25as_element(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_25as_element(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_element (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_24as_element(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_24as_element(struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_element", 0);

  /* "axon/_objects.py":687
 *     #
 *     def as_element(self):
 *         return c_new_element(self.name, self.mapping, list(self.sequence))             # <<<<<<<<<<<<<<
 *     #
 *     def as_instance(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_v_self->mapping;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->sequence);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->sequence);
  __Pyx_GIVEREF(__pyx_v_self->sequence);
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyList_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_new_element(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_4)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":686
 *         raise error("Instance->Sequence convertion isn't available")
 *     #
 *     def as_element(self):             # <<<<<<<<<<<<<<
 *         return c_new_element(self.name, self.mapping, list(self.sequence))
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.Instance.as_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":689
 *         return c_new_element(self.name, self.mapping, list(self.sequence))
 *     #
 *     def as_instance(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_27as_instance(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_27as_instance(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_instance (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_26as_instance(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_26as_instance(struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_instance", 0);

  /* "axon/_objects.py":690
 *     #
 *     def as_instance(self):
 *         return self             # <<<<<<<<<<<<<<
 * 
 * ####################################################################
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "axon/_objects.py":689
 *         return c_new_element(self.name, self.mapping, list(self.sequence))
 *     #
 *     def as_instance(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":283
 * @cython.final
 * cdef public class Instance[object InstanceObject, type InstanceType]:
 *     cdef public object name             # <<<<<<<<<<<<<<
 *     cdef public tuple sequence
 *     cdef public dict mapping
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_4name___get__(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_4name___get__(struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Instance_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_8Instance_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_4name_2__set__(((struct InstanceObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Instance_4name_2__set__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Instance_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_8Instance_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_4name_4__del__(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Instance_4name_4__del__(struct InstanceObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":284
 * cdef public class Instance[object InstanceObject, type InstanceType]:
 *     cdef public object name
 *     cdef public tuple sequence             # <<<<<<<<<<<<<<
 *     cdef public dict mapping
 *     #
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_8sequence_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_8sequence_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_8sequence___get__(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_8sequence___get__(struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sequence);
  __pyx_r = __pyx_v_self->sequence;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Instance_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_8Instance_8sequence_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_8sequence_2__set__(((struct InstanceObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Instance_8sequence_2__set__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyTuple_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Instance.sequence.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Instance_8sequence_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_8Instance_8sequence_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_8sequence_4__del__(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Instance_8sequence_4__del__(struct InstanceObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sequence);
  __Pyx_DECREF(__pyx_v_self->sequence);
  __pyx_v_self->sequence = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":285
 *     cdef public object name
 *     cdef public tuple sequence
 *     cdef public dict mapping             # <<<<<<<<<<<<<<
 *     #
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8Instance_7mapping_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8Instance_7mapping_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_7mapping___get__(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8Instance_7mapping___get__(struct InstanceObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->mapping);
  __pyx_r = __pyx_v_self->mapping;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Instance_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_8Instance_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_7mapping_2__set__(((struct InstanceObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Instance_7mapping_2__set__(struct InstanceObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.Instance.mapping.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8Instance_7mapping_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_8Instance_7mapping_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8Instance_7mapping_4__del__(((struct InstanceObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8Instance_7mapping_4__del__(struct InstanceObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":694
 * ####################################################################
 * 
 * def c_new_sequence(name, sequence):             # <<<<<<<<<<<<<<
 *     s = Sequence.__new__(Sequence)
 *     s.name = name
 */

PyObject *__pyx_f_4axon_8_objects_c_new_sequence(PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  struct SequenceObject *__pyx_v_s = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_sequence", 0);

  /* "axon/_objects.py":695
 * 
 * def c_new_sequence(name, sequence):
 *     s = Sequence.__new__(Sequence)             # <<<<<<<<<<<<<<
 *     s.name = name
 *     s.sequence = sequence
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Sequence(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Sequence)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 695; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Sequence)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 695; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_s = ((struct SequenceObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":696
 * def c_new_sequence(name, sequence):
 *     s = Sequence.__new__(Sequence)
 *     s.name = name             # <<<<<<<<<<<<<<
 *     s.sequence = sequence
 *     return s
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_s->name);
  __Pyx_DECREF(__pyx_v_s->name);
  __pyx_v_s->name = __pyx_v_name;

  /* "axon/_objects.py":697
 *     s = Sequence.__new__(Sequence)
 *     s.name = name
 *     s.sequence = sequence             # <<<<<<<<<<<<<<
 *     return s
 * 
 */
  __Pyx_INCREF(__pyx_v_sequence);
  __Pyx_GIVEREF(__pyx_v_sequence);
  __Pyx_GOTREF(__pyx_v_s->sequence);
  __Pyx_DECREF(__pyx_v_s->sequence);
  __pyx_v_s->sequence = __pyx_v_sequence;

  /* "axon/_objects.py":698
 *     s.name = name
 *     s.sequence = sequence
 *     return s             # <<<<<<<<<<<<<<
 * 
 * def c_new_mapping(name, mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_s));
  __pyx_r = ((PyObject *)__pyx_v_s);
  goto __pyx_L0;

  /* "axon/_objects.py":694
 * ####################################################################
 * 
 * def c_new_sequence(name, sequence):             # <<<<<<<<<<<<<<
 *     s = Sequence.__new__(Sequence)
 *     s.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_new_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":700
 *     return s
 * 
 * def c_new_mapping(name, mapping):             # <<<<<<<<<<<<<<
 *     o = Mapping.__new__(Mapping)
 *     o.name = name
 */

PyObject *__pyx_f_4axon_8_objects_c_new_mapping(PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  struct MappingObject *__pyx_v_o = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_mapping", 0);

  /* "axon/_objects.py":701
 * 
 * def c_new_mapping(name, mapping):
 *     o = Mapping.__new__(Mapping)             # <<<<<<<<<<<<<<
 *     o.name = name
 *     o.mapping = mapping
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Mapping(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Mapping)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 701; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Mapping)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 701; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_o = ((struct MappingObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":702
 * def c_new_mapping(name, mapping):
 *     o = Mapping.__new__(Mapping)
 *     o.name = name             # <<<<<<<<<<<<<<
 *     o.mapping = mapping
 *     return o
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_o->name);
  __Pyx_DECREF(__pyx_v_o->name);
  __pyx_v_o->name = __pyx_v_name;

  /* "axon/_objects.py":703
 *     o = Mapping.__new__(Mapping)
 *     o.name = name
 *     o.mapping = mapping             # <<<<<<<<<<<<<<
 *     return o
 * #
 */
  __Pyx_INCREF(__pyx_v_mapping);
  __Pyx_GIVEREF(__pyx_v_mapping);
  __Pyx_GOTREF(__pyx_v_o->mapping);
  __Pyx_DECREF(__pyx_v_o->mapping);
  __pyx_v_o->mapping = __pyx_v_mapping;

  /* "axon/_objects.py":704
 *     o.name = name
 *     o.mapping = mapping
 *     return o             # <<<<<<<<<<<<<<
 * #
 * def c_new_element(name, mapping, sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_o));
  __pyx_r = ((PyObject *)__pyx_v_o);
  goto __pyx_L0;

  /* "axon/_objects.py":700
 *     return s
 * 
 * def c_new_mapping(name, mapping):             # <<<<<<<<<<<<<<
 *     o = Mapping.__new__(Mapping)
 *     o.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_new_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_o);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":706
 *     return o
 * #
 * def c_new_element(name, mapping, sequence):             # <<<<<<<<<<<<<<
 *     e = Element.__new__(Element)
 *     e.name = name
 */

PyObject *__pyx_f_4axon_8_objects_c_new_element(PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  struct ElementObject *__pyx_v_e = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_element", 0);

  /* "axon/_objects.py":707
 * #
 * def c_new_element(name, mapping, sequence):
 *     e = Element.__new__(Element)             # <<<<<<<<<<<<<<
 *     e.name = name
 *     e.mapping = mapping
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Element(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Element)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 707; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Element)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 707; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_e = ((struct ElementObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":708
 * def c_new_element(name, mapping, sequence):
 *     e = Element.__new__(Element)
 *     e.name = name             # <<<<<<<<<<<<<<
 *     e.mapping = mapping
 *     e.sequence = sequence
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_e->name);
  __Pyx_DECREF(__pyx_v_e->name);
  __pyx_v_e->name = __pyx_v_name;

  /* "axon/_objects.py":709
 *     e = Element.__new__(Element)
 *     e.name = name
 *     e.mapping = mapping             # <<<<<<<<<<<<<<
 *     e.sequence = sequence
 *     return e
 */
  __Pyx_INCREF(__pyx_v_mapping);
  __Pyx_GIVEREF(__pyx_v_mapping);
  __Pyx_GOTREF(__pyx_v_e->mapping);
  __Pyx_DECREF(__pyx_v_e->mapping);
  __pyx_v_e->mapping = __pyx_v_mapping;

  /* "axon/_objects.py":710
 *     e.name = name
 *     e.mapping = mapping
 *     e.sequence = sequence             # <<<<<<<<<<<<<<
 *     return e
 * #
 */
  __Pyx_INCREF(__pyx_v_sequence);
  __Pyx_GIVEREF(__pyx_v_sequence);
  __Pyx_GOTREF(__pyx_v_e->sequence);
  __Pyx_DECREF(__pyx_v_e->sequence);
  __pyx_v_e->sequence = __pyx_v_sequence;

  /* "axon/_objects.py":711
 *     e.mapping = mapping
 *     e.sequence = sequence
 *     return e             # <<<<<<<<<<<<<<
 * #
 * def c_new_instance(name, args, mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_e));
  __pyx_r = ((PyObject *)__pyx_v_e);
  goto __pyx_L0;

  /* "axon/_objects.py":706
 *     return o
 * #
 * def c_new_element(name, mapping, sequence):             # <<<<<<<<<<<<<<
 *     e = Element.__new__(Element)
 *     e.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_new_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":713
 *     return e
 * #
 * def c_new_instance(name, args, mapping):             # <<<<<<<<<<<<<<
 *     e = Instance.__new__(Instance)
 *     e.name = name
 */

PyObject *__pyx_f_4axon_8_objects_c_new_instance(PyObject *__pyx_v_name, PyObject *__pyx_v_args, PyObject *__pyx_v_mapping) {
  struct InstanceObject *__pyx_v_e = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_instance", 0);

  /* "axon/_objects.py":714
 * #
 * def c_new_instance(name, args, mapping):
 *     e = Instance.__new__(Instance)             # <<<<<<<<<<<<<<
 *     e.name = name
 *     e.sequence = args
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Instance(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Instance)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 714; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Instance)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 714; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_e = ((struct InstanceObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":715
 * def c_new_instance(name, args, mapping):
 *     e = Instance.__new__(Instance)
 *     e.name = name             # <<<<<<<<<<<<<<
 *     e.sequence = args
 *     e.mapping = mapping
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_e->name);
  __Pyx_DECREF(__pyx_v_e->name);
  __pyx_v_e->name = __pyx_v_name;

  /* "axon/_objects.py":716
 *     e = Instance.__new__(Instance)
 *     e.name = name
 *     e.sequence = args             # <<<<<<<<<<<<<<
 *     e.mapping = mapping
 *     return e
 */
  __Pyx_INCREF(__pyx_v_args);
  __Pyx_GIVEREF(__pyx_v_args);
  __Pyx_GOTREF(__pyx_v_e->sequence);
  __Pyx_DECREF(__pyx_v_e->sequence);
  __pyx_v_e->sequence = __pyx_v_args;

  /* "axon/_objects.py":717
 *     e.name = name
 *     e.sequence = args
 *     e.mapping = mapping             # <<<<<<<<<<<<<<
 *     return e
 * 
 */
  __Pyx_INCREF(__pyx_v_mapping);
  __Pyx_GIVEREF(__pyx_v_mapping);
  __Pyx_GOTREF(__pyx_v_e->mapping);
  __Pyx_DECREF(__pyx_v_e->mapping);
  __pyx_v_e->mapping = __pyx_v_mapping;

  /* "axon/_objects.py":718
 *     e.sequence = args
 *     e.mapping = mapping
 *     return e             # <<<<<<<<<<<<<<
 * 
 * def c_new_empty(name):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_e));
  __pyx_r = ((PyObject *)__pyx_v_e);
  goto __pyx_L0;

  /* "axon/_objects.py":713
 *     return e
 * #
 * def c_new_instance(name, args, mapping):             # <<<<<<<<<<<<<<
 *     e = Instance.__new__(Instance)
 *     e.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_new_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":720
 *     return e
 * 
 * def c_new_empty(name):             # <<<<<<<<<<<<<<
 *     e = Empty.__new__(Empty)
 *     e.name = name
 */

PyObject *__pyx_f_4axon_8_objects_c_new_empty(PyObject *__pyx_v_name) {
  struct EmptyObject *__pyx_v_e = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_empty", 0);

  /* "axon/_objects.py":721
 * 
 * def c_new_empty(name):
 *     e = Empty.__new__(Empty)             # <<<<<<<<<<<<<<
 *     e.name = name
 *     return e
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Empty(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Empty)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Empty)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_e = ((struct EmptyObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":722
 * def c_new_empty(name):
 *     e = Empty.__new__(Empty)
 *     e.name = name             # <<<<<<<<<<<<<<
 *     return e
 * 
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_e->name);
  __Pyx_DECREF(__pyx_v_e->name);
  __pyx_v_e->name = __pyx_v_name;

  /* "axon/_objects.py":723
 *     e = Empty.__new__(Empty)
 *     e.name = name
 *     return e             # <<<<<<<<<<<<<<
 * 
 * #####################################################################################
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_e));
  __pyx_r = ((PyObject *)__pyx_v_e);
  goto __pyx_L0;

  /* "axon/_objects.py":720
 *     return e
 * 
 * def c_new_empty(name):             # <<<<<<<<<<<<<<
 *     e = Empty.__new__(Empty)
 *     e.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_new_empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":729
 * #NAME_IS_EMPTY = 'Name is empty'
 * 
 * def sequence(name, sequence=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named sequence.
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_25sequence(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4axon_8_objects_24sequence[] = "\n    Factory function for creating named sequence.\n\n    :param name:\n\n        name of sequence.\n\n    :param sequence:\n\n        python sequence containing values.\n    ";
static PyMethodDef __pyx_mdef_4axon_8_objects_25sequence = {__Pyx_NAMESTR("sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_25sequence, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_4axon_8_objects_24sequence)};
static PyObject *__pyx_pw_4axon_8_objects_25sequence(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sequence = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_sequence,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "sequence") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 729; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_sequence = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sequence", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 729; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_24sequence(__pyx_self, __pyx_v_name, __pyx_v_sequence);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_24sequence(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sequence", 0);

  /* "axon/_objects.py":741
 *         python sequence containing values.
 *     '''
 *     return c_new_sequence(c_as_name(name), c_as_list(sequence))             # <<<<<<<<<<<<<<
 * #
 * def mapping(name, mapping=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 741; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 741; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_new_sequence(__pyx_t_1, ((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 741; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":729
 * #NAME_IS_EMPTY = 'Name is empty'
 * 
 * def sequence(name, sequence=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named sequence.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":743
 *     return c_new_sequence(c_as_name(name), c_as_list(sequence))
 * #
 * def mapping(name, mapping=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named mapping.
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_27mapping(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4axon_8_objects_26mapping[] = "\n    Factory function for creating named mapping.\n\n    :param name:\n\n        name of sequence.\n\n    :param mapping:\n\n        python dictionary containing pairs of `name`/`value`.\n    ";
static PyMethodDef __pyx_mdef_4axon_8_objects_27mapping = {__Pyx_NAMESTR("mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_27mapping, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_4axon_8_objects_26mapping)};
static PyObject *__pyx_pw_4axon_8_objects_27mapping(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_mapping = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mapping (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_mapping,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "mapping") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_mapping = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mapping", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_26mapping(__pyx_self, __pyx_v_name, __pyx_v_mapping);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_26mapping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mapping", 0);

  /* "axon/_objects.py":755
 *         python dictionary containing pairs of `name`/`value`.
 *     '''
 *     return c_new_mapping(c_as_name(name), c_as_dict(mapping))             # <<<<<<<<<<<<<<
 * #
 * def element(name, mapping, sequence=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_new_mapping(__pyx_t_1, ((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":743
 *     return c_new_sequence(c_as_name(name), c_as_list(sequence))
 * #
 * def mapping(name, mapping=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named mapping.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":757
 *     return c_new_mapping(c_as_name(name), c_as_dict(mapping))
 * #
 * def element(name, mapping, sequence=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named element.
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_29element(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4axon_8_objects_28element[] = "\n    Factory function for creating named element.\n\n    :param name:\n\n        name of element.\n\n    :param mapping:\n\n        python dictionary containing pairs of `name: value`.\n\n    :param sequence:\n\n        python sequence containing child values.\n    ";
static PyMethodDef __pyx_mdef_4axon_8_objects_29element = {__Pyx_NAMESTR("element"), (PyCFunction)__pyx_pw_4axon_8_objects_29element, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_4axon_8_objects_28element)};
static PyObject *__pyx_pw_4axon_8_objects_29element(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_mapping = 0;
  PyObject *__pyx_v_sequence = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("element (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_mapping,&__pyx_n_s_sequence,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("element", 0, 2, 3, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "element") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_mapping = values[1];
    __pyx_v_sequence = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("element", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_28element(__pyx_self, __pyx_v_name, __pyx_v_mapping, __pyx_v_sequence);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_28element(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("element", 0);

  /* "axon/_objects.py":773
 *         python sequence containing child values.
 *     '''
 *     return c_new_element(c_as_name(name), c_as_dict(mapping), c_as_list(sequence))             # <<<<<<<<<<<<<<
 * #
 * def instance(name, sequence, mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 773; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 773; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 773; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_element(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 773; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":757
 *     return c_new_mapping(c_as_name(name), c_as_dict(mapping))
 * #
 * def element(name, mapping, sequence=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named element.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":775
 *     return c_new_element(c_as_name(name), c_as_dict(mapping), c_as_list(sequence))
 * #
 * def instance(name, sequence, mapping):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named instance.
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_31instance(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_4axon_8_objects_30instance[] = "\n    Factory function for creating named instance.\n\n    :param name:\n\n        name of object.\n\n    :param sequence:\n\n        python sequence containing required values.\n\n    :param mapping:\n\n        python dictionary containing optional values in form of of `name`: `value` pairs.\n\n    ";
static PyMethodDef __pyx_mdef_4axon_8_objects_31instance = {__Pyx_NAMESTR("instance"), (PyCFunction)__pyx_pw_4axon_8_objects_31instance, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_4axon_8_objects_30instance)};
static PyObject *__pyx_pw_4axon_8_objects_31instance(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_sequence = 0;
  PyObject *__pyx_v_mapping = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("instance (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_sequence,&__pyx_n_s_mapping,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sequence)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("instance", 1, 3, 3, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mapping)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("instance", 1, 3, 3, 2); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "instance") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_name = values[0];
    __pyx_v_sequence = values[1];
    __pyx_v_mapping = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("instance", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_30instance(__pyx_self, __pyx_v_name, __pyx_v_sequence, __pyx_v_mapping);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_30instance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("instance", 0);

  /* "axon/_objects.py":792
 * 
 *     '''
 *     return c_new_instance(c_as_name(name), c_as_tuple(sequence), c_as_dict(mapping))             # <<<<<<<<<<<<<<
 * #
 * def empty(name):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_tuple(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_4axon_8_objects_c_new_instance(__pyx_t_1, ((PyObject*)__pyx_t_2), ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 792; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":775
 *     return c_new_element(c_as_name(name), c_as_dict(mapping), c_as_list(sequence))
 * #
 * def instance(name, sequence, mapping):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named instance.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":794
 *     return c_new_instance(c_as_name(name), c_as_tuple(sequence), c_as_dict(mapping))
 * #
 * def empty(name):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating empty complex value.
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_33empty(PyObject *__pyx_self, PyObject *__pyx_v_name); /*proto*/
static char __pyx_doc_4axon_8_objects_32empty[] = "\n    Factory function for creating empty complex value.\n\n    :param name:\n\n        name of empty complex value.\n    ";
static PyMethodDef __pyx_mdef_4axon_8_objects_33empty = {__Pyx_NAMESTR("empty"), (PyCFunction)__pyx_pw_4axon_8_objects_33empty, METH_O, __Pyx_DOCSTR(__pyx_doc_4axon_8_objects_32empty)};
static PyObject *__pyx_pw_4axon_8_objects_33empty(PyObject *__pyx_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("empty (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_32empty(__pyx_self, ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_32empty(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty", 0);

  /* "axon/_objects.py":802
 *         name of empty complex value.
 *     '''
 *     return c_new_empty(c_as_name(name))             # <<<<<<<<<<<<<<
 * #
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_name(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_new_empty(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":794
 *     return c_new_instance(c_as_name(name), c_as_tuple(sequence), c_as_dict(mapping))
 * #
 * def empty(name):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating empty complex value.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":807
 * c_factory_dict = {}
 * 
 * def reset_factory():             # <<<<<<<<<<<<<<
 *     c_factory_dict = {}
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_35reset_factory(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_35reset_factory = {__Pyx_NAMESTR("reset_factory"), (PyCFunction)__pyx_pw_4axon_8_objects_35reset_factory, METH_NOARGS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_35reset_factory(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset_factory (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_34reset_factory(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_34reset_factory(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED PyObject *__pyx_v_c_factory_dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reset_factory", 0);

  /* "axon/_objects.py":808
 * 
 * def reset_factory():
 *     c_factory_dict = {}             # <<<<<<<<<<<<<<
 * 
 * def factory(name, factory_func=None):
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 808; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_c_factory_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":807
 * c_factory_dict = {}
 * 
 * def reset_factory():             # <<<<<<<<<<<<<<
 *     c_factory_dict = {}
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.reset_factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_c_factory_dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":810
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_37factory(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_37factory = {__Pyx_NAMESTR("factory"), (PyCFunction)__pyx_pw_4axon_8_objects_37factory, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_37factory(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_factory_func = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factory (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_factory_func,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_factory_func);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "factory") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_factory_func = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factory", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_36factory(__pyx_self, __pyx_v_name, __pyx_v_factory_func);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":813
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 *         def _factory(factory_func, name=name):             # <<<<<<<<<<<<<<
 *             c_factory_dict[name] = factory_func
 *             return factory_func
 */

static PyObject *__pyx_pf_4axon_8_objects_7factory_2__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_name);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_name);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_name);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.factory.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_7factory_1_factory(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_7factory_1_factory = {__Pyx_NAMESTR("_factory"), (PyCFunction)__pyx_pw_4axon_8_objects_7factory_1_factory, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_7factory_1_factory(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_factory_func = 0;
  PyObject *__pyx_v_name = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_factory (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_factory_func,&__pyx_n_s_name,0};
    PyObject* values[2] = {0,0};
    __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self);
    values[1] = __pyx_dynamic_args->__pyx_arg_name;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_factory_func)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_factory") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_factory_func = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_factory", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.factory._factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_7factory__factory(__pyx_self, __pyx_v_factory_func, __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_7factory__factory(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_factory_func, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_factory", 0);

  /* "axon/_objects.py":814
 *     if factory_func is None:
 *         def _factory(factory_func, name=name):
 *             c_factory_dict[name] = factory_func             # <<<<<<<<<<<<<<
 *             return factory_func
 *         return _factory
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyDict_SetItem(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, __pyx_v_factory_func) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":815
 *         def _factory(factory_func, name=name):
 *             c_factory_dict[name] = factory_func
 *             return factory_func             # <<<<<<<<<<<<<<
 *         return _factory
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_factory_func);
  __pyx_r = __pyx_v_factory_func;
  goto __pyx_L0;

  /* "axon/_objects.py":813
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 *         def _factory(factory_func, name=name):             # <<<<<<<<<<<<<<
 *             c_factory_dict[name] = factory_func
 *             return factory_func
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.factory._factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":810
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */

static PyObject *__pyx_pf_4axon_8_objects_36factory(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_factory_func) {
  PyObject *__pyx_v__factory = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factory", 0);
  __Pyx_INCREF(__pyx_v_name);

  /* "axon/_objects.py":811
 * 
 * def factory(name, factory_func=None):
 *     name = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *     if factory_func is None:
 *         def _factory(factory_func, name=name):
 */
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":812
 * def factory(name, factory_func=None):
 *     name = c_as_unicode(name)
 *     if factory_func is None:             # <<<<<<<<<<<<<<
 *         def _factory(factory_func, name=name):
 *             c_factory_dict[name] = factory_func
 */
  __pyx_t_2 = (__pyx_v_factory_func == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":813
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 *         def _factory(factory_func, name=name):             # <<<<<<<<<<<<<<
 *             c_factory_dict[name] = factory_func
 *             return factory_func
 */
    __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_7factory_1_factory, 0, __pyx_n_s_factory_locals__factory, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__16)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults), 1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_INCREF(__pyx_v_name);
    __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_t_1)->__pyx_arg_name = __pyx_v_name;
    __Pyx_GIVEREF(__pyx_v_name);
    __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_4axon_8_objects_7factory_2__defaults__);
    __pyx_v__factory = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.py":816
 *             c_factory_dict[name] = factory_func
 *             return factory_func
 *         return _factory             # <<<<<<<<<<<<<<
 *     else:
 *         c_factory_dict[name] = factory_func
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v__factory);
    __pyx_r = __pyx_v__factory;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":818
 *         return _factory
 *     else:
 *         c_factory_dict[name] = factory_func             # <<<<<<<<<<<<<<
 * 
 * class Builder:
 */
    if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 818; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, __pyx_v_factory_func) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 818; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_objects.py":810
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__factory);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":821
 * 
 * class Builder:
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

PyObject *__pyx_f_4axon_8_objects_7Builder_create_sequence(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_Builder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_sequence", 0);

  /* "axon/_objects.py":822
 * class Builder:
 *     def create_sequence(self, name, sequence):
 *         return None             # <<<<<<<<<<<<<<
 *     #
 *     def create_mapping(self, name, mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":821
 * 
 * class Builder:
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":824
 *         return None
 *     #
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

PyObject *__pyx_f_4axon_8_objects_7Builder_create_mapping(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_Builder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_mapping", 0);

  /* "axon/_objects.py":825
 *     #
 *     def create_mapping(self, name, mapping):
 *         return None             # <<<<<<<<<<<<<<
 *     #
 *     def create_element(self, name, mapping, sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":824
 *         return None
 *     #
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":827
 *         return None
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

PyObject *__pyx_f_4axon_8_objects_7Builder_create_element(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_Builder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_mapping, CYTHON_UNUSED PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_element", 0);

  /* "axon/_objects.py":828
 *     #
 *     def create_element(self, name, mapping, sequence):
 *         return None             # <<<<<<<<<<<<<<
 *     #
 *     def create_instance(self, name, args, mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":827
 *         return None
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":830
 *         return None
 *     #
 *     def create_instance(self, name, args, mapping):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

PyObject *__pyx_f_4axon_8_objects_7Builder_create_instance(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_Builder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_instance", 0);

  /* "axon/_objects.py":831
 *     #
 *     def create_instance(self, name, args, mapping):
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def create_empty(self, name):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":830
 *         return None
 *     #
 *     def create_instance(self, name, args, mapping):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":833
 *         return None
 * 
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

PyObject *__pyx_f_4axon_8_objects_7Builder_create_empty(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_Builder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_empty", 0);

  /* "axon/_objects.py":834
 * 
 *     def create_empty(self, name):
 *         return None             # <<<<<<<<<<<<<<
 * 
 * class SafeBuilder(Builder):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":833
 *         return None
 * 
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":838
 * class SafeBuilder(Builder):
 *     #
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         o = Mapping.__new__(Mapping)
 *         o.name = name
 */

PyObject *__pyx_f_4axon_8_objects_11SafeBuilder_create_mapping(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_SafeBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  struct MappingObject *__pyx_v_o = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_mapping", 0);

  /* "axon/_objects.py":839
 *     #
 *     def create_mapping(self, name, mapping):
 *         o = Mapping.__new__(Mapping)             # <<<<<<<<<<<<<<
 *         o.name = name
 *         o.mapping = mapping
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Mapping(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Mapping)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Mapping)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_o = ((struct MappingObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":840
 *     def create_mapping(self, name, mapping):
 *         o = Mapping.__new__(Mapping)
 *         o.name = name             # <<<<<<<<<<<<<<
 *         o.mapping = mapping
 *         return o
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_o->name);
  __Pyx_DECREF(__pyx_v_o->name);
  __pyx_v_o->name = __pyx_v_name;

  /* "axon/_objects.py":841
 *         o = Mapping.__new__(Mapping)
 *         o.name = name
 *         o.mapping = mapping             # <<<<<<<<<<<<<<
 *         return o
 *     #
 */
  __Pyx_INCREF(__pyx_v_mapping);
  __Pyx_GIVEREF(__pyx_v_mapping);
  __Pyx_GOTREF(__pyx_v_o->mapping);
  __Pyx_DECREF(__pyx_v_o->mapping);
  __pyx_v_o->mapping = __pyx_v_mapping;

  /* "axon/_objects.py":842
 *         o.name = name
 *         o.mapping = mapping
 *         return o             # <<<<<<<<<<<<<<
 *     #
 *     def create_sequence(self, name, sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_o));
  __pyx_r = ((PyObject *)__pyx_v_o);
  goto __pyx_L0;

  /* "axon/_objects.py":838
 * class SafeBuilder(Builder):
 *     #
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         o = Mapping.__new__(Mapping)
 *         o.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SafeBuilder.create_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_o);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":844
 *         return o
 *     #
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         s = Sequence.__new__(Sequence)
 *         s.name = name
 */

PyObject *__pyx_f_4axon_8_objects_11SafeBuilder_create_sequence(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_SafeBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  struct SequenceObject *__pyx_v_s = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_sequence", 0);

  /* "axon/_objects.py":845
 *     #
 *     def create_sequence(self, name, sequence):
 *         s = Sequence.__new__(Sequence)             # <<<<<<<<<<<<<<
 *         s.name = name
 *         s.sequence = sequence
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Sequence(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Sequence)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Sequence)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_s = ((struct SequenceObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":846
 *     def create_sequence(self, name, sequence):
 *         s = Sequence.__new__(Sequence)
 *         s.name = name             # <<<<<<<<<<<<<<
 *         s.sequence = sequence
 *         return s
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_s->name);
  __Pyx_DECREF(__pyx_v_s->name);
  __pyx_v_s->name = __pyx_v_name;

  /* "axon/_objects.py":847
 *         s = Sequence.__new__(Sequence)
 *         s.name = name
 *         s.sequence = sequence             # <<<<<<<<<<<<<<
 *         return s
 *     #
 */
  __Pyx_INCREF(__pyx_v_sequence);
  __Pyx_GIVEREF(__pyx_v_sequence);
  __Pyx_GOTREF(__pyx_v_s->sequence);
  __Pyx_DECREF(__pyx_v_s->sequence);
  __pyx_v_s->sequence = __pyx_v_sequence;

  /* "axon/_objects.py":848
 *         s.name = name
 *         s.sequence = sequence
 *         return s             # <<<<<<<<<<<<<<
 *     #
 *     def create_element(self, name, mapping, sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_s));
  __pyx_r = ((PyObject *)__pyx_v_s);
  goto __pyx_L0;

  /* "axon/_objects.py":844
 *         return o
 *     #
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         s = Sequence.__new__(Sequence)
 *         s.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SafeBuilder.create_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":850
 *         return s
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         e = Element.__new__(Element)
 *         e.name = name
 */

PyObject *__pyx_f_4axon_8_objects_11SafeBuilder_create_element(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_SafeBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  struct ElementObject *__pyx_v_e = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_element", 0);

  /* "axon/_objects.py":851
 *     #
 *     def create_element(self, name, mapping, sequence):
 *         e = Element.__new__(Element)             # <<<<<<<<<<<<<<
 *         e.name = name
 *         e.mapping = mapping
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Element(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Element)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Element)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_e = ((struct ElementObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":852
 *     def create_element(self, name, mapping, sequence):
 *         e = Element.__new__(Element)
 *         e.name = name             # <<<<<<<<<<<<<<
 *         e.mapping = mapping
 *         e.sequence = sequence
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_e->name);
  __Pyx_DECREF(__pyx_v_e->name);
  __pyx_v_e->name = __pyx_v_name;

  /* "axon/_objects.py":853
 *         e = Element.__new__(Element)
 *         e.name = name
 *         e.mapping = mapping             # <<<<<<<<<<<<<<
 *         e.sequence = sequence
 *         return e
 */
  __Pyx_INCREF(__pyx_v_mapping);
  __Pyx_GIVEREF(__pyx_v_mapping);
  __Pyx_GOTREF(__pyx_v_e->mapping);
  __Pyx_DECREF(__pyx_v_e->mapping);
  __pyx_v_e->mapping = __pyx_v_mapping;

  /* "axon/_objects.py":854
 *         e.name = name
 *         e.mapping = mapping
 *         e.sequence = sequence             # <<<<<<<<<<<<<<
 *         return e
 *     #
 */
  __Pyx_INCREF(__pyx_v_sequence);
  __Pyx_GIVEREF(__pyx_v_sequence);
  __Pyx_GOTREF(__pyx_v_e->sequence);
  __Pyx_DECREF(__pyx_v_e->sequence);
  __pyx_v_e->sequence = __pyx_v_sequence;

  /* "axon/_objects.py":855
 *         e.mapping = mapping
 *         e.sequence = sequence
 *         return e             # <<<<<<<<<<<<<<
 *     #
 *     def create_instance(self, name, args, mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_e));
  __pyx_r = ((PyObject *)__pyx_v_e);
  goto __pyx_L0;

  /* "axon/_objects.py":850
 *         return s
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         e = Element.__new__(Element)
 *         e.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SafeBuilder.create_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":857
 *         return e
 *     #
 *     def create_instance(self, name, args, mapping):             # <<<<<<<<<<<<<<
 *         e = Instance.__new__(Instance)
 *         e.name = name
 */

PyObject *__pyx_f_4axon_8_objects_11SafeBuilder_create_instance(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_SafeBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_args, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_instance", 0);

  /* "axon/_objects.py":858
 *     #
 *     def create_instance(self, name, args, mapping):
 *         e = Instance.__new__(Instance)             # <<<<<<<<<<<<<<
 *         e.name = name
 *         e.sequence = args
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Instance(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Instance)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_e = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":859
 *     def create_instance(self, name, args, mapping):
 *         e = Instance.__new__(Instance)
 *         e.name = name             # <<<<<<<<<<<<<<
 *         e.sequence = args
 *         e.mapping = mapping
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_e, __pyx_n_s_name, __pyx_v_name) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":860
 *         e = Instance.__new__(Instance)
 *         e.name = name
 *         e.sequence = args             # <<<<<<<<<<<<<<
 *         e.mapping = mapping
 *         return e
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_e, __pyx_n_s_sequence, __pyx_v_args) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 860; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":861
 *         e.name = name
 *         e.sequence = args
 *         e.mapping = mapping             # <<<<<<<<<<<<<<
 *         return e
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_e, __pyx_n_s_mapping, __pyx_v_mapping) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 861; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":862
 *         e.sequence = args
 *         e.mapping = mapping
 *         return e             # <<<<<<<<<<<<<<
 * 
 *     def create_empty(self, name):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_e);
  __pyx_r = __pyx_v_e;
  goto __pyx_L0;

  /* "axon/_objects.py":857
 *         return e
 *     #
 *     def create_instance(self, name, args, mapping):             # <<<<<<<<<<<<<<
 *         e = Instance.__new__(Instance)
 *         e.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SafeBuilder.create_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":864
 *         return e
 * 
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         e = Empty.__new__(Empty)
 *         e.name = name
 */

PyObject *__pyx_f_4axon_8_objects_11SafeBuilder_create_empty(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_SafeBuilder *__pyx_v_self, PyObject *__pyx_v_name) {
  struct EmptyObject *__pyx_v_e = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_empty", 0);

  /* "axon/_objects.py":865
 * 
 *     def create_empty(self, name):
 *         e = Empty.__new__(Empty)             # <<<<<<<<<<<<<<
 *         e.name = name
 *         return e
 */
  __pyx_t_1 = __pyx_tp_new_4axon_8_objects_Empty(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Empty)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_8_objects_Empty)))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_e = ((struct EmptyObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":866
 *     def create_empty(self, name):
 *         e = Empty.__new__(Empty)
 *         e.name = name             # <<<<<<<<<<<<<<
 *         return e
 * 
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_e->name);
  __Pyx_DECREF(__pyx_v_e->name);
  __pyx_v_e->name = __pyx_v_name;

  /* "axon/_objects.py":867
 *         e = Empty.__new__(Empty)
 *         e.name = name
 *         return e             # <<<<<<<<<<<<<<
 * 
 * class StrictBuilder(Builder):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_e));
  __pyx_r = ((PyObject *)__pyx_v_e);
  goto __pyx_L0;

  /* "axon/_objects.py":864
 *         return e
 * 
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         e = Empty.__new__(Empty)
 *         e.name = name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SafeBuilder.create_empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":874
 *     #    self.builder = SafeBuilder()
 * 
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_13StrictBuilder_create_mapping(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_StrictBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_mapping", 0);

  /* "axon/_objects.py":875
 * 
 *     def create_mapping(self, name, mapping):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_undefined
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 875; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 875; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":876
 *     def create_mapping(self, name, mapping):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_undefined
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":877
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_undefined             # <<<<<<<<<<<<<<
 *         else:
 *             return handler(mapping)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":879
 *             return c_undefined
 *         else:
 *             return handler(mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def create_sequence(self, name, sequence):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_mapping);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_mapping);
    __Pyx_GIVEREF(__pyx_v_mapping);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":874
 *     #    self.builder = SafeBuilder()
 * 
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.StrictBuilder.create_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":881
 *             return handler(mapping)
 *     #
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_13StrictBuilder_create_sequence(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_StrictBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_sequence", 0);

  /* "axon/_objects.py":882
 *     #
 *     def create_sequence(self, name, sequence):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_undefined
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 882; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 882; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":883
 *     def create_sequence(self, name, sequence):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_undefined
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":884
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_undefined             # <<<<<<<<<<<<<<
 *         else:
 *             return handler(sequence)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":886
 *             return c_undefined
 *         else:
 *             return handler(sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def create_element(self, name, mapping, sequence):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_sequence);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sequence);
    __Pyx_GIVEREF(__pyx_v_sequence);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":881
 *             return handler(mapping)
 *     #
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.StrictBuilder.create_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":888
 *             return handler(sequence)
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_13StrictBuilder_create_element(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_StrictBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_element", 0);

  /* "axon/_objects.py":889
 *     #
 *     def create_element(self, name, mapping, sequence):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_undefined
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 889; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 889; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":890
 *     def create_element(self, name, mapping, sequence):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_undefined
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":891
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_undefined             # <<<<<<<<<<<<<<
 *         else:
 *             return handler(mapping, sequence)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":893
 *             return c_undefined
 *         else:
 *             return handler(mapping, sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def create_instance(self, name, sequence, mapping):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_mapping);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_mapping);
    __Pyx_GIVEREF(__pyx_v_mapping);
    __Pyx_INCREF(__pyx_v_sequence);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_sequence);
    __Pyx_GIVEREF(__pyx_v_sequence);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":888
 *             return handler(sequence)
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.StrictBuilder.create_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":895
 *             return handler(mapping, sequence)
 *     #
 *     def create_instance(self, name, sequence, mapping):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_13StrictBuilder_create_instance(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_StrictBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_instance", 0);

  /* "axon/_objects.py":896
 *     #
 *     def create_instance(self, name, sequence, mapping):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_undefined
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":897
 *     def create_instance(self, name, sequence, mapping):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_undefined
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":898
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_undefined             # <<<<<<<<<<<<<<
 *         else:
 *             return handler(sequence, mapping)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":900
 *             return c_undefined
 *         else:
 *             return handler(sequence, mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def create_empty(self, name):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_sequence);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sequence);
    __Pyx_GIVEREF(__pyx_v_sequence);
    __Pyx_INCREF(__pyx_v_mapping);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_mapping);
    __Pyx_GIVEREF(__pyx_v_mapping);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":895
 *             return handler(mapping, sequence)
 *     #
 *     def create_instance(self, name, sequence, mapping):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.StrictBuilder.create_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":902
 *             return handler(sequence, mapping)
 *     #
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_13StrictBuilder_create_empty(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_StrictBuilder *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_empty", 0);

  /* "axon/_objects.py":903
 *     #
 *     def create_empty(self, name):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_undefined
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 903; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 903; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":904
 *     def create_empty(self, name):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_undefined
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":905
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_undefined             # <<<<<<<<<<<<<<
 *         else:
 *             return handler()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_4axon_8_objects_c_undefined);
    __pyx_r = __pyx_v_4axon_8_objects_c_undefined;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":907
 *             return c_undefined
 *         else:
 *             return handler()             # <<<<<<<<<<<<<<
 * 
 * class MixedBuilder(Builder):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 907; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":902
 *             return handler(sequence, mapping)
 *     #
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StrictBuilder.create_empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":911
 * class MixedBuilder(Builder):
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.builder = SafeBuilder()
 * 
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_12MixedBuilder_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_12MixedBuilder_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_4axon_8_objects_12MixedBuilder___init__(((struct __pyx_obj_4axon_8_objects_MixedBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_12MixedBuilder___init__(struct __pyx_obj_4axon_8_objects_MixedBuilder *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":912
 * 
 *     def __init__(self):
 *         self.builder = SafeBuilder()             # <<<<<<<<<<<<<<
 * 
 *     def create_mapping(self, name, mapping):
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_SafeBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 912; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->builder);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->builder));
  __pyx_v_self->builder = ((struct __pyx_obj_4axon_8_objects_SafeBuilder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":911
 * class MixedBuilder(Builder):
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.builder = SafeBuilder()
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.MixedBuilder.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":914
 *         self.builder = SafeBuilder()
 * 
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_12MixedBuilder_create_mapping(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_MixedBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_mapping", 0);

  /* "axon/_objects.py":915
 * 
 *     def create_mapping(self, name, mapping):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_new_mapping(name, mapping)
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":916
 *     def create_mapping(self, name, mapping):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_new_mapping(name, mapping)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":917
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_new_mapping(name, mapping)             # <<<<<<<<<<<<<<
 *         else:
 *             return handler(mapping)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_mapping(__pyx_v_name, __pyx_v_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 917; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":919
 *             return c_new_mapping(name, mapping)
 *         else:
 *             return handler(mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def create_sequence(self, name, sequence):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 919; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_mapping);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_mapping);
    __Pyx_GIVEREF(__pyx_v_mapping);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 919; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":914
 *         self.builder = SafeBuilder()
 * 
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.MixedBuilder.create_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":921
 *             return handler(mapping)
 *     #
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_12MixedBuilder_create_sequence(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_MixedBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_sequence", 0);

  /* "axon/_objects.py":922
 *     #
 *     def create_sequence(self, name, sequence):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_new_sequence(name, sequence)
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 922; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 922; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":923
 *     def create_sequence(self, name, sequence):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_new_sequence(name, sequence)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":924
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_new_sequence(name, sequence)             # <<<<<<<<<<<<<<
 *         else:
 *             return handler(sequence)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_sequence(__pyx_v_name, __pyx_v_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 924; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":926
 *             return c_new_sequence(name, sequence)
 *         else:
 *             return handler(sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def create_element(self, name, mapping, sequence):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 926; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_sequence);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sequence);
    __Pyx_GIVEREF(__pyx_v_sequence);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 926; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":921
 *             return handler(mapping)
 *     #
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.MixedBuilder.create_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":928
 *             return handler(sequence)
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_12MixedBuilder_create_element(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_MixedBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_element", 0);

  /* "axon/_objects.py":929
 *     #
 *     def create_element(self, name, mapping, sequence):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_new_element(name, mapping, sequence)
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 929; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 929; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":930
 *     def create_element(self, name, mapping, sequence):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_new_element(name, mapping, sequence)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":931
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_new_element(name, mapping, sequence)             # <<<<<<<<<<<<<<
 *         else:
 *             return handler(mapping, sequence)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_element(__pyx_v_name, __pyx_v_mapping, __pyx_v_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 931; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":933
 *             return c_new_element(name, mapping, sequence)
 *         else:
 *             return handler(mapping, sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def create_instance(self, name, sequence, mapping):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_mapping);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_mapping);
    __Pyx_GIVEREF(__pyx_v_mapping);
    __Pyx_INCREF(__pyx_v_sequence);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_sequence);
    __Pyx_GIVEREF(__pyx_v_sequence);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":928
 *             return handler(sequence)
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.MixedBuilder.create_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":935
 *             return handler(mapping, sequence)
 *     #
 *     def create_instance(self, name, sequence, mapping):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_12MixedBuilder_create_instance(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_MixedBuilder *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_instance", 0);

  /* "axon/_objects.py":936
 *     #
 *     def create_instance(self, name, sequence, mapping):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_new_instance(name, sequence, mapping)
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":937
 *     def create_instance(self, name, sequence, mapping):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_new_instance(name, sequence, mapping)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":938
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_new_instance(name, sequence, mapping)             # <<<<<<<<<<<<<<
 *         else:
 *             return handler(sequence, mapping)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_instance(__pyx_v_name, __pyx_v_sequence, __pyx_v_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 938; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":940
 *             return c_new_instance(name, sequence, mapping)
 *         else:
 *             return handler(sequence, mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def create_empty(self, name):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 940; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_sequence);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sequence);
    __Pyx_GIVEREF(__pyx_v_sequence);
    __Pyx_INCREF(__pyx_v_mapping);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_mapping);
    __Pyx_GIVEREF(__pyx_v_mapping);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 940; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":935
 *             return handler(mapping, sequence)
 *     #
 *     def create_instance(self, name, sequence, mapping):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.MixedBuilder.create_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":942
 *             return handler(sequence, mapping)
 *     #
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

PyObject *__pyx_f_4axon_8_objects_12MixedBuilder_create_empty(CYTHON_UNUSED struct __pyx_obj_4axon_8_objects_MixedBuilder *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_empty", 0);

  /* "axon/_objects.py":943
 *     #
 *     def create_empty(self, name):
 *         handler = c_factory_dict.get(name)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             return c_new_empty(name)
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_factory_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_factory_dict, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":944
 *     def create_empty(self, name):
 *         handler = c_factory_dict.get(name)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             return c_new_empty(name)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_handler == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":945
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 *             return c_new_empty(name)             # <<<<<<<<<<<<<<
 *         else:
 *             return handler()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_new_empty(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 945; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":947
 *             return c_new_empty(name)
 *         else:
 *             return handler()             # <<<<<<<<<<<<<<
 * 
 * class GenericBuilder(Builder):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_handler, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":942
 *             return handler(sequence, mapping)
 *     #
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         handler = c_factory_dict.get(name)
 *         if handler is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.MixedBuilder.create_empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":951
 * class GenericBuilder(Builder):
 * 
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         return self.mapping(name, c_as_dict(mapping))
 *     #
 */

PyObject *__pyx_f_4axon_8_objects_14GenericBuilder_create_mapping(struct GenericBuilderObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_mapping", 0);

  /* "axon/_objects.py":952
 * 
 *     def create_mapping(self, name, mapping):
 *         return self.mapping(name, c_as_dict(mapping))             # <<<<<<<<<<<<<<
 *     #
 *     def create_sequence(self, name, sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":951
 * class GenericBuilder(Builder):
 * 
 *     def create_mapping(self, name, mapping):             # <<<<<<<<<<<<<<
 *         return self.mapping(name, c_as_dict(mapping))
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.GenericBuilder.create_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":954
 *         return self.mapping(name, c_as_dict(mapping))
 *     #
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         return self.sequence(name, c_as_list(sequence))
 *     #
 */

PyObject *__pyx_f_4axon_8_objects_14GenericBuilder_create_sequence(struct GenericBuilderObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_sequence", 0);

  /* "axon/_objects.py":955
 *     #
 *     def create_sequence(self, name, sequence):
 *         return self.sequence(name, c_as_list(sequence))             # <<<<<<<<<<<<<<
 *     #
 *     def create_element(self, name, mapping, sequence):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 955; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 955; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 955; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 955; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":954
 *         return self.mapping(name, c_as_dict(mapping))
 *     #
 *     def create_sequence(self, name, sequence):             # <<<<<<<<<<<<<<
 *         return self.sequence(name, c_as_list(sequence))
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.GenericBuilder.create_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":957
 *         return self.sequence(name, c_as_list(sequence))
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         return self.element(name, c_as_dict(mapping), c_as_list(sequence))
 *     #
 */

PyObject *__pyx_f_4axon_8_objects_14GenericBuilder_create_element(struct GenericBuilderObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_mapping, PyObject *__pyx_v_sequence) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_element", 0);

  /* "axon/_objects.py":958
 *     #
 *     def create_element(self, name, mapping, sequence):
 *         return self.element(name, c_as_dict(mapping), c_as_list(sequence))             # <<<<<<<<<<<<<<
 *     #
 *     def create_instance(self, name, sequence, mapping):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_element_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":957
 *         return self.sequence(name, c_as_list(sequence))
 *     #
 *     def create_element(self, name, mapping, sequence):             # <<<<<<<<<<<<<<
 *         return self.element(name, c_as_dict(mapping), c_as_list(sequence))
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.GenericBuilder.create_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":960
 *         return self.element(name, c_as_dict(mapping), c_as_list(sequence))
 *     #
 *     def create_instance(self, name, sequence, mapping):             # <<<<<<<<<<<<<<
 *         return self.instance(name, c_as_list(sequence), c_as_dict(mapping))
 *     #
 */

PyObject *__pyx_f_4axon_8_objects_14GenericBuilder_create_instance(struct GenericBuilderObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_sequence, PyObject *__pyx_v_mapping) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_instance", 0);

  /* "axon/_objects.py":961
 *     #
 *     def create_instance(self, name, sequence, mapping):
 *         return self.instance(name, c_as_list(sequence), c_as_dict(mapping))             # <<<<<<<<<<<<<<
 *     #
 *     def create_empty(self, name):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_instance_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 961; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_8_objects_c_as_list(__pyx_v_sequence); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 961; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_dict(__pyx_v_mapping); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 961; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 961; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 961; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":960
 *         return self.element(name, c_as_dict(mapping), c_as_list(sequence))
 *     #
 *     def create_instance(self, name, sequence, mapping):             # <<<<<<<<<<<<<<
 *         return self.instance(name, c_as_list(sequence), c_as_dict(mapping))
 *     #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.GenericBuilder.create_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":963
 *         return self.instance(name, c_as_list(sequence), c_as_dict(mapping))
 *     #
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         return self.empty(name)
 * 
 */

PyObject *__pyx_f_4axon_8_objects_14GenericBuilder_create_empty(struct GenericBuilderObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_empty", 0);

  /* "axon/_objects.py":964
 *     #
 *     def create_empty(self, name):
 *         return self.empty(name)             # <<<<<<<<<<<<<<
 * 
 * c_builder_dict = {
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_empty_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 964; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 964; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_name);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 964; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":963
 *         return self.instance(name, c_as_list(sequence), c_as_dict(mapping))
 *     #
 *     def create_empty(self, name):             # <<<<<<<<<<<<<<
 *         return self.empty(name)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.GenericBuilder.create_empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":972
 * }
 * 
 * def register_builder(mode, builder):             # <<<<<<<<<<<<<<
 *     c_builder_dict[mode] = builder
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_39register_builder(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4axon_8_objects_39register_builder = {__Pyx_NAMESTR("register_builder"), (PyCFunction)__pyx_pw_4axon_8_objects_39register_builder, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_8_objects_39register_builder(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_mode = 0;
  PyObject *__pyx_v_builder = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("register_builder (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_mode,&__pyx_n_s_builder,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_mode)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_builder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("register_builder", 1, 2, 2, 1); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "register_builder") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_mode = values[0];
    __pyx_v_builder = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("register_builder", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.register_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_38register_builder(__pyx_self, __pyx_v_mode, __pyx_v_builder);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_38register_builder(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode, PyObject *__pyx_v_builder) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("register_builder", 0);

  /* "axon/_objects.py":973
 * 
 * def register_builder(mode, builder):
 *     c_builder_dict[mode] = builder             # <<<<<<<<<<<<<<
 * 
 * def get_builder(mode):
 */
  if (unlikely(__pyx_v_4axon_8_objects_c_builder_dict == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 973; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyDict_SetItem(__pyx_v_4axon_8_objects_c_builder_dict, __pyx_v_mode, __pyx_v_builder) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 973; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":972
 * }
 * 
 * def register_builder(mode, builder):             # <<<<<<<<<<<<<<
 *     c_builder_dict[mode] = builder
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._objects.register_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":975
 *     c_builder_dict[mode] = builder
 * 
 * def get_builder(mode):             # <<<<<<<<<<<<<<
 *     return c_get_builder(mode)
 * 
 */

static PyObject *__pyx_pw_4axon_8_objects_41get_builder(PyObject *__pyx_self, PyObject *__pyx_v_mode); /*proto*/
static struct __pyx_obj_4axon_8_objects_Builder *__pyx_f_4axon_8_objects_get_builder(PyObject *__pyx_v_mode, CYTHON_UNUSED int __pyx_skip_dispatch) {
  struct __pyx_obj_4axon_8_objects_Builder *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_builder", 0);

  /* "axon/_objects.py":976
 * 
 * def get_builder(mode):
 *     return c_get_builder(mode)             # <<<<<<<<<<<<<<
 * 
 * _inf = float('inf')
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_c_get_builder(__pyx_v_mode)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((struct __pyx_obj_4axon_8_objects_Builder *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":975
 *     c_builder_dict[mode] = builder
 * 
 * def get_builder(mode):             # <<<<<<<<<<<<<<
 *     return c_get_builder(mode)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.get_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_41get_builder(PyObject *__pyx_self, PyObject *__pyx_v_mode); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_41get_builder(PyObject *__pyx_self, PyObject *__pyx_v_mode) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_builder (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_40get_builder(__pyx_self, ((PyObject *)__pyx_v_mode));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_40get_builder(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_mode) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_builder", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_8_objects_get_builder(__pyx_v_mode, 0)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 975; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.get_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":990
 * class SimpleBuilder:
 * 
 *     def create_int(self, text):             # <<<<<<<<<<<<<<
 *         n = c_unicode_length(text)
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n+1)
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_int(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, PyObject *__pyx_v_text) {
  int __pyx_v_i;
  PyObject *__pyx_v_num_buffer = 0;
  char *__pyx_v_buf;
  int __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_int", 0);

  /* "axon/_objects.py":991
 * 
 *     def create_int(self, text):
 *         n = c_unicode_length(text)             # <<<<<<<<<<<<<<
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n+1)
 * 
 */
  __pyx_v_n = c_unicode_length(__pyx_v_text);

  /* "axon/_objects.py":992
 *     def create_int(self, text):
 *         n = c_unicode_length(text)
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n+1)             # <<<<<<<<<<<<<<
 * 
 *         buf = num_buffer
 */
  __pyx_t_1 = PyBytes_FromStringAndSize(NULL, (__pyx_v_n + 1)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 992; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_num_buffer = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":994
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n+1)
 * 
 *         buf = num_buffer             # <<<<<<<<<<<<<<
 * 
 *         for i in range(n):
 */
  __pyx_t_2 = __Pyx_PyObject_AsString(__pyx_v_num_buffer); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 994; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_buf = __pyx_t_2;

  /* "axon/_objects.py":996
 *         buf = num_buffer
 * 
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             buf[i] = c_unicode_char(text, i)
 *         buf[n] = 0
 */
  __pyx_t_3 = __pyx_v_n;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "axon/_objects.py":997
 * 
 *         for i in range(n):
 *             buf[i] = c_unicode_char(text, i)             # <<<<<<<<<<<<<<
 *         buf[n] = 0
 * 
 */
    (__pyx_v_buf[__pyx_v_i]) = c_unicode_char(__pyx_v_text, __pyx_v_i);
  }

  /* "axon/_objects.py":998
 *         for i in range(n):
 *             buf[i] = c_unicode_char(text, i)
 *         buf[n] = 0             # <<<<<<<<<<<<<<
 * 
 *         return c_int_fromstring(buf)
 */
  (__pyx_v_buf[__pyx_v_n]) = 0;

  /* "axon/_objects.py":1000
 *         buf[n] = 0
 * 
 *         return c_int_fromstring(buf)             # <<<<<<<<<<<<<<
 * 
 *     def create_float(self, text):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = c_int_fromstring(__pyx_v_buf); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1000; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":990
 * class SimpleBuilder:
 * 
 *     def create_int(self, text):             # <<<<<<<<<<<<<<
 *         n = c_unicode_length(text)
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n+1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_num_buffer);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1002
 *         return c_int_fromstring(buf)
 * 
 *     def create_float(self, text):             # <<<<<<<<<<<<<<
 *         n = c_unicode_length(text)
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_float(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, PyObject *__pyx_v_text) {
  int __pyx_v_i;
  PyObject *__pyx_v_num_buffer = 0;
  char *__pyx_v_buf;
  int __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_float", 0);

  /* "axon/_objects.py":1003
 * 
 *     def create_float(self, text):
 *         n = c_unicode_length(text)             # <<<<<<<<<<<<<<
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)
 * 
 */
  __pyx_v_n = c_unicode_length(__pyx_v_text);

  /* "axon/_objects.py":1004
 *     def create_float(self, text):
 *         n = c_unicode_length(text)
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)             # <<<<<<<<<<<<<<
 * 
 *         buf = num_buffer
 */
  __pyx_t_1 = PyBytes_FromStringAndSize(NULL, __pyx_v_n); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_num_buffer = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":1006
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)
 * 
 *         buf = num_buffer             # <<<<<<<<<<<<<<
 * 
 *         for i in range(n):
 */
  __pyx_t_2 = __Pyx_PyObject_AsString(__pyx_v_num_buffer); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1006; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_buf = __pyx_t_2;

  /* "axon/_objects.py":1008
 *         buf = num_buffer
 * 
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             buf[i] = c_unicode_char(text, i)
 * 
 */
  __pyx_t_3 = __pyx_v_n;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "axon/_objects.py":1009
 * 
 *         for i in range(n):
 *             buf[i] = c_unicode_char(text, i)             # <<<<<<<<<<<<<<
 * 
 *         return c_float_fromstring(num_buffer)
 */
    (__pyx_v_buf[__pyx_v_i]) = c_unicode_char(__pyx_v_text, __pyx_v_i);
  }

  /* "axon/_objects.py":1011
 *             buf[i] = c_unicode_char(text, i)
 * 
 *         return c_float_fromstring(num_buffer)             # <<<<<<<<<<<<<<
 * 
 *     def create_decimal(self, text):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = c_float_fromstring(__pyx_v_num_buffer); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1011; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1002
 *         return c_int_fromstring(buf)
 * 
 *     def create_float(self, text):             # <<<<<<<<<<<<<<
 *         n = c_unicode_length(text)
 *         num_buffer = PyBytes_FromStringAndSize(cython.NULL, n)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_float", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_num_buffer);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1013
 *         return c_float_fromstring(num_buffer)
 * 
 *     def create_decimal(self, text):             # <<<<<<<<<<<<<<
 *         return _str2decimal(text)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_decimal", 0);

  /* "axon/_objects.py":1014
 * 
 *     def create_decimal(self, text):
 *         return _str2decimal(text)             # <<<<<<<<<<<<<<
 * 
 *     def create_time(self, h, m, s, ms, tz):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1014; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_text);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_text);
  __Pyx_GIVEREF(__pyx_v_text);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_4axon_8_objects__str2decimal, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1014; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1013
 *         return c_float_fromstring(num_buffer)
 * 
 *     def create_decimal(self, text):             # <<<<<<<<<<<<<<
 *         return _str2decimal(text)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_decimal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1016
 *         return _str2decimal(text)
 * 
 *     def create_time(self, h, m, s, ms, tz):             # <<<<<<<<<<<<<<
 *         return time_new(h, m, s, ms, tz)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_time(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, int __pyx_v_h, int __pyx_v_m, int __pyx_v_s, int __pyx_v_ms, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_time", 0);

  /* "axon/_objects.py":1017
 * 
 *     def create_time(self, h, m, s, ms, tz):
 *         return time_new(h, m, s, ms, tz)             # <<<<<<<<<<<<<<
 * 
 *     def create_timedelta(self, d, s, ms):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_time_new(__pyx_v_h, __pyx_v_m, __pyx_v_s, __pyx_v_ms, __pyx_v_tz); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1017; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1016
 *         return _str2decimal(text)
 * 
 *     def create_time(self, h, m, s, ms, tz):             # <<<<<<<<<<<<<<
 *         return time_new(h, m, s, ms, tz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1019
 *         return time_new(h, m, s, ms, tz)
 * 
 *     def create_timedelta(self, d, s, ms):             # <<<<<<<<<<<<<<
 *         return timedelta_new(d, s, ms)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_timedelta(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, int __pyx_v_d, int __pyx_v_s, int __pyx_v_ms) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_timedelta", 0);

  /* "axon/_objects.py":1020
 * 
 *     def create_timedelta(self, d, s, ms):
 *         return timedelta_new(d, s, ms)             # <<<<<<<<<<<<<<
 * 
 *     def create_date(self, y, m, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_timedelta_new(__pyx_v_d, __pyx_v_s, __pyx_v_ms); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1020; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1019
 *         return time_new(h, m, s, ms, tz)
 * 
 *     def create_timedelta(self, d, s, ms):             # <<<<<<<<<<<<<<
 *         return timedelta_new(d, s, ms)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_timedelta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1022
 *         return timedelta_new(d, s, ms)
 * 
 *     def create_date(self, y, m, d):             # <<<<<<<<<<<<<<
 *         return date_new(y, m, d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_date(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, int __pyx_v_y, int __pyx_v_m, int __pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_date", 0);

  /* "axon/_objects.py":1023
 * 
 *     def create_date(self, y, m, d):
 *         return date_new(y, m, d)             # <<<<<<<<<<<<<<
 * 
 *     def create_datetime(self, y, M, d, h, m, s, ms, tz):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_date_new(__pyx_v_y, __pyx_v_m, __pyx_v_d); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1022
 *         return timedelta_new(d, s, ms)
 * 
 *     def create_date(self, y, m, d):             # <<<<<<<<<<<<<<
 *         return date_new(y, m, d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1025
 *         return date_new(y, m, d)
 * 
 *     def create_datetime(self, y, M, d, h, m, s, ms, tz):             # <<<<<<<<<<<<<<
 *         return datetime_new(y, M, d, h, m, s, ms, tz)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_datetime(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, int __pyx_v_y, int __pyx_v_M, int __pyx_v_d, int __pyx_v_h, int __pyx_v_m, int __pyx_v_s, int __pyx_v_ms, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_datetime", 0);

  /* "axon/_objects.py":1026
 * 
 *     def create_datetime(self, y, M, d, h, m, s, ms, tz):
 *         return datetime_new(y, M, d, h, m, s, ms, tz)             # <<<<<<<<<<<<<<
 * 
 *     def create_tzinfo(self, minutes):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_datetime_new(__pyx_v_y, __pyx_v_M, __pyx_v_d, __pyx_v_h, __pyx_v_m, __pyx_v_s, __pyx_v_ms, __pyx_v_tz); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1026; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1025
 *         return date_new(y, m, d)
 * 
 *     def create_datetime(self, y, M, d, h, m, s, ms, tz):             # <<<<<<<<<<<<<<
 *         return datetime_new(y, M, d, h, m, s, ms, tz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_datetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1028
 *         return datetime_new(y, M, d, h, m, s, ms, tz)
 * 
 *     def create_tzinfo(self, minutes):             # <<<<<<<<<<<<<<
 *         o_minutes = minutes
 *         tzinfo = tz_dict.get(o_minutes, None)
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_tzinfo(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, int __pyx_v_minutes) {
  int __pyx_v_o_minutes;
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_tzinfo", 0);

  /* "axon/_objects.py":1029
 * 
 *     def create_tzinfo(self, minutes):
 *         o_minutes = minutes             # <<<<<<<<<<<<<<
 *         tzinfo = tz_dict.get(o_minutes, None)
 *         if tzinfo is None:
 */
  __pyx_v_o_minutes = __pyx_v_minutes;

  /* "axon/_objects.py":1030
 *     def create_tzinfo(self, minutes):
 *         o_minutes = minutes
 *         tzinfo = tz_dict.get(o_minutes, None)             # <<<<<<<<<<<<<<
 *         if tzinfo is None:
 *             tzinfo = timezone_cls(datetime.timedelta(minutes=o_minutes))
 */
  if (unlikely(__pyx_v_4axon_8_objects_tz_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1030; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_o_minutes); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1030; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_tz_dict, __pyx_t_1, Py_None); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1030; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_tzinfo = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_objects.py":1031
 *         o_minutes = minutes
 *         tzinfo = tz_dict.get(o_minutes, None)
 *         if tzinfo is None:             # <<<<<<<<<<<<<<
 *             tzinfo = timezone_cls(datetime.timedelta(minutes=o_minutes))
 *             tz_dict[o_minutes] = tzinfo
 */
  __pyx_t_3 = (__pyx_v_tzinfo == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_objects.py":1032
 *         tzinfo = tz_dict.get(o_minutes, None)
 *         if tzinfo is None:
 *             tzinfo = timezone_cls(datetime.timedelta(minutes=o_minutes))             # <<<<<<<<<<<<<<
 *             tz_dict[o_minutes] = tzinfo
 *         return tzinfo
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_datetime); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_timedelta); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_o_minutes); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_minutes, __pyx_t_5) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_4axon_8_objects_timezone_cls, __pyx_t_2, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_tzinfo, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "axon/_objects.py":1033
 *         if tzinfo is None:
 *             tzinfo = timezone_cls(datetime.timedelta(minutes=o_minutes))
 *             tz_dict[o_minutes] = tzinfo             # <<<<<<<<<<<<<<
 *         return tzinfo
 * 
 */
    if (unlikely(__pyx_v_4axon_8_objects_tz_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_o_minutes); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely(PyDict_SetItem(__pyx_v_4axon_8_objects_tz_dict, __pyx_t_5, __pyx_v_tzinfo) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_objects.py":1034
 *             tzinfo = timezone_cls(datetime.timedelta(minutes=o_minutes))
 *             tz_dict[o_minutes] = tzinfo
 *         return tzinfo             # <<<<<<<<<<<<<<
 * 
 *     def create_inf(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_tzinfo);
  __pyx_r = __pyx_v_tzinfo;
  goto __pyx_L0;

  /* "axon/_objects.py":1028
 *         return datetime_new(y, M, d, h, m, s, ms, tz)
 * 
 *     def create_tzinfo(self, minutes):             # <<<<<<<<<<<<<<
 *         o_minutes = minutes
 *         tzinfo = tz_dict.get(o_minutes, None)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_tzinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1036
 *         return tzinfo
 * 
 *     def create_inf(self):             # <<<<<<<<<<<<<<
 *         return _inf
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_inf(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_inf", 0);

  /* "axon/_objects.py":1037
 * 
 *     def create_inf(self):
 *         return _inf             # <<<<<<<<<<<<<<
 * 
 *     def create_ninf(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_8_objects__inf);
  __pyx_r = __pyx_v_4axon_8_objects__inf;
  goto __pyx_L0;

  /* "axon/_objects.py":1036
 *         return tzinfo
 * 
 *     def create_inf(self):             # <<<<<<<<<<<<<<
 *         return _inf
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1039
 *         return _inf
 * 
 *     def create_ninf(self):             # <<<<<<<<<<<<<<
 *         return _ninf
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_ninf(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_ninf", 0);

  /* "axon/_objects.py":1040
 * 
 *     def create_ninf(self):
 *         return _ninf             # <<<<<<<<<<<<<<
 * 
 *     def create_nan(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_8_objects__ninf);
  __pyx_r = __pyx_v_4axon_8_objects__ninf;
  goto __pyx_L0;

  /* "axon/_objects.py":1039
 *         return _inf
 * 
 *     def create_ninf(self):             # <<<<<<<<<<<<<<
 *         return _ninf
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1042
 *         return _ninf
 * 
 *     def create_nan(self):             # <<<<<<<<<<<<<<
 *         return _nan
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_nan(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_nan", 0);

  /* "axon/_objects.py":1043
 * 
 *     def create_nan(self):
 *         return _nan             # <<<<<<<<<<<<<<
 * 
 *     def create_decimal_inf(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_8_objects__nan);
  __pyx_r = __pyx_v_4axon_8_objects__nan;
  goto __pyx_L0;

  /* "axon/_objects.py":1042
 *         return _ninf
 * 
 *     def create_nan(self):             # <<<<<<<<<<<<<<
 *         return _nan
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1045
 *         return _nan
 * 
 *     def create_decimal_inf(self):             # <<<<<<<<<<<<<<
 *         return _decimal_inf
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_inf(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_decimal_inf", 0);

  /* "axon/_objects.py":1046
 * 
 *     def create_decimal_inf(self):
 *         return _decimal_inf             # <<<<<<<<<<<<<<
 * 
 *     def create_decimal_ninf(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_8_objects__decimal_inf);
  __pyx_r = __pyx_v_4axon_8_objects__decimal_inf;
  goto __pyx_L0;

  /* "axon/_objects.py":1045
 *         return _nan
 * 
 *     def create_decimal_inf(self):             # <<<<<<<<<<<<<<
 *         return _decimal_inf
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1048
 *         return _decimal_inf
 * 
 *     def create_decimal_ninf(self):             # <<<<<<<<<<<<<<
 *         return _decimal_ninf
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_ninf(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_decimal_ninf", 0);

  /* "axon/_objects.py":1049
 * 
 *     def create_decimal_ninf(self):
 *         return _decimal_ninf             # <<<<<<<<<<<<<<
 * 
 *     def create_decimal_nan(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_8_objects__decimal_ninf);
  __pyx_r = __pyx_v_4axon_8_objects__decimal_ninf;
  goto __pyx_L0;

  /* "axon/_objects.py":1048
 *         return _decimal_inf
 * 
 *     def create_decimal_ninf(self):             # <<<<<<<<<<<<<<
 *         return _decimal_ninf
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1051
 *         return _decimal_ninf
 * 
 *     def create_decimal_nan(self):             # <<<<<<<<<<<<<<
 *         return _decimal_nan
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_nan(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_decimal_nan", 0);

  /* "axon/_objects.py":1052
 * 
 *     def create_decimal_nan(self):
 *         return _decimal_nan             # <<<<<<<<<<<<<<
 * 
 *     def create_binary(self, text):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_4axon_8_objects__decimal_nan);
  __pyx_r = __pyx_v_4axon_8_objects__decimal_nan;
  goto __pyx_L0;

  /* "axon/_objects.py":1051
 *         return _decimal_ninf
 * 
 *     def create_decimal_nan(self):             # <<<<<<<<<<<<<<
 *         return _decimal_nan
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1054
 *         return _decimal_nan
 * 
 *     def create_binary(self, text):             # <<<<<<<<<<<<<<
 *         return decodebytes(text.encode('ascii'))
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_13SimpleBuilder_create_binary(CYTHON_UNUSED struct SimpleBuilder *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_binary", 0);

  /* "axon/_objects.py":1055
 * 
 *     def create_binary(self, text):
 *         return decodebytes(text.encode('ascii'))             # <<<<<<<<<<<<<<
 * 
 * class StringReader:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_decodebytes); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1055; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_v_text == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "encode");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1055; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_2 = PyUnicode_AsASCIIString(__pyx_v_text); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1055; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1055; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1055; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1054
 *         return _decimal_nan
 * 
 *     def create_binary(self, text):             # <<<<<<<<<<<<<<
 *         return decodebytes(text.encode('ascii'))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.SimpleBuilder.create_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1059
 * class StringReader:
 * 
 *     def __init__(self, text):             # <<<<<<<<<<<<<<
 *         self.buffer = text
 *         self.pos = 0
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_12StringReader_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_12StringReader_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_text = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_text,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_text)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_text = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.StringReader.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_12StringReader___init__(((struct __pyx_obj_4axon_8_objects_StringReader *)__pyx_v_self), __pyx_v_text);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_12StringReader___init__(struct __pyx_obj_4axon_8_objects_StringReader *__pyx_v_self, PyObject *__pyx_v_text) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":1060
 * 
 *     def __init__(self, text):
 *         self.buffer = text             # <<<<<<<<<<<<<<
 *         self.pos = 0
 *         self.n = len(text)
 */
  if (!(likely(PyUnicode_CheckExact(__pyx_v_text))||((__pyx_v_text) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_text)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1060; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_text;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->buffer);
  __Pyx_DECREF(__pyx_v_self->buffer);
  __pyx_v_self->buffer = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":1061
 *     def __init__(self, text):
 *         self.buffer = text
 *         self.pos = 0             # <<<<<<<<<<<<<<
 *         self.n = len(text)
 * 
 */
  __pyx_v_self->pos = 0;

  /* "axon/_objects.py":1062
 *         self.buffer = text
 *         self.pos = 0
 *         self.n = len(text)             # <<<<<<<<<<<<<<
 * 
 *     def readline(self):
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_text); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1062; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->n = __pyx_t_2;

  /* "axon/_objects.py":1059
 * class StringReader:
 * 
 *     def __init__(self, text):             # <<<<<<<<<<<<<<
 *         self.buffer = text
 *         self.pos = 0
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringReader.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1064
 *         self.n = len(text)
 * 
 *     def readline(self):             # <<<<<<<<<<<<<<
 * 
 *         buffer = self.buffer
 */

static PyObject *__pyx_pw_4axon_8_objects_12StringReader_3readline(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_12StringReader_readline(struct __pyx_obj_4axon_8_objects_StringReader *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_v_buffer = 0;
  PyObject *__pyx_v_line = 0;
  int __pyx_v_pos;
  int __pyx_v_pos0;
  int __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("readline", 0);

  /* "axon/_objects.py":1066
 *     def readline(self):
 * 
 *         buffer = self.buffer             # <<<<<<<<<<<<<<
 *         pos = self.pos
 *         pos0 = self.pos
 */
  __pyx_t_1 = __pyx_v_self->buffer;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_buffer = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.py":1067
 * 
 *         buffer = self.buffer
 *         pos = self.pos             # <<<<<<<<<<<<<<
 *         pos0 = self.pos
 *         n = self.n
 */
  __pyx_t_2 = __pyx_v_self->pos;
  __pyx_v_pos = __pyx_t_2;

  /* "axon/_objects.py":1068
 *         buffer = self.buffer
 *         pos = self.pos
 *         pos0 = self.pos             # <<<<<<<<<<<<<<
 *         n = self.n
 * 
 */
  __pyx_t_2 = __pyx_v_self->pos;
  __pyx_v_pos0 = __pyx_t_2;

  /* "axon/_objects.py":1069
 *         pos = self.pos
 *         pos0 = self.pos
 *         n = self.n             # <<<<<<<<<<<<<<
 * 
 *         if pos >= n:
 */
  __pyx_t_2 = __pyx_v_self->n;
  __pyx_v_n = __pyx_t_2;

  /* "axon/_objects.py":1071
 *         n = self.n
 * 
 *         if pos >= n:             # <<<<<<<<<<<<<<
 *             return ''
 * 
 */
  __pyx_t_3 = ((__pyx_v_pos >= __pyx_v_n) != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.py":1072
 * 
 *         if pos >= n:
 *             return ''             # <<<<<<<<<<<<<<
 * 
 *         while 1:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u__17);
    __pyx_r = __pyx_kp_u__17;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":1074
 *             return ''
 * 
 *         while 1:             # <<<<<<<<<<<<<<
 *             if pos >= n:
 *                 line = c_unicode_substr(buffer, pos0, pos)
 */
  while (1) {

    /* "axon/_objects.py":1075
 * 
 *         while 1:
 *             if pos >= n:             # <<<<<<<<<<<<<<
 *                 line = c_unicode_substr(buffer, pos0, pos)
 *                 break
 */
    __pyx_t_3 = ((__pyx_v_pos >= __pyx_v_n) != 0);
    if (__pyx_t_3) {

      /* "axon/_objects.py":1076
 *         while 1:
 *             if pos >= n:
 *                 line = c_unicode_substr(buffer, pos0, pos)             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
      __pyx_t_1 = c_unicode_substr(__pyx_v_buffer, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1076; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_line = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "axon/_objects.py":1077
 *             if pos >= n:
 *                 line = c_unicode_substr(buffer, pos0, pos)
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             ch = c_unicode_char(buffer, pos)
 */
      goto __pyx_L5_break;
    }

    /* "axon/_objects.py":1079
 *                 break
 * 
 *             ch = c_unicode_char(buffer, pos)             # <<<<<<<<<<<<<<
 *             if ch == '\n':
 *                 pos += 1
 */
    __pyx_v_ch = c_unicode_char(__pyx_v_buffer, __pyx_v_pos);

    /* "axon/_objects.py":1092
 *                 line = c_unicode_substr(buffer, pos0, pos)
 *                 break
 *             elif ch == '\r':             # <<<<<<<<<<<<<<
 *                 pos += 1
 *                 if pos >= n:
 */
    switch (__pyx_v_ch) {

      /* "axon/_objects.py":1080
 * 
 *             ch = c_unicode_char(buffer, pos)
 *             if ch == '\n':             # <<<<<<<<<<<<<<
 *                 pos += 1
 *                 if pos >= n:
 */
      case 10:

      /* "axon/_objects.py":1081
 *             ch = c_unicode_char(buffer, pos)
 *             if ch == '\n':
 *                 pos += 1             # <<<<<<<<<<<<<<
 *                 if pos >= n:
 *                     line = c_unicode_substr(buffer, pos0, pos)
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_objects.py":1082
 *             if ch == '\n':
 *                 pos += 1
 *                 if pos >= n:             # <<<<<<<<<<<<<<
 *                     line = c_unicode_substr(buffer, pos0, pos)
 *                     break
 */
      __pyx_t_3 = ((__pyx_v_pos >= __pyx_v_n) != 0);
      if (__pyx_t_3) {

        /* "axon/_objects.py":1083
 *                 pos += 1
 *                 if pos >= n:
 *                     line = c_unicode_substr(buffer, pos0, pos)             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
        __pyx_t_1 = c_unicode_substr(__pyx_v_buffer, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1083; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_line = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "axon/_objects.py":1084
 *                 if pos >= n:
 *                     line = c_unicode_substr(buffer, pos0, pos)
 *                     break             # <<<<<<<<<<<<<<
 * 
 *                 ch = c_unicode_char(buffer, pos)
 */
        goto __pyx_L5_break;
      }

      /* "axon/_objects.py":1086
 *                     break
 * 
 *                 ch = c_unicode_char(buffer, pos)             # <<<<<<<<<<<<<<
 *                 if ch == '\r':
 *                     pos += 1
 */
      __pyx_v_ch = c_unicode_char(__pyx_v_buffer, __pyx_v_pos);

      /* "axon/_objects.py":1087
 * 
 *                 ch = c_unicode_char(buffer, pos)
 *                 if ch == '\r':             # <<<<<<<<<<<<<<
 *                     pos += 1
 * 
 */
      __pyx_t_3 = ((__pyx_v_ch == 13) != 0);
      if (__pyx_t_3) {

        /* "axon/_objects.py":1088
 *                 ch = c_unicode_char(buffer, pos)
 *                 if ch == '\r':
 *                     pos += 1             # <<<<<<<<<<<<<<
 * 
 *                 line = c_unicode_substr(buffer, pos0, pos)
 */
        __pyx_v_pos = (__pyx_v_pos + 1);
        goto __pyx_L8;
      }
      __pyx_L8:;

      /* "axon/_objects.py":1090
 *                     pos += 1
 * 
 *                 line = c_unicode_substr(buffer, pos0, pos)             # <<<<<<<<<<<<<<
 *                 break
 *             elif ch == '\r':
 */
      __pyx_t_1 = c_unicode_substr(__pyx_v_buffer, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1090; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_line = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "axon/_objects.py":1091
 * 
 *                 line = c_unicode_substr(buffer, pos0, pos)
 *                 break             # <<<<<<<<<<<<<<
 *             elif ch == '\r':
 *                 pos += 1
 */
      goto __pyx_L5_break;
      break;

      /* "axon/_objects.py":1092
 *                 line = c_unicode_substr(buffer, pos0, pos)
 *                 break
 *             elif ch == '\r':             # <<<<<<<<<<<<<<
 *                 pos += 1
 *                 if pos >= n:
 */
      case 13:

      /* "axon/_objects.py":1093
 *                 break
 *             elif ch == '\r':
 *                 pos += 1             # <<<<<<<<<<<<<<
 *                 if pos >= n:
 *                     line = c_unicode_substr(buffer, pos0, pos)
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_objects.py":1094
 *             elif ch == '\r':
 *                 pos += 1
 *                 if pos >= n:             # <<<<<<<<<<<<<<
 *                     line = c_unicode_substr(buffer, pos0, pos)
 *                     break
 */
      __pyx_t_3 = ((__pyx_v_pos >= __pyx_v_n) != 0);
      if (__pyx_t_3) {

        /* "axon/_objects.py":1095
 *                 pos += 1
 *                 if pos >= n:
 *                     line = c_unicode_substr(buffer, pos0, pos)             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
        __pyx_t_1 = c_unicode_substr(__pyx_v_buffer, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1095; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_line = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "axon/_objects.py":1096
 *                 if pos >= n:
 *                     line = c_unicode_substr(buffer, pos0, pos)
 *                     break             # <<<<<<<<<<<<<<
 * 
 *                 ch = c_unicode_char(buffer, pos)
 */
        goto __pyx_L5_break;
      }

      /* "axon/_objects.py":1098
 *                     break
 * 
 *                 ch = c_unicode_char(buffer, pos)             # <<<<<<<<<<<<<<
 *                 if ch == '\n':
 *                     pos += 1
 */
      __pyx_v_ch = c_unicode_char(__pyx_v_buffer, __pyx_v_pos);

      /* "axon/_objects.py":1099
 * 
 *                 ch = c_unicode_char(buffer, pos)
 *                 if ch == '\n':             # <<<<<<<<<<<<<<
 *                     pos += 1
 * 
 */
      __pyx_t_3 = ((__pyx_v_ch == 10) != 0);
      if (__pyx_t_3) {

        /* "axon/_objects.py":1100
 *                 ch = c_unicode_char(buffer, pos)
 *                 if ch == '\n':
 *                     pos += 1             # <<<<<<<<<<<<<<
 * 
 *                 line = c_unicode_substr(buffer, pos0, pos)
 */
        __pyx_v_pos = (__pyx_v_pos + 1);
        goto __pyx_L10;
      }
      __pyx_L10:;

      /* "axon/_objects.py":1102
 *                     pos += 1
 * 
 *                 line = c_unicode_substr(buffer, pos0, pos)             # <<<<<<<<<<<<<<
 *                 break
 *             else:
 */
      __pyx_t_1 = c_unicode_substr(__pyx_v_buffer, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_line = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "axon/_objects.py":1103
 * 
 *                 line = c_unicode_substr(buffer, pos0, pos)
 *                 break             # <<<<<<<<<<<<<<
 *             else:
 *                 pos += 1
 */
      goto __pyx_L5_break;
      break;
      default:

      /* "axon/_objects.py":1105
 *                 break
 *             else:
 *                 pos += 1             # <<<<<<<<<<<<<<
 *                 #ch = buffer[pos]
 * 
 */
      __pyx_v_pos = (__pyx_v_pos + 1);
      break;
    }
  }
  __pyx_L5_break:;

  /* "axon/_objects.py":1108
 *                 #ch = buffer[pos]
 * 
 *         self.pos = pos             # <<<<<<<<<<<<<<
 *         return line
 * 
 */
  __pyx_v_self->pos = __pyx_v_pos;

  /* "axon/_objects.py":1109
 * 
 *         self.pos = pos
 *         return line             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_line)) { __Pyx_RaiseUnboundLocalError("line"); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1109; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  __Pyx_INCREF(__pyx_v_line);
  __pyx_r = __pyx_v_line;
  goto __pyx_L0;

  /* "axon/_objects.py":1064
 *         self.n = len(text)
 * 
 *     def readline(self):             # <<<<<<<<<<<<<<
 * 
 *         buffer = self.buffer
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringReader.readline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_buffer);
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_12StringReader_3readline(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_12StringReader_3readline(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("readline (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_12StringReader_2readline(((struct __pyx_obj_4axon_8_objects_StringReader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_12StringReader_2readline(struct __pyx_obj_4axon_8_objects_StringReader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("readline", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_12StringReader_readline(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1064; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringReader.readline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1111
 *         return line
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         self.pos = self.n
 * 
 */

static PyObject *__pyx_pw_4axon_8_objects_12StringReader_5close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_12StringReader_close(struct __pyx_obj_4axon_8_objects_StringReader *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("close", 0);

  /* "axon/_objects.py":1112
 * 
 *     def close(self):
 *         self.pos = self.n             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_v_self->n;
  __pyx_v_self->pos = __pyx_t_1;

  /* "axon/_objects.py":1111
 *         return line
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         self.pos = self.n
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_12StringReader_5close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_12StringReader_5close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_12StringReader_4close(((struct __pyx_obj_4axon_8_objects_StringReader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_12StringReader_4close(struct __pyx_obj_4axon_8_objects_StringReader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("close", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_12StringReader_close(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringReader.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1117
 * class StringWriter:
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.blocks = []
 *         self.items = []
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_12StringWriter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_12StringWriter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_4axon_8_objects_12StringWriter___init__(((struct __pyx_obj_4axon_8_objects_StringWriter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_12StringWriter___init__(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":1118
 * 
 *     def __init__(self):
 *         self.blocks = []             # <<<<<<<<<<<<<<
 *         self.items = []
 *         self.n = 0
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->blocks);
  __Pyx_DECREF(__pyx_v_self->blocks);
  __pyx_v_self->blocks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":1119
 *     def __init__(self):
 *         self.blocks = []
 *         self.items = []             # <<<<<<<<<<<<<<
 *         self.n = 0
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->items);
  __Pyx_DECREF(__pyx_v_self->items);
  __pyx_v_self->items = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":1120
 *         self.blocks = []
 *         self.items = []
 *         self.n = 0             # <<<<<<<<<<<<<<
 * 
 *     def write(self, item):
 */
  __pyx_v_self->n = 0;

  /* "axon/_objects.py":1117
 * class StringWriter:
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.blocks = []
 *         self.items = []
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringWriter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1122
 *         self.n = 0
 * 
 *     def write(self, item):             # <<<<<<<<<<<<<<
 *         if self.n > 256:
 *             self.blocks.append(''.join(self.items))
 */

static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_3write(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_12StringWriter_write(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self, PyObject *__pyx_v_item, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("write", 0);

  /* "axon/_objects.py":1123
 * 
 *     def write(self, item):
 *         if self.n > 256:             # <<<<<<<<<<<<<<
 *             self.blocks.append(''.join(self.items))
 *             self.items = []
 */
  __pyx_t_1 = ((__pyx_v_self->n > 256) != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.py":1124
 *     def write(self, item):
 *         if self.n > 256:
 *             self.blocks.append(''.join(self.items))             # <<<<<<<<<<<<<<
 *             self.items = []
 *             self.n = 0
 */
    if (unlikely(__pyx_v_self->blocks == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __pyx_v_self->items;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__17, __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_self->blocks, __pyx_t_3); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_objects.py":1125
 *         if self.n > 256:
 *             self.blocks.append(''.join(self.items))
 *             self.items = []             # <<<<<<<<<<<<<<
 *             self.n = 0
 *         self.items.append(item)
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->items);
    __Pyx_DECREF(__pyx_v_self->items);
    __pyx_v_self->items = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_objects.py":1126
 *             self.blocks.append(''.join(self.items))
 *             self.items = []
 *             self.n = 0             # <<<<<<<<<<<<<<
 *         self.items.append(item)
 *         self.n += 1
 */
    __pyx_v_self->n = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_objects.py":1127
 *             self.items = []
 *             self.n = 0
 *         self.items.append(item)             # <<<<<<<<<<<<<<
 *         self.n += 1
 * 
 */
  if (unlikely(__pyx_v_self->items == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_self->items, __pyx_v_item); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":1128
 *             self.n = 0
 *         self.items.append(item)
 *         self.n += 1             # <<<<<<<<<<<<<<
 * 
 *     def getvalue(self):
 */
  __pyx_v_self->n = (__pyx_v_self->n + 1);

  /* "axon/_objects.py":1122
 *         self.n = 0
 * 
 *     def write(self, item):             # <<<<<<<<<<<<<<
 *         if self.n > 256:
 *             self.blocks.append(''.join(self.items))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.StringWriter.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_3write(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_3write(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_12StringWriter_2write(((struct __pyx_obj_4axon_8_objects_StringWriter *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_12StringWriter_2write(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("write", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_12StringWriter_write(__pyx_v_self, __pyx_v_item, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringWriter.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1130
 *         self.n += 1
 * 
 *     def getvalue(self):             # <<<<<<<<<<<<<<
 *         if self.items:
 *             self.blocks.append(''.join(self.items))
 */

static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_5getvalue(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_12StringWriter_getvalue(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getvalue", 0);

  /* "axon/_objects.py":1131
 * 
 *     def getvalue(self):
 *         if self.items:             # <<<<<<<<<<<<<<
 *             self.blocks.append(''.join(self.items))
 *             self.items = []
 */
  __pyx_t_1 = (__pyx_v_self->items != Py_None) && (PyList_GET_SIZE(__pyx_v_self->items) != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.py":1132
 *     def getvalue(self):
 *         if self.items:
 *             self.blocks.append(''.join(self.items))             # <<<<<<<<<<<<<<
 *             self.items = []
 *             self.n = 0
 */
    if (unlikely(__pyx_v_self->blocks == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __pyx_v_self->items;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__17, __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_self->blocks, __pyx_t_3); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_objects.py":1133
 *         if self.items:
 *             self.blocks.append(''.join(self.items))
 *             self.items = []             # <<<<<<<<<<<<<<
 *             self.n = 0
 *         return ''.join(self.blocks)
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->items);
    __Pyx_DECREF(__pyx_v_self->items);
    __pyx_v_self->items = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_objects.py":1134
 *             self.blocks.append(''.join(self.items))
 *             self.items = []
 *             self.n = 0             # <<<<<<<<<<<<<<
 *         return ''.join(self.blocks)
 * 
 */
    __pyx_v_self->n = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_objects.py":1135
 *             self.items = []
 *             self.n = 0
 *         return ''.join(self.blocks)             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_v_self->blocks;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__17, __pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1130
 *         self.n += 1
 * 
 *     def getvalue(self):             # <<<<<<<<<<<<<<
 *         if self.items:
 *             self.blocks.append(''.join(self.items))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.StringWriter.getvalue", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_5getvalue(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_5getvalue(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getvalue (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_12StringWriter_4getvalue(((struct __pyx_obj_4axon_8_objects_StringWriter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_12StringWriter_4getvalue(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getvalue", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_12StringWriter_getvalue(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringWriter.getvalue", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1137
 *         return ''.join(self.blocks)
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         self.items = []
 *         self.blocks = []
 */

static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_7close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_4axon_8_objects_12StringWriter_close(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("close", 0);

  /* "axon/_objects.py":1138
 * 
 *     def close(self):
 *         self.items = []             # <<<<<<<<<<<<<<
 *         self.blocks = []
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->items);
  __Pyx_DECREF(__pyx_v_self->items);
  __pyx_v_self->items = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":1139
 *     def close(self):
 *         self.items = []
 *         self.blocks = []             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->blocks);
  __Pyx_DECREF(__pyx_v_self->blocks);
  __pyx_v_self->blocks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":1137
 *         return ''.join(self.blocks)
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         self.items = []
 *         self.blocks = []
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringWriter.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_7close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_12StringWriter_7close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_12StringWriter_6close(((struct __pyx_obj_4axon_8_objects_StringWriter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_12StringWriter_6close(struct __pyx_obj_4axon_8_objects_StringWriter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("close", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_12StringWriter_close(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.StringWriter.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1146
 *     """Fixed offset in minutes east from UTC."""
 * 
 *     def __init__(self, offset, name=None):             # <<<<<<<<<<<<<<
 *         self.offset = offset
 *         self.name = name
 */

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8timezone_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_8_objects_8timezone_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_offset = 0;
  PyObject *__pyx_v_name = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_offset,&__pyx_n_s_name,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_offset)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1146; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_offset = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1146; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.timezone.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone___init__(((struct TimeZoneUTCObject *)__pyx_v_self), __pyx_v_offset, __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8timezone___init__(struct TimeZoneUTCObject *__pyx_v_self, PyObject *__pyx_v_offset, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_objects.py":1147
 * 
 *     def __init__(self, offset, name=None):
 *         self.offset = offset             # <<<<<<<<<<<<<<
 *         self.name = name
 * 
 */
  __Pyx_INCREF(__pyx_v_offset);
  __Pyx_GIVEREF(__pyx_v_offset);
  __Pyx_GOTREF(__pyx_v_self->offset);
  __Pyx_DECREF(__pyx_v_self->offset);
  __pyx_v_self->offset = __pyx_v_offset;

  /* "axon/_objects.py":1148
 *     def __init__(self, offset, name=None):
 *         self.offset = offset
 *         self.name = name             # <<<<<<<<<<<<<<
 * 
 *     def utcoffset(self, dt):
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_name;

  /* "axon/_objects.py":1146
 *     """Fixed offset in minutes east from UTC."""
 * 
 *     def __init__(self, offset, name=None):             # <<<<<<<<<<<<<<
 *         self.offset = offset
 *         self.name = name
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1150
 *         self.name = name
 * 
 *     def utcoffset(self, dt):             # <<<<<<<<<<<<<<
 *         return self.offset
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8timezone_3utcoffset(PyObject *__pyx_v_self, PyObject *__pyx_v_dt); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8timezone_3utcoffset(PyObject *__pyx_v_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("utcoffset (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_2utcoffset(((struct TimeZoneUTCObject *)__pyx_v_self), ((PyObject *)__pyx_v_dt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8timezone_2utcoffset(struct TimeZoneUTCObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("utcoffset", 0);

  /* "axon/_objects.py":1151
 * 
 *     def utcoffset(self, dt):
 *         return self.offset             # <<<<<<<<<<<<<<
 * 
 *     def tzname(self, dt):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->offset);
  __pyx_r = __pyx_v_self->offset;
  goto __pyx_L0;

  /* "axon/_objects.py":1150
 *         self.name = name
 * 
 *     def utcoffset(self, dt):             # <<<<<<<<<<<<<<
 *         return self.offset
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1153
 *         return self.offset
 * 
 *     def tzname(self, dt):             # <<<<<<<<<<<<<<
 *         seconds = self.offset.seconds + self.offset.days * 24 * 60 * 60
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8timezone_5tzname(PyObject *__pyx_v_self, PyObject *__pyx_v_dt); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8timezone_5tzname(PyObject *__pyx_v_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tzname (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_4tzname(((struct TimeZoneUTCObject *)__pyx_v_self), ((PyObject *)__pyx_v_dt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8timezone_4tzname(struct TimeZoneUTCObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt) {
  PyObject *__pyx_v_seconds = NULL;
  PyObject *__pyx_v_sign = NULL;
  PyObject *__pyx_v_minutes = NULL;
  PyObject *__pyx_v_hours = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tzname", 0);

  /* "axon/_objects.py":1154
 * 
 *     def tzname(self, dt):
 *         seconds = self.offset.seconds + self.offset.days * 24 * 60 * 60             # <<<<<<<<<<<<<<
 * 
 *         if seconds < 0:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->offset, __pyx_n_s_seconds); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->offset, __pyx_n_s_days); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_int_24); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_3, __pyx_int_60); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_int_60); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_seconds = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_objects.py":1156
 *         seconds = self.offset.seconds + self.offset.days * 24 * 60 * 60
 * 
 *         if seconds < 0:             # <<<<<<<<<<<<<<
 *             seconds = -seconds
 *             sign = '-'
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_seconds, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "axon/_objects.py":1157
 * 
 *         if seconds < 0:
 *             seconds = -seconds             # <<<<<<<<<<<<<<
 *             sign = '-'
 *         else:
 */
    __pyx_t_2 = PyNumber_Negative(__pyx_v_seconds); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_seconds, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "axon/_objects.py":1158
 *         if seconds < 0:
 *             seconds = -seconds
 *             sign = '-'             # <<<<<<<<<<<<<<
 *         else:
 *             sign = '+'
 */
    __Pyx_INCREF(__pyx_kp_u__18);
    __pyx_v_sign = __pyx_kp_u__18;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.py":1160
 *             sign = '-'
 *         else:
 *             sign = '+'             # <<<<<<<<<<<<<<
 * 
 *         minutes, seconds = builtins.divmod(seconds, 60)
 */
    __Pyx_INCREF(__pyx_kp_u__19);
    __pyx_v_sign = __pyx_kp_u__19;
  }
  __pyx_L3:;

  /* "axon/_objects.py":1162
 *             sign = '+'
 * 
 *         minutes, seconds = builtins.divmod(seconds, 60)             # <<<<<<<<<<<<<<
 *         hours, minutes = builtins.divmod(minutes, 60)
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_builtins); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_divmod); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_seconds);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_seconds);
  __Pyx_GIVEREF(__pyx_v_seconds);
  __Pyx_INCREF(__pyx_int_60);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_60);
  __Pyx_GIVEREF(__pyx_int_60);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_minutes = __pyx_t_2;
  __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_seconds, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_objects.py":1163
 * 
 *         minutes, seconds = builtins.divmod(seconds, 60)
 *         hours, minutes = builtins.divmod(minutes, 60)             # <<<<<<<<<<<<<<
 * 
 *         if minutes:
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_builtins); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_divmod); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_minutes);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_minutes);
  __Pyx_GIVEREF(__pyx_v_minutes);
  __Pyx_INCREF(__pyx_int_60);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_60);
  __Pyx_GIVEREF(__pyx_int_60);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_1)) goto __pyx_L6_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L6_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L7_unpacking_done;
    __pyx_L6_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L7_unpacking_done:;
  }
  __pyx_v_hours = __pyx_t_1;
  __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_minutes, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_objects.py":1165
 *         hours, minutes = builtins.divmod(minutes, 60)
 * 
 *         if minutes:             # <<<<<<<<<<<<<<
 *             return 'UTC%s%02d:%02d' % (sign, hours, minutes)
 *         else:
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_minutes); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_4) {

    /* "axon/_objects.py":1166
 * 
 *         if minutes:
 *             return 'UTC%s%02d:%02d' % (sign, hours, minutes)             # <<<<<<<<<<<<<<
 *         else:
 *             return 'UTC%s%02d' % (sign, hours)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_sign);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_sign);
    __Pyx_GIVEREF(__pyx_v_sign);
    __Pyx_INCREF(__pyx_v_hours);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_hours);
    __Pyx_GIVEREF(__pyx_v_hours);
    __Pyx_INCREF(__pyx_v_minutes);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_minutes);
    __Pyx_GIVEREF(__pyx_v_minutes);
    __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_UTC_s_02d_02d, __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":1168
 *             return 'UTC%s%02d:%02d' % (sign, hours, minutes)
 *         else:
 *             return 'UTC%s%02d' % (sign, hours)             # <<<<<<<<<<<<<<
 * 
 *     def dst(self, dt):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_sign);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_sign);
    __Pyx_GIVEREF(__pyx_v_sign);
    __Pyx_INCREF(__pyx_v_hours);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_hours);
    __Pyx_GIVEREF(__pyx_v_hours);
    __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_UTC_s_02d, __pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":1153
 *         return self.offset
 * 
 *     def tzname(self, dt):             # <<<<<<<<<<<<<<
 *         seconds = self.offset.seconds + self.offset.days * 24 * 60 * 60
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._objects.timezone.tzname", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_seconds);
  __Pyx_XDECREF(__pyx_v_sign);
  __Pyx_XDECREF(__pyx_v_minutes);
  __Pyx_XDECREF(__pyx_v_hours);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1170
 *             return 'UTC%s%02d' % (sign, hours)
 * 
 *     def dst(self, dt):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8timezone_7dst(PyObject *__pyx_v_self, PyObject *__pyx_v_dt); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8timezone_7dst(PyObject *__pyx_v_self, PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dst (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_6dst(((struct TimeZoneUTCObject *)__pyx_v_self), ((PyObject *)__pyx_v_dt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8timezone_6dst(CYTHON_UNUSED struct TimeZoneUTCObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dst", 0);

  /* "axon/_objects.py":1171
 * 
 *     def dst(self, dt):
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def __richcmp__(self, other, op):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "axon/_objects.py":1170
 *             return 'UTC%s%02d' % (sign, hours)
 * 
 *     def dst(self, dt):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1173
 *         return None
 * 
 *     def __richcmp__(self, other, op):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, tzinfo):
 *             raise TypeError('Invalid type: expected `tzinfo` instance')
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8timezone_9__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_arg_op); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8timezone_9__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_arg_op) {
  PyObject *__pyx_v_op = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__richcmp__ (wrapper)", 0);
  __pyx_v_op = __Pyx_PyInt_From_int(__pyx_arg_op); if (unlikely(!__pyx_v_op)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1173; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __Pyx_GOTREF(__pyx_v_op);
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._objects.timezone.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_8__richcmp__(((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_other), ((PyObject *)__pyx_v_op));

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8timezone_8__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_op) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__richcmp__", 0);

  /* "axon/_objects.py":1174
 * 
 *     def __richcmp__(self, other, op):
 *         if not isinstance(other, tzinfo):             # <<<<<<<<<<<<<<
 *             raise TypeError('Invalid type: expected `tzinfo` instance')
 * 
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, ((PyObject*)__pyx_ptype_7cpython_8datetime_tzinfo)); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.py":1175
 *     def __richcmp__(self, other, op):
 *         if not isinstance(other, tzinfo):
 *             raise TypeError('Invalid type: expected `tzinfo` instance')             # <<<<<<<<<<<<<<
 * 
 *         if op == 0:
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1175; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1175; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_objects.py":1177
 *             raise TypeError('Invalid type: expected `tzinfo` instance')
 * 
 *         if op == 0:             # <<<<<<<<<<<<<<
 *             return self.offset < other.offset
 *         elif op == 1:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_op, __pyx_int_0, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.py":1178
 * 
 *         if op == 0:
 *             return self.offset < other.offset             # <<<<<<<<<<<<<<
 *         elif op == 1:
 *             return self.offset <= other.offset
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_offset); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":1179
 *         if op == 0:
 *             return self.offset < other.offset
 *         elif op == 1:             # <<<<<<<<<<<<<<
 *             return self.offset <= other.offset
 *         elif op == 2:
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_op, __pyx_int_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.py":1180
 *             return self.offset < other.offset
 *         elif op == 1:
 *             return self.offset <= other.offset             # <<<<<<<<<<<<<<
 *         elif op == 2:
 *             return self.offset == other.offset
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_offset); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":1181
 *         elif op == 1:
 *             return self.offset <= other.offset
 *         elif op == 2:             # <<<<<<<<<<<<<<
 *             return self.offset == other.offset
 *         elif op == 3:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_op, __pyx_int_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.py":1182
 *             return self.offset <= other.offset
 *         elif op == 2:
 *             return self.offset == other.offset             # <<<<<<<<<<<<<<
 *         elif op == 3:
 *             return self.offset != other.offset
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_offset); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":1183
 *         elif op == 2:
 *             return self.offset == other.offset
 *         elif op == 3:             # <<<<<<<<<<<<<<
 *             return self.offset != other.offset
 *         elif op == 4:
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_op, __pyx_int_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.py":1184
 *             return self.offset == other.offset
 *         elif op == 3:
 *             return self.offset != other.offset             # <<<<<<<<<<<<<<
 *         elif op == 4:
 *             return self.offset > other.offset
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_offset); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":1185
 *         elif op == 3:
 *             return self.offset != other.offset
 *         elif op == 4:             # <<<<<<<<<<<<<<
 *             return self.offset > other.offset
 *         else:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_op, __pyx_int_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.py":1186
 *             return self.offset != other.offset
 *         elif op == 4:
 *             return self.offset > other.offset             # <<<<<<<<<<<<<<
 *         else:
 *             return self.offset >= other.offset
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_offset); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_t_4, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":1188
 *             return self.offset > other.offset
 *         else:
 *             return self.offset >= other.offset             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_offset); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":1173
 *         return None
 * 
 *     def __richcmp__(self, other, op):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, tzinfo):
 *             raise TypeError('Invalid type: expected `tzinfo` instance')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._objects.timezone.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1190
 *             return self.offset >= other.offset
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.tzname(None)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8timezone_11__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8timezone_11__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_10__str__(((struct TimeZoneUTCObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8timezone_10__str__(struct TimeZoneUTCObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "axon/_objects.py":1191
 * 
 *     def __str__(self):
 *         return self.tzname(None)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_tzname); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_objects.py":1190
 *             return self.offset >= other.offset
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.tzname(None)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._objects.timezone.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.py":1193
 *         return self.tzname(None)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         if self.name:
 *             return "timezone(%r, %s)" % (self.offset, self.name)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8timezone_13__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8timezone_13__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_12__repr__(((struct TimeZoneUTCObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8timezone_12__repr__(struct TimeZoneUTCObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_objects.py":1194
 * 
 *     def __repr__(self):
 *         if self.name:             # <<<<<<<<<<<<<<
 *             return "timezone(%r, %s)" % (self.offset, self.name)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->name); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_1) {

    /* "axon/_objects.py":1195
 *     def __repr__(self):
 *         if self.name:
 *             return "timezone(%r, %s)" % (self.offset, self.name)             # <<<<<<<<<<<<<<
 *         else:
 *             return "timezone(%r)" % (self.offset,)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_self->offset);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->offset);
    __Pyx_GIVEREF(__pyx_v_self->offset);
    __Pyx_INCREF(__pyx_v_self->name);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->name);
    __Pyx_GIVEREF(__pyx_v_self->name);
    __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_timezone_r_s, __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.py":1197
 *             return "timezone(%r, %s)" % (self.offset, self.name)
 *         else:
 *             return "timezone(%r)" % (self.offset,)             # <<<<<<<<<<<<<<
 * 
 * # class Context(object):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1197; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_self->offset);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->offset);
    __Pyx_GIVEREF(__pyx_v_self->offset);
    __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_timezone_r, __pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1197; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.py":1193
 *         return self.tzname(None)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         if self.name:
 *             return "timezone(%r, %s)" % (self.offset, self.name)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._objects.timezone.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":421
 *     """Fixed offset in minutes east from UTC."""
 * 
 *     cdef public object offset             # <<<<<<<<<<<<<<
 *     cdef public object name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8timezone_6offset_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8timezone_6offset_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_6offset___get__(((struct TimeZoneUTCObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8timezone_6offset___get__(struct TimeZoneUTCObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->offset);
  __pyx_r = __pyx_v_self->offset;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8timezone_6offset_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_8timezone_6offset_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_6offset_2__set__(((struct TimeZoneUTCObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8timezone_6offset_2__set__(struct TimeZoneUTCObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->offset);
  __Pyx_DECREF(__pyx_v_self->offset);
  __pyx_v_self->offset = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8timezone_6offset_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_8timezone_6offset_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_6offset_4__del__(((struct TimeZoneUTCObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8timezone_6offset_4__del__(struct TimeZoneUTCObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->offset);
  __Pyx_DECREF(__pyx_v_self->offset);
  __pyx_v_self->offset = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":422
 * 
 *     cdef public object offset
 *     cdef public object name             # <<<<<<<<<<<<<<
 * 
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_8_objects_8timezone_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_8_objects_8timezone_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_4name___get__(((struct TimeZoneUTCObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_8_objects_8timezone_4name___get__(struct TimeZoneUTCObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8timezone_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_8_objects_8timezone_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_4name_2__set__(((struct TimeZoneUTCObject *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8timezone_4name_2__set__(struct TimeZoneUTCObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_8_objects_8timezone_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_8_objects_8timezone_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_8_objects_8timezone_4name_4__del__(((struct TimeZoneUTCObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_8_objects_8timezone_4name_4__del__(struct TimeZoneUTCObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":104
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("import_datetime", 0);

  /* "cpython/datetime.pxd":105
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():
 *     PyDateTime_IMPORT             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DateTime CAPI factory function.
 */
  PyDateTime_IMPORT;

  /* "cpython/datetime.pxd":104
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "cpython/datetime.pxd":109
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_date_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_new", 0);

  /* "cpython/datetime.pxd":110
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object date_new(int year, int month, int day):
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)             # <<<<<<<<<<<<<<
 * 
 * # Create time object using DateTime CAPI factory function
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Date_FromDate(__pyx_v_year, __pyx_v_month, __pyx_v_day, PyDateTimeAPI->DateType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":109
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.date_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":114
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object time_new(int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI.TimeType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_new(int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("time_new", 0);

  /* "cpython/datetime.pxd":115
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object time_new(int hour, int minute, int second, int microsecond, object tz):
 *     return PyDateTimeAPI.Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI.TimeType)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Time_FromTime(__pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, PyDateTimeAPI->TimeType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":114
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object time_new(int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI.TimeType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.time_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":119
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromDateAndTime(year, month, day, hour, minute, second, microsecond, tz, PyDateTimeAPI.DateTimeType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day, int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_new", 0);

  /* "cpython/datetime.pxd":120
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz):
 *     return PyDateTimeAPI.DateTime_FromDateAndTime(year, month, day, hour, minute, second, microsecond, tz, PyDateTimeAPI.DateTimeType)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->DateTime_FromDateAndTime(__pyx_v_year, __pyx_v_month, __pyx_v_day, __pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, PyDateTimeAPI->DateTimeType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":119
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromDateAndTime(year, month, day, hour, minute, second, microsecond, tz, PyDateTimeAPI.DateTimeType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.datetime_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":124
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timedelta_new(int __pyx_v_days, int __pyx_v_seconds, int __pyx_v_useconds) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timedelta_new", 0);

  /* "cpython/datetime.pxd":125
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object timedelta_new(int days, int seconds, int useconds):
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)             # <<<<<<<<<<<<<<
 * 
 * # More recognizable getters for date/time/datetime/timedelta.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Delta_FromDelta(__pyx_v_days, __pyx_v_seconds, __pyx_v_useconds, 1, PyDateTimeAPI->DeltaType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":124
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.timedelta_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":133
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_Time*>o).hastzinfo:
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("time_tzinfo", 0);

  /* "cpython/datetime.pxd":134
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):
 *     if (<PyDateTime_Time*>o).hastzinfo:             # <<<<<<<<<<<<<<
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 *     else:
 */
  __pyx_t_1 = (((PyDateTime_Time *)__pyx_v_o)->hastzinfo != 0);
  if (__pyx_t_1) {

    /* "cpython/datetime.pxd":135
 * cdef inline object time_tzinfo(object o):
 *     if (<PyDateTime_Time*>o).hastzinfo:
 *         return <object>(<PyDateTime_Time*>o).tzinfo             # <<<<<<<<<<<<<<
 *     else:
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)((PyDateTime_Time *)__pyx_v_o)->tzinfo));
    __pyx_r = ((PyObject *)((PyDateTime_Time *)__pyx_v_o)->tzinfo);
    goto __pyx_L0;
  }
  /*else*/ {

    /* "cpython/datetime.pxd":137
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of datetime
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }

  /* "cpython/datetime.pxd":133
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_Time*>o).hastzinfo:
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":140
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_DateTime*>o).hastzinfo:
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("datetime_tzinfo", 0);

  /* "cpython/datetime.pxd":141
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):
 *     if (<PyDateTime_DateTime*>o).hastzinfo:             # <<<<<<<<<<<<<<
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 *     else:
 */
  __pyx_t_1 = (((PyDateTime_DateTime *)__pyx_v_o)->hastzinfo != 0);
  if (__pyx_t_1) {

    /* "cpython/datetime.pxd":142
 * cdef inline object datetime_tzinfo(object o):
 *     if (<PyDateTime_DateTime*>o).hastzinfo:
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo             # <<<<<<<<<<<<<<
 *     else:
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)((PyDateTime_DateTime *)__pyx_v_o)->tzinfo));
    __pyx_r = ((PyObject *)((PyDateTime_DateTime *)__pyx_v_o)->tzinfo);
    goto __pyx_L0;
  }
  /*else*/ {

    /* "cpython/datetime.pxd":144
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * # Get year of date
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }

  /* "cpython/datetime.pxd":140
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_DateTime*>o).hastzinfo:
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":147
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_year(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_year", 0);

  /* "cpython/datetime.pxd":148
 * # Get year of date
 * cdef inline int date_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of date
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":147
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":151
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_month(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_month", 0);

  /* "cpython/datetime.pxd":152
 * # Get month of date
 * cdef inline int date_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of date
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":151
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":155
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_day(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_day", 0);

  /* "cpython/datetime.pxd":156
 * # Get day of date
 * cdef inline int date_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of datetime
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":155
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":159
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_year(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_year", 0);

  /* "cpython/datetime.pxd":160
 * # Get year of datetime
 * cdef inline int datetime_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of datetime
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":159
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":163
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_month(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_month", 0);

  /* "cpython/datetime.pxd":164
 * # Get month of datetime
 * cdef inline int datetime_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of datetime
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":163
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":167
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_day(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_day", 0);

  /* "cpython/datetime.pxd":168
 * # Get day of datetime
 * cdef inline int datetime_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of time
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":167
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":171
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_hour(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_hour", 0);

  /* "cpython/datetime.pxd":172
 * # Get hour of time
 * cdef inline int time_hour(object o):
 *     return PyDateTime_TIME_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of time
 */
  __pyx_r = PyDateTime_TIME_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":171
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":175
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_minute(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_minute", 0);

  /* "cpython/datetime.pxd":176
 * # Get minute of time
 * cdef inline int time_minute(object o):
 *     return PyDateTime_TIME_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of time
 */
  __pyx_r = PyDateTime_TIME_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":175
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":179
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_second(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_second", 0);

  /* "cpython/datetime.pxd":180
 * # Get second of time
 * cdef inline int time_second(object o):
 *     return PyDateTime_TIME_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of time
 */
  __pyx_r = PyDateTime_TIME_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":179
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":183
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_microsecond", 0);

  /* "cpython/datetime.pxd":184
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):
 *     return PyDateTime_TIME_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of datetime
 */
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":183
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":187
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_hour(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_hour", 0);

  /* "cpython/datetime.pxd":188
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):
 *     return PyDateTime_DATE_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":187
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":191
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_minute(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_minute", 0);

  /* "cpython/datetime.pxd":192
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):
 *     return PyDateTime_DATE_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":191
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":195
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_second(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_second", 0);

  /* "cpython/datetime.pxd":196
 * # Get second of datetime
 * cdef inline int datetime_second(object o):
 *     return PyDateTime_DATE_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":195
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":199
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_microsecond", 0);

  /* "cpython/datetime.pxd":200
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):
 *     return PyDateTime_DATE_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get days of timedelta
 */
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":199
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":203
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_days(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_days", 0);

  /* "cpython/datetime.pxd":204
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):
 *     return (<PyDateTime_Delta*>o).days             # <<<<<<<<<<<<<<
 * 
 * # Get seconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->days;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":203
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":207
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_seconds(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_seconds", 0);

  /* "cpython/datetime.pxd":208
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):
 *     return (<PyDateTime_Delta*>o).seconds             # <<<<<<<<<<<<<<
 * 
 * # Get microseconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->seconds;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":207
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":211
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_microseconds(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_microseconds", 0);

  /* "cpython/datetime.pxd":212
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):
 *     return (<PyDateTime_Delta*>o).microseconds             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->microseconds;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":211
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":80
 * #        return <object>val
 * 
 * cdef inline dict c_as_dict(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is dict:
 *         return <dict>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_dict(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_dict", 0);

  /* "axon/_objects.pxd":81
 * 
 * cdef inline dict c_as_dict(object ob):
 *     if type(ob) is dict:             # <<<<<<<<<<<<<<
 *         return <dict>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyDict_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":82
 * cdef inline dict c_as_dict(object ob):
 *     if type(ob) is dict:
 *         return <dict>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return {}
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_ob));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":83
 *     if type(ob) is dict:
 *         return <dict>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return {}
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":84
 *         return <dict>ob
 *     elif ob is None:
 *         return {}             # <<<<<<<<<<<<<<
 *     else:
 *         return dict(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.pxd":86
 *         return {}
 *     else:
 *         return dict(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline list c_as_list(object ob):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyDict_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":80
 * #        return <object>val
 * 
 * cdef inline dict c_as_dict(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is dict:
 *         return <dict>ob
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":88
 *         return dict(ob)
 * 
 * cdef inline list c_as_list(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is list:
 *         return <list>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_list(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_list", 0);

  /* "axon/_objects.pxd":89
 * 
 * cdef inline list c_as_list(object ob):
 *     if type(ob) is list:             # <<<<<<<<<<<<<<
 *         return <list>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyList_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":90
 * cdef inline list c_as_list(object ob):
 *     if type(ob) is list:
 *         return <list>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_ob));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":91
 *     if type(ob) is list:
 *         return <list>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return []
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":92
 *         return <list>ob
 *     elif ob is None:
 *         return []             # <<<<<<<<<<<<<<
 *     else:
 *         return list(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.pxd":94
 *         return []
 *     else:
 *         return list(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple c_as_tuple(object ob):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyList_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":88
 *         return dict(ob)
 * 
 * cdef inline list c_as_list(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is list:
 *         return <list>ob
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":96
 *         return list(ob)
 * 
 * cdef inline tuple c_as_tuple(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is tuple:
 *         return <tuple>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_tuple(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_tuple", 0);

  /* "axon/_objects.pxd":97
 * 
 * cdef inline tuple c_as_tuple(object ob):
 *     if type(ob) is tuple:             # <<<<<<<<<<<<<<
 *         return <tuple>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyTuple_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":98
 * cdef inline tuple c_as_tuple(object ob):
 *     if type(ob) is tuple:
 *         return <tuple>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_ob));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":99
 *     if type(ob) is tuple:
 *         return <tuple>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return ()
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":100
 *         return <tuple>ob
 *     elif ob is None:
 *         return ()             # <<<<<<<<<<<<<<
 *     else:
 *         return tuple(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.pxd":102
 *         return ()
 *     else:
 *         return tuple(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline unicode c_as_unicode(object ob):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyTuple_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":96
 *         return list(ob)
 * 
 * cdef inline tuple c_as_tuple(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is tuple:
 *         return <tuple>ob
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":104
 *         return tuple(ob)
 * 
 * cdef inline unicode c_as_unicode(object ob):             # <<<<<<<<<<<<<<
 *     tp = type(ob)
 *     if tp is unicode:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_unicode(PyObject *__pyx_v_ob) {
  PyObject *__pyx_v_tp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_unicode", 0);

  /* "axon/_objects.pxd":105
 * 
 * cdef inline unicode c_as_unicode(object ob):
 *     tp = type(ob)             # <<<<<<<<<<<<<<
 *     if tp is unicode:
 *         return <unicode>ob
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_ob)));
  __pyx_v_tp = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_ob)));

  /* "axon/_objects.pxd":106
 * cdef inline unicode c_as_unicode(object ob):
 *     tp = type(ob)
 *     if tp is unicode:             # <<<<<<<<<<<<<<
 *         return <unicode>ob
 *     elif tp == c_str_type:
 */
  __pyx_t_1 = (__pyx_v_tp == ((PyObject*)(&PyUnicode_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":107
 *     tp = type(ob)
 *     if tp is unicode:
 *         return <unicode>ob             # <<<<<<<<<<<<<<
 *     elif tp == c_str_type:
 *         return c_object_to_unicode(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_ob));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":108
 *     if tp is unicode:
 *         return <unicode>ob
 *     elif tp == c_str_type:             # <<<<<<<<<<<<<<
 *         return c_object_to_unicode(ob)
 *     elif ob is None:
 */
  __pyx_t_3 = PyObject_RichCompare(((PyObject *)__pyx_v_tp), __pyx_v_4axon_8_objects_c_str_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":109
 *         return <unicode>ob
 *     elif tp == c_str_type:
 *         return c_object_to_unicode(ob)             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return c_object_to_unicode('')
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = c_object_to_unicode(__pyx_v_ob); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":110
 *     elif tp == c_str_type:
 *         return c_object_to_unicode(ob)
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return c_object_to_unicode('')
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":111
 *         return c_object_to_unicode(ob)
 *     elif ob is None:
 *         return c_object_to_unicode('')             # <<<<<<<<<<<<<<
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = c_object_to_unicode(__pyx_kp_s__17); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.pxd":113
 *         return c_object_to_unicode('')
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline unicode c_as_name(object name):
 */
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_This_object_r_is_not_unicode_com, __pyx_v_ob); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_objects.pxd":104
 *         return tuple(ob)
 * 
 * cdef inline unicode c_as_unicode(object ob):             # <<<<<<<<<<<<<<
 *     tp = type(ob)
 *     if tp is unicode:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_unicode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":115
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 * 
 * cdef inline unicode c_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_name(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_uname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_name", 0);

  /* "axon/_objects.pxd":116
 * 
 * cdef inline unicode c_as_name(object name):
 *     n = name_cache.get(name, None)             # <<<<<<<<<<<<<<
 *     if n is None:
 *         uname = c_as_unicode(name)
 */
  if (unlikely(__pyx_v_4axon_8_objects_name_cache == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_name_cache, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.pxd":117
 * cdef inline unicode c_as_name(object name):
 *     n = name_cache.get(name, None)
 *     if n is None:             # <<<<<<<<<<<<<<
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 */
  __pyx_t_2 = (__pyx_v_n == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.pxd":118
 *     n = name_cache.get(name, None)
 *     if n is None:
 *         uname = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *         name_cache[name] = uname
 *     elif name is None:
 */
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.pxd":119
 *     if n is None:
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname             # <<<<<<<<<<<<<<
 *     elif name is None:
 *         uname = empty_name
 */
    if (unlikely(__pyx_v_4axon_8_objects_name_cache == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(__pyx_v_4axon_8_objects_name_cache, __pyx_v_name, __pyx_v_uname) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":120
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 *     elif name is None:             # <<<<<<<<<<<<<<
 *         uname = empty_name
 *     else:
 */
  __pyx_t_3 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":121
 *         name_cache[name] = uname
 *     elif name is None:
 *         uname = empty_name             # <<<<<<<<<<<<<<
 *     else:
 *         uname = n
 */
    __Pyx_INCREF(__pyx_v_4axon_8_objects_empty_name);
    __pyx_v_uname = __pyx_v_4axon_8_objects_empty_name;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":123
 *         uname = empty_name
 *     else:
 *         uname = n             # <<<<<<<<<<<<<<
 *     return uname
 * 
 */
    __Pyx_INCREF(__pyx_v_n);
    __pyx_v_uname = __pyx_v_n;
  }
  __pyx_L3:;

  /* "axon/_objects.pxd":124
 *     else:
 *         uname = n
 *     return uname             # <<<<<<<<<<<<<<
 * 
 * cdef inline object py_as_name(object name):
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_uname))||((__pyx_v_uname) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_uname)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_uname);
  __pyx_r = ((PyObject*)__pyx_v_uname);
  goto __pyx_L0;

  /* "axon/_objects.pxd":115
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 * 
 * cdef inline unicode c_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_uname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":126
 *     return uname
 * 
 * cdef inline object py_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_py_as_name(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_uname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_as_name", 0);

  /* "axon/_objects.pxd":127
 * 
 * cdef inline object py_as_name(object name):
 *     n = name_cache.get(name, None)             # <<<<<<<<<<<<<<
 *     if n is None:
 *         uname = c_as_unicode(name)
 */
  if (unlikely(__pyx_v_4axon_8_objects_name_cache == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_name_cache, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.pxd":128
 * cdef inline object py_as_name(object name):
 *     n = name_cache.get(name, None)
 *     if n is None:             # <<<<<<<<<<<<<<
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 */
  __pyx_t_2 = (__pyx_v_n == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.pxd":129
 *     n = name_cache.get(name, None)
 *     if n is None:
 *         uname = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *         name_cache[name] = uname
 *     elif name is None:
 */
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.pxd":130
 *     if n is None:
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname             # <<<<<<<<<<<<<<
 *     elif name is None:
 *         uname = empty_name
 */
    if (unlikely(__pyx_v_4axon_8_objects_name_cache == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(__pyx_v_4axon_8_objects_name_cache, __pyx_v_name, __pyx_v_uname) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":131
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 *     elif name is None:             # <<<<<<<<<<<<<<
 *         uname = empty_name
 *     else:
 */
  __pyx_t_3 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":132
 *         name_cache[name] = uname
 *     elif name is None:
 *         uname = empty_name             # <<<<<<<<<<<<<<
 *     else:
 *         uname = n
 */
    __Pyx_INCREF(__pyx_v_4axon_8_objects_empty_name);
    __pyx_v_uname = __pyx_v_4axon_8_objects_empty_name;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":134
 *         uname = empty_name
 *     else:
 *         uname = n             # <<<<<<<<<<<<<<
 *     return uname
 * 
 */
    __Pyx_INCREF(__pyx_v_n);
    __pyx_v_uname = __pyx_v_n;
  }
  __pyx_L3:;

  /* "axon/_objects.pxd":135
 *     else:
 *         uname = n
 *     return uname             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_uname);
  __pyx_r = __pyx_v_uname;
  goto __pyx_L0;

  /* "axon/_objects.pxd":126
 *     return uname
 * 
 * cdef inline object py_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.py_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_uname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":351
 * cdef dict c_builder_dict
 * 
 * cdef inline Builder c_get_builder(object mode):             # <<<<<<<<<<<<<<
 *     return <Builder>c_builder_dict.get(mode, None)
 * 
 */

static CYTHON_INLINE struct __pyx_obj_4axon_8_objects_Builder *__pyx_f_4axon_8_objects_c_get_builder(PyObject *__pyx_v_mode) {
  struct __pyx_obj_4axon_8_objects_Builder *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_get_builder", 0);

  /* "axon/_objects.pxd":352
 * 
 * cdef inline Builder c_get_builder(object mode):
 *     return <Builder>c_builder_dict.get(mode, None)             # <<<<<<<<<<<<<<
 * 
 * cpdef Builder get_builder(object)
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_4axon_8_objects_c_builder_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_builder_dict, __pyx_v_mode, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)((struct __pyx_obj_4axon_8_objects_Builder *)__pyx_t_1)));
  __pyx_r = ((struct __pyx_obj_4axon_8_objects_Builder *)__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.pxd":351
 * cdef dict c_builder_dict
 * 
 * cdef inline Builder c_get_builder(object mode):             # <<<<<<<<<<<<<<
 *     return <Builder>c_builder_dict.get(mode, None)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_get_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_4axon_8_objects_Undefined(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Undefined(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_4axon_8_objects_Undefined[] = {
  {0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) UndefinedType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Undefined"), /*tp_name*/
  sizeof(struct UndefinedObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Undefined, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_9Undefined_1__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_4axon_8_objects_9Undefined_3__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_Undefined, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Undefined, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_rdict(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = (&PyDict_Type)->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_rdict(PyObject *o) {
  PyObject_GC_UnTrack(o);
  PyObject_GC_Track(o);
  (&PyDict_Type)->tp_dealloc(o);
}

static int __pyx_tp_traverse_4axon_8_objects_rdict(PyObject *o, visitproc v, void *a) {
  int e;
  if (!(&PyDict_Type)->tp_traverse); else { e = (&PyDict_Type)->tp_traverse(o,v,a); if (e) return e; }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_rdict(PyObject *o) {
  if (!(&PyDict_Type)->tp_clear); else (&PyDict_Type)->tp_clear(o);
  return 0;
}

static int __pyx_mp_ass_subscript_4axon_8_objects_rdict(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_4axon_8_objects_5rdict_1__setitem__(o, i, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_5rdict_5__delitem__(o, i);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_rdict[] = {
  {__Pyx_NAMESTR("setdefault"), (PyCFunction)__pyx_pw_4axon_8_objects_5rdict_3setdefault, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyMappingMethods __pyx_tp_as_mapping_rdict = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  __pyx_mp_ass_subscript_4axon_8_objects_rdict, /*mp_ass_subscript*/
};

DL_EXPORT(PyTypeObject) ReadonlyDictType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.rdict"), /*tp_name*/
  sizeof(struct ReadonlyDict), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_rdict, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_rdict, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_rdict, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_rdict, /*tp_clear*/
  __pyx_pw_4axon_8_objects_5rdict_7__richcmp__, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_rdict, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_rdict, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_rlist(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = (&PyList_Type)->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_rlist(PyObject *o) {
  PyObject_GC_UnTrack(o);
  PyObject_GC_Track(o);
  (&PyList_Type)->tp_dealloc(o);
}

static int __pyx_tp_traverse_4axon_8_objects_rlist(PyObject *o, visitproc v, void *a) {
  int e;
  if (!(&PyList_Type)->tp_traverse); else { e = (&PyList_Type)->tp_traverse(o,v,a); if (e) return e; }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_rlist(PyObject *o) {
  if (!(&PyList_Type)->tp_clear); else (&PyList_Type)->tp_clear(o);
  return 0;
}

static int __pyx_mp_ass_subscript_4axon_8_objects_rlist(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_4axon_8_objects_5rlist_1__setitem__(o, i, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_5rlist_3__delitem__(o, i);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_rlist[] = {
  {0, 0, 0, 0}
};

static PyMappingMethods __pyx_tp_as_mapping_rlist = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  __pyx_mp_ass_subscript_4axon_8_objects_rlist, /*mp_ass_subscript*/
};

DL_EXPORT(PyTypeObject) ReadonlyListType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.rlist"), /*tp_name*/
  sizeof(struct ReadonlyList), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_rlist, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_rlist, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_rlist, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_rlist, /*tp_clear*/
  __pyx_pw_4axon_8_objects_5rlist_5__richcmp__, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_rlist, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_rlist, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_NamedValue(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_8_objects_NamedValue *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_8_objects_NamedValue *)o);
  p->__name__ = Py_None; Py_INCREF(Py_None);
  p->__value__ = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_NamedValue(PyObject *o) {
  struct __pyx_obj_4axon_8_objects_NamedValue *p = (struct __pyx_obj_4axon_8_objects_NamedValue *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__name__);
  Py_CLEAR(p->__value__);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_NamedValue(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_8_objects_NamedValue *p = (struct __pyx_obj_4axon_8_objects_NamedValue *)o;
  if (p->__name__) {
    e = (*v)(p->__name__, a); if (e) return e;
  }
  if (p->__value__) {
    e = (*v)(p->__value__, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_NamedValue(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4axon_8_objects_NamedValue *p = (struct __pyx_obj_4axon_8_objects_NamedValue *)o;
  tmp = ((PyObject*)p->__name__);
  p->__name__ = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__value__);
  p->__value__ = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_4axon_8_objects_NamedValue(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_4axon_8_objects_NamedValue(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_4axon_8_objects_10NamedValue_5__setitem__(o, i, v);
  }
  else {
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by %.200s", Py_TYPE(o)->tp_name);
    return -1;
  }
}

static PyObject *__pyx_tp_getattro_4axon_8_objects_NamedValue(PyObject *o, PyObject *n) {
  PyObject *v = PyObject_GenericGetAttr(o, n);
  if (!v && PyErr_ExceptionMatches(PyExc_AttributeError)) {
    PyErr_Clear();
    v = __pyx_pw_4axon_8_objects_10NamedValue_7__getattr__(o, n);
  }
  return v;
}

static PyObject *__pyx_getprop_4axon_8_objects_10NamedValue___name__(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_10NamedValue_8__name___1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_10NamedValue___name__(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_10NamedValue_8__name___3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_10NamedValue_8__name___5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_10NamedValue___value__(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_10NamedValue_9__value___1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_10NamedValue___value__(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_10NamedValue_9__value___3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_10NamedValue_9__value___5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_NamedValue[] = {
  {__Pyx_NAMESTR("__getattr__"), (PyCFunction)__pyx_pw_4axon_8_objects_10NamedValue_7__getattr__, METH_O|METH_COEXIST, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("__isinstancecheck__"), (PyCFunction)__pyx_pw_4axon_8_objects_10NamedValue_9__isinstancecheck__, METH_O, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_NamedValue[] = {
  {(char *)"__name__", __pyx_getprop_4axon_8_objects_10NamedValue___name__, __pyx_setprop_4axon_8_objects_10NamedValue___name__, 0, 0},
  {(char *)"__value__", __pyx_getprop_4axon_8_objects_10NamedValue___value__, __pyx_setprop_4axon_8_objects_10NamedValue___value__, 0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_NamedValue = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_4axon_8_objects_NamedValue, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_NamedValue = {
  0, /*mp_length*/
  __pyx_pw_4axon_8_objects_10NamedValue_3__getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_4axon_8_objects_NamedValue, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_4axon_8_objects_NamedValue = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.NamedValue"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_8_objects_NamedValue), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_NamedValue, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_NamedValue, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_NamedValue, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  __pyx_tp_getattro_4axon_8_objects_NamedValue, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_NamedValue, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_NamedValue, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_NamedValue, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_NamedValue, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_10NamedValue_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_NamedValue, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_Attribute(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct Attribute *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct Attribute *)o);
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->value = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Attribute(PyObject *o) {
  struct Attribute *p = (struct Attribute *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  Py_CLEAR(p->value);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_Attribute(PyObject *o, visitproc v, void *a) {
  int e;
  struct Attribute *p = (struct Attribute *)o;
  if (p->value) {
    e = (*v)(p->value, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_Attribute(PyObject *o) {
  PyObject* tmp;
  struct Attribute *p = (struct Attribute *)o;
  tmp = ((PyObject*)p->value);
  p->value = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_4axon_8_objects_Attribute(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_getprop_4axon_8_objects_9Attribute_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_9Attribute_4name_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_9Attribute_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_9Attribute_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_9Attribute_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_9Attribute_value(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_9Attribute_5value_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_9Attribute_value(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_9Attribute_5value_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_9Attribute_5value_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_Attribute[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_Attribute[] = {
  {(char *)"name", __pyx_getprop_4axon_8_objects_9Attribute_name, __pyx_setprop_4axon_8_objects_9Attribute_name, 0, 0},
  {(char *)"value", __pyx_getprop_4axon_8_objects_9Attribute_value, __pyx_setprop_4axon_8_objects_9Attribute_value, 0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_Attribute = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_4axon_8_objects_Attribute, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Attribute = {
  0, /*mp_length*/
  __pyx_pw_4axon_8_objects_9Attribute_3__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

DL_EXPORT(PyTypeObject) AttributeType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Attribute"), /*tp_name*/
  sizeof(struct Attribute), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Attribute, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_9Attribute_5__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Attribute, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Attribute, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_Attribute, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_Attribute, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_Attribute, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_Attribute, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_9Attribute_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Attribute, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_Attrs(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_8_objects_Attrs *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_8_objects_Attrs *)o);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Attrs(PyObject *o) {
  struct __pyx_obj_4axon_8_objects_Attrs *p = (struct __pyx_obj_4axon_8_objects_Attrs *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->mapping);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_Attrs(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_8_objects_Attrs *p = (struct __pyx_obj_4axon_8_objects_Attrs *)o;
  if (p->mapping) {
    e = (*v)(p->mapping, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_Attrs(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4axon_8_objects_Attrs *p = (struct __pyx_obj_4axon_8_objects_Attrs *)o;
  tmp = ((PyObject*)p->mapping);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_4axon_8_objects_Attrs(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_tp_getattro_4axon_8_objects_Attrs(PyObject *o, PyObject *n) {
  PyObject *v = PyObject_GenericGetAttr(o, n);
  if (!v && PyErr_ExceptionMatches(PyExc_AttributeError)) {
    PyErr_Clear();
    v = __pyx_pw_4axon_8_objects_5Attrs_1__getattr__(o, n);
  }
  return v;
}

static PyObject *__pyx_getprop_4axon_8_objects_5Attrs_mapping(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_5Attrs_7mapping_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_5Attrs_mapping(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_5Attrs_7mapping_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_5Attrs_7mapping_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_Attrs[] = {
  {__Pyx_NAMESTR("__getattr__"), (PyCFunction)__pyx_pw_4axon_8_objects_5Attrs_1__getattr__, METH_O|METH_COEXIST, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_Attrs[] = {
  {(char *)"mapping", __pyx_getprop_4axon_8_objects_5Attrs_mapping, __pyx_setprop_4axon_8_objects_5Attrs_mapping, 0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_Attrs = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_4axon_8_objects_Attrs, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Attrs = {
  0, /*mp_length*/
  __pyx_pw_4axon_8_objects_5Attrs_3__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_4axon_8_objects_Attrs = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Attrs"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_8_objects_Attrs), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Attrs, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_5Attrs_5__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Attrs, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Attrs, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  __pyx_tp_getattro_4axon_8_objects_Attrs, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_Attrs, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_Attrs, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_Attrs, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_Attrs, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Attrs, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_Empty(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct EmptyObject *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct EmptyObject *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Empty(PyObject *o) {
  struct EmptyObject *p = (struct EmptyObject *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_Empty(PyObject *o, visitproc v, void *a) {
  int e;
  struct EmptyObject *p = (struct EmptyObject *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_Empty(PyObject *o) {
  PyObject* tmp;
  struct EmptyObject *p = (struct EmptyObject *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_4axon_8_objects_5Empty_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_5Empty_4name_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_5Empty_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_5Empty_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_5Empty_4name_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_Empty[] = {
  {__Pyx_NAMESTR("mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_5Empty_1mapping, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_5Empty_3sequence, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("a"), (PyCFunction)__pyx_pw_4axon_8_objects_5Empty_5a, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_5Empty_11as_mapping, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_5Empty_13as_sequence, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_element"), (PyCFunction)__pyx_pw_4axon_8_objects_5Empty_15as_element, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_instance"), (PyCFunction)__pyx_pw_4axon_8_objects_5Empty_17as_instance, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_Empty[] = {
  {(char *)"name", __pyx_getprop_4axon_8_objects_5Empty_name, __pyx_setprop_4axon_8_objects_5Empty_name, 0, 0},
  {0, 0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) EmptyType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Empty"), /*tp_name*/
  sizeof(struct EmptyObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Empty, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_5Empty_9__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    Empty named complex value.\n\n    .. py:attribute:: _name\n\n    Name of complex value\n\n    .. py:attribute:: _mapping\n\n    Dictionary of attributes.\n\n    .. py:attribute:: _sequence\n\n    List of values.\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_Empty, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_Empty, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_Empty, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_Empty, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_5Empty_7__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Empty, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_Sequence(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct SequenceObject *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct SequenceObject *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  p->sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Sequence(PyObject *o) {
  struct SequenceObject *p = (struct SequenceObject *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  Py_CLEAR(p->sequence);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_Sequence(PyObject *o, visitproc v, void *a) {
  int e;
  struct SequenceObject *p = (struct SequenceObject *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  if (p->sequence) {
    e = (*v)(p->sequence, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_Sequence(PyObject *o) {
  PyObject* tmp;
  struct SequenceObject *p = (struct SequenceObject *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sequence);
  p->sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_4axon_8_objects_Sequence(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_4axon_8_objects_Sequence(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8Sequence_9__setitem__(o, i, v);
  }
  else {
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by %.200s", Py_TYPE(o)->tp_name);
    return -1;
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_8Sequence_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_8Sequence_4name_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_8Sequence_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8Sequence_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_8Sequence_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_8Sequence_sequence(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_8Sequence_8sequence_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_8Sequence_sequence(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8Sequence_8sequence_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_8Sequence_8sequence_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_Sequence[] = {
  {__Pyx_NAMESTR("mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_8Sequence_1mapping, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("a"), (PyCFunction)__pyx_pw_4axon_8_objects_8Sequence_3a, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_8Sequence_13as_mapping, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_8Sequence_15as_sequence, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_element"), (PyCFunction)__pyx_pw_4axon_8_objects_8Sequence_17as_element, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_instance"), (PyCFunction)__pyx_pw_4axon_8_objects_8Sequence_19as_instance, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_Sequence[] = {
  {(char *)"name", __pyx_getprop_4axon_8_objects_8Sequence_name, __pyx_setprop_4axon_8_objects_8Sequence_name, 0, 0},
  {(char *)"sequence", __pyx_getprop_4axon_8_objects_8Sequence_sequence, __pyx_setprop_4axon_8_objects_8Sequence_sequence, 0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_Sequence = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_4axon_8_objects_Sequence, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Sequence = {
  0, /*mp_length*/
  __pyx_pw_4axon_8_objects_8Sequence_7__getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_4axon_8_objects_Sequence, /*mp_ass_subscript*/
};

DL_EXPORT(PyTypeObject) SequenceType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Sequence"), /*tp_name*/
  sizeof(struct SequenceObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Sequence, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_8Sequence_11__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Sequence, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Sequence, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    Named sequence of values.\n\n    .. py:attribute:: _name\n\n    Name of sequence.\n\n    .. py:attribute:: _mapping\n\n    Empty dictionary of attributes.\n\n    .. py:attribute:: _sequence\n\n    List of values.\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_Sequence, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_Sequence, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_Sequence, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_Sequence, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_8Sequence_5__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Sequence, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_Mapping(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct MappingObject *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct MappingObject *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Mapping(PyObject *o) {
  struct MappingObject *p = (struct MappingObject *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  Py_CLEAR(p->mapping);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_Mapping(PyObject *o, visitproc v, void *a) {
  int e;
  struct MappingObject *p = (struct MappingObject *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  if (p->mapping) {
    e = (*v)(p->mapping, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_Mapping(PyObject *o) {
  PyObject* tmp;
  struct MappingObject *p = (struct MappingObject *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->mapping);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_4axon_8_objects_7Mapping_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_7Mapping_4name_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_7Mapping_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_7Mapping_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_7Mapping_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_7Mapping_mapping(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_7Mapping_7mapping_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_7Mapping_mapping(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_7Mapping_7mapping_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_7Mapping_7mapping_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_Mapping[] = {
  {__Pyx_NAMESTR("sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_1sequence, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("a"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_3a, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_7get, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("set"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_9set, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("update"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_11update, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_17as_mapping, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_19as_sequence, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_element"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_21as_element, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_instance"), (PyCFunction)__pyx_pw_4axon_8_objects_7Mapping_23as_instance, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_Mapping[] = {
  {(char *)"name", __pyx_getprop_4axon_8_objects_7Mapping_name, __pyx_setprop_4axon_8_objects_7Mapping_name, 0, 0},
  {(char *)"mapping", __pyx_getprop_4axon_8_objects_7Mapping_mapping, __pyx_setprop_4axon_8_objects_7Mapping_mapping, 0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_Mapping = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_4axon_8_objects_7Mapping_13__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

DL_EXPORT(PyTypeObject) MappingType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Mapping"), /*tp_name*/
  sizeof(struct MappingObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Mapping, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_7Mapping_15__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Mapping, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    Named mapping containing pairs of `name`/`value`.\n\n    .. py:attribute:: _name\n\n    Name of mapping\n\n    .. py:attribute:: _mapping\n\n    Mapping containing pairs of name: value.\n\n    .. py:attribute:: _sequence\n\n    Empty list of values.\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_Mapping, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_Mapping, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_Mapping, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_Mapping, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_7Mapping_5__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Mapping, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_Element(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct ElementObject *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct ElementObject *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Element(PyObject *o) {
  struct ElementObject *p = (struct ElementObject *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  Py_CLEAR(p->mapping);
  Py_CLEAR(p->sequence);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_Element(PyObject *o, visitproc v, void *a) {
  int e;
  struct ElementObject *p = (struct ElementObject *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  if (p->mapping) {
    e = (*v)(p->mapping, a); if (e) return e;
  }
  if (p->sequence) {
    e = (*v)(p->sequence, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_Element(PyObject *o) {
  PyObject* tmp;
  struct ElementObject *p = (struct ElementObject *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->mapping);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sequence);
  p->sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_4axon_8_objects_Element(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_4axon_8_objects_Element(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_4axon_8_objects_7Element_7__setitem__(o, i, v);
  }
  else {
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by %.200s", Py_TYPE(o)->tp_name);
    return -1;
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_7Element_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_7Element_4name_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_7Element_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_7Element_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_7Element_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_7Element_mapping(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_7Element_7mapping_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_7Element_mapping(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_7Element_7mapping_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_7Element_7mapping_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_7Element_sequence(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_7Element_8sequence_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_7Element_sequence(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_7Element_8sequence_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_7Element_8sequence_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_Element[] = {
  {__Pyx_NAMESTR("a"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_1a, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_11get, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("set"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_13set, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("update"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_15update, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("append"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_17append, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("extend"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_19extend, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_23as_mapping, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_25as_sequence, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_element"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_27as_element, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_instance"), (PyCFunction)__pyx_pw_4axon_8_objects_7Element_29as_instance, METH_NOARGS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_Element[] = {
  {(char *)"name", __pyx_getprop_4axon_8_objects_7Element_name, __pyx_setprop_4axon_8_objects_7Element_name, 0, 0},
  {(char *)"mapping", __pyx_getprop_4axon_8_objects_7Element_mapping, __pyx_setprop_4axon_8_objects_7Element_mapping, 0, 0},
  {(char *)"sequence", __pyx_getprop_4axon_8_objects_7Element_sequence, __pyx_setprop_4axon_8_objects_7Element_sequence, 0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_Element = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_4axon_8_objects_Element, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_4axon_8_objects_7Element_9__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Element = {
  0, /*mp_length*/
  __pyx_pw_4axon_8_objects_7Element_5__getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_4axon_8_objects_Element, /*mp_ass_subscript*/
};

DL_EXPORT(PyTypeObject) ElementType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Element"), /*tp_name*/
  sizeof(struct ElementObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Element, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_7Element_21__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Element, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Element, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    Named mapping containing list of values.\n\n    .. py:attribute:: _name\n\n    Name of element\n\n    .. py:attribute:: _mapping\n\n    Mapping containing pairs of `name`/`value`.\n\n    .. py:attribute:: _sequence\n\n    Child list of values.\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_Element, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_Element, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_Element, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_Element, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_7Element_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Element, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_Instance(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct InstanceObject *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct InstanceObject *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  p->sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Instance(PyObject *o) {
  struct InstanceObject *p = (struct InstanceObject *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  Py_CLEAR(p->sequence);
  Py_CLEAR(p->mapping);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_Instance(PyObject *o, visitproc v, void *a) {
  int e;
  struct InstanceObject *p = (struct InstanceObject *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  if (p->sequence) {
    e = (*v)(p->sequence, a); if (e) return e;
  }
  if (p->mapping) {
    e = (*v)(p->mapping, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_Instance(PyObject *o) {
  PyObject* tmp;
  struct InstanceObject *p = (struct InstanceObject *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sequence);
  p->sequence = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->mapping);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_4axon_8_objects_Instance(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_4axon_8_objects_Instance(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8Instance_7__setitem__(o, i, v);
  }
  else {
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by %.200s", Py_TYPE(o)->tp_name);
    return -1;
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_8Instance_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_8Instance_4name_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_8Instance_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8Instance_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_8Instance_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_8Instance_sequence(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_8Instance_8sequence_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_8Instance_sequence(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8Instance_8sequence_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_8Instance_8sequence_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_8Instance_mapping(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_8Instance_7mapping_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_8Instance_mapping(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8Instance_7mapping_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_8Instance_7mapping_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_Instance[] = {
  {__Pyx_NAMESTR("a"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_1a, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_9get, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("set"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_11set, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("update"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_13update, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("append"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_15append, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("extend"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_17extend, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_mapping"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_21as_mapping, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_sequence"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_23as_sequence, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_element"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_25as_element, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("as_instance"), (PyCFunction)__pyx_pw_4axon_8_objects_8Instance_27as_instance, METH_NOARGS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_Instance[] = {
  {(char *)"name", __pyx_getprop_4axon_8_objects_8Instance_name, __pyx_setprop_4axon_8_objects_8Instance_name, 0, 0},
  {(char *)"sequence", __pyx_getprop_4axon_8_objects_8Instance_sequence, __pyx_setprop_4axon_8_objects_8Instance_sequence, 0, 0},
  {(char *)"mapping", __pyx_getprop_4axon_8_objects_8Instance_mapping, __pyx_setprop_4axon_8_objects_8Instance_mapping, 0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_Instance = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_4axon_8_objects_Instance, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Instance = {
  0, /*mp_length*/
  __pyx_pw_4axon_8_objects_8Instance_5__getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_4axon_8_objects_Instance, /*mp_ass_subscript*/
};

DL_EXPORT(PyTypeObject) InstanceType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Instance"), /*tp_name*/
  sizeof(struct InstanceObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Instance, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_8Instance_19__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Instance, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Instance, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    Named sequence containing pairs of name: value.\n\n    .. py:attribute:: _name\n\n    Name of object.\n\n    .. py:attribute:: _mapping\n\n    Mapping containing optional values in form of `name`: `value` pairs.\n\n    .. py:attribute:: _sequence\n\n    List of requiered values.\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_Instance, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_Instance, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_Instance, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_Instance, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_8Instance_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Instance, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_vtable_4axon_8_objects_Builder;

static PyObject *__pyx_tp_new_4axon_8_objects_Builder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_8_objects_Builder *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_8_objects_Builder *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_8_objects_Builder;
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_Builder(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyTypeObject __pyx_type_4axon_8_objects_Builder = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.Builder"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_8_objects_Builder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Builder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_Builder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_8_objects_SafeBuilder __pyx_vtable_4axon_8_objects_SafeBuilder;

static PyObject *__pyx_tp_new_4axon_8_objects_SafeBuilder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4axon_8_objects_SafeBuilder *p;
  PyObject *o = __pyx_tp_new_4axon_8_objects_Builder(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_8_objects_SafeBuilder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4axon_8_objects_Builder*)__pyx_vtabptr_4axon_8_objects_SafeBuilder;
  return o;
}

static PyTypeObject __pyx_type_4axon_8_objects_SafeBuilder = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.SafeBuilder"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_8_objects_SafeBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Builder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_SafeBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_8_objects_StrictBuilder __pyx_vtable_4axon_8_objects_StrictBuilder;

static PyObject *__pyx_tp_new_4axon_8_objects_StrictBuilder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4axon_8_objects_StrictBuilder *p;
  PyObject *o = __pyx_tp_new_4axon_8_objects_Builder(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_8_objects_StrictBuilder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4axon_8_objects_Builder*)__pyx_vtabptr_4axon_8_objects_StrictBuilder;
  return o;
}

static PyTypeObject __pyx_type_4axon_8_objects_StrictBuilder = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.StrictBuilder"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_8_objects_StrictBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Builder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_StrictBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_8_objects_MixedBuilder __pyx_vtable_4axon_8_objects_MixedBuilder;

static PyObject *__pyx_tp_new_4axon_8_objects_MixedBuilder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_4axon_8_objects_MixedBuilder *p;
  PyObject *o = __pyx_tp_new_4axon_8_objects_Builder(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_8_objects_MixedBuilder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4axon_8_objects_Builder*)__pyx_vtabptr_4axon_8_objects_MixedBuilder;
  p->builder = ((struct __pyx_obj_4axon_8_objects_SafeBuilder *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_MixedBuilder(PyObject *o) {
  struct __pyx_obj_4axon_8_objects_MixedBuilder *p = (struct __pyx_obj_4axon_8_objects_MixedBuilder *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->builder);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (PyType_IS_GC(Py_TYPE(o)->tp_base))
  #endif
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_4axon_8_objects_Builder(o);
}

static int __pyx_tp_traverse_4axon_8_objects_MixedBuilder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_8_objects_MixedBuilder *p = (struct __pyx_obj_4axon_8_objects_MixedBuilder *)o;
  e = ((likely(__pyx_ptype_4axon_8_objects_Builder)) ? ((__pyx_ptype_4axon_8_objects_Builder->tp_traverse) ? __pyx_ptype_4axon_8_objects_Builder->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_4axon_8_objects_MixedBuilder)); if (e) return e;
  if (p->builder) {
    e = (*v)(((PyObject*)p->builder), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_MixedBuilder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4axon_8_objects_MixedBuilder *p = (struct __pyx_obj_4axon_8_objects_MixedBuilder *)o;
  if (likely(__pyx_ptype_4axon_8_objects_Builder)) { if (__pyx_ptype_4axon_8_objects_Builder->tp_clear) __pyx_ptype_4axon_8_objects_Builder->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_4axon_8_objects_MixedBuilder);
  tmp = ((PyObject*)p->builder);
  p->builder = ((struct __pyx_obj_4axon_8_objects_SafeBuilder *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_8_objects_MixedBuilder[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_8_objects_MixedBuilder = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.MixedBuilder"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_8_objects_MixedBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_MixedBuilder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_MixedBuilder, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_MixedBuilder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_MixedBuilder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_12MixedBuilder_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_MixedBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_8_objects_GenericBuilder __pyx_vtable_4axon_8_objects_GenericBuilder;

static PyObject *__pyx_tp_new_4axon_8_objects_GenericBuilder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct GenericBuilderObject *p;
  PyObject *o = __pyx_tp_new_4axon_8_objects_Builder(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct GenericBuilderObject *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_4axon_8_objects_Builder*)__pyx_vtabptr_4axon_8_objects_GenericBuilder;
  return o;
}

DL_EXPORT(PyTypeObject) GenericBuilderType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.GenericBuilder"), /*tp_name*/
  sizeof(struct GenericBuilderObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_Builder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_GenericBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_8_objects_SimpleBuilder __pyx_vtable_4axon_8_objects_SimpleBuilder;

static PyObject *__pyx_tp_new_4axon_8_objects_SimpleBuilder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct SimpleBuilder *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct SimpleBuilder *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_8_objects_SimpleBuilder;
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_SimpleBuilder(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

DL_EXPORT(PyTypeObject) SimpleBuilderType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.SimpleBuilder"), /*tp_name*/
  sizeof(struct SimpleBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_SimpleBuilder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_SimpleBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_8_objects_StringReader __pyx_vtable_4axon_8_objects_StringReader;

static PyObject *__pyx_tp_new_4axon_8_objects_StringReader(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_8_objects_StringReader *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_8_objects_StringReader *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_8_objects_StringReader;
  p->buffer = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_StringReader(PyObject *o) {
  struct __pyx_obj_4axon_8_objects_StringReader *p = (struct __pyx_obj_4axon_8_objects_StringReader *)o;
  Py_CLEAR(p->buffer);
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_4axon_8_objects_StringReader[] = {
  {__Pyx_NAMESTR("readline"), (PyCFunction)__pyx_pw_4axon_8_objects_12StringReader_3readline, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("close"), (PyCFunction)__pyx_pw_4axon_8_objects_12StringReader_5close, METH_NOARGS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_8_objects_StringReader = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.StringReader"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_8_objects_StringReader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_StringReader, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_StringReader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_12StringReader_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_StringReader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_8_objects_StringWriter __pyx_vtable_4axon_8_objects_StringWriter;

static PyObject *__pyx_tp_new_4axon_8_objects_StringWriter(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_8_objects_StringWriter *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_8_objects_StringWriter *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_8_objects_StringWriter;
  p->blocks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->items = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_StringWriter(PyObject *o) {
  struct __pyx_obj_4axon_8_objects_StringWriter *p = (struct __pyx_obj_4axon_8_objects_StringWriter *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->blocks);
  Py_CLEAR(p->items);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_8_objects_StringWriter(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_8_objects_StringWriter *p = (struct __pyx_obj_4axon_8_objects_StringWriter *)o;
  if (p->blocks) {
    e = (*v)(p->blocks, a); if (e) return e;
  }
  if (p->items) {
    e = (*v)(p->items, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_StringWriter(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4axon_8_objects_StringWriter *p = (struct __pyx_obj_4axon_8_objects_StringWriter *)o;
  tmp = ((PyObject*)p->blocks);
  p->blocks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->items);
  p->items = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_8_objects_StringWriter[] = {
  {__Pyx_NAMESTR("write"), (PyCFunction)__pyx_pw_4axon_8_objects_12StringWriter_3write, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("getvalue"), (PyCFunction)__pyx_pw_4axon_8_objects_12StringWriter_5getvalue, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("close"), (PyCFunction)__pyx_pw_4axon_8_objects_12StringWriter_7close, METH_NOARGS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_8_objects_StringWriter = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.StringWriter"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_8_objects_StringWriter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_StringWriter, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_StringWriter, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_StringWriter, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_StringWriter, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_12StringWriter_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_StringWriter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_8_objects_timezone(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct TimeZoneUTCObject *p;
  PyObject *o = __pyx_ptype_7cpython_8datetime_tzinfo->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct TimeZoneUTCObject *)o);
  p->offset = Py_None; Py_INCREF(Py_None);
  p->name = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_8_objects_timezone(PyObject *o) {
  struct TimeZoneUTCObject *p = (struct TimeZoneUTCObject *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->offset);
  Py_CLEAR(p->name);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (PyType_IS_GC(Py_TYPE(o)->tp_base))
  #endif
  PyObject_GC_Track(o);
  if (likely(__pyx_ptype_7cpython_8datetime_tzinfo)) __pyx_ptype_7cpython_8datetime_tzinfo->tp_dealloc(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_4axon_8_objects_timezone);
}

static int __pyx_tp_traverse_4axon_8_objects_timezone(PyObject *o, visitproc v, void *a) {
  int e;
  struct TimeZoneUTCObject *p = (struct TimeZoneUTCObject *)o;
  e = ((likely(__pyx_ptype_7cpython_8datetime_tzinfo)) ? ((__pyx_ptype_7cpython_8datetime_tzinfo->tp_traverse) ? __pyx_ptype_7cpython_8datetime_tzinfo->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_4axon_8_objects_timezone)); if (e) return e;
  if (p->offset) {
    e = (*v)(p->offset, a); if (e) return e;
  }
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_8_objects_timezone(PyObject *o) {
  PyObject* tmp;
  struct TimeZoneUTCObject *p = (struct TimeZoneUTCObject *)o;
  if (likely(__pyx_ptype_7cpython_8datetime_tzinfo)) { if (__pyx_ptype_7cpython_8datetime_tzinfo->tp_clear) __pyx_ptype_7cpython_8datetime_tzinfo->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_4axon_8_objects_timezone);
  tmp = ((PyObject*)p->offset);
  p->offset = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_4axon_8_objects_8timezone_offset(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_8timezone_6offset_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_8timezone_offset(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8timezone_6offset_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_8timezone_6offset_5__del__(o);
  }
}

static PyObject *__pyx_getprop_4axon_8_objects_8timezone_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_8_objects_8timezone_4name_1__get__(o);
}

static int __pyx_setprop_4axon_8_objects_8timezone_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_8_objects_8timezone_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_8_objects_8timezone_4name_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_8_objects_timezone[] = {
  {__Pyx_NAMESTR("utcoffset"), (PyCFunction)__pyx_pw_4axon_8_objects_8timezone_3utcoffset, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("tzname"), (PyCFunction)__pyx_pw_4axon_8_objects_8timezone_5tzname, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("dst"), (PyCFunction)__pyx_pw_4axon_8_objects_8timezone_7dst, METH_O, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_8_objects_timezone[] = {
  {(char *)"offset", __pyx_getprop_4axon_8_objects_8timezone_offset, __pyx_setprop_4axon_8_objects_8timezone_offset, 0, 0},
  {(char *)"name", __pyx_getprop_4axon_8_objects_8timezone_name, __pyx_setprop_4axon_8_objects_8timezone_name, 0, 0},
  {0, 0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) TimeZoneUTCType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._objects.timezone"), /*tp_name*/
  sizeof(struct TimeZoneUTCObject), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_8_objects_timezone, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_8_objects_8timezone_13__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_4axon_8_objects_8timezone_11__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("Fixed offset in minutes east from UTC."), /*tp_doc*/
  __pyx_tp_traverse_4axon_8_objects_timezone, /*tp_traverse*/
  __pyx_tp_clear_4axon_8_objects_timezone, /*tp_clear*/
  __pyx_pw_4axon_8_objects_8timezone_9__richcmp__, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_8_objects_timezone, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_8_objects_timezone, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_8_objects_8timezone_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_8_objects_timezone, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {__Pyx_NAMESTR("named"), (PyCFunction)__pyx_pw_4axon_8_objects_21named, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("new_attribute"), (PyCFunction)__pyx_pw_4axon_8_objects_23new_attribute, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_builder"), (PyCFunction)__pyx_pw_4axon_8_objects_41get_builder, METH_O, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    __Pyx_NAMESTR("_objects"),
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
  {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
  {&__pyx_kp_u_Element_Mapping_convertion_isn_t, __pyx_k_Element_Mapping_convertion_isn_t, sizeof(__pyx_k_Element_Mapping_convertion_isn_t), 0, 1, 0, 0},
  {&__pyx_kp_u_Element_Sequence_convertion_isn, __pyx_k_Element_Sequence_convertion_isn, sizeof(__pyx_k_Element_Sequence_convertion_isn), 0, 1, 0, 0},
  {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
  {&__pyx_kp_u_Index_out_of_range, __pyx_k_Index_out_of_range, sizeof(__pyx_k_Index_out_of_range), 0, 1, 0, 0},
  {&__pyx_n_u_Infinity, __pyx_k_Infinity, sizeof(__pyx_k_Infinity), 0, 1, 0, 1},
  {&__pyx_kp_u_Infinity_2, __pyx_k_Infinity_2, sizeof(__pyx_k_Infinity_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Instance_Mapping_convertion_isn, __pyx_k_Instance_Mapping_convertion_isn, sizeof(__pyx_k_Instance_Mapping_convertion_isn), 0, 1, 0, 0},
  {&__pyx_kp_u_Instance_Sequence_convertion_isn, __pyx_k_Instance_Sequence_convertion_isn, sizeof(__pyx_k_Instance_Sequence_convertion_isn), 0, 1, 0, 0},
  {&__pyx_kp_u_Invalid_name_r, __pyx_k_Invalid_name_r, sizeof(__pyx_k_Invalid_name_r), 0, 1, 0, 0},
  {&__pyx_kp_u_Invalid_type_expected_tzinfo_ins, __pyx_k_Invalid_type_expected_tzinfo_ins, sizeof(__pyx_k_Invalid_type_expected_tzinfo_ins), 0, 1, 0, 0},
  {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
  {&__pyx_kp_u_Mapping_Sequence_convertion_isn, __pyx_k_Mapping_Sequence_convertion_isn, sizeof(__pyx_k_Mapping_Sequence_convertion_isn), 0, 1, 0, 0},
  {&__pyx_n_u_NaN, __pyx_k_NaN, sizeof(__pyx_k_NaN), 0, 1, 0, 1},
  {&__pyx_kp_u_Object_r_contains_an_empty_mappi, __pyx_k_Object_r_contains_an_empty_mappi, sizeof(__pyx_k_Object_r_contains_an_empty_mappi), 0, 1, 0, 0},
  {&__pyx_kp_u_Object_r_contains_an_empty_seque, __pyx_k_Object_r_contains_an_empty_seque, sizeof(__pyx_k_Object_r_contains_an_empty_seque), 0, 1, 0, 0},
  {&__pyx_kp_u_Readonly_object_type_r_don_t_sup, __pyx_k_Readonly_object_type_r_don_t_sup, sizeof(__pyx_k_Readonly_object_type_r_don_t_sup), 0, 1, 0, 0},
  {&__pyx_kp_u_Sequence_Mapping_convertion_isn, __pyx_k_Sequence_Mapping_convertion_isn, sizeof(__pyx_k_Sequence_Mapping_convertion_isn), 0, 1, 0, 0},
  {&__pyx_kp_u_The_type_of_r_is_not_rdict, __pyx_k_The_type_of_r_is_not_rdict, sizeof(__pyx_k_The_type_of_r_is_not_rdict), 0, 1, 0, 0},
  {&__pyx_kp_u_The_type_of_r_is_not_rlist, __pyx_k_The_type_of_r_is_not_rlist, sizeof(__pyx_k_The_type_of_r_is_not_rlist), 0, 1, 0, 0},
  {&__pyx_kp_s_This_object_r_is_not_unicode_com, __pyx_k_This_object_r_is_not_unicode_com, sizeof(__pyx_k_This_object_r_is_not_unicode_com), 0, 0, 1, 0},
  {&__pyx_kp_u_This_type_of_comparison_is_not_s, __pyx_k_This_type_of_comparison_is_not_s, sizeof(__pyx_k_This_type_of_comparison_is_not_s), 0, 1, 0, 0},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_kp_u_UTC_s_02d, __pyx_k_UTC_s_02d, sizeof(__pyx_k_UTC_s_02d), 0, 1, 0, 0},
  {&__pyx_kp_u_UTC_s_02d_02d, __pyx_k_UTC_s_02d_02d, sizeof(__pyx_k_UTC_s_02d_02d), 0, 1, 0, 0},
  {&__pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_k_Users_sz_repos_pyaxon_lib_axon, sizeof(__pyx_k_Users_sz_repos_pyaxon_lib_axon), 0, 0, 1, 0},
  {&__pyx_kp_s__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 0, 1, 0},
  {&__pyx_kp_u__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 1, 0, 0},
  {&__pyx_kp_u__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 1, 0, 0},
  {&__pyx_kp_u__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 1, 0, 0},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_n_s__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 0, 1, 1},
  {&__pyx_n_u__33, __pyx_k__33, sizeof(__pyx_k__33), 0, 1, 0, 1},
  {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
  {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
  {&__pyx_kp_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 0},
  {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_as_dict, __pyx_k_as_dict, sizeof(__pyx_k_as_dict), 0, 0, 1, 1},
  {&__pyx_n_s_as_list, __pyx_k_as_list, sizeof(__pyx_k_as_list), 0, 0, 1, 1},
  {&__pyx_n_s_as_tuple, __pyx_k_as_tuple, sizeof(__pyx_k_as_tuple), 0, 0, 1, 1},
  {&__pyx_n_s_as_unicode, __pyx_k_as_unicode, sizeof(__pyx_k_as_unicode), 0, 0, 1, 1},
  {&__pyx_n_s_axon__objects, __pyx_k_axon__objects, sizeof(__pyx_k_axon__objects), 0, 0, 1, 1},
  {&__pyx_n_s_axon_errors, __pyx_k_axon_errors, sizeof(__pyx_k_axon_errors), 0, 0, 1, 1},
  {&__pyx_n_s_axon_types, __pyx_k_axon_types, sizeof(__pyx_k_axon_types), 0, 0, 1, 1},
  {&__pyx_n_s_base64, __pyx_k_base64, sizeof(__pyx_k_base64), 0, 0, 1, 1},
  {&__pyx_n_s_builder, __pyx_k_builder, sizeof(__pyx_k_builder), 0, 0, 1, 1},
  {&__pyx_n_s_builtins, __pyx_k_builtins, sizeof(__pyx_k_builtins), 0, 0, 1, 1},
  {&__pyx_n_s_c_builder_dict, __pyx_k_c_builder_dict, sizeof(__pyx_k_c_builder_dict), 0, 0, 1, 1},
  {&__pyx_n_s_c_empty_dict, __pyx_k_c_empty_dict, sizeof(__pyx_k_c_empty_dict), 0, 0, 1, 1},
  {&__pyx_n_s_c_empty_list, __pyx_k_c_empty_list, sizeof(__pyx_k_c_empty_list), 0, 0, 1, 1},
  {&__pyx_n_s_c_factory_dict, __pyx_k_c_factory_dict, sizeof(__pyx_k_c_factory_dict), 0, 0, 1, 1},
  {&__pyx_n_s_c_str_type, __pyx_k_c_str_type, sizeof(__pyx_k_c_str_type), 0, 0, 1, 1},
  {&__pyx_n_s_c_undefined, __pyx_k_c_undefined, sizeof(__pyx_k_c_undefined), 0, 0, 1, 1},
  {&__pyx_n_s_c_undescore, __pyx_k_c_undescore, sizeof(__pyx_k_c_undescore), 0, 0, 1, 1},
  {&__pyx_n_s_cdecimal, __pyx_k_cdecimal, sizeof(__pyx_k_cdecimal), 0, 0, 1, 1},
  {&__pyx_n_s_clear_all_names, __pyx_k_clear_all_names, sizeof(__pyx_k_clear_all_names), 0, 0, 1, 1},
  {&__pyx_n_s_create_decimal, __pyx_k_create_decimal, sizeof(__pyx_k_create_decimal), 0, 0, 1, 1},
  {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
  {&__pyx_n_s_days, __pyx_k_days, sizeof(__pyx_k_days), 0, 0, 1, 1},
  {&__pyx_n_s_decimal, __pyx_k_decimal, sizeof(__pyx_k_decimal), 0, 0, 1, 1},
  {&__pyx_n_s_decimal2str, __pyx_k_decimal2str, sizeof(__pyx_k_decimal2str), 0, 0, 1, 1},
  {&__pyx_n_s_decimal_2, __pyx_k_decimal_2, sizeof(__pyx_k_decimal_2), 0, 0, 1, 1},
  {&__pyx_n_s_decimal_inf, __pyx_k_decimal_inf, sizeof(__pyx_k_decimal_inf), 0, 0, 1, 1},
  {&__pyx_n_s_decimal_nan, __pyx_k_decimal_nan, sizeof(__pyx_k_decimal_nan), 0, 0, 1, 1},
  {&__pyx_n_s_decimal_ninf, __pyx_k_decimal_ninf, sizeof(__pyx_k_decimal_ninf), 0, 0, 1, 1},
  {&__pyx_n_s_decodebytes, __pyx_k_decodebytes, sizeof(__pyx_k_decodebytes), 0, 0, 1, 1},
  {&__pyx_n_s_decodestring, __pyx_k_decodestring, sizeof(__pyx_k_decodestring), 0, 0, 1, 1},
  {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
  {&__pyx_n_s_default_decimal_context, __pyx_k_default_decimal_context, sizeof(__pyx_k_default_decimal_context), 0, 0, 1, 1},
  {&__pyx_n_s_divmod, __pyx_k_divmod, sizeof(__pyx_k_divmod), 0, 0, 1, 1},
  {&__pyx_kp_u_element, __pyx_k_element, sizeof(__pyx_k_element), 0, 1, 0, 0},
  {&__pyx_n_s_element_2, __pyx_k_element_2, sizeof(__pyx_k_element_2), 0, 0, 1, 1},
  {&__pyx_kp_u_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 1, 0, 0},
  {&__pyx_n_s_empty_2, __pyx_k_empty_2, sizeof(__pyx_k_empty_2), 0, 0, 1, 1},
  {&__pyx_n_s_empty_name, __pyx_k_empty_name, sizeof(__pyx_k_empty_name), 0, 0, 1, 1},
  {&__pyx_n_s_encodebytes, __pyx_k_encodebytes, sizeof(__pyx_k_encodebytes), 0, 0, 1, 1},
  {&__pyx_n_s_encodestring, __pyx_k_encodestring, sizeof(__pyx_k_encodestring), 0, 0, 1, 1},
  {&__pyx_n_s_eq, __pyx_k_eq, sizeof(__pyx_k_eq), 0, 0, 1, 1},
  {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
  {&__pyx_n_s_error_empty_mapping, __pyx_k_error_empty_mapping, sizeof(__pyx_k_error_empty_mapping), 0, 0, 1, 1},
  {&__pyx_n_s_error_empty_sequence, __pyx_k_error_empty_sequence, sizeof(__pyx_k_error_empty_sequence), 0, 0, 1, 1},
  {&__pyx_n_s_error_invalid_name, __pyx_k_error_invalid_name, sizeof(__pyx_k_error_invalid_name), 0, 0, 1, 1},
  {&__pyx_n_s_error_readonly, __pyx_k_error_readonly, sizeof(__pyx_k_error_readonly), 0, 0, 1, 1},
  {&__pyx_n_s_errors, __pyx_k_errors, sizeof(__pyx_k_errors), 0, 0, 1, 1},
  {&__pyx_n_s_extend, __pyx_k_extend, sizeof(__pyx_k_extend), 0, 0, 1, 1},
  {&__pyx_n_s_factory, __pyx_k_factory, sizeof(__pyx_k_factory), 0, 0, 1, 1},
  {&__pyx_n_s_factory_2, __pyx_k_factory_2, sizeof(__pyx_k_factory_2), 0, 0, 1, 1},
  {&__pyx_n_s_factory_func, __pyx_k_factory_func, sizeof(__pyx_k_factory_func), 0, 0, 1, 1},
  {&__pyx_n_s_factory_locals__factory, __pyx_k_factory_locals__factory, sizeof(__pyx_k_factory_locals__factory), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_getcontext, __pyx_k_getcontext, sizeof(__pyx_k_getcontext), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_inf, __pyx_k_inf, sizeof(__pyx_k_inf), 0, 0, 1, 1},
  {&__pyx_n_u_inf_2, __pyx_k_inf_2, sizeof(__pyx_k_inf_2), 0, 1, 0, 1},
  {&__pyx_kp_u_inf_3, __pyx_k_inf_3, sizeof(__pyx_k_inf_3), 0, 1, 0, 0},
  {&__pyx_kp_u_instance, __pyx_k_instance, sizeof(__pyx_k_instance), 0, 1, 0, 0},
  {&__pyx_n_s_instance_2, __pyx_k_instance_2, sizeof(__pyx_k_instance_2), 0, 0, 1, 1},
  {&__pyx_n_s_isundef, __pyx_k_isundef, sizeof(__pyx_k_isundef), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_mapping, __pyx_k_mapping, sizeof(__pyx_k_mapping), 0, 0, 1, 1},
  {&__pyx_kp_u_mapping_2, __pyx_k_mapping_2, sizeof(__pyx_k_mapping_2), 0, 1, 0, 0},
  {&__pyx_n_s_minutes, __pyx_k_minutes, sizeof(__pyx_k_minutes), 0, 0, 1, 1},
  {&__pyx_n_u_mixed, __pyx_k_mixed, sizeof(__pyx_k_mixed), 0, 1, 0, 1},
  {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_cache, __pyx_k_name_cache, sizeof(__pyx_k_name_cache), 0, 0, 1, 1},
  {&__pyx_n_s_nan, __pyx_k_nan, sizeof(__pyx_k_nan), 0, 0, 1, 1},
  {&__pyx_n_u_nan_2, __pyx_k_nan_2, sizeof(__pyx_k_nan_2), 0, 1, 0, 1},
  {&__pyx_n_s_ninf, __pyx_k_ninf, sizeof(__pyx_k_ninf), 0, 0, 1, 1},
  {&__pyx_n_s_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 0, 1, 1},
  {&__pyx_n_s_offset, __pyx_k_offset, sizeof(__pyx_k_offset), 0, 0, 1, 1},
  {&__pyx_n_s_property, __pyx_k_property, sizeof(__pyx_k_property), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_capi, __pyx_k_pyx_capi, sizeof(__pyx_k_pyx_capi), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_register_builder, __pyx_k_register_builder, sizeof(__pyx_k_register_builder), 0, 0, 1, 1},
  {&__pyx_n_s_reset_factory, __pyx_k_reset_factory, sizeof(__pyx_k_reset_factory), 0, 0, 1, 1},
  {&__pyx_n_u_safe, __pyx_k_safe, sizeof(__pyx_k_safe), 0, 1, 0, 1},
  {&__pyx_n_s_seconds, __pyx_k_seconds, sizeof(__pyx_k_seconds), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_sequence, __pyx_k_sequence, sizeof(__pyx_k_sequence), 0, 0, 1, 1},
  {&__pyx_kp_u_sequence_2, __pyx_k_sequence_2, sizeof(__pyx_k_sequence_2), 0, 1, 0, 0},
  {&__pyx_n_s_sequences, __pyx_k_sequences, sizeof(__pyx_k_sequences), 0, 0, 1, 1},
  {&__pyx_n_s_str2decimal, __pyx_k_str2decimal, sizeof(__pyx_k_str2decimal), 0, 0, 1, 1},
  {&__pyx_n_s_str_type, __pyx_k_str_type, sizeof(__pyx_k_str_type), 0, 0, 1, 1},
  {&__pyx_n_u_strict, __pyx_k_strict, sizeof(__pyx_k_strict), 0, 1, 0, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
  {&__pyx_n_s_timedelta, __pyx_k_timedelta, sizeof(__pyx_k_timedelta), 0, 0, 1, 1},
  {&__pyx_n_s_timezone, __pyx_k_timezone, sizeof(__pyx_k_timezone), 0, 0, 1, 1},
  {&__pyx_n_s_timezone_cls, __pyx_k_timezone_cls, sizeof(__pyx_k_timezone_cls), 0, 0, 1, 1},
  {&__pyx_kp_u_timezone_r, __pyx_k_timezone_r, sizeof(__pyx_k_timezone_r), 0, 1, 0, 0},
  {&__pyx_kp_u_timezone_r_s, __pyx_k_timezone_r_s, sizeof(__pyx_k_timezone_r_s), 0, 1, 0, 0},
  {&__pyx_n_s_to_eng_string, __pyx_k_to_eng_string, sizeof(__pyx_k_to_eng_string), 0, 0, 1, 1},
  {&__pyx_n_s_tz_dict, __pyx_k_tz_dict, sizeof(__pyx_k_tz_dict), 0, 0, 1, 1},
  {&__pyx_n_s_tzname, __pyx_k_tzname, sizeof(__pyx_k_tzname), 0, 0, 1, 1},
  {&__pyx_n_s_undef, __pyx_k_undef, sizeof(__pyx_k_undef), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_val, __pyx_k_val, sizeof(__pyx_k_val), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_value_2, __pyx_k_value_2, sizeof(__pyx_k_value_2), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_property = __Pyx_GetBuiltinName(__pyx_n_s_property); if (!__pyx_builtin_property) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 996; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "axon/_objects.py":163
 *             elif op == 3:
 *                 return not dict.__eq__(self, other)
 *             raise TypeError('This type of comparison is not supported')             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError('The type of %r is not rdict' % type(self))
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_u_This_type_of_comparison_is_not_s); if (unlikely(!__pyx_tuple__3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "axon/_objects.py":190
 *             elif op == 3:
 *                 return not list.__eq__(self, other)
 *             raise TypeError('This type of comparison is not supported')             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError('The type of %r is not rlist' % type(self))
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_u_This_type_of_comparison_is_not_s); if (unlikely(!__pyx_tuple__4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "axon/_objects.py":271
 *             return self.value
 *         else:
 *             raise IndexError('Index out of range')             # <<<<<<<<<<<<<<
 *     #
 *     def __repr__(self):
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_u_Index_out_of_range); if (unlikely(!__pyx_tuple__5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "axon/_objects.py":434
 *     #
 *     def as_mapping(self):
 *         raise error("Sequence->Mapping convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_sequence(self):
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_Sequence_Mapping_convertion_isn); if (unlikely(!__pyx_tuple__9)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "axon/_objects.py":512
 *     #
 *     def as_sequence(self):
 *         raise error("Mapping->Sequence convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_element(self, sequence=None):
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_Mapping_Sequence_convertion_isn); if (unlikely(!__pyx_tuple__10)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "axon/_objects.py":596
 *     #
 *     def as_mapping(self):
 *         raise error("Element->Mapping convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_sequence(self):
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_Element_Mapping_convertion_isn_t); if (unlikely(!__pyx_tuple__11)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 596; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "axon/_objects.py":599
 *     #
 *     def as_sequence(self):
 *         raise error("Element->Sequence convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_element(self):
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_Element_Sequence_convertion_isn); if (unlikely(!__pyx_tuple__12)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 599; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "axon/_objects.py":681
 *     #
 *     def as_mapping(self):
 *         raise error("Instance->Mapping convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_sequence(self):
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_kp_u_Instance_Mapping_convertion_isn); if (unlikely(!__pyx_tuple__13)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "axon/_objects.py":684
 *     #
 *     def as_sequence(self):
 *         raise error("Instance->Sequence convertion isn't available")             # <<<<<<<<<<<<<<
 *     #
 *     def as_element(self):
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_u_Instance_Sequence_convertion_isn); if (unlikely(!__pyx_tuple__14)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 684; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "axon/_objects.py":813
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 *         def _factory(factory_func, name=name):             # <<<<<<<<<<<<<<
 *             c_factory_dict[name] = factory_func
 *             return factory_func
 */
  __pyx_tuple__15 = PyTuple_Pack(2, __pyx_n_s_factory_func, __pyx_n_s_name); if (unlikely(!__pyx_tuple__15)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_factory, 813, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":1175
 *     def __richcmp__(self, other, op):
 *         if not isinstance(other, tzinfo):
 *             raise TypeError('Invalid type: expected `tzinfo` instance')             # <<<<<<<<<<<<<<
 * 
 *         if op == 0:
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_u_Invalid_type_expected_tzinfo_ins); if (unlikely(!__pyx_tuple__20)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1175; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "axon/_objects.py":1191
 * 
 *     def __str__(self):
 *         return self.tzname(None)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_tuple__21 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__21)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "axon/_objects.py":95
 *         return '??'
 * 
 * def isundef(o):             # <<<<<<<<<<<<<<
 *     return type(o) is Undefined
 * 
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_n_s_o); if (unlikely(!__pyx_tuple__23)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);
  __pyx_codeobj__24 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__23, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_isundef, 95, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__24)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":101
 * undef = c_undefined
 * 
 * def _error_readonly(self):             # <<<<<<<<<<<<<<
 *     return AttributeError(
 *         'Readonly object type %r don\'t support assigning items or attributes' \
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__25)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);
  __pyx_codeobj__26 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__25, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_error_readonly, 101, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__26)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":106
 *         % type(self))
 * 
 * def _error_empty_mapping(self):             # <<<<<<<<<<<<<<
 *     return KeyError(
 *         'Object %r contains an empty mapping' \
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__27)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);
  __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__27, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_error_empty_mapping, 106, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":111
 *         % type(self))
 * 
 * def _error_empty_sequence(self):             # <<<<<<<<<<<<<<
 *     return KeyError(
 *         'Object %r contains an empty sequence' \
 */
  __pyx_tuple__29 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__29)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);
  __pyx_codeobj__30 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__29, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_error_empty_sequence, 111, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__30)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":116
 *         % type(self))
 * 
 * def _error_invalid_name(name):             # <<<<<<<<<<<<<<
 *     return KeyError('Invalid name: %r' % type(name))
 * 
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_n_s_name); if (unlikely(!__pyx_tuple__31)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);
  __pyx_codeobj__32 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_error_invalid_name, 116, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__32)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":128
 * name_cache = {None: empty_name, c_undescore: c_undescore}
 * 
 * def clear_all_names():             # <<<<<<<<<<<<<<
 *     name_cache = {}
 * 
 */
  __pyx_tuple__34 = PyTuple_Pack(1, __pyx_n_s_name_cache); if (unlikely(!__pyx_tuple__34)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);
  __pyx_codeobj__35 = (PyObject*)__Pyx_PyCode_New(0, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__34, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_clear_all_names, 128, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__35)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":131
 *     name_cache = {}
 * 
 * def as_unicode(o):             # <<<<<<<<<<<<<<
 *     return c_as_unicode(o)
 * 
 */
  __pyx_tuple__36 = PyTuple_Pack(1, __pyx_n_s_o); if (unlikely(!__pyx_tuple__36)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);
  __pyx_codeobj__37 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__36, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_as_unicode, 131, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__37)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":134
 *     return c_as_unicode(o)
 * 
 * def as_list(o):             # <<<<<<<<<<<<<<
 *     return c_as_list(o)
 * 
 */
  __pyx_tuple__38 = PyTuple_Pack(1, __pyx_n_s_o); if (unlikely(!__pyx_tuple__38)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__38, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_as_list, 134, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":137
 *     return c_as_list(o)
 * 
 * def as_dict(o):             # <<<<<<<<<<<<<<
 *     return c_as_dict(o)
 * 
 */
  __pyx_tuple__40 = PyTuple_Pack(1, __pyx_n_s_o); if (unlikely(!__pyx_tuple__40)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);
  __pyx_codeobj__41 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__40, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_as_dict, 137, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__41)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":140
 *     return c_as_dict(o)
 * 
 * def as_tuple(o):             # <<<<<<<<<<<<<<
 *     return c_as_tuple(o)
 * 
 */
  __pyx_tuple__42 = PyTuple_Pack(1, __pyx_n_s_o); if (unlikely(!__pyx_tuple__42)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);
  __pyx_codeobj__43 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__42, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_as_tuple, 140, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__43)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":729
 * #NAME_IS_EMPTY = 'Name is empty'
 * 
 * def sequence(name, sequence=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named sequence.
 */
  __pyx_tuple__44 = PyTuple_Pack(2, __pyx_n_s_name, __pyx_n_s_sequence); if (unlikely(!__pyx_tuple__44)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 729; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__44, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_sequence, 729, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 729; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_tuple__46 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__46)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 729; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "axon/_objects.py":743
 *     return c_new_sequence(c_as_name(name), c_as_list(sequence))
 * #
 * def mapping(name, mapping=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named mapping.
 */
  __pyx_tuple__47 = PyTuple_Pack(2, __pyx_n_s_name, __pyx_n_s_mapping); if (unlikely(!__pyx_tuple__47)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);
  __pyx_codeobj__48 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_mapping, 743, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__48)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_tuple__49 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__49)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "axon/_objects.py":757
 *     return c_new_mapping(c_as_name(name), c_as_dict(mapping))
 * #
 * def element(name, mapping, sequence=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named element.
 */
  __pyx_tuple__50 = PyTuple_Pack(3, __pyx_n_s_name, __pyx_n_s_mapping, __pyx_n_s_sequence); if (unlikely(!__pyx_tuple__50)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__50, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_element_2, 757, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_tuple__52 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__52)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "axon/_objects.py":775
 *     return c_new_element(c_as_name(name), c_as_dict(mapping), c_as_list(sequence))
 * #
 * def instance(name, sequence, mapping):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named instance.
 */
  __pyx_tuple__53 = PyTuple_Pack(3, __pyx_n_s_name, __pyx_n_s_sequence, __pyx_n_s_mapping); if (unlikely(!__pyx_tuple__53)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);
  __pyx_codeobj__54 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__53, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_instance_2, 775, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__54)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":794
 *     return c_new_instance(c_as_name(name), c_as_tuple(sequence), c_as_dict(mapping))
 * #
 * def empty(name):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating empty complex value.
 */
  __pyx_tuple__55 = PyTuple_Pack(1, __pyx_n_s_name); if (unlikely(!__pyx_tuple__55)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);
  __pyx_codeobj__56 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__55, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_empty_2, 794, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__56)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":807
 * c_factory_dict = {}
 * 
 * def reset_factory():             # <<<<<<<<<<<<<<
 *     c_factory_dict = {}
 * 
 */
  __pyx_tuple__57 = PyTuple_Pack(1, __pyx_n_s_c_factory_dict); if (unlikely(!__pyx_tuple__57)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);
  __pyx_codeobj__58 = (PyObject*)__Pyx_PyCode_New(0, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__57, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_reset_factory, 807, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__58)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":810
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */
  __pyx_tuple__59 = PyTuple_Pack(4, __pyx_n_s_name, __pyx_n_s_factory_func, __pyx_n_s_factory, __pyx_n_s_factory); if (unlikely(!__pyx_tuple__59)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);
  __pyx_codeobj__60 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__59, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_factory_2, 810, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__60)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_tuple__61 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__61)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "axon/_objects.py":972
 * }
 * 
 * def register_builder(mode, builder):             # <<<<<<<<<<<<<<
 *     c_builder_dict[mode] = builder
 * 
 */
  __pyx_tuple__62 = PyTuple_Pack(2, __pyx_n_s_mode, __pyx_n_s_builder); if (unlikely(!__pyx_tuple__62)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__62, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_register_builder, 972, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":981
 * _ninf = float('-inf')
 * _nan = float('nan')
 * _decimal_inf = _str2decimal('Infinity')             # <<<<<<<<<<<<<<
 * _decimal_ninf = _str2decimal('-Infinity')
 * _decimal_nan = _str2decimal('NaN')
 */
  __pyx_tuple__64 = PyTuple_Pack(1, __pyx_n_u_Infinity); if (unlikely(!__pyx_tuple__64)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 981; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "axon/_objects.py":982
 * _nan = float('nan')
 * _decimal_inf = _str2decimal('Infinity')
 * _decimal_ninf = _str2decimal('-Infinity')             # <<<<<<<<<<<<<<
 * _decimal_nan = _str2decimal('NaN')
 * 
 */
  __pyx_tuple__65 = PyTuple_Pack(1, __pyx_kp_u_Infinity_2); if (unlikely(!__pyx_tuple__65)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 982; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "axon/_objects.py":983
 * _decimal_inf = _str2decimal('Infinity')
 * _decimal_ninf = _str2decimal('-Infinity')
 * _decimal_nan = _str2decimal('NaN')             # <<<<<<<<<<<<<<
 * 
 * tz_dict = {}
 */
  __pyx_tuple__66 = PyTuple_Pack(1, __pyx_n_u_NaN); if (unlikely(!__pyx_tuple__66)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 983; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_24 = PyInt_FromLong(24); if (unlikely(!__pyx_int_24)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_60 = PyInt_FromLong(60); if (unlikely(!__pyx_int_60)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_objects(void); /*proto*/
PyMODINIT_FUNC init_objects(void)
#else
PyMODINIT_FUNC PyInit__objects(void); /*proto*/
PyMODINIT_FUNC PyInit__objects(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  double __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__objects(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("_objects"), __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_axon___objects) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "axon._objects")) {
      if (unlikely(PyDict_SetItemString(modules, "axon._objects", __pyx_m) < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  __pyx_v_4axon_8_objects__decimal2str = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_empty_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_c_undescore = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_c_undefined = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_name_cache = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_c_str_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_c_empty_dict = ((struct ReadonlyDict *)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_c_empty_list = ((struct ReadonlyList *)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_c_factory_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_c_builder_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects__str2decimal = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects__inf = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects__ninf = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects__nan = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects__decimal_inf = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects__decimal_ninf = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects__decimal_nan = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_tz_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_8_objects_timezone_cls = Py_None; Py_INCREF(Py_None);
  /*--- Variable export code ---*/
  if (__Pyx_ExportVoidPtr(__pyx_n_s_decimal2str, (void *)&__pyx_v_4axon_8_objects__decimal2str, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_empty_name, (void *)&__pyx_v_4axon_8_objects_empty_name, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_undescore, (void *)&__pyx_v_4axon_8_objects_c_undescore, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_undefined, (void *)&__pyx_v_4axon_8_objects_c_undefined, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_name_cache, (void *)&__pyx_v_4axon_8_objects_name_cache, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_str_type, (void *)&__pyx_v_4axon_8_objects_c_str_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_empty_dict, (void *)&__pyx_v_4axon_8_objects_c_empty_dict, "struct ReadonlyDict *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_empty_list, (void *)&__pyx_v_4axon_8_objects_c_empty_list, "struct ReadonlyList *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_factory_dict, (void *)&__pyx_v_4axon_8_objects_c_factory_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_builder_dict, (void *)&__pyx_v_4axon_8_objects_c_builder_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_str2decimal, (void *)&__pyx_v_4axon_8_objects__str2decimal, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_inf, (void *)&__pyx_v_4axon_8_objects__inf, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_ninf, (void *)&__pyx_v_4axon_8_objects__ninf, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_nan, (void *)&__pyx_v_4axon_8_objects__nan, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_decimal_inf, (void *)&__pyx_v_4axon_8_objects__decimal_inf, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_decimal_ninf, (void *)&__pyx_v_4axon_8_objects__decimal_ninf, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_decimal_nan, (void *)&__pyx_v_4axon_8_objects__decimal_nan, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_tz_dict, (void *)&__pyx_v_4axon_8_objects_tz_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_timezone_cls, (void *)&__pyx_v_4axon_8_objects_timezone_cls, "PyObject *") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("named", (void (*)(void))__pyx_f_4axon_8_objects_named, "PyObject *(PyObject *, PyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("new_attribute", (void (*)(void))__pyx_f_4axon_8_objects_new_attribute, "PyObject *(PyObject *, PyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_attribute", (void (*)(void))__pyx_f_4axon_8_objects_c_new_attribute, "struct Attribute *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("new_attrs", (void (*)(void))__pyx_f_4axon_8_objects_new_attrs, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_sequence", (void (*)(void))__pyx_f_4axon_8_objects_c_new_sequence, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_mapping", (void (*)(void))__pyx_f_4axon_8_objects_c_new_mapping, "PyObject *(PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_element", (void (*)(void))__pyx_f_4axon_8_objects_c_new_element, "PyObject *(PyObject *, PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_instance", (void (*)(void))__pyx_f_4axon_8_objects_c_new_instance, "PyObject *(PyObject *, PyObject *, PyObject *)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_empty", (void (*)(void))__pyx_f_4axon_8_objects_c_new_empty, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("get_builder", (void (*)(void))__pyx_f_4axon_8_objects_get_builder, "struct __pyx_obj_4axon_8_objects_Builder *(PyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Type init code ---*/
  if (PyType_Ready(&UndefinedType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  UndefinedType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Undefined", (PyObject *)&UndefinedType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Undefined = &UndefinedType;
  ReadonlyDictType.tp_base = (&PyDict_Type);
  if (PyType_Ready(&ReadonlyDictType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  ReadonlyDictType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "rdict", (PyObject *)&ReadonlyDictType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_rdict = &ReadonlyDictType;
  ReadonlyListType.tp_base = (&PyList_Type);
  if (PyType_Ready(&ReadonlyListType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  ReadonlyListType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "rlist", (PyObject *)&ReadonlyListType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_rlist = &ReadonlyListType;
  if (PyType_Ready(&__pyx_type_4axon_8_objects_NamedValue) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_8_objects_NamedValue.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "NamedValue", (PyObject *)&__pyx_type_4axon_8_objects_NamedValue) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_NamedValue = &__pyx_type_4axon_8_objects_NamedValue;
  if (PyType_Ready(&AttributeType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  AttributeType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Attribute", (PyObject *)&AttributeType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Attribute = &AttributeType;
  if (PyType_Ready(&__pyx_type_4axon_8_objects_Attrs) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_8_objects_Attrs.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Attrs", (PyObject *)&__pyx_type_4axon_8_objects_Attrs) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 294; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Attrs = &__pyx_type_4axon_8_objects_Attrs;
  if (PyType_Ready(&EmptyType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 316; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  EmptyType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Empty", (PyObject *)&EmptyType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 316; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Empty = &EmptyType;
  if (PyType_Ready(&SequenceType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  SequenceType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Sequence", (PyObject *)&SequenceType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 379; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Sequence = &SequenceType;
  if (PyType_Ready(&MappingType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 448; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  MappingType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Mapping", (PyObject *)&MappingType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 448; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Mapping = &MappingType;
  if (PyType_Ready(&ElementType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 524; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  ElementType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Element", (PyObject *)&ElementType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 524; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Element = &ElementType;
  if (PyType_Ready(&InstanceType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 610; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  InstanceType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Instance", (PyObject *)&InstanceType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 610; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Instance = &InstanceType;
  __pyx_vtabptr_4axon_8_objects_Builder = &__pyx_vtable_4axon_8_objects_Builder;
  __pyx_vtable_4axon_8_objects_Builder.create_mapping = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_7Builder_create_mapping;
  __pyx_vtable_4axon_8_objects_Builder.create_element = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_7Builder_create_element;
  __pyx_vtable_4axon_8_objects_Builder.create_sequence = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_7Builder_create_sequence;
  __pyx_vtable_4axon_8_objects_Builder.create_instance = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_7Builder_create_instance;
  __pyx_vtable_4axon_8_objects_Builder.create_empty = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *))__pyx_f_4axon_8_objects_7Builder_create_empty;
  if (PyType_Ready(&__pyx_type_4axon_8_objects_Builder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_8_objects_Builder.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_4axon_8_objects_Builder.tp_dict, __pyx_vtabptr_4axon_8_objects_Builder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Builder", (PyObject *)&__pyx_type_4axon_8_objects_Builder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Builder = &__pyx_type_4axon_8_objects_Builder;
  __pyx_vtabptr_4axon_8_objects_SafeBuilder = &__pyx_vtable_4axon_8_objects_SafeBuilder;
  __pyx_vtable_4axon_8_objects_SafeBuilder.__pyx_base = *__pyx_vtabptr_4axon_8_objects_Builder;
  __pyx_vtable_4axon_8_objects_SafeBuilder.__pyx_base.create_mapping = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_11SafeBuilder_create_mapping;
  __pyx_vtable_4axon_8_objects_SafeBuilder.__pyx_base.create_element = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_11SafeBuilder_create_element;
  __pyx_vtable_4axon_8_objects_SafeBuilder.__pyx_base.create_sequence = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_11SafeBuilder_create_sequence;
  __pyx_vtable_4axon_8_objects_SafeBuilder.__pyx_base.create_instance = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_11SafeBuilder_create_instance;
  __pyx_vtable_4axon_8_objects_SafeBuilder.__pyx_base.create_empty = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *))__pyx_f_4axon_8_objects_11SafeBuilder_create_empty;
  __pyx_type_4axon_8_objects_SafeBuilder.tp_base = __pyx_ptype_4axon_8_objects_Builder;
  if (PyType_Ready(&__pyx_type_4axon_8_objects_SafeBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_8_objects_SafeBuilder.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_4axon_8_objects_SafeBuilder.tp_dict, __pyx_vtabptr_4axon_8_objects_SafeBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "SafeBuilder", (PyObject *)&__pyx_type_4axon_8_objects_SafeBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_SafeBuilder = &__pyx_type_4axon_8_objects_SafeBuilder;
  __pyx_vtabptr_4axon_8_objects_StrictBuilder = &__pyx_vtable_4axon_8_objects_StrictBuilder;
  __pyx_vtable_4axon_8_objects_StrictBuilder.__pyx_base = *__pyx_vtabptr_4axon_8_objects_Builder;
  __pyx_vtable_4axon_8_objects_StrictBuilder.__pyx_base.create_mapping = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_13StrictBuilder_create_mapping;
  __pyx_vtable_4axon_8_objects_StrictBuilder.__pyx_base.create_element = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_13StrictBuilder_create_element;
  __pyx_vtable_4axon_8_objects_StrictBuilder.__pyx_base.create_sequence = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_13StrictBuilder_create_sequence;
  __pyx_vtable_4axon_8_objects_StrictBuilder.__pyx_base.create_instance = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_13StrictBuilder_create_instance;
  __pyx_vtable_4axon_8_objects_StrictBuilder.__pyx_base.create_empty = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *))__pyx_f_4axon_8_objects_13StrictBuilder_create_empty;
  __pyx_type_4axon_8_objects_StrictBuilder.tp_base = __pyx_ptype_4axon_8_objects_Builder;
  if (PyType_Ready(&__pyx_type_4axon_8_objects_StrictBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 869; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_8_objects_StrictBuilder.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_4axon_8_objects_StrictBuilder.tp_dict, __pyx_vtabptr_4axon_8_objects_StrictBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 869; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "StrictBuilder", (PyObject *)&__pyx_type_4axon_8_objects_StrictBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 869; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_StrictBuilder = &__pyx_type_4axon_8_objects_StrictBuilder;
  __pyx_vtabptr_4axon_8_objects_MixedBuilder = &__pyx_vtable_4axon_8_objects_MixedBuilder;
  __pyx_vtable_4axon_8_objects_MixedBuilder.__pyx_base = *__pyx_vtabptr_4axon_8_objects_Builder;
  __pyx_vtable_4axon_8_objects_MixedBuilder.__pyx_base.create_mapping = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_12MixedBuilder_create_mapping;
  __pyx_vtable_4axon_8_objects_MixedBuilder.__pyx_base.create_element = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_12MixedBuilder_create_element;
  __pyx_vtable_4axon_8_objects_MixedBuilder.__pyx_base.create_sequence = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_12MixedBuilder_create_sequence;
  __pyx_vtable_4axon_8_objects_MixedBuilder.__pyx_base.create_instance = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_12MixedBuilder_create_instance;
  __pyx_vtable_4axon_8_objects_MixedBuilder.__pyx_base.create_empty = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *))__pyx_f_4axon_8_objects_12MixedBuilder_create_empty;
  __pyx_type_4axon_8_objects_MixedBuilder.tp_base = __pyx_ptype_4axon_8_objects_Builder;
  if (PyType_Ready(&__pyx_type_4axon_8_objects_MixedBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 909; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_8_objects_MixedBuilder.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_4axon_8_objects_MixedBuilder.tp_dict, __pyx_vtabptr_4axon_8_objects_MixedBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 909; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "MixedBuilder", (PyObject *)&__pyx_type_4axon_8_objects_MixedBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 909; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_MixedBuilder = &__pyx_type_4axon_8_objects_MixedBuilder;
  __pyx_vtabptr_4axon_8_objects_GenericBuilder = &__pyx_vtable_4axon_8_objects_GenericBuilder;
  __pyx_vtable_4axon_8_objects_GenericBuilder.__pyx_base = *__pyx_vtabptr_4axon_8_objects_Builder;
  __pyx_vtable_4axon_8_objects_GenericBuilder.__pyx_base.create_mapping = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_14GenericBuilder_create_mapping;
  __pyx_vtable_4axon_8_objects_GenericBuilder.__pyx_base.create_element = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_14GenericBuilder_create_element;
  __pyx_vtable_4axon_8_objects_GenericBuilder.__pyx_base.create_sequence = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_14GenericBuilder_create_sequence;
  __pyx_vtable_4axon_8_objects_GenericBuilder.__pyx_base.create_instance = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *))__pyx_f_4axon_8_objects_14GenericBuilder_create_instance;
  __pyx_vtable_4axon_8_objects_GenericBuilder.__pyx_base.create_empty = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *))__pyx_f_4axon_8_objects_14GenericBuilder_create_empty;
  GenericBuilderType.tp_base = __pyx_ptype_4axon_8_objects_Builder;
  if (PyType_Ready(&GenericBuilderType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 949; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  GenericBuilderType.tp_print = 0;
  if (__Pyx_SetVtable(GenericBuilderType.tp_dict, __pyx_vtabptr_4axon_8_objects_GenericBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 949; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "GenericBuilder", (PyObject *)&GenericBuilderType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 949; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_GenericBuilder = &GenericBuilderType;
  __pyx_vtabptr_4axon_8_objects_SimpleBuilder = &__pyx_vtable_4axon_8_objects_SimpleBuilder;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_int = (PyObject *(*)(struct SimpleBuilder *, PyObject *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_int;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_float = (PyObject *(*)(struct SimpleBuilder *, PyObject *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_float;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_decimal = (PyObject *(*)(struct SimpleBuilder *, PyObject *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_time = (PyObject *(*)(struct SimpleBuilder *, int, int, int, int, PyObject *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_time;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_timedelta = (PyObject *(*)(struct SimpleBuilder *, int, int, int))__pyx_f_4axon_8_objects_13SimpleBuilder_create_timedelta;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_date = (PyObject *(*)(struct SimpleBuilder *, int, int, int))__pyx_f_4axon_8_objects_13SimpleBuilder_create_date;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_datetime = (PyObject *(*)(struct SimpleBuilder *, int, int, int, int, int, int, int, PyObject *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_datetime;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_tzinfo = (PyObject *(*)(struct SimpleBuilder *, int))__pyx_f_4axon_8_objects_13SimpleBuilder_create_tzinfo;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_inf = (PyObject *(*)(struct SimpleBuilder *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_inf;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_ninf = (PyObject *(*)(struct SimpleBuilder *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_ninf;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_nan = (PyObject *(*)(struct SimpleBuilder *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_nan;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_decimal_inf = (PyObject *(*)(struct SimpleBuilder *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_inf;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_decimal_ninf = (PyObject *(*)(struct SimpleBuilder *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_ninf;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_decimal_nan = (PyObject *(*)(struct SimpleBuilder *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_decimal_nan;
  __pyx_vtable_4axon_8_objects_SimpleBuilder.create_binary = (PyObject *(*)(struct SimpleBuilder *, PyObject *))__pyx_f_4axon_8_objects_13SimpleBuilder_create_binary;
  if (PyType_Ready(&SimpleBuilderType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 988; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  SimpleBuilderType.tp_print = 0;
  if (__Pyx_SetVtable(SimpleBuilderType.tp_dict, __pyx_vtabptr_4axon_8_objects_SimpleBuilder) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 988; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "SimpleBuilder", (PyObject *)&SimpleBuilderType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 988; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_SimpleBuilder = &SimpleBuilderType;
  __pyx_vtabptr_4axon_8_objects_StringReader = &__pyx_vtable_4axon_8_objects_StringReader;
  __pyx_vtable_4axon_8_objects_StringReader.readline = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch))__pyx_f_4axon_8_objects_12StringReader_readline;
  __pyx_vtable_4axon_8_objects_StringReader.close = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch))__pyx_f_4axon_8_objects_12StringReader_close;
  if (PyType_Ready(&__pyx_type_4axon_8_objects_StringReader) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1057; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_8_objects_StringReader.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_4axon_8_objects_StringReader.tp_dict, __pyx_vtabptr_4axon_8_objects_StringReader) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1057; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "StringReader", (PyObject *)&__pyx_type_4axon_8_objects_StringReader) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1057; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_StringReader = &__pyx_type_4axon_8_objects_StringReader;
  __pyx_vtabptr_4axon_8_objects_StringWriter = &__pyx_vtable_4axon_8_objects_StringWriter;
  __pyx_vtable_4axon_8_objects_StringWriter.write = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_StringWriter *, PyObject *, int __pyx_skip_dispatch))__pyx_f_4axon_8_objects_12StringWriter_write;
  __pyx_vtable_4axon_8_objects_StringWriter.getvalue = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_StringWriter *, int __pyx_skip_dispatch))__pyx_f_4axon_8_objects_12StringWriter_getvalue;
  __pyx_vtable_4axon_8_objects_StringWriter.close = (PyObject *(*)(struct __pyx_obj_4axon_8_objects_StringWriter *, int __pyx_skip_dispatch))__pyx_f_4axon_8_objects_12StringWriter_close;
  if (PyType_Ready(&__pyx_type_4axon_8_objects_StringWriter) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_8_objects_StringWriter.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_4axon_8_objects_StringWriter.tp_dict, __pyx_vtabptr_4axon_8_objects_StringWriter) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "StringWriter", (PyObject *)&__pyx_type_4axon_8_objects_StringWriter) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_StringWriter = &__pyx_type_4axon_8_objects_StringWriter;
  __pyx_ptype_7cpython_8datetime_tzinfo = __Pyx_ImportType("datetime", "tzinfo", sizeof(PyDateTime_TZInfo), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_tzinfo)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  TimeZoneUTCType.tp_base = __pyx_ptype_7cpython_8datetime_tzinfo;
  if (PyType_Ready(&TimeZoneUTCType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  TimeZoneUTCType.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "timezone", (PyObject *)&TimeZoneUTCType) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_timezone = &TimeZoneUTCType;
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_8datetime_date = __Pyx_ImportType("datetime", "date", sizeof(PyDateTime_Date), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_date)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_time = __Pyx_ImportType("datetime", "time", sizeof(PyDateTime_Time), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_time)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_datetime = __Pyx_ImportType("datetime", "datetime", sizeof(PyDateTime_DateTime), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_datetime)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_timedelta = __Pyx_ImportType("datetime", "timedelta", sizeof(PyDateTime_Delta), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_timedelta)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "axon/_objects.py":38
 * import cython
 * 
 * from axon.errors import error             # <<<<<<<<<<<<<<
 * import axon.errors as errors
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_error);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_error);
  __Pyx_GIVEREF(__pyx_n_s_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_axon_errors, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_error); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_error, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_objects.py":39
 * 
 * from axon.errors import error
 * import axon.errors as errors             # <<<<<<<<<<<<<<
 * 
 * from axon.types import builtins
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s__22);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s__22);
  __Pyx_GIVEREF(__pyx_n_s__22);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_axon_errors, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_errors, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":41
 * import axon.errors as errors
 * 
 * from axon.types import builtins             # <<<<<<<<<<<<<<
 * 
 * from axon.types import str_type
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_builtins);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_builtins);
  __Pyx_GIVEREF(__pyx_n_s_builtins);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_axon_types, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_builtins); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_builtins, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_objects.py":43
 * from axon.types import builtins
 * 
 * from axon.types import str_type             # <<<<<<<<<<<<<<
 * c_str_type = str_type
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_str_type);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_str_type);
  __Pyx_GIVEREF(__pyx_n_s_str_type);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_axon_types, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_str_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_str_type, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":44
 * 
 * from axon.types import str_type
 * c_str_type = str_type             # <<<<<<<<<<<<<<
 * 
 * import datetime
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_str_type); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects_c_str_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_c_str_type, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":46
 * c_str_type = str_type
 * 
 * import datetime             # <<<<<<<<<<<<<<
 * import_datetime()
 * 
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_datetime, 0, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":47
 * 
 * import datetime
 * import_datetime()             # <<<<<<<<<<<<<<
 * 
 * try:
 */
  __pyx_f_7cpython_8datetime_import_datetime();

  /* "axon/_objects.py":49
 * import_datetime()
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from datetime import timezone as timezone_cls
 * except:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "axon/_objects.py":50
 * 
 * try:
 *     from datetime import timezone as timezone_cls             # <<<<<<<<<<<<<<
 * except:
 *     timezone_cls = timezone
 */
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_n_s_timezone);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_timezone);
      __Pyx_GIVEREF(__pyx_n_s_timezone);
      __pyx_t_2 = __Pyx_Import(__pyx_n_s_datetime, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_timezone); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_v_4axon_8_objects_timezone_cls);
      __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_timezone_cls, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L2_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_objects.py":51
 * try:
 *     from datetime import timezone as timezone_cls
 * except:             # <<<<<<<<<<<<<<
 *     timezone_cls = timezone
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._objects", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_1, &__pyx_t_6) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_6);

      /* "axon/_objects.py":52
 *     from datetime import timezone as timezone_cls
 * except:
 *     timezone_cls = timezone             # <<<<<<<<<<<<<<
 * 
 * try:
 */
      __Pyx_INCREF(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_timezone)));
      __Pyx_XGOTREF(__pyx_v_4axon_8_objects_timezone_cls);
      __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_timezone_cls, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_timezone)));
      __Pyx_GIVEREF(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_timezone)));
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L3_exception_handled;
    }
    __pyx_L4_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L9_try_end:;
  }

  /* "axon/_objects.py":54
 *     timezone_cls = timezone
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from base64 import encodebytes, decodebytes
 * except:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "axon/_objects.py":55
 * 
 * try:
 *     from base64 import encodebytes, decodebytes             # <<<<<<<<<<<<<<
 * except:
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes
 */
      __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_n_s_encodebytes);
      PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_s_encodebytes);
      __Pyx_GIVEREF(__pyx_n_s_encodebytes);
      __Pyx_INCREF(__pyx_n_s_decodebytes);
      PyList_SET_ITEM(__pyx_t_6, 1, __pyx_n_s_decodebytes);
      __Pyx_GIVEREF(__pyx_n_s_decodebytes);
      __pyx_t_1 = __Pyx_Import(__pyx_n_s_base64, __pyx_t_6, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_encodebytes); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_encodebytes, __pyx_t_6) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_decodebytes); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_decodebytes, __pyx_t_6) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L19_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "axon/_objects.py":56
 * try:
 *     from base64 import encodebytes, decodebytes
 * except:             # <<<<<<<<<<<<<<
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._objects", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_2) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_2);

      /* "axon/_objects.py":57
 *     from base64 import encodebytes, decodebytes
 * except:
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes             # <<<<<<<<<<<<<<
 * 
 * try:
 */
      __pyx_t_7 = PyList_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_n_s_encodestring);
      PyList_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_encodestring);
      __Pyx_GIVEREF(__pyx_n_s_encodestring);
      __Pyx_INCREF(__pyx_n_s_decodestring);
      PyList_SET_ITEM(__pyx_t_7, 1, __pyx_n_s_decodestring);
      __Pyx_GIVEREF(__pyx_n_s_decodestring);
      __pyx_t_8 = __Pyx_Import(__pyx_n_s_base64, __pyx_t_7, 0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_8, __pyx_n_s_encodestring); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_encodebytes, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_8, __pyx_n_s_decodestring); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_decodebytes, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L13_exception_handled;
    }
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L13_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
    __pyx_L19_try_end:;
  }

  /* "axon/_objects.py":59
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes
 * 
 * try:             # <<<<<<<<<<<<<<
 *     import cdecimal as _decimal
 * except:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "axon/_objects.py":60
 * 
 * try:
 *     import cdecimal as _decimal             # <<<<<<<<<<<<<<
 * except:
 *     import decimal as _decimal
 */
      __pyx_t_2 = __Pyx_Import(__pyx_n_s_cdecimal, 0, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L22_error;}
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_decimal, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L22_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L29_try_end;
    __pyx_L22_error:;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "axon/_objects.py":61
 * try:
 *     import cdecimal as _decimal
 * except:             # <<<<<<<<<<<<<<
 *     import decimal as _decimal
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._objects", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_6, &__pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L24_except_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_1);

      /* "axon/_objects.py":62
 *     import cdecimal as _decimal
 * except:
 *     import decimal as _decimal             # <<<<<<<<<<<<<<
 * 
 * default_decimal_context = _decimal.getcontext()
 */
      __pyx_t_8 = __Pyx_Import(__pyx_n_s_decimal_2, 0, 0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L24_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_decimal, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L24_except_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L23_exception_handled;
    }
    __pyx_L24_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L23_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L29_try_end:;
  }

  /* "axon/_objects.py":64
 *     import decimal as _decimal
 * 
 * default_decimal_context = _decimal.getcontext()             # <<<<<<<<<<<<<<
 * _str2decimal = default_decimal_context.create_decimal
 * _decimal2str = default_decimal_context.to_eng_string
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_decimal); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_getcontext); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_default_decimal_context, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":65
 * 
 * default_decimal_context = _decimal.getcontext()
 * _str2decimal = default_decimal_context.create_decimal             # <<<<<<<<<<<<<<
 * _decimal2str = default_decimal_context.to_eng_string
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_default_decimal_context); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_create_decimal); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects__str2decimal);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects__str2decimal, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "axon/_objects.py":66
 * default_decimal_context = _decimal.getcontext()
 * _str2decimal = default_decimal_context.create_decimal
 * _decimal2str = default_decimal_context.to_eng_string             # <<<<<<<<<<<<<<
 * 
 * # ATOMIC = 1
 */
  __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_default_decimal_context); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_eng_string); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects__decimal2str);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects__decimal2str, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":95
 *         return '??'
 * 
 * def isundef(o):             # <<<<<<<<<<<<<<
 *     return type(o) is Undefined
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_1isundef, 0, __pyx_n_s_isundef, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__24)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_isundef, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":98
 *     return type(o) is Undefined
 * 
 * c_undefined = Undefined()             # <<<<<<<<<<<<<<
 * undef = c_undefined
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Undefined)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects_c_undefined);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_c_undefined, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":99
 * 
 * c_undefined = Undefined()
 * undef = c_undefined             # <<<<<<<<<<<<<<
 * 
 * def _error_readonly(self):
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_undef, __pyx_v_4axon_8_objects_c_undefined) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_objects.py":101
 * undef = c_undefined
 * 
 * def _error_readonly(self):             # <<<<<<<<<<<<<<
 *     return AttributeError(
 *         'Readonly object type %r don\'t support assigning items or attributes' \
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_3_error_readonly, 0, __pyx_n_s_error_readonly, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__26)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_error_readonly, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":106
 *         % type(self))
 * 
 * def _error_empty_mapping(self):             # <<<<<<<<<<<<<<
 *     return KeyError(
 *         'Object %r contains an empty mapping' \
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_5_error_empty_mapping, 0, __pyx_n_s_error_empty_mapping, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__28)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_error_empty_mapping, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":111
 *         % type(self))
 * 
 * def _error_empty_sequence(self):             # <<<<<<<<<<<<<<
 *     return KeyError(
 *         'Object %r contains an empty sequence' \
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_7_error_empty_sequence, 0, __pyx_n_s_error_empty_sequence, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__30)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_error_empty_sequence, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":116
 *         % type(self))
 * 
 * def _error_invalid_name(name):             # <<<<<<<<<<<<<<
 *     return KeyError('Invalid name: %r' % type(name))
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_9_error_invalid_name, 0, __pyx_n_s_error_invalid_name, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__32)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_error_invalid_name, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":123
 * #####################################################
 * 
 * c_undescore = '_'             # <<<<<<<<<<<<<<
 * empty_name = ''
 * 
 */
  __Pyx_INCREF(__pyx_n_u__33);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects_c_undescore);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_c_undescore, __pyx_n_u__33);
  __Pyx_GIVEREF(__pyx_n_u__33);

  /* "axon/_objects.py":124
 * 
 * c_undescore = '_'
 * empty_name = ''             # <<<<<<<<<<<<<<
 * 
 * name_cache = {None: empty_name, c_undescore: c_undescore}
 */
  __Pyx_INCREF(__pyx_kp_u__17);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects_empty_name);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_empty_name, __pyx_kp_u__17);
  __Pyx_GIVEREF(__pyx_kp_u__17);

  /* "axon/_objects.py":126
 * empty_name = ''
 * 
 * name_cache = {None: empty_name, c_undescore: c_undescore}             # <<<<<<<<<<<<<<
 * 
 * def clear_all_names():
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, Py_None, __pyx_v_4axon_8_objects_empty_name) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_1, __pyx_v_4axon_8_objects_c_undescore, __pyx_v_4axon_8_objects_c_undescore) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects_name_cache);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_name_cache, ((PyObject*)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":128
 * name_cache = {None: empty_name, c_undescore: c_undescore}
 * 
 * def clear_all_names():             # <<<<<<<<<<<<<<
 *     name_cache = {}
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_11clear_all_names, 0, __pyx_n_s_clear_all_names, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__35)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_clear_all_names, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":131
 *     name_cache = {}
 * 
 * def as_unicode(o):             # <<<<<<<<<<<<<<
 *     return c_as_unicode(o)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_13as_unicode, 0, __pyx_n_s_as_unicode, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__37)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_as_unicode, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":134
 *     return c_as_unicode(o)
 * 
 * def as_list(o):             # <<<<<<<<<<<<<<
 *     return c_as_list(o)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_15as_list, 0, __pyx_n_s_as_list, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__39)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_as_list, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":137
 *     return c_as_list(o)
 * 
 * def as_dict(o):             # <<<<<<<<<<<<<<
 *     return c_as_dict(o)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_17as_dict, 0, __pyx_n_s_as_dict, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__41)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_as_dict, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":140
 *     return c_as_dict(o)
 * 
 * def as_tuple(o):             # <<<<<<<<<<<<<<
 *     return c_as_tuple(o)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_19as_tuple, 0, __pyx_n_s_as_tuple, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__43)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_as_tuple, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":194
 *             raise TypeError('The type of %r is not rlist' % type(self))
 * 
 * c_empty_dict = rdict({})             # <<<<<<<<<<<<<<
 * c_empty_list = rlist([])
 * 
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_rdict)), __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_8_objects_c_empty_dict));
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_c_empty_dict, ((struct ReadonlyDict *)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":195
 * 
 * c_empty_dict = rdict({})
 * c_empty_list = rlist([])             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_rlist)), __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_8_objects_c_empty_list));
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_c_empty_list, ((struct ReadonlyList *)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":334
 *     '''
 *     @property
 *     def mapping(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Empty, __pyx_n_s_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":333
 * 
 *     '''
 *     @property             # <<<<<<<<<<<<<<
 *     def mapping(self):
 *         return None
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Empty->tp_dict, __pyx_n_s_mapping, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Empty);

  /* "axon/_objects.py":338
 *     #
 *     @property
 *     def sequence(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Empty, __pyx_n_s_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":337
 *         return None
 *     #
 *     @property             # <<<<<<<<<<<<<<
 *     def sequence(self):
 *         return None
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 337; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 337; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Empty->tp_dict, __pyx_n_s_sequence, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Empty);

  /* "axon/_objects.py":342
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(c_empty_dict)
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Empty, __pyx_n_s_a); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":341
 *         return None
 *     #
 *     @property             # <<<<<<<<<<<<<<
 *     def a(self):
 *         return new_attrs(c_empty_dict)
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 341; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 341; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Empty->tp_dict, __pyx_n_s_a, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Empty);

  /* "axon/_objects.py":398
 *     #
 *     @property
 *     def mapping(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Sequence, __pyx_n_s_mapping); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 398; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":397
 *     '''
 *     #
 *     @property             # <<<<<<<<<<<<<<
 *     def mapping(self):
 *         return None
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Sequence->tp_dict, __pyx_n_s_mapping, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 398; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Sequence);

  /* "axon/_objects.py":402
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(c_empty_dict)
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Sequence, __pyx_n_s_a); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":401
 *         return None
 *     #
 *     @property             # <<<<<<<<<<<<<<
 *     def a(self):
 *         return new_attrs(c_empty_dict)
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 401; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 401; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Sequence->tp_dict, __pyx_n_s_a, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Sequence);

  /* "axon/_objects.py":467
 *     #
 *     @property
 *     def sequence(self):             # <<<<<<<<<<<<<<
 *         return None
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Mapping, __pyx_n_s_sequence); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 467; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":466
 *     '''
 *     #
 *     @property             # <<<<<<<<<<<<<<
 *     def sequence(self):
 *         return None
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Mapping->tp_dict, __pyx_n_s_sequence, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 467; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Mapping);

  /* "axon/_objects.py":471
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Mapping, __pyx_n_s_a); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":470
 *         return None
 *     #
 *     @property             # <<<<<<<<<<<<<<
 *     def a(self):
 *         return new_attrs(self.mapping)
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Mapping->tp_dict, __pyx_n_s_a, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Mapping);

  /* "axon/_objects.py":543
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Element, __pyx_n_s_a); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":542
 *     '''
 *     #
 *     @property             # <<<<<<<<<<<<<<
 *     def a(self):
 *         return new_attrs(self.mapping)
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 542; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 542; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Element->tp_dict, __pyx_n_s_a, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Element);

  /* "axon/_objects.py":629
 *     #
 *     @property
 *     def a(self):             # <<<<<<<<<<<<<<
 *         return new_attrs(self.mapping)
 *     #
 */
  __pyx_t_1 = __Pyx_GetNameInClass((PyObject *)__pyx_ptype_4axon_8_objects_Instance, __pyx_n_s_a); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":628
 *     '''
 *     #
 *     @property             # <<<<<<<<<<<<<<
 *     def a(self):
 *         return new_attrs(self.mapping)
 */
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 628; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_property, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 628; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_4axon_8_objects_Instance->tp_dict, __pyx_n_s_a, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_4axon_8_objects_Instance);

  /* "axon/_objects.py":729
 * #NAME_IS_EMPTY = 'Name is empty'
 * 
 * def sequence(name, sequence=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named sequence.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_25sequence, 0, __pyx_n_s_sequence, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 729; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__46);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sequence, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 729; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":743
 *     return c_new_sequence(c_as_name(name), c_as_list(sequence))
 * #
 * def mapping(name, mapping=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named mapping.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_27mapping, 0, __pyx_n_s_mapping, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__48)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__49);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mapping, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":757
 *     return c_new_mapping(c_as_name(name), c_as_dict(mapping))
 * #
 * def element(name, mapping, sequence=None):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named element.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_29element, 0, __pyx_n_s_element_2, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__52);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_element_2, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 757; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":775
 *     return c_new_element(c_as_name(name), c_as_dict(mapping), c_as_list(sequence))
 * #
 * def instance(name, sequence, mapping):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating named instance.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_31instance, 0, __pyx_n_s_instance_2, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__54)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_instance_2, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":794
 *     return c_new_instance(c_as_name(name), c_as_tuple(sequence), c_as_dict(mapping))
 * #
 * def empty(name):             # <<<<<<<<<<<<<<
 *     '''
 *     Factory function for creating empty complex value.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_33empty, 0, __pyx_n_s_empty_2, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__56)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_empty_2, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":805
 * #
 * 
 * c_factory_dict = {}             # <<<<<<<<<<<<<<
 * 
 * def reset_factory():
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects_c_factory_dict);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_c_factory_dict, ((PyObject*)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":807
 * c_factory_dict = {}
 * 
 * def reset_factory():             # <<<<<<<<<<<<<<
 *     c_factory_dict = {}
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_35reset_factory, 0, __pyx_n_s_reset_factory, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__58)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reset_factory, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 807; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":810
 *     c_factory_dict = {}
 * 
 * def factory(name, factory_func=None):             # <<<<<<<<<<<<<<
 *     name = c_as_unicode(name)
 *     if factory_func is None:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_37factory, 0, __pyx_n_s_factory_2, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__60)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__61);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_factory_2, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 810; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":966
 *         return self.empty(name)
 * 
 * c_builder_dict = {             # <<<<<<<<<<<<<<
 *     'safe': SafeBuilder(),
 *     'strict': StrictBuilder(),
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "axon/_objects.py":967
 * 
 * c_builder_dict = {
 *     'safe': SafeBuilder(),             # <<<<<<<<<<<<<<
 *     'strict': StrictBuilder(),
 *     'mixed': MixedBuilder()
 */
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_SafeBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 967; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_safe, __pyx_t_6) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "axon/_objects.py":968
 * c_builder_dict = {
 *     'safe': SafeBuilder(),
 *     'strict': StrictBuilder(),             # <<<<<<<<<<<<<<
 *     'mixed': MixedBuilder()
 * }
 */
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_StrictBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 968; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_strict, __pyx_t_6) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "axon/_objects.py":969
 *     'safe': SafeBuilder(),
 *     'strict': StrictBuilder(),
 *     'mixed': MixedBuilder()             # <<<<<<<<<<<<<<
 * }
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_MixedBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_mixed, __pyx_t_6) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects_c_builder_dict);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_c_builder_dict, ((PyObject*)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":972
 * }
 * 
 * def register_builder(mode, builder):             # <<<<<<<<<<<<<<
 *     c_builder_dict[mode] = builder
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_8_objects_39register_builder, 0, __pyx_n_s_register_builder, NULL, __pyx_n_s_axon__objects, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_register_builder, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.py":978
 *     return c_get_builder(mode)
 * 
 * _inf = float('inf')             # <<<<<<<<<<<<<<
 * _ninf = float('-inf')
 * _nan = float('nan')
 */
  __pyx_t_9 = __Pyx_PyObject_AsDouble(__pyx_n_u_inf_2); if (unlikely(__pyx_t_9 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 978; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = PyFloat_FromDouble(__pyx_t_9); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 978; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects__inf);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects__inf, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":979
 * 
 * _inf = float('inf')
 * _ninf = float('-inf')             # <<<<<<<<<<<<<<
 * _nan = float('nan')
 * _decimal_inf = _str2decimal('Infinity')
 */
  __pyx_t_9 = __Pyx_PyObject_AsDouble(__pyx_kp_u_inf_3); if (unlikely(__pyx_t_9 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 979; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = PyFloat_FromDouble(__pyx_t_9); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 979; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects__ninf);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects__ninf, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":980
 * _inf = float('inf')
 * _ninf = float('-inf')
 * _nan = float('nan')             # <<<<<<<<<<<<<<
 * _decimal_inf = _str2decimal('Infinity')
 * _decimal_ninf = _str2decimal('-Infinity')
 */
  __pyx_t_9 = __Pyx_PyObject_AsDouble(__pyx_n_u_nan_2); if (unlikely(__pyx_t_9 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = PyFloat_FromDouble(__pyx_t_9); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects__nan);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects__nan, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":981
 * _ninf = float('-inf')
 * _nan = float('nan')
 * _decimal_inf = _str2decimal('Infinity')             # <<<<<<<<<<<<<<
 * _decimal_ninf = _str2decimal('-Infinity')
 * _decimal_nan = _str2decimal('NaN')
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_4axon_8_objects__str2decimal, __pyx_tuple__64, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 981; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects__decimal_inf);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects__decimal_inf, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":982
 * _nan = float('nan')
 * _decimal_inf = _str2decimal('Infinity')
 * _decimal_ninf = _str2decimal('-Infinity')             # <<<<<<<<<<<<<<
 * _decimal_nan = _str2decimal('NaN')
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_4axon_8_objects__str2decimal, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 982; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects__decimal_ninf);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects__decimal_ninf, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":983
 * _decimal_inf = _str2decimal('Infinity')
 * _decimal_ninf = _str2decimal('-Infinity')
 * _decimal_nan = _str2decimal('NaN')             # <<<<<<<<<<<<<<
 * 
 * tz_dict = {}
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_4axon_8_objects__str2decimal, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 983; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects__decimal_nan);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects__decimal_nan, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":985
 * _decimal_nan = _str2decimal('NaN')
 * 
 * tz_dict = {}             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 985; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_4axon_8_objects_tz_dict);
  __Pyx_DECREF_SET(__pyx_v_4axon_8_objects_tz_dict, ((PyObject*)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_objects.py":1
 * # coding: utf-8             # <<<<<<<<<<<<<<
 * 
 * #cython: boundscheck=False
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_objects.pxd":351
 * cdef dict c_builder_dict
 * 
 * cdef inline Builder c_get_builder(object mode):             # <<<<<<<<<<<<<<
 *     return <Builder>c_builder_dict.get(mode, None)
 * 
 */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  if (__pyx_m) {
    __Pyx_AddTraceback("init axon._objects", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init axon._objects");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
#if PY_VERSION_HEX >= 0x02060000
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
#endif
    result = (*call)(func, arg, kw);
#if PY_VERSION_HEX >= 0x02060000
    Py_LeaveRecursiveCall();
#endif
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON
    result = PyDict_GetItem(__pyx_d, name);
    if (result) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    #if PY_VERSION_HEX < 0x02050000
    if (PyClass_Check(type)) {
    #else
    if (PyType_Check(type)) {
    #endif
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        #if PY_VERSION_HEX < 0x02050000
        if (PyInstance_Check(type)) {
            type = (PyObject*) ((PyInstanceObject*)type)->in_class;
            Py_INCREF(type);
        } else {
            type = 0;
            PyErr_SetString(PyExc_TypeError,
                "raise: exception must be an old-style class or instance");
            goto raise_error;
        }
        #else
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
        #endif
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else /* Python 3+ */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                if (PyObject_IsSubclass(instance_class, type)) {
                    type = instance_class;
                } else {
                    instance_class = NULL;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_COMPILING_IN_CPYTHON
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    } else {
        if (default_value == Py_None)
            default_value = NULL;
        value = PyObject_CallMethodObjArgs(
            d, __pyx_n_s_get, key, default_value, NULL);
    }
#endif
    return value;
}

static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL)
        value = Py_None; /* Mark as deleted */
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    Py_DECREF(res);
    return 0;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
#ifndef PY_WRITE_RESTRICTED /* < Py2.5 */
#define PY_WRITE_RESTRICTED WRITE_RESTRICTED
#endif
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CyFunctionObject, func.m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {__Pyx_NAMESTR("__reduce__"), (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    op->func_weakreflist = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyMem_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    if (m->func_weakreflist != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return PyMethod_New(func,
                            type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
#if CYTHON_COMPILING_IN_PYPY
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    Py_ssize_t size;
    switch (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)) {
    case METH_VARARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0)
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 0)
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 1)
                return (*meth)(self, PyTuple_GET_ITEM(arg, 0));
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
#else
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
	return PyCFunction_Call(func, arg, kw);
}
#endif
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __Pyx_NAMESTR("cython_function_or_method"), /*tp_name*/
    sizeof(__pyx_CyFunctionObject),   /*tp_basicsize*/
    0,                                  /*tp_itemsize*/
    (destructor) __Pyx_CyFunction_dealloc, /*tp_dealloc*/
    0,                                  /*tp_print*/
    0,                                  /*tp_getattr*/
    0,                                  /*tp_setattr*/
#if PY_MAJOR_VERSION < 3
    0,                                  /*tp_compare*/
#else
    0,                                  /*reserved*/
#endif
    (reprfunc) __Pyx_CyFunction_repr,   /*tp_repr*/
    0,                                  /*tp_as_number*/
    0,                                  /*tp_as_sequence*/
    0,                                  /*tp_as_mapping*/
    0,                                  /*tp_hash*/
    __Pyx_CyFunction_Call,              /*tp_call*/
    0,                                  /*tp_str*/
    0,                                  /*tp_getattro*/
    0,                                  /*tp_setattro*/
    0,                                  /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC, /* tp_flags*/
    0,                                  /*tp_doc*/
    (traverseproc) __Pyx_CyFunction_traverse,   /*tp_traverse*/
    (inquiry) __Pyx_CyFunction_clear,   /*tp_clear*/
    0,                                  /*tp_richcompare*/
    offsetof(__pyx_CyFunctionObject, func_weakreflist), /* tp_weaklistoffse */
    0,                                  /*tp_iter*/
    0,                                  /*tp_iternext*/
    __pyx_CyFunction_methods,           /*tp_methods*/
    __pyx_CyFunction_members,           /*tp_members*/
    __pyx_CyFunction_getsets,           /*tp_getset*/
    0,                                  /*tp_base*/
    0,                                  /*tp_dict*/
    __Pyx_CyFunction_descr_get,         /*tp_descr_get*/
    0,                                  /*tp_descr_set*/
    offsetof(__pyx_CyFunctionObject, func_dict),/*tp_dictoffset*/
    0,                                  /*tp_init*/
    0,                                  /*tp_alloc*/
    0,                                  /*tp_new*/
    0,                                  /*tp_free*/
    0,                                  /*tp_is_gc*/
    0,                                  /*tp_bases*/
    0,                                  /*tp_mro*/
    0,                                  /*tp_cache*/
    0,                                  /*tp_subclasses*/
    0,                                  /*tp_weaklist*/
    0,                                  /*tp_del*/
#if PY_VERSION_HEX >= 0x02060000
    0,                                  /*tp_version_tag*/
#endif
#if PY_VERSION_HEX >= 0x030400a1
    0,                                  /*tp_finalize*/
#endif
};
static int __Pyx_CyFunction_init(void) {
#if !CYTHON_COMPILING_IN_PYPY
    __pyx_CyFunctionType_type.tp_call = PyCFunction_Call;
#endif
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (__pyx_CyFunctionType == NULL) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyMem_Malloc(size);
    if (!m->defaults)
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_traverse != current_tp_traverse)
        type = type->tp_base;
    while (type && type->tp_traverse == current_tp_traverse)
        type = type->tp_base;
    if (type && type->tp_traverse)
        return type->tp_traverse(obj, v, a);
    return 0;
}

static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_clear != current_tp_clear)
        type = type->tp_base;
    while (type && type->tp_clear == current_tp_clear)
        type = type->tp_base;
    if (type && type->tp_clear)
        type->tp_clear(obj);
}

static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_dealloc != current_tp_dealloc)
        type = type->tp_base;
    while (type && type->tp_dealloc == current_tp_dealloc)
        type = type->tp_base;
    if (type)
        type->tp_dealloc(obj);
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
#else
    PyErr_GetExcInfo(type, value, tb);
#endif
}
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(type, value, tb);
#endif
}

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

static PyObject *__Pyx_GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    result = __Pyx_PyObject_GetAttrStr(nmspace, name);
    if (!result)
        result = __Pyx_GetModuleGlobalName(name);
    return result;
}

static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if CYTHON_COMPILING_IN_PYPY
    float_value = PyNumber_Float(obj);
#else
    PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
    if (likely(nb) && likely(nb->nb_float)) {
        float_value = nb->nb_float(obj);
        if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
            PyErr_Format(PyExc_TypeError,
                "__float__ returned non-float (type %.200s)",
                Py_TYPE(float_value)->tp_name);
            Py_DECREF(float_value);
            goto bad;
        }
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(int) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func)             \
    {                                                                     \
        func_type value = func(x);                                        \
        if (sizeof(target_type) < sizeof(func_type)) {                    \
            if (unlikely(value != (func_type) (target_type) value)) {     \
                func_type zero = 0;                                       \
                PyErr_SetString(PyExc_OverflowError,                      \
                    (is_unsigned && unlikely(value < zero)) ?             \
                    "can't convert negative value to " #target_type :     \
                    "value too large to convert to " #target_type);       \
                return (target_type) -1;                                  \
            }                                                             \
        }                                                                 \
        return (target_type) value;                                       \
    }

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG)
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to int");
                return (int) -1;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(int)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (int) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to int");
                return (int) -1;
            }
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long, PyLong_AsUnsignedLong)
            } else if (sizeof(int) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long long, PyLong_AsUnsignedLongLong)
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(int)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(int) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(int) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(int, long, PyLong_AsLong)
            } else if (sizeof(int) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(int, long long, PyLong_AsLongLong)
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(long) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG)
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long) -1;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long) -1;
            }
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long, PyLong_AsUnsignedLong)
            } else if (sizeof(long) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long long, PyLong_AsUnsignedLongLong)
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(long, long, PyLong_AsLong)
            } else if (sizeof(long) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(long, long long, PyLong_AsLongLong)
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig) {
    PyObject *d;
    PyObject *cobj = 0;
    d = PyDict_GetItem(__pyx_d, __pyx_n_s_pyx_capi);
    Py_XINCREF(d);
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (__Pyx_PyObject_SetAttrStr(__pyx_m, __pyx_n_s_pyx_capi, d) < 0)
            goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    cobj = PyCapsule_New(p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItem(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    cobj = PyCapsule_New(tmp.p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(tmp.p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        #if PY_VERSION_HEX < 0x02050000
        if (PyErr_Warn(NULL, warning) < 0) goto bad;
        #else
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
        #endif
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif /*__PYX_DEFAULT_STRING_ENCODING_IS_ASCII*/
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else /* PY_VERSION_HEX < 0x03030000 */
        if (PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_DATA_SIZE(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
        return PyUnicode_AsUTF8AndSize(o, length);
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
#endif /* PY_VERSION_HEX < 0x03030000 */
    } else
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII  || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT */
#if !CYTHON_COMPILING_IN_PYPY
#if PY_VERSION_HEX >= 0x02060000
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b)))
      return PyInt_AS_LONG(b);
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
     #if CYTHON_USE_PYLONG_INTERNALS
       switch (Py_SIZE(b)) {
       case -1: return -(sdigit)((PyLongObject*)b)->ob_digit[0];
       case  0: return 0;
       case  1: return ((PyLongObject*)b)->ob_digit[0];
       }
     #endif
    #endif
  #if PY_VERSION_HEX < 0x02060000
    return PyInt_AsSsize_t(b);
  #else
    return PyLong_AsSsize_t(b);
  #endif
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}


#endif /* Py_PYTHON_H */
