/* Generated by Cython 0.20.1 on Mon Jun 23 19:17:59 2014 */

#define PY_SSIZE_T_CLEAN
#ifndef CYTHON_USE_PYLONG_INTERNALS
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 0
#else
#include "pyconfig.h"
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 1
#else
#define CYTHON_USE_PYLONG_INTERNALS 0
#endif
#endif
#endif
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#define CYTHON_ABI "0_20_1"
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if CYTHON_COMPILING_IN_PYPY
#define Py_OptimizeFlag 0
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_As_int(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_TPFLAGS_HAVE_VERSION_TAG 0
#endif
#if PY_VERSION_HEX < 0x02060000 && !defined(Py_TPFLAGS_IS_ABSTRACT)
  #define Py_TPFLAGS_IS_ABSTRACT 0
#endif
#if PY_VERSION_HEX < 0x030400a1 && !defined(Py_TPFLAGS_HAVE_FINALIZE)
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ? \
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#define __Pyx_PyString_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj) || \
                                         PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  /* Initialize NaN. The sign is irrelevant, an exponent with all bits 1 and
   a nonzero mantissa means NaN. If the first bit in the mantissa is 1, it is
   a quiet NaN. */
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__axon___dumper
#define __PYX_HAVE_API__axon___dumper
#include "math.h"
#include "floatobject.h"
#include "utils.h"
#include "string.h"
#include "stdio.h"
#include "datetime.h"
#include "bytesobject.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (    \
    (sizeof(type) < sizeof(Py_ssize_t))  ||             \
    (sizeof(type) > sizeof(Py_ssize_t) &&               \
          likely(v < (type)PY_SSIZE_T_MAX ||            \
                 v == (type)PY_SSIZE_T_MAX)  &&         \
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||       \
                                v == (type)PY_SSIZE_T_MIN)))  ||  \
    (sizeof(type) == sizeof(Py_ssize_t) &&              \
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||        \
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromUString(s)  __Pyx_PyObject_FromString((char*)s)
#define __Pyx_PyBytes_FromUString(s)   __Pyx_PyBytes_FromString((char*)s)
#define __Pyx_PyByteArray_FromUString(s)   __Pyx_PyByteArray_FromString((char*)s)
#define __Pyx_PyStr_FromUString(s)     __Pyx_PyStr_FromString((char*)s)
#define __Pyx_PyUnicode_FromUString(s) __Pyx_PyUnicode_FromString((char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return u_end - u - 1;
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    if (strcmp(PyBytes_AsString(default_encoding), "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        const char* default_encoding_c = PyBytes_AS_STRING(default_encoding);
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (ascii_chars_u == NULL) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (ascii_chars_b == NULL || strncmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
    }
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    default_encoding_c = PyBytes_AS_STRING(default_encoding);
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(sys);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "_dumper.py",
  "_dumper.pxd",
  "datetime.pxd",
  "_objects.pxd",
};

/*--- Type declarations ---*/
struct UndefinedObject;
struct ReadonlyDict;
struct ReadonlyList;
struct __pyx_obj_4axon_8_objects_NamedValue;
struct Attribute;
struct __pyx_obj_4axon_8_objects_Attrs;
struct EmptyObject;
struct SequenceObject;
struct MappingObject;
struct ElementObject;
struct InstanceObject;
struct __pyx_obj_4axon_8_objects_Builder;
struct __pyx_obj_4axon_8_objects_SafeBuilder;
struct __pyx_obj_4axon_8_objects_StrictBuilder;
struct __pyx_obj_4axon_8_objects_MixedBuilder;
struct GenericBuilderObject;
struct SimpleBuilder;
struct __pyx_obj_4axon_8_objects_StringReader;
struct __pyx_obj_4axon_8_objects_StringWriter;
struct TimeZoneUTCObject;
struct __pyx_obj_4axon_7_dumper_PyInt;
struct __pyx_obj_4axon_7_dumper_PyPointer;
struct __pyx_obj_4axon_7_dumper_SimpleDumper;
struct SimpleDumpers;
struct Dumper;
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce;
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str;

/* "axon/_objects.pxd":142
 * 
 * 
 * ctypedef PyObject* PyObjectPtr             # <<<<<<<<<<<<<<
 * 
 * cdef public unicode empty_name
 */
typedef PyObject *__pyx_t_4axon_8_objects_PyObjectPtr;

/* "axon/_objects.pxd":193
 * 
 * @cython.final
 * cdef public class Undefined[object UndefinedObject, type UndefinedType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct UndefinedObject {
  PyObject_HEAD
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) UndefinedType;

/* "axon/_objects.pxd":200
 * #
 * @cython.final
 * cdef public class rdict(dict)[object ReadonlyDict, type ReadonlyDictType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct ReadonlyDict {
  PyDictObject __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ReadonlyDictType;

/* "axon/_objects.pxd":207
 * #
 * @cython.final
 * cdef public class rlist(list)[object ReadonlyList, type ReadonlyListType]:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct ReadonlyList {
  PyListObject __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ReadonlyListType;

/* "axon/_objects.pxd":213
 * cdef public rlist c_empty_list
 * 
 * cdef class NamedValue:             # <<<<<<<<<<<<<<
 *     cdef public object __name__
 *     cdef public object __value__
 */
struct __pyx_obj_4axon_8_objects_NamedValue {
  PyObject_HEAD
  PyObject *__name__;
  PyObject *__value__;
};


/* "axon/_objects.pxd":223
 * #
 * @cython.final
 * cdef public class Attribute[type AttributeType, object Attribute]:             # <<<<<<<<<<<<<<
 *     cdef public unicode name
 *     cdef public object value
 */
struct Attribute {
  PyObject_HEAD
  PyObject *name;
  PyObject *value;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) AttributeType;

/* "axon/_objects.pxd":232
 * cdef public Attribute c_new_attribute(unicode name, object value)
 * 
 * cdef class Attrs(object):             # <<<<<<<<<<<<<<
 *     #
 *     cdef public dict mapping
 */
struct __pyx_obj_4axon_8_objects_Attrs {
  PyObject_HEAD
  PyObject *mapping;
};


/* "axon/_objects.pxd":244
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Empty[type EmptyType, object EmptyObject]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 * 
 */
struct EmptyObject {
  PyObject_HEAD
  PyObject *name;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) EmptyType;

/* "axon/_objects.pxd":252
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Sequence[object SequenceObject, type SequenceType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public list sequence
 */
struct SequenceObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SequenceType;

/* "axon/_objects.pxd":262
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Mapping[object MappingObject, type MappingType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public dict mapping
 */
struct MappingObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) MappingType;

/* "axon/_objects.pxd":272
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Element[object ElementObject, type ElementType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public dict mapping
 */
struct ElementObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *mapping;
  PyObject *sequence;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) ElementType;

/* "axon/_objects.pxd":282
 * @cython.freelist(64)
 * @cython.final
 * cdef public class Instance[object InstanceObject, type InstanceType]:             # <<<<<<<<<<<<<<
 *     cdef public object name
 *     cdef public tuple sequence
 */
struct InstanceObject {
  PyObject_HEAD
  PyObject *name;
  PyObject *sequence;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) InstanceType;

/* "axon/_objects.pxd":308
 * cdef public dict c_factory_dict
 * 
 * cdef class Builder:             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */
struct __pyx_obj_4axon_8_objects_Builder {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_Builder *__pyx_vtab;
};


/* "axon/_objects.pxd":315
 *     cdef public object create_empty(self, object)
 * 
 * cdef class SafeBuilder(Builder):             # <<<<<<<<<<<<<<
 *     @cython.locals(o=Mapping)
 *     cdef public object create_mapping(self, object, dict)
 */
struct __pyx_obj_4axon_8_objects_SafeBuilder {
  struct __pyx_obj_4axon_8_objects_Builder __pyx_base;
};


/* "axon/_objects.pxd":327
 *     cdef public object create_empty(self, object)
 * 
 * cdef class StrictBuilder(Builder):             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */
struct __pyx_obj_4axon_8_objects_StrictBuilder {
  struct __pyx_obj_4axon_8_objects_Builder __pyx_base;
};


/* "axon/_objects.pxd":334
 *     cdef public object create_empty(self, object)
 * 
 * cdef class MixedBuilder(Builder):             # <<<<<<<<<<<<<<
 *     cdef SafeBuilder builder
 *     cdef public object create_mapping(self, object, dict)
 */
struct __pyx_obj_4axon_8_objects_MixedBuilder {
  struct __pyx_obj_4axon_8_objects_Builder __pyx_base;
  struct __pyx_obj_4axon_8_objects_SafeBuilder *builder;
};


/* "axon/_objects.pxd":342
 *     cdef public object create_empty(self, object)
 * 
 * cdef public class GenericBuilder(Builder)[object GenericBuilderObject, type GenericBuilderType]:             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */
struct GenericBuilderObject {
  struct __pyx_obj_4axon_8_objects_Builder __pyx_base;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) GenericBuilderType;

/* "axon/_objects.pxd":367
 * cdef dict tz_dict = {}
 * 
 * cdef public class SimpleBuilder[type SimpleBuilderType, object SimpleBuilder]:             # <<<<<<<<<<<<<<
 * 
 *     @cython.locals(n=int, i=int, buf=cython.p_char, num_buffer=bytes)
 */
struct SimpleBuilder {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_SimpleBuilder *__pyx_vtab;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleBuilderType;

/* "axon/_objects.pxd":392
 * 
 * @cython.final
 * cdef class StringReader:             # <<<<<<<<<<<<<<
 *     cdef unicode buffer
 *     cdef int pos
 */
struct __pyx_obj_4axon_8_objects_StringReader {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_StringReader *__pyx_vtab;
  PyObject *buffer;
  int pos;
  int n;
};


/* "axon/_objects.pxd":404
 * 
 * @cython.final
 * cdef class StringWriter:             # <<<<<<<<<<<<<<
 * 
 *     cdef list blocks
 */
struct __pyx_obj_4axon_8_objects_StringWriter {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_8_objects_StringWriter *__pyx_vtab;
  PyObject *blocks;
  PyObject *items;
  int n;
};


/* "axon/_objects.pxd":418
 * cdef object timezone_cls
 * 
 * cdef public class timezone(tzinfo)[object TimeZoneUTCObject, type TimeZoneUTCType]:             # <<<<<<<<<<<<<<
 *     """Fixed offset in minutes east from UTC."""
 * 
 */
struct TimeZoneUTCObject {
  PyDateTime_TZInfo __pyx_base;
  PyObject *offset;
  PyObject *name;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) TimeZoneUTCType;

/* "axon/_dumper.pxd":117
 *     return <Empty>ob
 * 
 * cdef class PyInt:             # <<<<<<<<<<<<<<
 *     cdef long val
 * 
 */
struct __pyx_obj_4axon_7_dumper_PyInt {
  PyObject_HEAD
  long val;
};


/* "axon/_dumper.pxd":174
 * cdef public dict c_reduce_dict
 * 
 * cdef class PyPointer:             # <<<<<<<<<<<<<<
 *     cdef unicode (*ptr)(object)
 * 
 */
struct __pyx_obj_4axon_7_dumper_PyPointer {
  PyObject_HEAD
  PyObject *(*ptr)(PyObject *);
};


/* "axon/_dumper.pxd":180
 * cdef PyPointer c_new_pyptr(unicode (*p)(object))
 * 
 * cdef class SimpleDumper:             # <<<<<<<<<<<<<<
 * 
 *     cdef inline unicode dump_int(SimpleDumper, object)
 */
struct __pyx_obj_4axon_7_dumper_SimpleDumper {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumper *__pyx_vtab;
};


/* "axon/_dumper.pxd":213
 * cdef SimpleDumper _simple_dumper
 * 
 * cdef public class SimpleDumpers[type SimpleDumpersType, object SimpleDumpers]:             # <<<<<<<<<<<<<<
 *     cdef public dict mapping
 * 
 */
struct SimpleDumpers {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumpers *__pyx_vtab;
  PyObject *mapping;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleDumpersType;

/* "axon/_dumper.pxd":279
 * 
 * @cython.final
 * cdef public class Dumper[object Dumper, type DumperType]:             # <<<<<<<<<<<<<<
 *     '''
 *     Dumper class
 */
struct Dumper {
  PyObject_HEAD
  struct __pyx_vtabstruct_4axon_7_dumper_Dumper *__pyx_vtab;
  PyObject *c_simple_dumpers;
  PyObject *c_type_reducers;
  long size;
  long max_size;
  int hsize;
  PyObject *fd;
  struct __pyx_obj_4axon_8_objects_StringWriter *sfd;
  struct __pyx_obj_4axon_7_dumper_SimpleDumper *sdumper;
  int pretty;
  int sorted;
  int crossref;
  PyObject *crossref_dict;
  PyObject *crossref_set;
  PyObject *crossref_set2;
  int quote;
};

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) DumperType;

/* "axon/_dumper.py":150
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce {
  PyObject_HEAD
  PyObject *__pyx_v_type_;
};


/* "axon/_dumper.py":418
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */
struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str {
  PyObject_HEAD
  PyObject *__pyx_v_tp;
};



/* "axon/_objects.pxd":308
 * cdef public dict c_factory_dict
 * 
 * cdef class Builder:             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */

struct __pyx_vtabstruct_4axon_8_objects_Builder {
  PyObject *(*create_mapping)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *);
  PyObject *(*create_element)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *);
  PyObject *(*create_sequence)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *);
  PyObject *(*create_instance)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *, PyObject *, PyObject *);
  PyObject *(*create_empty)(struct __pyx_obj_4axon_8_objects_Builder *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_8_objects_Builder *__pyx_vtabptr_4axon_8_objects_Builder;


/* "axon/_objects.pxd":315
 *     cdef public object create_empty(self, object)
 * 
 * cdef class SafeBuilder(Builder):             # <<<<<<<<<<<<<<
 *     @cython.locals(o=Mapping)
 *     cdef public object create_mapping(self, object, dict)
 */

struct __pyx_vtabstruct_4axon_8_objects_SafeBuilder {
  struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_base;
};
static struct __pyx_vtabstruct_4axon_8_objects_SafeBuilder *__pyx_vtabptr_4axon_8_objects_SafeBuilder;


/* "axon/_objects.pxd":327
 *     cdef public object create_empty(self, object)
 * 
 * cdef class StrictBuilder(Builder):             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */

struct __pyx_vtabstruct_4axon_8_objects_StrictBuilder {
  struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_base;
};
static struct __pyx_vtabstruct_4axon_8_objects_StrictBuilder *__pyx_vtabptr_4axon_8_objects_StrictBuilder;


/* "axon/_objects.pxd":334
 *     cdef public object create_empty(self, object)
 * 
 * cdef class MixedBuilder(Builder):             # <<<<<<<<<<<<<<
 *     cdef SafeBuilder builder
 *     cdef public object create_mapping(self, object, dict)
 */

struct __pyx_vtabstruct_4axon_8_objects_MixedBuilder {
  struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_base;
};
static struct __pyx_vtabstruct_4axon_8_objects_MixedBuilder *__pyx_vtabptr_4axon_8_objects_MixedBuilder;

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) GenericBuilderType;

/* "axon/_objects.pxd":342
 *     cdef public object create_empty(self, object)
 * 
 * cdef public class GenericBuilder(Builder)[object GenericBuilderObject, type GenericBuilderType]:             # <<<<<<<<<<<<<<
 *     cdef public object create_mapping(self, object, dict)
 *     cdef public object create_element(self, object, dict, list)
 */

struct __pyx_vtabstruct_4axon_8_objects_GenericBuilder {
  struct __pyx_vtabstruct_4axon_8_objects_Builder __pyx_base;
};
static struct __pyx_vtabstruct_4axon_8_objects_GenericBuilder *__pyx_vtabptr_4axon_8_objects_GenericBuilder;

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleBuilderType;

/* "axon/_objects.pxd":367
 * cdef dict tz_dict = {}
 * 
 * cdef public class SimpleBuilder[type SimpleBuilderType, object SimpleBuilder]:             # <<<<<<<<<<<<<<
 * 
 *     @cython.locals(n=int, i=int, buf=cython.p_char, num_buffer=bytes)
 */

struct __pyx_vtabstruct_4axon_8_objects_SimpleBuilder {
  PyObject *(*create_int)(struct SimpleBuilder *, PyObject *);
  PyObject *(*create_float)(struct SimpleBuilder *, PyObject *);
  PyObject *(*create_decimal)(struct SimpleBuilder *, PyObject *);
  PyObject *(*create_time)(struct SimpleBuilder *, int, int, int, int, PyObject *);
  PyObject *(*create_timedelta)(struct SimpleBuilder *, int, int, int);
  PyObject *(*create_date)(struct SimpleBuilder *, int, int, int);
  PyObject *(*create_datetime)(struct SimpleBuilder *, int, int, int, int, int, int, int, PyObject *);
  PyObject *(*create_tzinfo)(struct SimpleBuilder *, int);
  PyObject *(*create_inf)(struct SimpleBuilder *);
  PyObject *(*create_ninf)(struct SimpleBuilder *);
  PyObject *(*create_nan)(struct SimpleBuilder *);
  PyObject *(*create_decimal_inf)(struct SimpleBuilder *);
  PyObject *(*create_decimal_ninf)(struct SimpleBuilder *);
  PyObject *(*create_decimal_nan)(struct SimpleBuilder *);
  PyObject *(*create_binary)(struct SimpleBuilder *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_8_objects_SimpleBuilder *__pyx_vtabptr_4axon_8_objects_SimpleBuilder;


/* "axon/_objects.pxd":392
 * 
 * @cython.final
 * cdef class StringReader:             # <<<<<<<<<<<<<<
 *     cdef unicode buffer
 *     cdef int pos
 */

struct __pyx_vtabstruct_4axon_8_objects_StringReader {
  PyObject *(*readline)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_4axon_8_objects_StringReader *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4axon_8_objects_StringReader *__pyx_vtabptr_4axon_8_objects_StringReader;


/* "axon/_objects.pxd":404
 * 
 * @cython.final
 * cdef class StringWriter:             # <<<<<<<<<<<<<<
 * 
 *     cdef list blocks
 */

struct __pyx_vtabstruct_4axon_8_objects_StringWriter {
  PyObject *(*write)(struct __pyx_obj_4axon_8_objects_StringWriter *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getvalue)(struct __pyx_obj_4axon_8_objects_StringWriter *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_4axon_8_objects_StringWriter *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_4axon_8_objects_StringWriter *__pyx_vtabptr_4axon_8_objects_StringWriter;


/* "axon/_dumper.py":228
 * #
 * 
 * class SimpleDumper:             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, o):
 */

struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumper {
  PyObject *(*dump_int)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_float)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_decimal)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_str)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_bytes)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_unicode)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_bool)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_date)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*_dump_tzinfo)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_time)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_datetime)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
  PyObject *(*dump_none)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumper *__pyx_vtabptr_4axon_7_dumper_SimpleDumper;
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_int(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_float(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_decimal(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_str(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_bytes(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_unicode(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_bool(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_date(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper__dump_tzinfo(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_time(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_datetime(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_none(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *);

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) SimpleDumpersType;

/* "axon/_dumper.py":402
 * _simple_dumper = SimpleDumper()
 * 
 * class SimpleDumpers:             # <<<<<<<<<<<<<<
 *     #cdef dict c_mapping
 * 
 */

struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumpers {
  void (*add)(struct SimpleDumpers *, PyObject *, PyObject *(*)(PyObject *));
  void (*update)(struct SimpleDumpers *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumpers *__pyx_vtabptr_4axon_7_dumper_SimpleDumpers;

__PYX_EXTERN_C DL_EXPORT(PyTypeObject) DumperType;

/* "axon/_dumper.py":517
 * 
 * 
 * class Dumper:             # <<<<<<<<<<<<<<
 *     '''
 *     Dumper class
 */

struct __pyx_vtabstruct_4axon_7_dumper_Dumper {
  void (*write)(struct Dumper *, PyObject *);
  void (*_pretty_dump_crossref)(struct Dumper *, PyObject *);
  void (*_dump_crossref)(struct Dumper *, PyObject *);
  int (*_dump_label)(struct Dumper *, PyObject *);
  int (*_dump)(struct Dumper *, PyObject *);
  int (*_pretty_dump)(struct Dumper *, PyObject *, PyObject *, int);
  int (*_dump_value)(struct Dumper *, PyObject *);
  int (*_dump_dict_sequence)(struct Dumper *, PyObject *);
  int (*_dump_attr_sequence)(struct Dumper *, PyObject *);
  int (*_dump_list_sequence)(struct Dumper *, PyObject *);
  int (*_dump_tuple_sequence)(struct Dumper *, PyObject *);
  int (*dump_list)(struct Dumper *, PyObject *);
  int (*dump_dict)(struct Dumper *, PyObject *);
  int (*dump_tuple)(struct Dumper *, PyObject *);
  int (*dump_mapping)(struct Dumper *, struct MappingObject *);
  int (*dump_element)(struct Dumper *, struct ElementObject *);
  int (*dump_sequence)(struct Dumper *, struct SequenceObject *);
  int (*dump_instance)(struct Dumper *, struct InstanceObject *);
  int (*dump_empty)(struct Dumper *, struct EmptyObject *);
  int (*_pretty_dump_dict_sequence)(struct Dumper *, PyObject *, PyObject *, int);
  int (*_pretty_dump_attr_sequence)(struct Dumper *, PyObject *, PyObject *, int);
  int (*_pretty_dump_list_sequence)(struct Dumper *, PyObject *, PyObject *, int);
  int (*_pretty_dump_tuple_sequence)(struct Dumper *, PyObject *, PyObject *, int);
  int (*pretty_dump_list)(struct Dumper *, PyObject *, PyObject *, int);
  int (*pretty_dump_dict)(struct Dumper *, PyObject *, PyObject *, int);
  int (*pretty_dump_mapping)(struct Dumper *, struct MappingObject *, PyObject *, int);
  int (*pretty_dump_element)(struct Dumper *, struct ElementObject *, PyObject *, int);
  int (*pretty_dump_sequence)(struct Dumper *, struct SequenceObject *, PyObject *, int);
  int (*pretty_dump_instance)(struct Dumper *, struct InstanceObject *, PyObject *, int);
  int (*pretty_dump_empty)(struct Dumper *, struct EmptyObject *, PyObject *, int);
  void (*apply_crossref)(struct Dumper *);
  int (*_collect)(struct Dumper *, PyObject *);
  int (*_collect_list)(struct Dumper *, PyObject *);
  int (*_collect_tuple)(struct Dumper *, PyObject *);
  int (*_collect_set)(struct Dumper *, PyObject *);
  int (*_collect_dict)(struct Dumper *, PyObject *);
  int (*_collect_mapping)(struct Dumper *, struct MappingObject *);
  int (*_collect_sequence)(struct Dumper *, struct SequenceObject *);
  int (*_collect_element)(struct Dumper *, struct ElementObject *);
  int (*_collect_instance)(struct Dumper *, struct InstanceObject *);
  int (*_collect_empty)(struct Dumper *, struct EmptyObject *);
  int (*collect)(struct Dumper *, PyObject *);
};
static struct __pyx_vtabstruct_4axon_7_dumper_Dumper *__pyx_vtabptr_4axon_7_dumper_Dumper;
static CYTHON_INLINE void __pyx_f_4axon_7_dumper_6Dumper_write(struct Dumper *, PyObject *);
static void __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_crossref(struct Dumper *, PyObject *);
static void __pyx_f_4axon_7_dumper_6Dumper__dump_crossref(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_label(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(struct Dumper *, PyObject *, PyObject *, int);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_value(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_dict_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_list(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_dict(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_tuple(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_mapping(struct Dumper *, struct MappingObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_element(struct Dumper *, struct ElementObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_sequence(struct Dumper *, struct SequenceObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_instance(struct Dumper *, struct InstanceObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_dump_empty(struct Dumper *, struct EmptyObject *);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_dict_sequence(struct Dumper *, PyObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence(struct Dumper *, PyObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(struct Dumper *, PyObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence(struct Dumper *, PyObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_list(struct Dumper *, PyObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_dict(struct Dumper *, PyObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_mapping(struct Dumper *, struct MappingObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_element(struct Dumper *, struct ElementObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_sequence(struct Dumper *, struct SequenceObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_instance(struct Dumper *, struct InstanceObject *, PyObject *, int);
static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_empty(struct Dumper *, struct EmptyObject *, PyObject *, int);
static void __pyx_f_4axon_7_dumper_6Dumper_apply_crossref(struct Dumper *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_list(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_tuple(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_set(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_dict(struct Dumper *, PyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_mapping(struct Dumper *, struct MappingObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_sequence(struct Dumper *, struct SequenceObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_element(struct Dumper *, struct ElementObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_instance(struct Dumper *, struct InstanceObject *);
static int __pyx_f_4axon_7_dumper_6Dumper__collect_empty(struct Dumper *, struct EmptyObject *);
static int __pyx_f_4axon_7_dumper_6Dumper_collect(struct Dumper *, PyObject *);
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_XDECREF_SET(r, v) do {                            \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_XDECREF(tmp);                              \
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {                             \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_DECREF(tmp);                               \
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw); /*proto*/
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

static CYTHON_INLINE int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

#define __Pyx_CyFunction_USED 1
#include <structmember.h>
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f) \
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f) \
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f) \
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g) \
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
    PyObject *func_dict;
    PyObject *func_weakreflist;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj; /* No-args super() class cell */
    void *defaults;
    int defaults_pyobjects;
    int flags;
    PyObject *defaults_tuple;   /* Const defaults tuple */
    PyObject *defaults_kwdict;  /* Const kwonly defaults dict */
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations; /* function annotations dict */
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code) \
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __Pyx_CyFunction_init(void);

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type); /*proto*/

static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value); /*proto*/

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void); /*proto*/

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected); /*proto*/

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

#define __Pyx_GetItemInt_Unicode(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck) \
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ? \
    __Pyx_GetItemInt_Unicode_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) : \
    (PyErr_SetString(PyExc_IndexError, "string index out of range"), (Py_UCS4)-1))
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck);

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

static CYTHON_INLINE int __Pyx_PySequence_Contains(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

#if PY_VERSION_HEX < 0x02050000
#ifndef PyAnySet_CheckExact
#define PyAnySet_CheckExact(ob) \
    ((ob)->ob_type == &PySet_Type || \
     (ob)->ob_type == &PyFrozenSet_Type)
#define PySet_New(iterable) \
    PyObject_CallFunctionObjArgs((PyObject *)&PySet_Type, (iterable), NULL)
#define Pyx_PyFrozenSet_New(iterable) \
    PyObject_CallFunctionObjArgs((PyObject *)&PyFrozenSet_Type, (iterable), NULL)
#define PySet_Size(anyset) \
    PyObject_Size((anyset))
#define PySet_Contains(anyset, key) \
    PySequence_Contains((anyset), (key))
#define PySet_Pop(set) \
    PyObject_CallMethod((set), (char*)"pop", NULL)
static CYTHON_INLINE int PySet_Clear(PyObject *set) {
    PyObject *ret = PyObject_CallMethod(set, (char*)"clear", NULL);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
static CYTHON_INLINE int PySet_Discard(PyObject *set, PyObject *key) {
    PyObject *ret = PyObject_CallMethod(set, (char*)"discard", (char*)"(O)", key);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
static CYTHON_INLINE int PySet_Add(PyObject *set, PyObject *key) {
    PyObject *ret = PyObject_CallMethod(set, (char*)"add", (char*)"(O)", key);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
#endif /* PyAnySet_CheckExact (<= Py2.4) */
#endif /* < Py2.5  */

static PyObject* __Pyx_PyObject_CallMethodTuple(PyObject* obj, PyObject* method_name, PyObject* args) {
    PyObject *method, *result = NULL;
    if (unlikely(!args)) return NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_Call(method, args, NULL);
    Py_DECREF(method);
bad:
    Py_DECREF(args);
    return result;
}
#define __Pyx_PyObject_CallMethod3(obj, name, arg1, arg2, arg3) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(3, arg1, arg2, arg3))
#define __Pyx_PyObject_CallMethod2(obj, name, arg1, arg2) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(2, arg1, arg2))
#define __Pyx_PyObject_CallMethod1(obj, name, arg1) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(1, arg1))
#define __Pyx_PyObject_CallMethod0(obj, name) \
    __Pyx_PyObject_CallMethodTuple(obj, name, (Py_INCREF(__pyx_empty_tuple), __pyx_empty_tuple))

static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d); /*proto*/

#define __Pyx_PyIter_Next(obj) __Pyx_PyIter_Next2(obj, NULL)
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject *, PyObject *); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index); /*proto*/

static CYTHON_INLINE int __Pyx_unpack_tuple2(PyObject* tuple, PyObject** value1, PyObject** value2,
                                             int is_tuple, int has_known_size, int decref_tuple);

static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

#include <string.h>

static int __Pyx_SetVtable(PyObject *dict, void *vtable); /*proto*/

static void* __Pyx_GetVtable(PyObject *dict); /*proto*/

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name); /*proto*/

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb); /*proto*/
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb); /*proto*/

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level); /*proto*/

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

static int __Pyx_check_binary_version(void);

#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig); /*proto*/

static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig); /*proto*/

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyObject *__Pyx_ImportModule(const char *name); /*proto*/

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);  /*proto*/

static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig); /*proto*/

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'cython' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.dict' */

/* Module declarations from 'cpython.unicode' */

/* Module declarations from 'cpython.bytes' */

/* Module declarations from 'cpython.long' */

/* Module declarations from 'datetime' */

/* Module declarations from 'cpython.datetime' */
static PyTypeObject *__pyx_ptype_7cpython_8datetime_date = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_time = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_datetime = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_timedelta = 0;
static PyTypeObject *__pyx_ptype_7cpython_8datetime_tzinfo = 0;
static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_date_new(int, int, int); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_new(int, int, int, int, PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_new(int, int, int, int, int, int, int, PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timedelta_new(int, int, int); /*proto*/

/* Module declarations from 'axon._objects' */
static PyTypeObject *__pyx_ptype_4axon_8_objects_Undefined = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_rdict = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_rlist = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_NamedValue = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Attribute = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Attrs = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Empty = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Sequence = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Mapping = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Element = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Instance = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_Builder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_SafeBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_StrictBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_MixedBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_GenericBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_SimpleBuilder = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_StringReader = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_StringWriter = 0;
static PyTypeObject *__pyx_ptype_4axon_8_objects_timezone = 0;
static PyObject **__pyx_vp_4axon_8_objects__decimal2str = 0;
#define __pyx_v_4axon_8_objects__decimal2str (*__pyx_vp_4axon_8_objects__decimal2str)
static PyObject **__pyx_vp_4axon_8_objects_empty_name = 0;
#define __pyx_v_4axon_8_objects_empty_name (*__pyx_vp_4axon_8_objects_empty_name)
static PyObject **__pyx_vp_4axon_8_objects_c_undescore = 0;
#define __pyx_v_4axon_8_objects_c_undescore (*__pyx_vp_4axon_8_objects_c_undescore)
static PyObject **__pyx_vp_4axon_8_objects_c_undefined = 0;
#define __pyx_v_4axon_8_objects_c_undefined (*__pyx_vp_4axon_8_objects_c_undefined)
static PyObject **__pyx_vp_4axon_8_objects_name_cache = 0;
#define __pyx_v_4axon_8_objects_name_cache (*__pyx_vp_4axon_8_objects_name_cache)
static PyObject **__pyx_vp_4axon_8_objects_c_str_type = 0;
#define __pyx_v_4axon_8_objects_c_str_type (*__pyx_vp_4axon_8_objects_c_str_type)
static struct ReadonlyDict **__pyx_vp_4axon_8_objects_c_empty_dict = 0;
#define __pyx_v_4axon_8_objects_c_empty_dict (*__pyx_vp_4axon_8_objects_c_empty_dict)
static struct ReadonlyList **__pyx_vp_4axon_8_objects_c_empty_list = 0;
#define __pyx_v_4axon_8_objects_c_empty_list (*__pyx_vp_4axon_8_objects_c_empty_list)
static PyObject **__pyx_vp_4axon_8_objects_c_factory_dict = 0;
#define __pyx_v_4axon_8_objects_c_factory_dict (*__pyx_vp_4axon_8_objects_c_factory_dict)
static PyObject **__pyx_vp_4axon_8_objects_c_builder_dict = 0;
#define __pyx_v_4axon_8_objects_c_builder_dict (*__pyx_vp_4axon_8_objects_c_builder_dict)
static PyObject **__pyx_vp_4axon_8_objects__str2decimal = 0;
#define __pyx_v_4axon_8_objects__str2decimal (*__pyx_vp_4axon_8_objects__str2decimal)
static PyObject **__pyx_vp_4axon_8_objects__inf = 0;
#define __pyx_v_4axon_8_objects__inf (*__pyx_vp_4axon_8_objects__inf)
static PyObject **__pyx_vp_4axon_8_objects__ninf = 0;
#define __pyx_v_4axon_8_objects__ninf (*__pyx_vp_4axon_8_objects__ninf)
static PyObject **__pyx_vp_4axon_8_objects__nan = 0;
#define __pyx_v_4axon_8_objects__nan (*__pyx_vp_4axon_8_objects__nan)
static PyObject **__pyx_vp_4axon_8_objects__decimal_inf = 0;
#define __pyx_v_4axon_8_objects__decimal_inf (*__pyx_vp_4axon_8_objects__decimal_inf)
static PyObject **__pyx_vp_4axon_8_objects__decimal_ninf = 0;
#define __pyx_v_4axon_8_objects__decimal_ninf (*__pyx_vp_4axon_8_objects__decimal_ninf)
static PyObject **__pyx_vp_4axon_8_objects__decimal_nan = 0;
#define __pyx_v_4axon_8_objects__decimal_nan (*__pyx_vp_4axon_8_objects__decimal_nan)
static PyObject **__pyx_vp_4axon_8_objects_tz_dict = 0;
#define __pyx_v_4axon_8_objects_tz_dict (*__pyx_vp_4axon_8_objects_tz_dict)
static PyObject **__pyx_vp_4axon_8_objects_timezone_cls = 0;
#define __pyx_v_4axon_8_objects_timezone_cls (*__pyx_vp_4axon_8_objects_timezone_cls)
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_unicode(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_name(PyObject *); /*proto*/
static struct Attribute *(*__pyx_f_4axon_8_objects_c_new_attribute)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_sequence)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_mapping)(PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_element)(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_instance)(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *(*__pyx_f_4axon_8_objects_c_new_empty)(PyObject *); /*proto*/

/* Module declarations from 'axon._dumper' */
static PyTypeObject *__pyx_ptype_4axon_7_dumper_PyInt = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper_PyPointer = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper_SimpleDumper = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper_SimpleDumpers = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper_Dumper = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper___pyx_scope_struct__reduce = 0;
static PyTypeObject *__pyx_ptype_4axon_7_dumper___pyx_scope_struct_1_dump_as_str = 0;
static PyObject *__pyx_v_4axon_7_dumper_unicode_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_str_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_int_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_long_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_decimal_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_bool_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_float_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_bytes_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_bytearray_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_none_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_date_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_time_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_datetime_type = 0;
static PyObject *__pyx_v_4axon_7_dumper_simple_types = 0;
__PYX_EXTERN_C DL_EXPORT(PyObject) *c_reduce_dict;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_7_dumper_c_all_names;
static PyObject *__pyx_v_4axon_7_dumper__c_type_reducers = 0;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_7_dumper_c_factory_dict;
static struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_4axon_7_dumper__simple_dumper = 0;
__PYX_EXTERN_C DL_EXPORT(PyObject) *__pyx_v_4axon_7_dumper_c_simple_dumpers;
static PyObject *__pyx_v_4axon_7_dumper__simple_types = 0;
static PyObject *__pyx_f_4axon_7_dumper_mapping_reduce(struct MappingObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_element_reduce(struct ElementObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_sequence_reduce(struct SequenceObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_instance_reduce(struct InstanceObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_empty_reduce(struct EmptyObject *, int __pyx_skip_dispatch); /*proto*/
static struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_f_4axon_7_dumper_c_new_pyptr(PyObject *(*)(PyObject *)); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_dump_default(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_name(PyObject *); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper__dump_key(PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "axon._dumper"
int __pyx_module_is_main_axon___dumper = 0;

/* Implementation of 'axon._dumper' */
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_sorted;
static int __pyx_pf_4axon_7_dumper_5PyInt___init__(struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_self, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_5PyInt_2__repr__(struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_mapping_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct MappingObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_2element_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct ElementObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_4sequence_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct SequenceObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6instance_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct InstanceObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_8empty_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct EmptyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_10reset_reduce(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6reduce__factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_12reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_type_, PyObject *__pyx_v_reduce_func); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_14_dump_undef(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_o); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_12SimpleDumper___call__(struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o); /* proto */
static int __pyx_pf_4axon_7_dumper_13SimpleDumpers___init__(struct SimpleDumpers *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping___get__(struct SimpleDumpers *__pyx_v_self); /* proto */
static int __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_2__set__(struct SimpleDumpers *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_4__del__(struct SimpleDumpers *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_11dump_as_str__dump_as_str(PyObject *__pyx_self, PyObject *__pyx_v_func); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_16dump_as_str(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tp); /* proto */
static int __pyx_pf_4axon_7_dumper_6Dumper___init__(struct Dumper *__pyx_v_self, PyObject *__pyx_v_fd, PyObject *__pyx_v_pretty, PyObject *__pyx_v_braces, PyObject *__pyx_v_sorted, PyObject *__pyx_v_hsize, PyObject *__pyx_v_crossref); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_2_dump_set_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_4pretty_dump_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, CYTHON_UNUSED PyObject *__pyx_v_use_offset); /* proto */
static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_6dump(struct Dumper *__pyx_v_self, PyObject *__pyx_v_seq); /* proto */
static PyObject *__pyx_tp_new_4axon_7_dumper_PyInt(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper_PyPointer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper_SimpleDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper_SimpleDumpers(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper_Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct__reduce(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static char __pyx_k_0[] = "-0";
static char __pyx_k_D[] = "D";
static char __pyx_k_l[] = "l";
static char __pyx_k_o[] = "o";
static char __pyx_k_w[] = "w";
static char __pyx_k__3[] = "\077\077";
static char __pyx_k__4[] = "\"";
static char __pyx_k__5[] = "\077\077?";
static char __pyx_k__6[] = "?";
static char __pyx_k__7[] = "-\342\210\236";
static char __pyx_k__8[] = "\342\210\236";
static char __pyx_k__9[] = "|";
static char __pyx_k_fd[] = "fd";
static char __pyx_k_id[] = "id";
static char __pyx_k_tp[] = "tp";
static char __pyx_k_0_2[] = "0";
static char __pyx_k__10[] = "";
static char __pyx_k__11[] = "\\\"";
static char __pyx_k__13[] = "-";
static char __pyx_k__14[] = "+";
static char __pyx_k__18[] = "\\'";
static char __pyx_k__19[] = "'";
static char __pyx_k__20[] = " &";
static char __pyx_k__21[] = " ";
static char __pyx_k__22[] = "&";
static char __pyx_k__23[] = "*";
static char __pyx_k__24[] = "  ";
static char __pyx_k__25[] = ":";
static char __pyx_k__26[] = "{";
static char __pyx_k__27[] = "}";
static char __pyx_k__28[] = "{}";
static char __pyx_k__29[] = "[";
static char __pyx_k__30[] = "]";
static char __pyx_k__31[] = "(";
static char __pyx_k__32[] = ")";
static char __pyx_k__33[] = "\n";
static char __pyx_k__34[] = ": ";
static char __pyx_k__35[] = " {";
  static char __pyx_k__36[] = ":\n";
  static char __pyx_k__37[] = " {}";
  static char __pyx_k_day[] = "day";
  static char __pyx_k_get[] = "get";
  static char __pyx_k_ptr[] = "ptr";
  static char __pyx_k_val[] = "val";
  static char __pyx_k_days[] = "days";
  static char __pyx_k_func[] = "func";
  static char __pyx_k_hour[] = "hour";
  static char __pyx_k_main[] = "__main__";
  static char __pyx_k_null[] = "null";
  static char __pyx_k_test[] = "__test__";
  static char __pyx_k_true[] = "true";
  static char __pyx_k_type[] = "type_";
  static char __pyx_k_year[] = "year";
  static char __pyx_k_ascii[] = "ascii";
  static char __pyx_k_false[] = "false";
  static char __pyx_k_hsize[] = "hsize";
  static char __pyx_k_items[] = "items";
  static char __pyx_k_month[] = "month";
  static char __pyx_k_s_02d[] = "%s%02d";
  static char __pyx_k_types[] = "types";
  static char __pyx_k_write[] = "write";
  static char __pyx_k_base64[] = "base64";
  static char __pyx_k_braces[] = "braces";
  static char __pyx_k_divmod[] = "divmod";
  static char __pyx_k_import[] = "__import__";
  static char __pyx_k_is_nan[] = "is_nan";
  static char __pyx_k_minute[] = "minute";
  static char __pyx_k_pretty[] = "pretty";
  static char __pyx_k_reduce[] = "reduce";
  static char __pyx_k_remove[] = "remove";
  static char __pyx_k_second[] = "second";
  static char __pyx_k_sorted[] = "sorted";
  static char __pyx_k_strict[] = "strict";
  static char __pyx_k_tzinfo[] = "tzinfo";
  static char __pyx_k_update[] = "update";
  static char __pyx_k_values[] = "values";
  static char __pyx_k_02d_02d[] = "%02d:%02d";
  static char __pyx_k_decimal[] = "_decimal";
  static char __pyx_k_factory[] = "_factory";
  static char __pyx_k_seconds[] = "seconds";
  static char __pyx_k_builtins[] = "builtins";
  static char __pyx_k_cdecimal[] = "cdecimal";
  static char __pyx_k_crossref[] = "crossref";
  static char __pyx_k_datetime[] = "datetime";
  static char __pyx_k_int_type[] = "int_type";
  static char __pyx_k_pyx_capi[] = "__pyx_capi__";
  static char __pyx_k_str_type[] = "str_type";
  static char __pyx_k_TypeError[] = "TypeError";
  static char __pyx_k_bool_type[] = "bool_type";
  static char __pyx_k_d_02d_02d[] = "%d-%02d-%02d";
  static char __pyx_k_date_type[] = "date_type";
  static char __pyx_k_decimal_2[] = "decimal";
  static char __pyx_k_is_finite[] = "is_finite";
  static char __pyx_k_is_signed[] = "is_signed";
  static char __pyx_k_long_type[] = "long_type";
  static char __pyx_k_none_type[] = "none_type";
  static char __pyx_k_s_02d_02d[] = "%s%02d:%02d";
  static char __pyx_k_time_type[] = "time_type";
  static char __pyx_k_utcoffset[] = "utcoffset";
  static char __pyx_k_Empty_name[] = "Empty name";
  static char __pyx_k_ValueError[] = "ValueError";
  static char __pyx_k_axon_types[] = "axon.types";
  static char __pyx_k_bytes_type[] = "bytes_type";
  static char __pyx_k_dump_undef[] = "_dump_undef";
  static char __pyx_k_float_type[] = "float_type";
  static char __pyx_k_getcontext[] = "getcontext";
  static char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
  static char __pyx_k_use_offset[] = "use_offset";
  static char __pyx_k_02d_02d_02d[] = "%02d:%02d:%02d";
  static char __pyx_k_c_all_names[] = "c_all_names";
  static char __pyx_k_decimal2str[] = "_decimal2str";
  static char __pyx_k_decodebytes[] = "decodebytes";
  static char __pyx_k_dump_as_str[] = "_dump_as_str";
  static char __pyx_k_encodebytes[] = "encodebytes";
  static char __pyx_k_is_infinite[] = "is_infinite";
  static char __pyx_k_microsecond[] = "microsecond";
  static char __pyx_k_reduce_dict[] = "reduce_dict";
  static char __pyx_k_reduce_func[] = "reduce_func";
  static char __pyx_k_RuntimeError[] = "RuntimeError";
  static char __pyx_k_axon__dumper[] = "axon._dumper";
  static char __pyx_k_decimal_type[] = "decimal_type";
  static char __pyx_k_decodestring[] = "decodestring";
  static char __pyx_k_empty_reduce[] = "empty_reduce";
  static char __pyx_k_encodestring[] = "encodestring";
  static char __pyx_k_factory_func[] = "factory_func";
  static char __pyx_k_reset_reduce[] = "reset_reduce";
  static char __pyx_k_simple_types[] = "simple_types";
  static char __pyx_k_unicode_type[] = "unicode_type";
  static char __pyx_k_c_reduce_dict[] = "c_reduce_dict";
  static char __pyx_k_datetime_type[] = "datetime_type";
  static char __pyx_k_dump_as_str_2[] = "dump_as_str";
  static char __pyx_k_simple_dumper[] = "_simple_dumper";
  static char __pyx_k_to_eng_string[] = "to_eng_string";
  static char __pyx_k_bytearray_type[] = "bytearray_type";
  static char __pyx_k_c_factory_dict[] = "c_factory_dict";
  static char __pyx_k_element_reduce[] = "element_reduce";
  static char __pyx_k_mapping_reduce[] = "mapping_reduce";
  static char __pyx_k_simple_types_2[] = "_simple_types";
  static char __pyx_k_02d_02d_02d_06d[] = "%02d:%02d:%02d.%06d";
  static char __pyx_k_c_type_reducers[] = "_c_type_reducers";
  static char __pyx_k_instance_reduce[] = "instance_reduce";
  static char __pyx_k_sequence_reduce[] = "sequence_reduce";
  static char __pyx_k_c_simple_dumpers[] = "c_simple_dumpers";
  static char __pyx_k_pretty_dump_tuple[] = "pretty_dump_tuple";
  static char __pyx_k_d_02d_02dT_02d_02d[] = "%d-%02d-%02dT%02d:%02d";
  static char __pyx_k_d_02d_02dT_02d_02d_02d[] = "%d-%02d-%02dT%02d:%02d:%02d";
  static char __pyx_k_reduce_locals__factory[] = "reduce.<locals>._factory";
  static char __pyx_k_default_decimal_context[] = "default_decimal_context";
  static char __pyx_k_d_02d_02dT_02d_02d_02d_06d[] = "%d-%02d-%02dT%02d:%02d:%02d.%06d";
  static char __pyx_k_Users_sz_repos_pyaxon_lib_axon[] = "/Users/sz/repos/pyaxon/lib/axon/_dumper.py";
  static char __pyx_k_dump_as_str_locals__dump_as_str[] = "dump_as_str.<locals>._dump_as_str";
  static char __pyx_k_There_is_no_reducer_for_this_typ[] = "There is no reducer for this type: ";
  static char __pyx_k_This_object_r_is_not_unicode_com[] = "This object %r is not unicode compatible";
  static char __pyx_k_There_is_no_reducer_for_this_typ_2[] = "There is no reducer for this type: %r %r";
  static PyObject *__pyx_kp_u_0;
  static PyObject *__pyx_kp_u_02d_02d;
  static PyObject *__pyx_kp_u_02d_02d_02d;
  static PyObject *__pyx_kp_u_02d_02d_02d_06d;
  static PyObject *__pyx_kp_u_0_2;
  static PyObject *__pyx_n_u_D;
  static PyObject *__pyx_kp_u_Empty_name;
  static PyObject *__pyx_n_s_RuntimeError;
  static PyObject *__pyx_kp_u_There_is_no_reducer_for_this_typ;
  static PyObject *__pyx_kp_u_There_is_no_reducer_for_this_typ_2;
  static PyObject *__pyx_kp_s_This_object_r_is_not_unicode_com;
  static PyObject *__pyx_n_s_TypeError;
  static PyObject *__pyx_kp_s_Users_sz_repos_pyaxon_lib_axon;
  static PyObject *__pyx_n_s_ValueError;
  static PyObject *__pyx_kp_s__10;
  static PyObject *__pyx_kp_u__10;
  static PyObject *__pyx_kp_u__11;
  static PyObject *__pyx_kp_u__13;
  static PyObject *__pyx_kp_u__14;
  static PyObject *__pyx_kp_u__18;
  static PyObject *__pyx_kp_u__19;
  static PyObject *__pyx_kp_u__20;
  static PyObject *__pyx_kp_u__21;
  static PyObject *__pyx_kp_u__22;
  static PyObject *__pyx_n_s__23;
  static PyObject *__pyx_kp_u__23;
  static PyObject *__pyx_kp_u__24;
  static PyObject *__pyx_kp_u__25;
  static PyObject *__pyx_kp_u__26;
  static PyObject *__pyx_kp_u__27;
  static PyObject *__pyx_kp_u__28;
  static PyObject *__pyx_kp_u__29;
  static PyObject *__pyx_kp_u__3;
  static PyObject *__pyx_kp_u__30;
  static PyObject *__pyx_kp_u__31;
  static PyObject *__pyx_kp_u__32;
  static PyObject *__pyx_kp_u__33;
  static PyObject *__pyx_kp_u__34;
  static PyObject *__pyx_kp_u__35;
  static PyObject *__pyx_kp_u__36;
  static PyObject *__pyx_kp_u__37;
  static PyObject *__pyx_kp_u__4;
  static PyObject *__pyx_kp_u__5;
  static PyObject *__pyx_kp_u__6;
  static PyObject *__pyx_kp_u__7;
  static PyObject *__pyx_kp_u__8;
  static PyObject *__pyx_kp_u__9;
  static PyObject *__pyx_n_s_axon__dumper;
  static PyObject *__pyx_n_s_axon_types;
  static PyObject *__pyx_n_s_base64;
  static PyObject *__pyx_n_s_bool_type;
  static PyObject *__pyx_n_s_braces;
  static PyObject *__pyx_n_s_builtins;
  static PyObject *__pyx_n_s_bytearray_type;
  static PyObject *__pyx_n_s_bytes_type;
  static PyObject *__pyx_n_s_c_all_names;
  static PyObject *__pyx_n_s_c_factory_dict;
  static PyObject *__pyx_n_s_c_reduce_dict;
  static PyObject *__pyx_n_s_c_simple_dumpers;
  static PyObject *__pyx_n_s_c_type_reducers;
  static PyObject *__pyx_n_s_cdecimal;
  static PyObject *__pyx_n_s_crossref;
  static PyObject *__pyx_kp_u_d_02d_02d;
  static PyObject *__pyx_kp_u_d_02d_02dT_02d_02d;
  static PyObject *__pyx_kp_u_d_02d_02dT_02d_02d_02d;
  static PyObject *__pyx_kp_u_d_02d_02dT_02d_02d_02d_06d;
  static PyObject *__pyx_n_s_date_type;
  static PyObject *__pyx_n_s_datetime;
  static PyObject *__pyx_n_s_datetime_type;
  static PyObject *__pyx_n_s_day;
  static PyObject *__pyx_n_s_days;
  static PyObject *__pyx_n_s_decimal;
  static PyObject *__pyx_n_s_decimal2str;
  static PyObject *__pyx_n_s_decimal_2;
  static PyObject *__pyx_n_s_decimal_type;
  static PyObject *__pyx_n_s_decodebytes;
  static PyObject *__pyx_n_s_decodestring;
  static PyObject *__pyx_n_s_default_decimal_context;
  static PyObject *__pyx_n_s_divmod;
  static PyObject *__pyx_n_s_dump_as_str;
  static PyObject *__pyx_n_s_dump_as_str_2;
  static PyObject *__pyx_n_s_dump_as_str_locals__dump_as_str;
  static PyObject *__pyx_n_s_dump_undef;
  static PyObject *__pyx_n_s_element_reduce;
  static PyObject *__pyx_n_s_empty_reduce;
  static PyObject *__pyx_n_s_encodebytes;
  static PyObject *__pyx_n_s_encodestring;
  static PyObject *__pyx_n_s_factory;
  static PyObject *__pyx_n_s_factory_func;
  static PyObject *__pyx_n_u_false;
  static PyObject *__pyx_n_s_fd;
  static PyObject *__pyx_n_s_float_type;
  static PyObject *__pyx_n_s_func;
  static PyObject *__pyx_n_s_get;
  static PyObject *__pyx_n_s_getcontext;
  static PyObject *__pyx_n_s_hour;
  static PyObject *__pyx_n_s_hsize;
  static PyObject *__pyx_n_s_id;
  static PyObject *__pyx_n_s_import;
  static PyObject *__pyx_n_s_instance_reduce;
  static PyObject *__pyx_n_s_int_type;
  static PyObject *__pyx_n_s_is_finite;
  static PyObject *__pyx_n_s_is_infinite;
  static PyObject *__pyx_n_s_is_nan;
  static PyObject *__pyx_n_s_is_signed;
  static PyObject *__pyx_n_s_items;
  static PyObject *__pyx_n_s_l;
  static PyObject *__pyx_n_s_long_type;
  static PyObject *__pyx_n_s_main;
  static PyObject *__pyx_n_s_mapping_reduce;
  static PyObject *__pyx_n_s_microsecond;
  static PyObject *__pyx_n_s_minute;
  static PyObject *__pyx_n_s_month;
  static PyObject *__pyx_n_s_none_type;
  static PyObject *__pyx_n_u_null;
  static PyObject *__pyx_n_s_o;
  static PyObject *__pyx_n_s_pretty;
  static PyObject *__pyx_n_s_pretty_dump_tuple;
  static PyObject *__pyx_n_s_ptr;
  static PyObject *__pyx_n_s_pyx_capi;
  static PyObject *__pyx_n_s_pyx_vtable;
  static PyObject *__pyx_n_s_reduce;
  static PyObject *__pyx_n_s_reduce_dict;
  static PyObject *__pyx_n_s_reduce_func;
  static PyObject *__pyx_n_s_reduce_locals__factory;
  static PyObject *__pyx_n_s_remove;
  static PyObject *__pyx_n_s_reset_reduce;
  static PyObject *__pyx_kp_u_s_02d;
  static PyObject *__pyx_kp_u_s_02d_02d;
  static PyObject *__pyx_n_s_second;
  static PyObject *__pyx_n_s_seconds;
  static PyObject *__pyx_n_s_sequence_reduce;
  static PyObject *__pyx_n_s_simple_dumper;
  static PyObject *__pyx_n_s_simple_types;
  static PyObject *__pyx_n_s_simple_types_2;
  static PyObject *__pyx_n_s_sorted;
  static PyObject *__pyx_n_s_str_type;
  static PyObject *__pyx_n_s_test;
  static PyObject *__pyx_n_s_time_type;
  static PyObject *__pyx_n_s_to_eng_string;
  static PyObject *__pyx_n_s_tp;
  static PyObject *__pyx_n_u_true;
  static PyObject *__pyx_n_s_type;
  static PyObject *__pyx_n_s_types;
  static PyObject *__pyx_n_s_tzinfo;
  static PyObject *__pyx_n_s_unicode_type;
  static PyObject *__pyx_n_s_update;
  static PyObject *__pyx_n_s_use_offset;
  static PyObject *__pyx_n_s_utcoffset;
  static PyObject *__pyx_n_s_val;
  static PyObject *__pyx_n_s_values;
  static PyObject *__pyx_n_s_w;
  static PyObject *__pyx_n_s_write;
  static PyObject *__pyx_n_s_year;
  static PyObject *__pyx_int_0;
  static PyObject *__pyx_int_1;
  static PyObject *__pyx_int_60;
  static PyObject *__pyx_int_86400;
  static PyObject *__pyx_tuple_;
  static PyObject *__pyx_tuple__12;
  static PyObject *__pyx_tuple__15;
  static PyObject *__pyx_tuple__17;
  static PyObject *__pyx_tuple__38;
  static PyObject *__pyx_tuple__39;
  static PyObject *__pyx_tuple__41;
  static PyObject *__pyx_tuple__43;
  static PyObject *__pyx_tuple__44;
  static PyObject *__pyx_tuple__46;
  static PyObject *__pyx_tuple__48;
  static PyObject *__pyx_codeobj__2;
  static PyObject *__pyx_codeobj__16;
  static PyObject *__pyx_codeobj__40;
  static PyObject *__pyx_codeobj__42;
  static PyObject *__pyx_codeobj__45;
  static PyObject *__pyx_codeobj__47;
PyObject *c_reduce_dict = 0;
PyObject *__pyx_v_4axon_7_dumper_c_all_names = 0;
PyObject *__pyx_v_4axon_7_dumper_c_factory_dict = 0;
PyObject *__pyx_v_4axon_7_dumper_c_simple_dumpers = 0;

/* "axon/_dumper.py":85
 * class PyInt:
 * 
 *     def __init__(self, val):             # <<<<<<<<<<<<<<
 *         self.val = val
 * 
 */

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_5PyInt_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_7_dumper_5PyInt_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_val = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_val)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_val = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.PyInt.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_5PyInt___init__(((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_dumper_5PyInt___init__(struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_self, PyObject *__pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_dumper.py":86
 * 
 *     def __init__(self, val):
 *         self.val = val             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_t_1 = __Pyx_PyInt_As_long(__pyx_v_val); if (unlikely((__pyx_t_1 == (long)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->val = __pyx_t_1;

  /* "axon/_dumper.py":85
 * class PyInt:
 * 
 *     def __init__(self, val):             # <<<<<<<<<<<<<<
 *         self.val = val
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.PyInt.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":88
 *         self.val = val
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return str(self.val)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_5PyInt_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_5PyInt_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_5PyInt_2__repr__(((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_5PyInt_2__repr__(struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "axon/_dumper.py":89
 * 
 *     def __repr__(self):
 *         return str(self.val)             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v_self->val); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_dumper.py":88
 *         self.val = val
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return str(self.val)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.PyInt.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":95
 * #
 * 
 * def mapping_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_1mapping_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_mapping_reduce(struct MappingObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mapping_reduce", 0);

  /* "axon/_dumper.py":96
 * 
 * def mapping_reduce(o):
 *     return o             # <<<<<<<<<<<<<<
 * #
 * def element_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_o));
  __pyx_r = ((PyObject *)__pyx_v_o);
  goto __pyx_L0;

  /* "axon/_dumper.py":95
 * #
 * 
 * def mapping_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_1mapping_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_1mapping_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mapping_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Mapping, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_mapping_reduce(__pyx_self, ((struct MappingObject *)__pyx_v_o));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_mapping_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct MappingObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mapping_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_mapping_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.mapping_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":98
 *     return o
 * #
 * def element_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_3element_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_element_reduce(struct ElementObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("element_reduce", 0);

  /* "axon/_dumper.py":99
 * #
 * def element_reduce(o):
 *     return o             # <<<<<<<<<<<<<<
 * #
 * def sequence_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_o));
  __pyx_r = ((PyObject *)__pyx_v_o);
  goto __pyx_L0;

  /* "axon/_dumper.py":98
 *     return o
 * #
 * def element_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_3element_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_3element_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("element_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Element, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_2element_reduce(__pyx_self, ((struct ElementObject *)__pyx_v_o));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_2element_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct ElementObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("element_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_element_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.element_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":101
 *     return o
 * #
 * def sequence_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_5sequence_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_sequence_reduce(struct SequenceObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence_reduce", 0);

  /* "axon/_dumper.py":102
 * #
 * def sequence_reduce(o):
 *     return o             # <<<<<<<<<<<<<<
 * #
 * def instance_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_o));
  __pyx_r = ((PyObject *)__pyx_v_o);
  goto __pyx_L0;

  /* "axon/_dumper.py":101
 *     return o
 * #
 * def sequence_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_5sequence_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_5sequence_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Sequence, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_4sequence_reduce(__pyx_self, ((struct SequenceObject *)__pyx_v_o));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_4sequence_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct SequenceObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sequence_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_sequence_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.sequence_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":104
 *     return o
 * #
 * def instance_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_7instance_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_instance_reduce(struct InstanceObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("instance_reduce", 0);

  /* "axon/_dumper.py":105
 * #
 * def instance_reduce(o):
 *     return o             # <<<<<<<<<<<<<<
 * #
 * def empty_reduce(o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_o));
  __pyx_r = ((PyObject *)__pyx_v_o);
  goto __pyx_L0;

  /* "axon/_dumper.py":104
 *     return o
 * #
 * def instance_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_7instance_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_7instance_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("instance_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Instance, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_6instance_reduce(__pyx_self, ((struct InstanceObject *)__pyx_v_o));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_6instance_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct InstanceObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("instance_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_instance_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.instance_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":107
 *     return o
 * #
 * def empty_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

static PyObject *__pyx_pw_4axon_7_dumper_9empty_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_f_4axon_7_dumper_empty_reduce(struct EmptyObject *__pyx_v_o, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("empty_reduce", 0);

  /* "axon/_dumper.py":108
 * #
 * def empty_reduce(o):
 *     return o             # <<<<<<<<<<<<<<
 * #
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_o));
  __pyx_r = ((PyObject *)__pyx_v_o);
  goto __pyx_L0;

  /* "axon/_dumper.py":107
 *     return o
 * #
 * def empty_reduce(o):             # <<<<<<<<<<<<<<
 *     return o
 * #
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_9empty_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_9empty_reduce(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("empty_reduce (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_o), __pyx_ptype_4axon_8_objects_Empty, 1, "o", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_4axon_7_dumper_8empty_reduce(__pyx_self, ((struct EmptyObject *)__pyx_v_o));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_8empty_reduce(CYTHON_UNUSED PyObject *__pyx_self, struct EmptyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty_reduce", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_7_dumper_empty_reduce(__pyx_v_o, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.empty_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":143
 * c_reduce_dict = _c_type_reducers.copy()
 * 
 * def reset_reduce():             # <<<<<<<<<<<<<<
 *     c_reduce_dict = _c_type_reducers.copy()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_11reset_reduce(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_11reset_reduce = {__Pyx_NAMESTR("reset_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_11reset_reduce, METH_NOARGS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_11reset_reduce(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset_reduce (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_10reset_reduce(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_10reset_reduce(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED PyObject *__pyx_v_c_reduce_dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reset_reduce", 0);

  /* "axon/_dumper.py":144
 * 
 * def reset_reduce():
 *     c_reduce_dict = _c_type_reducers.copy()             # <<<<<<<<<<<<<<
 * 
 * #class Namespace(dict):
 */
  if (unlikely(__pyx_v_4axon_7_dumper__c_type_reducers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "copy");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PyDict_Copy(__pyx_v_4axon_7_dumper__c_type_reducers); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_c_reduce_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":143
 * c_reduce_dict = _c_type_reducers.copy()
 * 
 * def reset_reduce():             # <<<<<<<<<<<<<<
 *     c_reduce_dict = _c_type_reducers.copy()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.reset_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_c_reduce_dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":150
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_13reduce(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_13reduce = {__Pyx_NAMESTR("reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_13reduce, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_13reduce(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_type_ = 0;
  PyObject *__pyx_v_reduce_func = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reduce (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_type,&__pyx_n_s_reduce_func,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_reduce_func);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "reduce") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_type_ = values[0];
    __pyx_v_reduce_func = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("reduce", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_12reduce(__pyx_self, __pyx_v_type_, __pyx_v_reduce_func);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":152
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6reduce_1_factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_6reduce_1_factory = {__Pyx_NAMESTR("_factory"), (PyCFunction)__pyx_pw_4axon_7_dumper_6reduce_1_factory, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_6reduce_1_factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_factory (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_6reduce__factory(__pyx_self, ((PyObject *)__pyx_v_factory_func));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_6reduce__factory(PyObject *__pyx_self, PyObject *__pyx_v_factory_func) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *__pyx_cur_scope;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_factory", 0);
  __pyx_outer_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "axon/_dumper.py":153
 *     if reduce_func is None:
 *         def _factory(factory_func):
 *             c_reduce_dict[type_] = factory_func             # <<<<<<<<<<<<<<
 *             return factory_func
 *         return _factory
 */
  if (unlikely(c_reduce_dict == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_type_)) { __Pyx_RaiseClosureNameError("type_"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  if (unlikely(PyDict_SetItem(c_reduce_dict, __pyx_cur_scope->__pyx_v_type_, __pyx_v_factory_func) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":154
 *         def _factory(factory_func):
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func             # <<<<<<<<<<<<<<
 *         return _factory
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_factory_func);
  __pyx_r = __pyx_v_factory_func;
  goto __pyx_L0;

  /* "axon/_dumper.py":152
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.reduce._factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":150
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */

static PyObject *__pyx_pf_4axon_7_dumper_12reduce(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_type_, PyObject *__pyx_v_reduce_func) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *__pyx_cur_scope;
  PyObject *__pyx_v__factory = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reduce", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)__pyx_tp_new_4axon_7_dumper___pyx_scope_struct__reduce(__pyx_ptype_4axon_7_dumper___pyx_scope_struct__reduce, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_type_ = __pyx_v_type_;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_type_);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_type_);

  /* "axon/_dumper.py":151
 * 
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:             # <<<<<<<<<<<<<<
 *         def _factory(factory_func):
 *             c_reduce_dict[type_] = factory_func
 */
  __pyx_t_1 = (__pyx_v_reduce_func == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":152
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 */
    __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_6reduce_1_factory, 0, __pyx_n_s_reduce_locals__factory, ((PyObject*)__pyx_cur_scope), __pyx_n_s_axon__dumper, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__2)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v__factory = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":155
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 *         return _factory             # <<<<<<<<<<<<<<
 *     else:
 *         c_reduce_dict[type_] = reduce_func
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v__factory);
    __pyx_r = __pyx_v__factory;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_dumper.py":157
 *         return _factory
 *     else:
 *         c_reduce_dict[type_] = reduce_func             # <<<<<<<<<<<<<<
 * 
 * reduce_dict = c_reduce_dict
 */
    if (unlikely(c_reduce_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(c_reduce_dict, __pyx_cur_scope->__pyx_v_type_, __pyx_v_reduce_func) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_dumper.py":150
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__factory);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":172
 *     pass
 * 
 * def c_new_pyptr(p):             # <<<<<<<<<<<<<<
 *     pyptr = PyPointer.__new__(PyPointer)
 *     pyptr.ptr = p
 */

static struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_f_4axon_7_dumper_c_new_pyptr(PyObject *(*__pyx_v_p)(PyObject *)) {
  struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_v_pyptr = 0;
  struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_new_pyptr", 0);

  /* "axon/_dumper.py":173
 * 
 * def c_new_pyptr(p):
 *     pyptr = PyPointer.__new__(PyPointer)             # <<<<<<<<<<<<<<
 *     pyptr.ptr = p
 *     return pyptr
 */
  __pyx_t_1 = __pyx_tp_new_4axon_7_dumper_PyPointer(((PyTypeObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_PyPointer)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_4axon_7_dumper_PyPointer)))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_pyptr = ((struct __pyx_obj_4axon_7_dumper_PyPointer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":174
 * def c_new_pyptr(p):
 *     pyptr = PyPointer.__new__(PyPointer)
 *     pyptr.ptr = p             # <<<<<<<<<<<<<<
 *     return pyptr
 * 
 */
  __pyx_v_pyptr->ptr = __pyx_v_p;

  /* "axon/_dumper.py":175
 *     pyptr = PyPointer.__new__(PyPointer)
 *     pyptr.ptr = p
 *     return pyptr             # <<<<<<<<<<<<<<
 * 
 * def _dump_undef(o):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_pyptr));
  __pyx_r = __pyx_v_pyptr;
  goto __pyx_L0;

  /* "axon/_dumper.py":172
 *     pass
 * 
 * def c_new_pyptr(p):             # <<<<<<<<<<<<<<
 *     pyptr = PyPointer.__new__(PyPointer)
 *     pyptr.ptr = p
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.c_new_pyptr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pyptr);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":177
 *     return pyptr
 * 
 * def _dump_undef(o):             # <<<<<<<<<<<<<<
 *     return '??'
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_15_dump_undef(PyObject *__pyx_self, PyObject *__pyx_v_o); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_15_dump_undef = {__Pyx_NAMESTR("_dump_undef"), (PyCFunction)__pyx_pw_4axon_7_dumper_15_dump_undef, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_15_dump_undef(PyObject *__pyx_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_dump_undef (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_14_dump_undef(__pyx_self, ((PyObject *)__pyx_v_o));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_14_dump_undef(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_dump_undef", 0);

  /* "axon/_dumper.py":178
 * 
 * def _dump_undef(o):
 *     return '??'             # <<<<<<<<<<<<<<
 * 
 * # cdef unicode _dump_Name(object o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__3);
  __pyx_r = __pyx_kp_u__3;
  goto __pyx_L0;

  /* "axon/_dumper.py":177
 *     return pyptr
 * 
 * def _dump_undef(o):             # <<<<<<<<<<<<<<
 *     return '??'
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":193
 * #     dumper._pertty_dump(attr.c_value, offset, 0)
 * 
 * def dump_default(v):             # <<<<<<<<<<<<<<
 *     return c_object_to_unicode(v)
 * 
 */

static PyObject *__pyx_f_4axon_7_dumper_dump_default(PyObject *__pyx_v_v) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_default", 0);

  /* "axon/_dumper.py":194
 * 
 * def dump_default(v):
 *     return c_object_to_unicode(v)             # <<<<<<<<<<<<<<
 * 
 * c_simple_dumpers = {}
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = c_object_to_unicode(__pyx_v_v); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_dumper.py":193
 * #     dumper._pertty_dump(attr.c_value, offset, 0)
 * 
 * def dump_default(v):             # <<<<<<<<<<<<<<
 *     return c_object_to_unicode(v)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.dump_default", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":230
 * class SimpleDumper:
 * 
 *     def __call__(self, o):             # <<<<<<<<<<<<<<
 *         otype = type(o)
 *         if otype is unicode_type:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_12SimpleDumper_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_12SimpleDumper_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_o = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_o,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_o)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 230; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_o = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 230; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_12SimpleDumper___call__(((struct __pyx_obj_4axon_7_dumper_SimpleDumper *)__pyx_v_self), __pyx_v_o);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_12SimpleDumper___call__(struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_otype = NULL;
  PyObject *__pyx_v__dumper = NULL;
  PyObject *__pyx_v_ptr = NULL;
  PyObject *__pyx_v_text = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "axon/_dumper.py":231
 * 
 *     def __call__(self, o):
 *         otype = type(o)             # <<<<<<<<<<<<<<
 *         if otype is unicode_type:
 *             return '"' + self.dump_unicode(o) + '"'
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
  __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

  /* "axon/_dumper.py":232
 *     def __call__(self, o):
 *         otype = type(o)
 *         if otype is unicode_type:             # <<<<<<<<<<<<<<
 *             return '"' + self.dump_unicode(o) + '"'
 *         elif otype is str_type:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_unicode_type));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":233
 *         otype = type(o)
 *         if otype is unicode_type:
 *             return '"' + self.dump_unicode(o) + '"'             # <<<<<<<<<<<<<<
 *         elif otype is str_type:
 *             return '"' + self.dump_str(o) + '"'
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_unicode(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u__4, __pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":234
 *         if otype is unicode_type:
 *             return '"' + self.dump_unicode(o) + '"'
 *         elif otype is str_type:             # <<<<<<<<<<<<<<
 *             return '"' + self.dump_str(o) + '"'
 *         elif otype is long_type or otype is int_type:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_str_type));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":235
 *             return '"' + self.dump_unicode(o) + '"'
 *         elif otype is str_type:
 *             return '"' + self.dump_str(o) + '"'             # <<<<<<<<<<<<<<
 *         elif otype is long_type or otype is int_type:
 *             return self.dump_int(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_str(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u__4, __pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":236
 *         elif otype is str_type:
 *             return '"' + self.dump_str(o) + '"'
 *         elif otype is long_type or otype is int_type:             # <<<<<<<<<<<<<<
 *             return self.dump_int(o)
 *         elif otype is float_type:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_long_type));
  if (!(__pyx_t_1 != 0)) {
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_int_type));
    __pyx_t_5 = (__pyx_t_2 != 0);
  } else {
    __pyx_t_5 = (__pyx_t_1 != 0);
  }
  if (__pyx_t_5) {

    /* "axon/_dumper.py":237
 *             return '"' + self.dump_str(o) + '"'
 *         elif otype is long_type or otype is int_type:
 *             return self.dump_int(o)             # <<<<<<<<<<<<<<
 *         elif otype is float_type:
 *             return self.dump_float(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_int(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":238
 *         elif otype is long_type or otype is int_type:
 *             return self.dump_int(o)
 *         elif otype is float_type:             # <<<<<<<<<<<<<<
 *             return self.dump_float(o)
 *         elif otype is decimal_type:
 */
  __pyx_t_5 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_float_type));
  __pyx_t_1 = (__pyx_t_5 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":239
 *             return self.dump_int(o)
 *         elif otype is float_type:
 *             return self.dump_float(o)             # <<<<<<<<<<<<<<
 *         elif otype is decimal_type:
 *             return self.dump_decimal(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_float(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":240
 *         elif otype is float_type:
 *             return self.dump_float(o)
 *         elif otype is decimal_type:             # <<<<<<<<<<<<<<
 *             return self.dump_decimal(o)
 *         elif otype is none_type:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_decimal_type));
  __pyx_t_5 = (__pyx_t_1 != 0);
  if (__pyx_t_5) {

    /* "axon/_dumper.py":241
 *             return self.dump_float(o)
 *         elif otype is decimal_type:
 *             return self.dump_decimal(o)             # <<<<<<<<<<<<<<
 *         elif otype is none_type:
 *             return self.dump_none(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_decimal(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 241; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":242
 *         elif otype is decimal_type:
 *             return self.dump_decimal(o)
 *         elif otype is none_type:             # <<<<<<<<<<<<<<
 *             return self.dump_none(o)
 *         elif otype is bytes_type or otype is bytearray_type:
 */
  __pyx_t_5 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_none_type));
  __pyx_t_1 = (__pyx_t_5 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":243
 *             return self.dump_decimal(o)
 *         elif otype is none_type:
 *             return self.dump_none(o)             # <<<<<<<<<<<<<<
 *         elif otype is bytes_type or otype is bytearray_type:
 *             return self.dump_bytes(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_none(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 243; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":244
 *         elif otype is none_type:
 *             return self.dump_none(o)
 *         elif otype is bytes_type or otype is bytearray_type:             # <<<<<<<<<<<<<<
 *             return self.dump_bytes(o)
 *         elif otype is date_type:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_bytes_type));
  if (!(__pyx_t_1 != 0)) {
    __pyx_t_5 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_bytearray_type));
    __pyx_t_2 = (__pyx_t_5 != 0);
  } else {
    __pyx_t_2 = (__pyx_t_1 != 0);
  }
  if (__pyx_t_2) {

    /* "axon/_dumper.py":245
 *             return self.dump_none(o)
 *         elif otype is bytes_type or otype is bytearray_type:
 *             return self.dump_bytes(o)             # <<<<<<<<<<<<<<
 *         elif otype is date_type:
 *             return self.dump_date(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_bytes(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 245; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":246
 *         elif otype is bytes_type or otype is bytearray_type:
 *             return self.dump_bytes(o)
 *         elif otype is date_type:             # <<<<<<<<<<<<<<
 *             return self.dump_date(o)
 *         elif otype is time_type:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_date_type));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":247
 *             return self.dump_bytes(o)
 *         elif otype is date_type:
 *             return self.dump_date(o)             # <<<<<<<<<<<<<<
 *         elif otype is time_type:
 *             return self.dump_time(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_date(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":248
 *         elif otype is date_type:
 *             return self.dump_date(o)
 *         elif otype is time_type:             # <<<<<<<<<<<<<<
 *             return self.dump_time(o)
 *         elif otype is datetime_type:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_time_type));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":249
 *             return self.dump_date(o)
 *         elif otype is time_type:
 *             return self.dump_time(o)             # <<<<<<<<<<<<<<
 *         elif otype is datetime_type:
 *             return self.dump_datetime(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_time(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":250
 *         elif otype is time_type:
 *             return self.dump_time(o)
 *         elif otype is datetime_type:             # <<<<<<<<<<<<<<
 *             return self.dump_datetime(o)
 *         elif otype is bool_type:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_datetime_type));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":251
 *             return self.dump_time(o)
 *         elif otype is datetime_type:
 *             return self.dump_datetime(o)             # <<<<<<<<<<<<<<
 *         elif otype is bool_type:
 *             return self.dump_bool(o)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_datetime(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":252
 *         elif otype is datetime_type:
 *             return self.dump_datetime(o)
 *         elif otype is bool_type:             # <<<<<<<<<<<<<<
 *             return self.dump_bool(o)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_bool_type));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":253
 *             return self.dump_datetime(o)
 *         elif otype is bool_type:
 *             return self.dump_bool(o)             # <<<<<<<<<<<<<<
 *         else:
 *             _dumper = c_simple_dumpers.get(otype, None)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_bool(__pyx_v_self, __pyx_v_o); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_dumper.py":255
 *             return self.dump_bool(o)
 *         else:
 *             _dumper = c_simple_dumpers.get(otype, None)             # <<<<<<<<<<<<<<
 *             if _dumper is None:
 *                 return '???'
 */
    if (unlikely(__pyx_v_4axon_7_dumper_c_simple_dumpers == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 255; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_7_dumper_c_simple_dumpers, ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 255; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v__dumper = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":256
 *         else:
 *             _dumper = c_simple_dumpers.get(otype, None)
 *             if _dumper is None:             # <<<<<<<<<<<<<<
 *                 return '???'
 *             else:
 */
    __pyx_t_2 = (__pyx_v__dumper == Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":257
 *             _dumper = c_simple_dumpers.get(otype, None)
 *             if _dumper is None:
 *                 return '???'             # <<<<<<<<<<<<<<
 *             else:
 *                 if type(_dumper) is PyPointer:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__5);
      __pyx_r = __pyx_kp_u__5;
      goto __pyx_L0;
    }
    /*else*/ {

      /* "axon/_dumper.py":259
 *                 return '???'
 *             else:
 *                 if type(_dumper) is PyPointer:             # <<<<<<<<<<<<<<
 *                     ptr = _dumper
 *                     text = ptr.ptr(o)
 */
      __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v__dumper)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_PyPointer)));
      __pyx_t_2 = (__pyx_t_1 != 0);
      if (__pyx_t_2) {

        /* "axon/_dumper.py":260
 *             else:
 *                 if type(_dumper) is PyPointer:
 *                     ptr = _dumper             # <<<<<<<<<<<<<<
 *                     text = ptr.ptr(o)
 *                 else:
 */
        __Pyx_INCREF(__pyx_v__dumper);
        __pyx_v_ptr = __pyx_v__dumper;

        /* "axon/_dumper.py":261
 *                 if type(_dumper) is PyPointer:
 *                     ptr = _dumper
 *                     text = ptr.ptr(o)             # <<<<<<<<<<<<<<
 *                 else:
 *                     text = _dumper(o)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ptr, __pyx_n_s_ptr); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_v_o);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_o);
        __Pyx_GIVEREF(__pyx_v_o);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_v_text = __pyx_t_6;
        __pyx_t_6 = 0;
        goto __pyx_L5;
      }
      /*else*/ {

        /* "axon/_dumper.py":263
 *                     text = ptr.ptr(o)
 *                 else:
 *                     text = _dumper(o)             # <<<<<<<<<<<<<<
 *                 return text
 * 
 */
        __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_v_o);
        PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_o);
        __Pyx_GIVEREF(__pyx_v_o);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v__dumper, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_text = __pyx_t_4;
        __pyx_t_4 = 0;
      }
      __pyx_L5:;

      /* "axon/_dumper.py":264
 *                 else:
 *                     text = _dumper(o)
 *                 return text             # <<<<<<<<<<<<<<
 * 
 *     def dump_int(self, o):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_text);
      __pyx_r = __pyx_v_text;
      goto __pyx_L0;
    }
  }

  /* "axon/_dumper.py":230
 * class SimpleDumper:
 * 
 *     def __call__(self, o):             # <<<<<<<<<<<<<<
 *         otype = type(o)
 *         if otype is unicode_type:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF(__pyx_v__dumper);
  __Pyx_XDECREF(__pyx_v_ptr);
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":266
 *                 return text
 * 
 *     def dump_int(self, o):             # <<<<<<<<<<<<<<
 *         return c_int_tostring(o)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_int(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_int", 0);

  /* "axon/_dumper.py":267
 * 
 *     def dump_int(self, o):
 *         return c_int_tostring(o)             # <<<<<<<<<<<<<<
 * 
 *     def dump_float(self, o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = c_int_tostring(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_dumper.py":266
 *                 return text
 * 
 *     def dump_int(self, o):             # <<<<<<<<<<<<<<
 *         return c_int_tostring(o)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":269
 *         return c_int_tostring(o)
 * 
 *     def dump_float(self, o):             # <<<<<<<<<<<<<<
 *         d = PyFloat_AS_DOUBLE(o)
 *         if isfinite(d):
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_float(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  double __pyx_v_d;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_float", 0);

  /* "axon/_dumper.py":270
 * 
 *     def dump_float(self, o):
 *         d = PyFloat_AS_DOUBLE(o)             # <<<<<<<<<<<<<<
 *         if isfinite(d):
 *             return c_object_to_unicode(o)
 */
  __pyx_v_d = PyFloat_AS_DOUBLE(__pyx_v_o);

  /* "axon/_dumper.py":271
 *     def dump_float(self, o):
 *         d = PyFloat_AS_DOUBLE(o)
 *         if isfinite(d):             # <<<<<<<<<<<<<<
 *             return c_object_to_unicode(o)
 * 
 */
  __pyx_t_1 = (isfinite(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":272
 *         d = PyFloat_AS_DOUBLE(o)
 *         if isfinite(d):
 *             return c_object_to_unicode(o)             # <<<<<<<<<<<<<<
 * 
 *         if isnan(d):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = c_object_to_unicode(__pyx_v_o); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":274
 *             return c_object_to_unicode(o)
 * 
 *         if isnan(d):             # <<<<<<<<<<<<<<
 *             return '?'
 * 
 */
  __pyx_t_1 = (isnan(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":275
 * 
 *         if isnan(d):
 *             return '?'             # <<<<<<<<<<<<<<
 * 
 *         if isinf(d):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u__6);
    __pyx_r = __pyx_kp_u__6;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":277
 *             return '?'
 * 
 *         if isinf(d):             # <<<<<<<<<<<<<<
 *             if signbit(d):
 *                 return '-'
 */
  __pyx_t_1 = (isinf(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":278
 * 
 *         if isinf(d):
 *             if signbit(d):             # <<<<<<<<<<<<<<
 *                 return '-'
 *             else:
 */
    __pyx_t_1 = (signbit(__pyx_v_d) != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":279
 *         if isinf(d):
 *             if signbit(d):
 *                 return '-'             # <<<<<<<<<<<<<<
 *             else:
 *                 return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__7);
      __pyx_r = __pyx_kp_u__7;
      goto __pyx_L0;
    }
    /*else*/ {

      /* "axon/_dumper.py":281
 *                 return '-'
 *             else:
 *                 return ''             # <<<<<<<<<<<<<<
 * 
 *         if signbit(d):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      goto __pyx_L0;
    }
  }

  /* "axon/_dumper.py":283
 *                 return ''
 * 
 *         if signbit(d):             # <<<<<<<<<<<<<<
 *             return '-0'
 * 
 */
  __pyx_t_1 = (signbit(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":284
 * 
 *         if signbit(d):
 *             return '-0'             # <<<<<<<<<<<<<<
 * 
 *         return '0'
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_0);
    __pyx_r = __pyx_kp_u_0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":286
 *             return '-0'
 * 
 *         return '0'             # <<<<<<<<<<<<<<
 * 
 *     def dump_decimal(self, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u_0_2);
  __pyx_r = __pyx_kp_u_0_2;
  goto __pyx_L0;

  /* "axon/_dumper.py":269
 *         return c_int_tostring(o)
 * 
 *     def dump_float(self, o):             # <<<<<<<<<<<<<<
 *         d = PyFloat_AS_DOUBLE(o)
 *         if isfinite(d):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_float", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":288
 *         return '0'
 * 
 *     def dump_decimal(self, d):             # <<<<<<<<<<<<<<
 *         if d.is_finite():
 *             val  = c_object_to_unicode(_decimal2str(d))
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_decimal(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_d) {
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_decimal", 0);

  /* "axon/_dumper.py":289
 * 
 *     def dump_decimal(self, d):
 *         if d.is_finite():             # <<<<<<<<<<<<<<
 *             val  = c_object_to_unicode(_decimal2str(d))
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_is_finite); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 289; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 289; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 289; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "axon/_dumper.py":290
 *     def dump_decimal(self, d):
 *         if d.is_finite():
 *             val  = c_object_to_unicode(_decimal2str(d))             # <<<<<<<<<<<<<<
 * 
 *         elif d.is_nan():
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_decimal2str); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_d);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_d);
    __Pyx_GIVEREF(__pyx_v_d);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = c_object_to_unicode(__pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_val = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":292
 *             val  = c_object_to_unicode(_decimal2str(d))
 * 
 *         elif d.is_nan():             # <<<<<<<<<<<<<<
 *             val = '?'
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_is_nan); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "axon/_dumper.py":293
 * 
 *         elif d.is_nan():
 *             val = '?'             # <<<<<<<<<<<<<<
 * 
 *         elif d.is_infinite():
 */
    __Pyx_INCREF(__pyx_kp_u__6);
    __pyx_v_val = __pyx_kp_u__6;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":295
 *             val = '?'
 * 
 *         elif d.is_infinite():             # <<<<<<<<<<<<<<
 *             if d.is_signed():
 *                 val = '-'
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_is_infinite); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "axon/_dumper.py":296
 * 
 *         elif d.is_infinite():
 *             if d.is_signed():             # <<<<<<<<<<<<<<
 *                 val = '-'
 *             else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_is_signed); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_3) {

      /* "axon/_dumper.py":297
 *         elif d.is_infinite():
 *             if d.is_signed():
 *                 val = '-'             # <<<<<<<<<<<<<<
 *             else:
 *                 val = ''
 */
      __Pyx_INCREF(__pyx_kp_u__7);
      __pyx_v_val = __pyx_kp_u__7;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "axon/_dumper.py":299
 *                 val = '-'
 *             else:
 *                 val = ''             # <<<<<<<<<<<<<<
 * 
 *         elif d.is_signed():
 */
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_v_val = __pyx_kp_u__8;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":301
 *                 val = ''
 * 
 *         elif d.is_signed():             # <<<<<<<<<<<<<<
 *             val = '-0'
 *         else:
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_is_signed); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "axon/_dumper.py":302
 * 
 *         elif d.is_signed():
 *             val = '-0'             # <<<<<<<<<<<<<<
 *         else:
 *             val = '0'
 */
    __Pyx_INCREF(__pyx_kp_u_0);
    __pyx_v_val = __pyx_kp_u_0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":304
 *             val = '-0'
 *         else:
 *             val = '0'             # <<<<<<<<<<<<<<
 * 
 *         return val + 'D'
 */
    __Pyx_INCREF(__pyx_kp_u_0_2);
    __pyx_v_val = __pyx_kp_u_0_2;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":306
 *             val = '0'
 * 
 *         return val + 'D'             # <<<<<<<<<<<<<<
 * 
 *     def dump_bytes(self, o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_val, __pyx_n_u_D); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_dumper.py":288
 *         return '0'
 * 
 *     def dump_decimal(self, d):             # <<<<<<<<<<<<<<
 *         if d.is_finite():
 *             val  = c_object_to_unicode(_decimal2str(d))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_decimal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":308
 *         return val + 'D'
 * 
 *     def dump_bytes(self, o):             # <<<<<<<<<<<<<<
 *         text = PyUnicode_FromEncodedObject(encodebytes(o), 'ascii', 'strict')
 *         return c_as_unicode('|' + text)
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_bytes(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_bytes", 0);

  /* "axon/_dumper.py":309
 * 
 *     def dump_bytes(self, o):
 *         text = PyUnicode_FromEncodedObject(encodebytes(o), 'ascii', 'strict')             # <<<<<<<<<<<<<<
 *         return c_as_unicode('|' + text)
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_encodebytes); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 309; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 309; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 309; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyUnicode_FromEncodedObject(__pyx_t_3, __pyx_k_ascii, __pyx_k_strict); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 309; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 309; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_text = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":310
 *     def dump_bytes(self, o):
 *         text = PyUnicode_FromEncodedObject(encodebytes(o), 'ascii', 'strict')
 *         return c_as_unicode('|' + text)             # <<<<<<<<<<<<<<
 * 
 *     def dump_str(self, o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u__9, __pyx_v_text); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "axon/_dumper.py":308
 *         return val + 'D'
 * 
 *     def dump_bytes(self, o):             # <<<<<<<<<<<<<<
 *         text = PyUnicode_FromEncodedObject(encodebytes(o), 'ascii', 'strict')
 *         return c_as_unicode('|' + text)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_bytes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":312
 *         return c_as_unicode('|' + text)
 * 
 *     def dump_str(self, o):             # <<<<<<<<<<<<<<
 *         return self.dump_unicode(c_as_unicode(o))
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_str(struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_str", 0);

  /* "axon/_dumper.py":313
 * 
 *     def dump_str(self, o):
 *         return self.dump_unicode(c_as_unicode(o))             # <<<<<<<<<<<<<<
 * 
 *     def dump_unicode(self, line):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_unicode(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "axon/_dumper.py":312
 *         return c_as_unicode('|' + text)
 * 
 *     def dump_str(self, o):             # <<<<<<<<<<<<<<
 *         return self.dump_unicode(c_as_unicode(o))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":315
 *         return self.dump_unicode(c_as_unicode(o))
 * 
 *     def dump_unicode(self, line):             # <<<<<<<<<<<<<<
 *         pos0 = 0
 *         pos = 0
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_unicode(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_line) {
  int __pyx_v_flag;
  Py_UCS4 __pyx_v_ch;
  PyObject *__pyx_v_text = 0;
  int __pyx_v_pos;
  int __pyx_v_pos0;
  int __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_unicode", 0);

  /* "axon/_dumper.py":316
 * 
 *     def dump_unicode(self, line):
 *         pos0 = 0             # <<<<<<<<<<<<<<
 *         pos = 0
 *         text = ''
 */
  __pyx_v_pos0 = 0;

  /* "axon/_dumper.py":317
 *     def dump_unicode(self, line):
 *         pos0 = 0
 *         pos = 0             # <<<<<<<<<<<<<<
 *         text = ''
 *         flag = 0
 */
  __pyx_v_pos = 0;

  /* "axon/_dumper.py":318
 *         pos0 = 0
 *         pos = 0
 *         text = ''             # <<<<<<<<<<<<<<
 *         flag = 0
 * 
 */
  __Pyx_INCREF(__pyx_kp_u__10);
  __pyx_v_text = __pyx_kp_u__10;

  /* "axon/_dumper.py":319
 *         pos = 0
 *         text = ''
 *         flag = 0             # <<<<<<<<<<<<<<
 * 
 *         n = c_unicode_length(line)
 */
  __pyx_v_flag = 0;

  /* "axon/_dumper.py":321
 *         flag = 0
 * 
 *         n = c_unicode_length(line)             # <<<<<<<<<<<<<<
 *         while pos < n:
 *             ch = c_unicode_char(line, pos)
 */
  __pyx_v_n = c_unicode_length(__pyx_v_line);

  /* "axon/_dumper.py":322
 * 
 *         n = c_unicode_length(line)
 *         while pos < n:             # <<<<<<<<<<<<<<
 *             ch = c_unicode_char(line, pos)
 *             if ch == '"':
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_pos < __pyx_v_n) != 0);
    if (!__pyx_t_1) break;

    /* "axon/_dumper.py":323
 *         n = c_unicode_length(line)
 *         while pos < n:
 *             ch = c_unicode_char(line, pos)             # <<<<<<<<<<<<<<
 *             if ch == '"':
 *                 if pos != pos0:
 */
    __pyx_v_ch = c_unicode_char(__pyx_v_line, __pyx_v_pos);

    /* "axon/_dumper.py":324
 *         while pos < n:
 *             ch = c_unicode_char(line, pos)
 *             if ch == '"':             # <<<<<<<<<<<<<<
 *                 if pos != pos0:
 *                     text += c_unicode_substr(line, pos0, pos)
 */
    __pyx_t_1 = ((__pyx_v_ch == 34) != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":325
 *             ch = c_unicode_char(line, pos)
 *             if ch == '"':
 *                 if pos != pos0:             # <<<<<<<<<<<<<<
 *                     text += c_unicode_substr(line, pos0, pos)
 *                 text += '\\"'
 */
      __pyx_t_1 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
      if (__pyx_t_1) {

        /* "axon/_dumper.py":326
 *             if ch == '"':
 *                 if pos != pos0:
 *                     text += c_unicode_substr(line, pos0, pos)             # <<<<<<<<<<<<<<
 *                 text += '\\"'
 *                 pos += 1
 */
        __pyx_t_2 = c_unicode_substr(__pyx_v_line, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_text, __pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_3));
        __pyx_t_3 = 0;
        goto __pyx_L6;
      }
      __pyx_L6:;

      /* "axon/_dumper.py":327
 *                 if pos != pos0:
 *                     text += c_unicode_substr(line, pos0, pos)
 *                 text += '\\"'             # <<<<<<<<<<<<<<
 *                 pos += 1
 *                 pos0 = pos
 */
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_v_text, __pyx_kp_u__11); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "axon/_dumper.py":328
 *                     text += c_unicode_substr(line, pos0, pos)
 *                 text += '\\"'
 *                 pos += 1             # <<<<<<<<<<<<<<
 *                 pos0 = pos
 *                 flag = 1
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_dumper.py":329
 *                 text += '\\"'
 *                 pos += 1
 *                 pos0 = pos             # <<<<<<<<<<<<<<
 *                 flag = 1
 *             else:
 */
      __pyx_v_pos0 = __pyx_v_pos;

      /* "axon/_dumper.py":330
 *                 pos += 1
 *                 pos0 = pos
 *                 flag = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 pos += 1
 */
      __pyx_v_flag = 1;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_dumper.py":332
 *                 flag = 1
 *             else:
 *                 pos += 1             # <<<<<<<<<<<<<<
 * 
 *         if pos != pos0:
 */
      __pyx_v_pos = (__pyx_v_pos + 1);
    }
    __pyx_L5:;
  }

  /* "axon/_dumper.py":334
 *                 pos += 1
 * 
 *         if pos != pos0:             # <<<<<<<<<<<<<<
 *             if flag:
 *                 text += c_unicode_substr(line, pos0, pos)
 */
  __pyx_t_1 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":335
 * 
 *         if pos != pos0:
 *             if flag:             # <<<<<<<<<<<<<<
 *                 text += c_unicode_substr(line, pos0, pos)
 *             else:
 */
    __pyx_t_1 = (__pyx_v_flag != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":336
 *         if pos != pos0:
 *             if flag:
 *                 text += c_unicode_substr(line, pos0, pos)             # <<<<<<<<<<<<<<
 *             else:
 *                 text = c_unicode_substr(line, pos0, pos)
 */
      __pyx_t_3 = c_unicode_substr(__pyx_v_line, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 336; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_text, __pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 336; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;
      goto __pyx_L8;
    }
    /*else*/ {

      /* "axon/_dumper.py":338
 *                 text += c_unicode_substr(line, pos0, pos)
 *             else:
 *                 text = c_unicode_substr(line, pos0, pos)             # <<<<<<<<<<<<<<
 *         return text
 * 
 */
      __pyx_t_2 = c_unicode_substr(__pyx_v_line, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 338; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;
    }
    __pyx_L8:;
    goto __pyx_L7;
  }
  __pyx_L7:;

  /* "axon/_dumper.py":339
 *             else:
 *                 text = c_unicode_substr(line, pos0, pos)
 *         return text             # <<<<<<<<<<<<<<
 * 
 *     def dump_bool(self, o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_text);
  __pyx_r = __pyx_v_text;
  goto __pyx_L0;

  /* "axon/_dumper.py":315
 *         return self.dump_unicode(c_as_unicode(o))
 * 
 *     def dump_unicode(self, line):             # <<<<<<<<<<<<<<
 *         pos0 = 0
 *         pos = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_unicode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":341
 *         return text
 * 
 *     def dump_bool(self, o):             # <<<<<<<<<<<<<<
 *         #return '' if o else ''
 *         return 'true' if o else 'false'
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_bool(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_bool", 0);

  /* "axon/_dumper.py":343
 *     def dump_bool(self, o):
 *         #return '' if o else ''
 *         return 'true' if o else 'false'             # <<<<<<<<<<<<<<
 * 
 *     def dump_date(self, o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_o); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_n_u_true);
    __pyx_t_1 = __pyx_n_u_true;
  } else {
    __Pyx_INCREF(__pyx_n_u_false);
    __pyx_t_1 = __pyx_n_u_false;
  }
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_dumper.py":341
 *         return text
 * 
 *     def dump_bool(self, o):             # <<<<<<<<<<<<<<
 *         #return '' if o else ''
 *         return 'true' if o else 'false'
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_bool", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":345
 *         return 'true' if o else 'false'
 * 
 *     def dump_date(self, o):             # <<<<<<<<<<<<<<
 *         d = "%d-%02d-%02d" % (o.year, o.month, o.day)
 *         return d
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_date(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_d = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_date", 0);

  /* "axon/_dumper.py":346
 * 
 *     def dump_date(self, o):
 *         d = "%d-%02d-%02d" % (o.year, o.month, o.day)             # <<<<<<<<<<<<<<
 *         return d
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_month); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_day); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_d_02d_02d, __pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_d = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":347
 *     def dump_date(self, o):
 *         d = "%d-%02d-%02d" % (o.year, o.month, o.day)
 *         return d             # <<<<<<<<<<<<<<
 * 
 *     def _dump_tzinfo(self, o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_d);
  __pyx_r = __pyx_v_d;
  goto __pyx_L0;

  /* "axon/_dumper.py":345
 *         return 'true' if o else 'false'
 * 
 *     def dump_date(self, o):             # <<<<<<<<<<<<<<
 *         d = "%d-%02d-%02d" % (o.year, o.month, o.day)
 *         return d
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":349
 *         return d
 * 
 *     def _dump_tzinfo(self, o):             # <<<<<<<<<<<<<<
 *         offset = o.utcoffset(None)
 *         seconds = offset.seconds + offset.days * 86400 # 24 * 60 * 60
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper__dump_tzinfo(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_offset = NULL;
  PyObject *__pyx_v_seconds = NULL;
  PyObject *__pyx_v_sign = NULL;
  PyObject *__pyx_v_minutes = NULL;
  PyObject *__pyx_v_hours = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_tzinfo", 0);

  /* "axon/_dumper.py":350
 * 
 *     def _dump_tzinfo(self, o):
 *         offset = o.utcoffset(None)             # <<<<<<<<<<<<<<
 *         seconds = offset.seconds + offset.days * 86400 # 24 * 60 * 60
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_utcoffset); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 350; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 350; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_offset = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":351
 *     def _dump_tzinfo(self, o):
 *         offset = o.utcoffset(None)
 *         seconds = offset.seconds + offset.days * 86400 # 24 * 60 * 60             # <<<<<<<<<<<<<<
 * 
 *         if seconds < 0:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_offset, __pyx_n_s_seconds); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_offset, __pyx_n_s_days); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_int_86400); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_seconds = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":353
 *         seconds = offset.seconds + offset.days * 86400 # 24 * 60 * 60
 * 
 *         if seconds < 0:             # <<<<<<<<<<<<<<
 *             seconds = -seconds
 *             sign = '-'
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_seconds, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 353; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 353; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "axon/_dumper.py":354
 * 
 *         if seconds < 0:
 *             seconds = -seconds             # <<<<<<<<<<<<<<
 *             sign = '-'
 *         else:
 */
    __pyx_t_1 = PyNumber_Negative(__pyx_v_seconds); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_seconds, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "axon/_dumper.py":355
 *         if seconds < 0:
 *             seconds = -seconds
 *             sign = '-'             # <<<<<<<<<<<<<<
 *         else:
 *             sign = '+'
 */
    __Pyx_INCREF(__pyx_kp_u__13);
    __pyx_v_sign = __pyx_kp_u__13;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":357
 *             sign = '-'
 *         else:
 *             sign = '+'             # <<<<<<<<<<<<<<
 * 
 *         minutes, seconds = builtins.divmod(seconds, 60)
 */
    __Pyx_INCREF(__pyx_kp_u__14);
    __pyx_v_sign = __pyx_kp_u__14;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":359
 *             sign = '+'
 * 
 *         minutes, seconds = builtins.divmod(seconds, 60)             # <<<<<<<<<<<<<<
 *         hours, minutes = builtins.divmod(minutes, 60)
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_builtins); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_divmod); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_seconds);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_seconds);
  __Pyx_GIVEREF(__pyx_v_seconds);
  __Pyx_INCREF(__pyx_int_60);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_60);
  __Pyx_GIVEREF(__pyx_int_60);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_minutes = __pyx_t_1;
  __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_seconds, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":360
 * 
 *         minutes, seconds = builtins.divmod(seconds, 60)
 *         hours, minutes = builtins.divmod(minutes, 60)             # <<<<<<<<<<<<<<
 * 
 *         if minutes:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_builtins); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_divmod); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_minutes);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_minutes);
  __Pyx_GIVEREF(__pyx_v_minutes);
  __Pyx_INCREF(__pyx_int_60);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_60);
  __Pyx_GIVEREF(__pyx_int_60);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L6_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L6_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L7_unpacking_done;
    __pyx_L6_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L7_unpacking_done:;
  }
  __pyx_v_hours = __pyx_t_2;
  __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_minutes, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":362
 *         hours, minutes = builtins.divmod(minutes, 60)
 * 
 *         if minutes:             # <<<<<<<<<<<<<<
 *             return '%s%02d:%02d' % (sign, hours, minutes)
 *         else:
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_minutes); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_4) {

    /* "axon/_dumper.py":363
 * 
 *         if minutes:
 *             return '%s%02d:%02d' % (sign, hours, minutes)             # <<<<<<<<<<<<<<
 *         else:
 *             return '%s%02d' % (sign, hours)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_sign);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sign);
    __Pyx_GIVEREF(__pyx_v_sign);
    __Pyx_INCREF(__pyx_v_hours);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_hours);
    __Pyx_GIVEREF(__pyx_v_hours);
    __Pyx_INCREF(__pyx_v_minutes);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_minutes);
    __Pyx_GIVEREF(__pyx_v_minutes);
    __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_s_02d_02d, __pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_dumper.py":365
 *             return '%s%02d:%02d' % (sign, hours, minutes)
 *         else:
 *             return '%s%02d' % (sign, hours)             # <<<<<<<<<<<<<<
 * 
 *     def dump_time(self, o):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 365; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_sign);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_sign);
    __Pyx_GIVEREF(__pyx_v_sign);
    __Pyx_INCREF(__pyx_v_hours);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_hours);
    __Pyx_GIVEREF(__pyx_v_hours);
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_s_02d, __pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 365; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":349
 *         return d
 * 
 *     def _dump_tzinfo(self, o):             # <<<<<<<<<<<<<<
 *         offset = o.utcoffset(None)
 *         seconds = offset.seconds + offset.days * 86400 # 24 * 60 * 60
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper._dump_tzinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_offset);
  __Pyx_XDECREF(__pyx_v_seconds);
  __Pyx_XDECREF(__pyx_v_sign);
  __Pyx_XDECREF(__pyx_v_minutes);
  __Pyx_XDECREF(__pyx_v_hours);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":367
 *             return '%s%02d' % (sign, hours)
 * 
 *     def dump_time(self, o):             # <<<<<<<<<<<<<<
 *         if o.second:
 *             if o.microsecond:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_time(struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_time", 0);

  /* "axon/_dumper.py":368
 * 
 *     def dump_time(self, o):
 *         if o.second:             # <<<<<<<<<<<<<<
 *             if o.microsecond:
 *                 t = "%02d:%02d:%02d.%06d" % (o.hour, o.minute, o.second, o.microsecond)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_second); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 368; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 368; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_dumper.py":369
 *     def dump_time(self, o):
 *         if o.second:
 *             if o.microsecond:             # <<<<<<<<<<<<<<
 *                 t = "%02d:%02d:%02d.%06d" % (o.hour, o.minute, o.second, o.microsecond)
 *             else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_microsecond); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "axon/_dumper.py":370
 *         if o.second:
 *             if o.microsecond:
 *                 t = "%02d:%02d:%02d.%06d" % (o.hour, o.minute, o.second, o.microsecond)             # <<<<<<<<<<<<<<
 *             else:
 *                 t = "%02d:%02d:%02d" % (o.hour, o.minute, o.second)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_hour); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_minute); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_second); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_microsecond); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_1 = 0;
      __pyx_t_3 = 0;
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_5 = PyUnicode_Format(__pyx_kp_u_02d_02d_02d_06d, __pyx_t_6); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_t = ((PyObject*)__pyx_t_5);
      __pyx_t_5 = 0;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "axon/_dumper.py":372
 *                 t = "%02d:%02d:%02d.%06d" % (o.hour, o.minute, o.second, o.microsecond)
 *             else:
 *                 t = "%02d:%02d:%02d" % (o.hour, o.minute, o.second)             # <<<<<<<<<<<<<<
 *         else:
 *                 t = "%02d:%02d" % (o.hour, o.minute)
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_hour); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_minute); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_second); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_4 = 0;
      __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_02d_02d_02d, __pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_t = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":374
 *                 t = "%02d:%02d:%02d" % (o.hour, o.minute, o.second)
 *         else:
 *                 t = "%02d:%02d" % (o.hour, o.minute)             # <<<<<<<<<<<<<<
 * 
 *         tzinfo = o.tzinfo
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_hour); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 374; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_minute); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 374; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 374; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_02d_02d, __pyx_t_6); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 374; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_t = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":376
 *                 t = "%02d:%02d" % (o.hour, o.minute)
 * 
 *         tzinfo = o.tzinfo             # <<<<<<<<<<<<<<
 *         if tzinfo is not None:
 *             t += self._dump_tzinfo(tzinfo)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_tzinfo); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_tzinfo = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":377
 * 
 *         tzinfo = o.tzinfo
 *         if tzinfo is not None:             # <<<<<<<<<<<<<<
 *             t += self._dump_tzinfo(tzinfo)
 * 
 */
  __pyx_t_2 = (__pyx_v_tzinfo != Py_None);
  __pyx_t_7 = (__pyx_t_2 != 0);
  if (__pyx_t_7) {

    /* "axon/_dumper.py":378
 *         tzinfo = o.tzinfo
 *         if tzinfo is not None:
 *             t += self._dump_tzinfo(tzinfo)             # <<<<<<<<<<<<<<
 * 
 *         return t
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper_12SimpleDumper__dump_tzinfo(__pyx_v_self, __pyx_v_tzinfo); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 378; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_t, __pyx_t_3); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 378; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_t, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":380
 *             t += self._dump_tzinfo(tzinfo)
 * 
 *         return t             # <<<<<<<<<<<<<<
 * 
 *     def dump_datetime(self, o):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_t);
  __pyx_r = __pyx_v_t;
  goto __pyx_L0;

  /* "axon/_dumper.py":367
 *             return '%s%02d' % (sign, hours)
 * 
 *     def dump_time(self, o):             # <<<<<<<<<<<<<<
 *         if o.second:
 *             if o.microsecond:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":382
 *         return t
 * 
 *     def dump_datetime(self, o):             # <<<<<<<<<<<<<<
 *         if o.second:
 *             if o.microsecond:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_datetime(struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_datetime", 0);

  /* "axon/_dumper.py":383
 * 
 *     def dump_datetime(self, o):
 *         if o.second:             # <<<<<<<<<<<<<<
 *             if o.microsecond:
 *                 t = "%d-%02d-%02dT%02d:%02d:%02d.%06d" % (o.year, o.month, o.day, o.hour, o.minute, o.second, o.microsecond)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_second); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 383; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 383; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "axon/_dumper.py":384
 *     def dump_datetime(self, o):
 *         if o.second:
 *             if o.microsecond:             # <<<<<<<<<<<<<<
 *                 t = "%d-%02d-%02dT%02d:%02d:%02d.%06d" % (o.year, o.month, o.day, o.hour, o.minute, o.second, o.microsecond)
 *             else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_microsecond); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 384; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 384; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "axon/_dumper.py":385
 *         if o.second:
 *             if o.microsecond:
 *                 t = "%d-%02d-%02dT%02d:%02d:%02d.%06d" % (o.year, o.month, o.day, o.hour, o.minute, o.second, o.microsecond)             # <<<<<<<<<<<<<<
 *             else:
 *                 t = "%d-%02d-%02dT%02d:%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute, o.second)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_month); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_day); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_hour); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_minute); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_second); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_microsecond); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = PyTuple_New(7); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 5, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_9, 6, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      __pyx_t_1 = 0;
      __pyx_t_3 = 0;
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_7 = 0;
      __pyx_t_8 = 0;
      __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_d_02d_02dT_02d_02d_02d_06d, __pyx_t_9); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_t = ((PyObject*)__pyx_t_8);
      __pyx_t_8 = 0;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "axon/_dumper.py":387
 *                 t = "%d-%02d-%02dT%02d:%02d:%02d.%06d" % (o.year, o.month, o.day, o.hour, o.minute, o.second, o.microsecond)
 *             else:
 *                 t = "%d-%02d-%02dT%02d:%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute, o.second)             # <<<<<<<<<<<<<<
 *         else:
 *                 t = "%d-%02d-%02dT%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute)
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_year); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_month); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_day); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_hour); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_minute); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_second); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(6); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_8 = 0;
      __pyx_t_9 = 0;
      __pyx_t_7 = 0;
      __pyx_t_6 = 0;
      __pyx_t_5 = 0;
      __pyx_t_4 = 0;
      __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_d_02d_02dT_02d_02d_02d, __pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_t = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":389
 *                 t = "%d-%02d-%02dT%02d:%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute, o.second)
 *         else:
 *                 t = "%d-%02d-%02dT%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute)             # <<<<<<<<<<<<<<
 * 
 *         tzinfo = o.tzinfo
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_year); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_month); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_day); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_hour); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_minute); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = PyTuple_New(5); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_7 = PyUnicode_Format(__pyx_kp_u_d_02d_02dT_02d_02d, __pyx_t_9); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_t = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":391
 *                 t = "%d-%02d-%02dT%02d:%02d" % (o.year, o.month, o.day, o.hour, o.minute)
 * 
 *         tzinfo = o.tzinfo             # <<<<<<<<<<<<<<
 *         if tzinfo is not None:
 *             t += self._dump_tzinfo(tzinfo)
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_o, __pyx_n_s_tzinfo); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 391; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_tzinfo = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "axon/_dumper.py":392
 * 
 *         tzinfo = o.tzinfo
 *         if tzinfo is not None:             # <<<<<<<<<<<<<<
 *             t += self._dump_tzinfo(tzinfo)
 * 
 */
  __pyx_t_2 = (__pyx_v_tzinfo != Py_None);
  __pyx_t_10 = (__pyx_t_2 != 0);
  if (__pyx_t_10) {

    /* "axon/_dumper.py":393
 *         tzinfo = o.tzinfo
 *         if tzinfo is not None:
 *             t += self._dump_tzinfo(tzinfo)             # <<<<<<<<<<<<<<
 * 
 *         return c_as_unicode(t)
 */
    __pyx_t_7 = __pyx_f_4axon_7_dumper_12SimpleDumper__dump_tzinfo(__pyx_v_self, __pyx_v_tzinfo); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_t, __pyx_t_7); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_t, ((PyObject*)__pyx_t_9));
    __pyx_t_9 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":395
 *             t += self._dump_tzinfo(tzinfo)
 * 
 *         return c_as_unicode(t)             # <<<<<<<<<<<<<<
 * 
 *     def dump_none(self, o):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_9 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_t); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 395; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_r = ((PyObject*)__pyx_t_9);
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "axon/_dumper.py":382
 *         return t
 * 
 *     def dump_datetime(self, o):             # <<<<<<<<<<<<<<
 *         if o.second:
 *             if o.microsecond:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("axon._dumper.SimpleDumper.dump_datetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":397
 *         return c_as_unicode(t)
 * 
 *     def dump_none(self, o):             # <<<<<<<<<<<<<<
 *         return 'null'
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_12SimpleDumper_dump_none(CYTHON_UNUSED struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump_none", 0);

  /* "axon/_dumper.py":398
 * 
 *     def dump_none(self, o):
 *         return 'null'             # <<<<<<<<<<<<<<
 * 
 * _simple_dumper = SimpleDumper()
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_n_u_null);
  __pyx_r = __pyx_n_u_null;
  goto __pyx_L0;

  /* "axon/_dumper.py":397
 *         return c_as_unicode(t)
 * 
 *     def dump_none(self, o):             # <<<<<<<<<<<<<<
 *         return 'null'
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":405
 *     #cdef dict c_mapping
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.mapping = c_simple_dumpers.copy()
 * 
 */

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_4axon_7_dumper_13SimpleDumpers___init__(((struct SimpleDumpers *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_dumper_13SimpleDumpers___init__(struct SimpleDumpers *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_dumper.py":406
 * 
 *     def __init__(self):
 *         self.mapping = c_simple_dumpers.copy()             # <<<<<<<<<<<<<<
 * 
 *     def add(self, tp, ptr):
 */
  if (unlikely(__pyx_v_4axon_7_dumper_c_simple_dumpers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "copy");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PyDict_Copy(__pyx_v_4axon_7_dumper_c_simple_dumpers); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":405
 *     #cdef dict c_mapping
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.mapping = c_simple_dumpers.copy()
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.SimpleDumpers.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":408
 *         self.mapping = c_simple_dumpers.copy()
 * 
 *     def add(self, tp, ptr):             # <<<<<<<<<<<<<<
 *         self.mapping[tp] = c_new_pyptr(ptr)
 * 
 */

static void __pyx_f_4axon_7_dumper_13SimpleDumpers_add(struct SimpleDumpers *__pyx_v_self, PyObject *__pyx_v_tp, PyObject *(*__pyx_v_ptr)(PyObject *)) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);

  /* "axon/_dumper.py":409
 * 
 *     def add(self, tp, ptr):
 *         self.mapping[tp] = c_new_pyptr(ptr)             # <<<<<<<<<<<<<<
 * 
 *     def update(self, o):
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_v_ptr)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_v_self->mapping == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(PyDict_SetItem(__pyx_v_self->mapping, ((PyObject *)__pyx_v_tp), __pyx_t_1) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":408
 *         self.mapping = c_simple_dumpers.copy()
 * 
 *     def add(self, tp, ptr):             # <<<<<<<<<<<<<<
 *         self.mapping[tp] = c_new_pyptr(ptr)
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("axon._dumper.SimpleDumpers.add", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":411
 *         self.mapping[tp] = c_new_pyptr(ptr)
 * 
 *     def update(self, o):             # <<<<<<<<<<<<<<
 *         if type(o) is dict:
 *             self.mapping.update(o)
 */

static void __pyx_f_4axon_7_dumper_13SimpleDumpers_update(struct SimpleDumpers *__pyx_v_self, PyObject *__pyx_v_o) {
  struct SimpleDumpers *__pyx_v_sd = 0;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 0);

  /* "axon/_dumper.py":412
 * 
 *     def update(self, o):
 *         if type(o) is dict:             # <<<<<<<<<<<<<<
 *             self.mapping.update(o)
 *         elif type(o) is SimpleDumpers:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_o)) == ((PyObject *)((PyObject*)(&PyDict_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":413
 *     def update(self, o):
 *         if type(o) is dict:
 *             self.mapping.update(o)             # <<<<<<<<<<<<<<
 *         elif type(o) is SimpleDumpers:
 *             sd = o
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->mapping, __pyx_n_s_update); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_o);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_o);
    __Pyx_GIVEREF(__pyx_v_o);
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":414
 *         if type(o) is dict:
 *             self.mapping.update(o)
 *         elif type(o) is SimpleDumpers:             # <<<<<<<<<<<<<<
 *             sd = o
 *             self.mapping.update(sd.mapping)
 */
  __pyx_t_2 = (((PyObject *)Py_TYPE(__pyx_v_o)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_SimpleDumpers)));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":415
 *             self.mapping.update(o)
 *         elif type(o) is SimpleDumpers:
 *             sd = o             # <<<<<<<<<<<<<<
 *             self.mapping.update(sd.mapping)
 * 
 */
    if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_7_dumper_SimpleDumpers))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 415; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_v_o;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_v_sd = ((struct SimpleDumpers *)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "axon/_dumper.py":416
 *         elif type(o) is SimpleDumpers:
 *             sd = o
 *             self.mapping.update(sd.mapping)             # <<<<<<<<<<<<<<
 * 
 * def dump_as_str(tp=None):
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->mapping, __pyx_n_s_update); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_sd->mapping);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_sd->mapping);
    __Pyx_GIVEREF(__pyx_v_sd->mapping);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 416; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":411
 *         self.mapping[tp] = c_new_pyptr(ptr)
 * 
 *     def update(self, o):             # <<<<<<<<<<<<<<
 *         if type(o) is dict:
 *             self.mapping.update(o)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_WriteUnraisable("axon._dumper.SimpleDumpers.update", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sd);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.pxd":214
 * 
 * cdef public class SimpleDumpers[type SimpleDumpersType, object SimpleDumpers]:
 *     cdef public dict mapping             # <<<<<<<<<<<<<<
 * 
 *     cdef void add(self, type tp, unicode (*ptr)(object))
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping___get__(((struct SimpleDumpers *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping___get__(struct SimpleDumpers *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->mapping);
  __pyx_r = __pyx_v_self->mapping;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_2__set__(((struct SimpleDumpers *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_2__set__(struct SimpleDumpers *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.SimpleDumpers.mapping.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_4__del__(((struct SimpleDumpers *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_dumper_13SimpleDumpers_7mapping_4__del__(struct SimpleDumpers *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->mapping);
  __Pyx_DECREF(__pyx_v_self->mapping);
  __pyx_v_self->mapping = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":418
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_17dump_as_str(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_17dump_as_str = {__Pyx_NAMESTR("dump_as_str"), (PyCFunction)__pyx_pw_4axon_7_dumper_17dump_as_str, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_17dump_as_str(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_tp = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump_as_str (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tp,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tp);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "dump_as_str") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_tp = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump_as_str", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.dump_as_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_16dump_as_str(__pyx_self, __pyx_v_tp);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":420
 * def dump_as_str(tp=None):
 *     if tp is None:
 *         def _dump_as_str(func):             # <<<<<<<<<<<<<<
 *             c_simple_dumpers[tp] = func
 *             return func
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_11dump_as_str_1_dump_as_str(PyObject *__pyx_self, PyObject *__pyx_v_func); /*proto*/
static PyMethodDef __pyx_mdef_4axon_7_dumper_11dump_as_str_1_dump_as_str = {__Pyx_NAMESTR("_dump_as_str"), (PyCFunction)__pyx_pw_4axon_7_dumper_11dump_as_str_1_dump_as_str, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_4axon_7_dumper_11dump_as_str_1_dump_as_str(PyObject *__pyx_self, PyObject *__pyx_v_func) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_dump_as_str (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_11dump_as_str__dump_as_str(__pyx_self, ((PyObject *)__pyx_v_func));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_11dump_as_str__dump_as_str(PyObject *__pyx_self, PyObject *__pyx_v_func) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *__pyx_cur_scope;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_as_str", 0);
  __pyx_outer_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "axon/_dumper.py":421
 *     if tp is None:
 *         def _dump_as_str(func):
 *             c_simple_dumpers[tp] = func             # <<<<<<<<<<<<<<
 *             return func
 *         return _dump_as_str
 */
  if (unlikely(__pyx_v_4axon_7_dumper_c_simple_dumpers == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 421; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_tp)) { __Pyx_RaiseClosureNameError("tp"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 421; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
  if (unlikely(PyDict_SetItem(__pyx_v_4axon_7_dumper_c_simple_dumpers, __pyx_cur_scope->__pyx_v_tp, __pyx_v_func) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 421; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":422
 *         def _dump_as_str(func):
 *             c_simple_dumpers[tp] = func
 *             return func             # <<<<<<<<<<<<<<
 *         return _dump_as_str
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_func);
  __pyx_r = __pyx_v_func;
  goto __pyx_L0;

  /* "axon/_dumper.py":420
 * def dump_as_str(tp=None):
 *     if tp is None:
 *         def _dump_as_str(func):             # <<<<<<<<<<<<<<
 *             c_simple_dumpers[tp] = func
 *             return func
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.dump_as_str._dump_as_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":418
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */

static PyObject *__pyx_pf_4axon_7_dumper_16dump_as_str(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tp) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *__pyx_cur_scope;
  PyObject *__pyx_v__dump_as_str = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_as_str", 0);
  __pyx_cur_scope = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(__pyx_ptype_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_tp = __pyx_v_tp;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_tp);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_tp);

  /* "axon/_dumper.py":419
 * 
 * def dump_as_str(tp=None):
 *     if tp is None:             # <<<<<<<<<<<<<<
 *         def _dump_as_str(func):
 *             c_simple_dumpers[tp] = func
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_tp == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":420
 * def dump_as_str(tp=None):
 *     if tp is None:
 *         def _dump_as_str(func):             # <<<<<<<<<<<<<<
 *             c_simple_dumpers[tp] = func
 *             return func
 */
    __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_11dump_as_str_1_dump_as_str, 0, __pyx_n_s_dump_as_str_locals__dump_as_str, ((PyObject*)__pyx_cur_scope), __pyx_n_s_axon__dumper, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__16)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v__dump_as_str = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":423
 *             c_simple_dumpers[tp] = func
 *             return func
 *         return _dump_as_str             # <<<<<<<<<<<<<<
 *     else:
 *         c_simple_dumpers[tp] = c_new_pyptr(dump_default)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v__dump_as_str);
    __pyx_r = __pyx_v__dump_as_str;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_dumper.py":425
 *         return _dump_as_str
 *     else:
 *         c_simple_dumpers[tp] = c_new_pyptr(dump_default)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = ((PyObject *)__pyx_f_4axon_7_dumper_c_new_pyptr(__pyx_f_4axon_7_dumper_dump_default)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(__pyx_v_4axon_7_dumper_c_simple_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(__pyx_v_4axon_7_dumper_c_simple_dumpers, __pyx_cur_scope->__pyx_v_tp, __pyx_t_3) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }

  /* "axon/_dumper.py":418
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.dump_as_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__dump_as_str);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":432
 * #
 * 
 * def _dump_name(ob):             # <<<<<<<<<<<<<<
 *     name = ob
 *     pos0 = 0
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_name(PyObject *__pyx_v_ob) {
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_is_qname;
  PyObject *__pyx_v_text = 0;
  int __pyx_v_pos;
  int __pyx_v_pos0;
  PyObject *__pyx_v_name = 0;
  Py_ssize_t __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_name", 0);

  /* "axon/_dumper.py":433
 * 
 * def _dump_name(ob):
 *     name = ob             # <<<<<<<<<<<<<<
 *     pos0 = 0
 *     pos = 0
 */
  if (!(likely(PyUnicode_CheckExact(__pyx_v_ob))||((__pyx_v_ob) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_ob)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_ob;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":434
 * def _dump_name(ob):
 *     name = ob
 *     pos0 = 0             # <<<<<<<<<<<<<<
 *     pos = 0
 *     text = None
 */
  __pyx_v_pos0 = 0;

  /* "axon/_dumper.py":435
 *     name = ob
 *     pos0 = 0
 *     pos = 0             # <<<<<<<<<<<<<<
 *     text = None
 *     is_qname = 0
 */
  __pyx_v_pos = 0;

  /* "axon/_dumper.py":436
 *     pos0 = 0
 *     pos = 0
 *     text = None             # <<<<<<<<<<<<<<
 *     is_qname = 0
 * 
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_text = ((PyObject*)Py_None);

  /* "axon/_dumper.py":437
 *     pos = 0
 *     text = None
 *     is_qname = 0             # <<<<<<<<<<<<<<
 * 
 *     n = len(name)
 */
  __pyx_v_is_qname = 0;

  /* "axon/_dumper.py":439
 *     is_qname = 0
 * 
 *     n = len(name)             # <<<<<<<<<<<<<<
 *     if n == 0:
 *         raise ValueError('Empty name')
 */
  if (unlikely(__pyx_v_name == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 439; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_2 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_name); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 439; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_2;

  /* "axon/_dumper.py":440
 * 
 *     n = len(name)
 *     if n == 0:             # <<<<<<<<<<<<<<
 *         raise ValueError('Empty name')
 * 
 */
  __pyx_t_3 = ((__pyx_v_n == 0) != 0);
  if (__pyx_t_3) {

    /* "axon/_dumper.py":441
 *     n = len(name)
 *     if n == 0:
 *         raise ValueError('Empty name')             # <<<<<<<<<<<<<<
 * 
 *     ch = name[pos]
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_dumper.py":443
 *         raise ValueError('Empty name')
 * 
 *     ch = name[pos]             # <<<<<<<<<<<<<<
 *     if ch.isalpha() or ch == '_':
 *         pos += 1
 */
  __pyx_t_4 = __Pyx_GetItemInt_Unicode(__pyx_v_name, __pyx_v_pos, int, 1, __Pyx_PyInt_From_int, 0, 0, 0); if (unlikely(__pyx_t_4 == (Py_UCS4)-1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_v_ch = __pyx_t_4;

  /* "axon/_dumper.py":444
 * 
 *     ch = name[pos]
 *     if ch.isalpha() or ch == '_':             # <<<<<<<<<<<<<<
 *         pos += 1
 *     else:
 */
  __pyx_t_3 = Py_UNICODE_ISALPHA(__pyx_v_ch); 
  if (!(__pyx_t_3 != 0)) {
    __pyx_t_5 = (__pyx_v_ch == 95);
    __pyx_t_6 = __pyx_t_5;
  } else {
    __pyx_t_6 = (__pyx_t_3 != 0);
  }
  if (__pyx_t_6) {

    /* "axon/_dumper.py":445
 *     ch = name[pos]
 *     if ch.isalpha() or ch == '_':
 *         pos += 1             # <<<<<<<<<<<<<<
 *     else:
 *         is_qname = 1
 */
    __pyx_v_pos = (__pyx_v_pos + 1);
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_dumper.py":447
 *         pos += 1
 *     else:
 *         is_qname = 1             # <<<<<<<<<<<<<<
 *         pos += 1
 * 
 */
    __pyx_v_is_qname = 1;

    /* "axon/_dumper.py":448
 *     else:
 *         is_qname = 1
 *         pos += 1             # <<<<<<<<<<<<<<
 * 
 *     while pos < n:
 */
    __pyx_v_pos = (__pyx_v_pos + 1);
  }
  __pyx_L4:;

  /* "axon/_dumper.py":450
 *         pos += 1
 * 
 *     while pos < n:             # <<<<<<<<<<<<<<
 *         ch = name[pos]
 *         if ch.isalnum() or ch == '_' or ch == '.':
 */
  while (1) {
    __pyx_t_6 = ((__pyx_v_pos < __pyx_v_n) != 0);
    if (!__pyx_t_6) break;

    /* "axon/_dumper.py":451
 * 
 *     while pos < n:
 *         ch = name[pos]             # <<<<<<<<<<<<<<
 *         if ch.isalnum() or ch == '_' or ch == '.':
 *             pos += 1
 */
    __pyx_t_4 = __Pyx_GetItemInt_Unicode(__pyx_v_name, __pyx_v_pos, int, 1, __Pyx_PyInt_From_int, 0, 0, 0); if (unlikely(__pyx_t_4 == (Py_UCS4)-1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 451; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __pyx_v_ch = __pyx_t_4;

    /* "axon/_dumper.py":452
 *     while pos < n:
 *         ch = name[pos]
 *         if ch.isalnum() or ch == '_' or ch == '.':             # <<<<<<<<<<<<<<
 *             pos += 1
 *         elif ch == "'":
 */
    __pyx_t_6 = Py_UNICODE_ISALNUM(__pyx_v_ch); 
    if (!(__pyx_t_6 != 0)) {
      switch (__pyx_v_ch) {
        case 95:
        case 46:
        __pyx_t_3 = 1;
        break;
        default:
        __pyx_t_3 = 0;
        break;
      }
      __pyx_t_5 = __pyx_t_3;
    } else {
      __pyx_t_5 = (__pyx_t_6 != 0);
    }
    if (__pyx_t_5) {

      /* "axon/_dumper.py":453
 *         ch = name[pos]
 *         if ch.isalnum() or ch == '_' or ch == '.':
 *             pos += 1             # <<<<<<<<<<<<<<
 *         elif ch == "'":
 *             pos += 1
 */
      __pyx_v_pos = (__pyx_v_pos + 1);
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":454
 *         if ch.isalnum() or ch == '_' or ch == '.':
 *             pos += 1
 *         elif ch == "'":             # <<<<<<<<<<<<<<
 *             pos += 1
 *             pos0 = pos
 */
    __pyx_t_5 = ((__pyx_v_ch == 39) != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":455
 *             pos += 1
 *         elif ch == "'":
 *             pos += 1             # <<<<<<<<<<<<<<
 *             pos0 = pos
 *             text += r"\'"
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_dumper.py":456
 *         elif ch == "'":
 *             pos += 1
 *             pos0 = pos             # <<<<<<<<<<<<<<
 *             text += r"\'"
 *         else:
 */
      __pyx_v_pos0 = __pyx_v_pos;

      /* "axon/_dumper.py":457
 *             pos += 1
 *             pos0 = pos
 *             text += r"\'"             # <<<<<<<<<<<<<<
 *         else:
 *             pos += 1
 */
      __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_text, __pyx_kp_u__18); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_dumper.py":459
 *             text += r"\'"
 *         else:
 *             pos += 1             # <<<<<<<<<<<<<<
 *             is_qname = 1
 * 
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_dumper.py":460
 *         else:
 *             pos += 1
 *             is_qname = 1             # <<<<<<<<<<<<<<
 * 
 *     if pos != pos0:
 */
      __pyx_v_is_qname = 1;
    }
    __pyx_L7:;
  }

  /* "axon/_dumper.py":462
 *             is_qname = 1
 * 
 *     if pos != pos0:             # <<<<<<<<<<<<<<
 *         if text is None:
 *             text = name[pos0: pos]
 */
  __pyx_t_5 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
  if (__pyx_t_5) {

    /* "axon/_dumper.py":463
 * 
 *     if pos != pos0:
 *         if text is None:             # <<<<<<<<<<<<<<
 *             text = name[pos0: pos]
 *         else:
 */
    __pyx_t_5 = (__pyx_v_text == ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "axon/_dumper.py":464
 *     if pos != pos0:
 *         if text is None:
 *             text = name[pos0: pos]             # <<<<<<<<<<<<<<
 *         else:
 *             text += name[pos0: pos]
 */
      if (unlikely(__pyx_v_name == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_name, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;
      goto __pyx_L9;
    }
    /*else*/ {

      /* "axon/_dumper.py":466
 *             text = name[pos0: pos]
 *         else:
 *             text += name[pos0: pos]             # <<<<<<<<<<<<<<
 *         if is_qname:
 *             text = "'" + text + "'"
 */
      if (unlikely(__pyx_v_name == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_name, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_text, __pyx_t_1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_7));
      __pyx_t_7 = 0;
    }
    __pyx_L9:;

    /* "axon/_dumper.py":467
 *         else:
 *             text += name[pos0: pos]
 *         if is_qname:             # <<<<<<<<<<<<<<
 *             text = "'" + text + "'"
 * 
 */
    __pyx_t_6 = (__pyx_v_is_qname != 0);
    if (__pyx_t_6) {

      /* "axon/_dumper.py":468
 *             text += name[pos0: pos]
 *         if is_qname:
 *             text = "'" + text + "'"             # <<<<<<<<<<<<<<
 * 
 *     return text
 */
      __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_kp_u__19, __pyx_v_text); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 468; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_7, __pyx_kp_u__19); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 468; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;
      goto __pyx_L10;
    }
    __pyx_L10:;
    goto __pyx_L8;
  }
  __pyx_L8:;

  /* "axon/_dumper.py":470
 *             text = "'" + text + "'"
 * 
 *     return text             # <<<<<<<<<<<<<<
 * 
 * def _dump_key(ob):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_text);
  __pyx_r = __pyx_v_text;
  goto __pyx_L0;

  /* "axon/_dumper.py":432
 * #
 * 
 * def _dump_name(ob):             # <<<<<<<<<<<<<<
 *     name = ob
 *     pos0 = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("axon._dumper._dump_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":472
 *     return text
 * 
 * def _dump_key(ob):             # <<<<<<<<<<<<<<
 *     pos0 = 0
 *     pos = 0
 */

static PyObject *__pyx_f_4axon_7_dumper__dump_key(PyObject *__pyx_v_ob) {
  PyObject *__pyx_v_text = 0;
  Py_UCS4 __pyx_v_ch;
  int __pyx_v_pos;
  int __pyx_v_pos0;
  int __pyx_v_is_qname;
  int __pyx_v_n;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_key", 0);

  /* "axon/_dumper.py":473
 * 
 * def _dump_key(ob):
 *     pos0 = 0             # <<<<<<<<<<<<<<
 *     pos = 0
 *     text = None
 */
  __pyx_v_pos0 = 0;

  /* "axon/_dumper.py":474
 * def _dump_key(ob):
 *     pos0 = 0
 *     pos = 0             # <<<<<<<<<<<<<<
 *     text = None
 *     is_qname = 0
 */
  __pyx_v_pos = 0;

  /* "axon/_dumper.py":475
 *     pos0 = 0
 *     pos = 0
 *     text = None             # <<<<<<<<<<<<<<
 *     is_qname = 0
 * 
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_text = ((PyObject*)Py_None);

  /* "axon/_dumper.py":476
 *     pos = 0
 *     text = None
 *     is_qname = 0             # <<<<<<<<<<<<<<
 * 
 *     n = c_unicode_length(ob)
 */
  __pyx_v_is_qname = 0;

  /* "axon/_dumper.py":478
 *     is_qname = 0
 * 
 *     n = c_unicode_length(ob)             # <<<<<<<<<<<<<<
 *     while pos < n:
 *         ch = c_unicode_char(ob, pos)
 */
  __pyx_v_n = c_unicode_length(__pyx_v_ob);

  /* "axon/_dumper.py":479
 * 
 *     n = c_unicode_length(ob)
 *     while pos < n:             # <<<<<<<<<<<<<<
 *         ch = c_unicode_char(ob, pos)
 *         if ch.isalnum() or ch == '_':
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_pos < __pyx_v_n) != 0);
    if (!__pyx_t_1) break;

    /* "axon/_dumper.py":480
 *     n = c_unicode_length(ob)
 *     while pos < n:
 *         ch = c_unicode_char(ob, pos)             # <<<<<<<<<<<<<<
 *         if ch.isalnum() or ch == '_':
 *             pos += 1
 */
    __pyx_v_ch = c_unicode_char(__pyx_v_ob, __pyx_v_pos);

    /* "axon/_dumper.py":481
 *     while pos < n:
 *         ch = c_unicode_char(ob, pos)
 *         if ch.isalnum() or ch == '_':             # <<<<<<<<<<<<<<
 *             pos += 1
 *         elif ch == '"':
 */
    __pyx_t_1 = Py_UNICODE_ISALNUM(__pyx_v_ch); 
    if (!(__pyx_t_1 != 0)) {
      __pyx_t_2 = (__pyx_v_ch == 95);
      __pyx_t_3 = __pyx_t_2;
    } else {
      __pyx_t_3 = (__pyx_t_1 != 0);
    }
    if (__pyx_t_3) {

      /* "axon/_dumper.py":482
 *         ch = c_unicode_char(ob, pos)
 *         if ch.isalnum() or ch == '_':
 *             pos += 1             # <<<<<<<<<<<<<<
 *         elif ch == '"':
 *             if pos != pos0:
 */
      __pyx_v_pos = (__pyx_v_pos + 1);
      goto __pyx_L5;
    }

    /* "axon/_dumper.py":483
 *         if ch.isalnum() or ch == '_':
 *             pos += 1
 *         elif ch == '"':             # <<<<<<<<<<<<<<
 *             if pos != pos0:
 *                 if text is None:
 */
    __pyx_t_3 = ((__pyx_v_ch == 34) != 0);
    if (__pyx_t_3) {

      /* "axon/_dumper.py":484
 *             pos += 1
 *         elif ch == '"':
 *             if pos != pos0:             # <<<<<<<<<<<<<<
 *                 if text is None:
 *                     text = c_unicode_substr(ob, pos0, pos)
 */
      __pyx_t_3 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
      if (__pyx_t_3) {

        /* "axon/_dumper.py":485
 *         elif ch == '"':
 *             if pos != pos0:
 *                 if text is None:             # <<<<<<<<<<<<<<
 *                     text = c_unicode_substr(ob, pos0, pos)
 *                 else:
 */
        __pyx_t_3 = (__pyx_v_text == ((PyObject*)Py_None));
        __pyx_t_1 = (__pyx_t_3 != 0);
        if (__pyx_t_1) {

          /* "axon/_dumper.py":486
 *             if pos != pos0:
 *                 if text is None:
 *                     text = c_unicode_substr(ob, pos0, pos)             # <<<<<<<<<<<<<<
 *                 else:
 *                     text += c_unicode_substr(ob, pos0, pos)
 */
          __pyx_t_4 = c_unicode_substr(__pyx_v_ob, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_4));
          __pyx_t_4 = 0;
          goto __pyx_L7;
        }
        /*else*/ {

          /* "axon/_dumper.py":488
 *                     text = c_unicode_substr(ob, pos0, pos)
 *                 else:
 *                     text += c_unicode_substr(ob, pos0, pos)             # <<<<<<<<<<<<<<
 *             text += '\\"'
 *             pos += 1
 */
          __pyx_t_4 = c_unicode_substr(__pyx_v_ob, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 488; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_text, __pyx_t_4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 488; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_5));
          __pyx_t_5 = 0;
        }
        __pyx_L7:;
        goto __pyx_L6;
      }
      __pyx_L6:;

      /* "axon/_dumper.py":489
 *                 else:
 *                     text += c_unicode_substr(ob, pos0, pos)
 *             text += '\\"'             # <<<<<<<<<<<<<<
 *             pos += 1
 *             pos0 = pos
 */
      __pyx_t_5 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_text, __pyx_kp_u__11); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_5));
      __pyx_t_5 = 0;

      /* "axon/_dumper.py":490
 *                     text += c_unicode_substr(ob, pos0, pos)
 *             text += '\\"'
 *             pos += 1             # <<<<<<<<<<<<<<
 *             pos0 = pos
 *             is_qname = 1
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_dumper.py":491
 *             text += '\\"'
 *             pos += 1
 *             pos0 = pos             # <<<<<<<<<<<<<<
 *             is_qname = 1
 *         else:
 */
      __pyx_v_pos0 = __pyx_v_pos;

      /* "axon/_dumper.py":492
 *             pos += 1
 *             pos0 = pos
 *             is_qname = 1             # <<<<<<<<<<<<<<
 *         else:
 *             pos += 1
 */
      __pyx_v_is_qname = 1;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "axon/_dumper.py":494
 *             is_qname = 1
 *         else:
 *             pos += 1             # <<<<<<<<<<<<<<
 *             is_qname = 1
 * 
 */
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "axon/_dumper.py":495
 *         else:
 *             pos += 1
 *             is_qname = 1             # <<<<<<<<<<<<<<
 * 
 *     if pos != pos0:
 */
      __pyx_v_is_qname = 1;
    }
    __pyx_L5:;
  }

  /* "axon/_dumper.py":497
 *             is_qname = 1
 * 
 *     if pos != pos0:             # <<<<<<<<<<<<<<
 *         if text is None:
 *             text = c_unicode_substr(ob, pos0, pos)
 */
  __pyx_t_1 = ((__pyx_v_pos != __pyx_v_pos0) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":498
 * 
 *     if pos != pos0:
 *         if text is None:             # <<<<<<<<<<<<<<
 *             text = c_unicode_substr(ob, pos0, pos)
 *         else:
 */
    __pyx_t_1 = (__pyx_v_text == ((PyObject*)Py_None));
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "axon/_dumper.py":499
 *     if pos != pos0:
 *         if text is None:
 *             text = c_unicode_substr(ob, pos0, pos)             # <<<<<<<<<<<<<<
 *         else:
 *             text += c_unicode_substr(ob, pos0, pos)
 */
      __pyx_t_5 = c_unicode_substr(__pyx_v_ob, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 499; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_5));
      __pyx_t_5 = 0;
      goto __pyx_L9;
    }
    /*else*/ {

      /* "axon/_dumper.py":501
 *             text = c_unicode_substr(ob, pos0, pos)
 *         else:
 *             text += c_unicode_substr(ob, pos0, pos)             # <<<<<<<<<<<<<<
 * 
 *     if is_qname:
 */
      __pyx_t_5 = c_unicode_substr(__pyx_v_ob, __pyx_v_pos0, __pyx_v_pos); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 501; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_text, __pyx_t_5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 501; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;
    }
    __pyx_L9:;
    goto __pyx_L8;
  }
  __pyx_L8:;

  /* "axon/_dumper.py":503
 *             text += c_unicode_substr(ob, pos0, pos)
 * 
 *     if is_qname:             # <<<<<<<<<<<<<<
 *         return '"' + text + '"'
 *     else:
 */
  __pyx_t_3 = (__pyx_v_is_qname != 0);
  if (__pyx_t_3) {

    /* "axon/_dumper.py":504
 * 
 *     if is_qname:
 *         return '"' + text + '"'             # <<<<<<<<<<<<<<
 *     else:
 *         return text
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u__4, __pyx_v_text); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_dumper.py":506
 *         return '"' + text + '"'
 *     else:
 *         return text             # <<<<<<<<<<<<<<
 * 
 * _simple_types = {
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_text);
    __pyx_r = __pyx_v_text;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":472
 *     return text
 * 
 * def _dump_key(ob):             # <<<<<<<<<<<<<<
 *     pos0 = 0
 *     pos = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._dumper._dump_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":513
 *     types.date_type, types.time_type, types.datetime_type}
 * 
 * def is_simple_type(self, o):             # <<<<<<<<<<<<<<
 *     return type(o) in _simple_types or (self.crossref and id(o) in self.crossref_set2)
 * 
 */

static int __pyx_f_4axon_7_dumper_is_simple_type(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_simple_type", 0);

  /* "axon/_dumper.py":514
 * 
 * def is_simple_type(self, o):
 *     return type(o) in _simple_types or (self.crossref and id(o) in self.crossref_set2)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_o)), __pyx_v_4axon_7_dumper__simple_types, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!__pyx_t_1) {
    if (__pyx_v_self->crossref) {
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_o);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_o);
      __Pyx_GIVEREF(__pyx_v_o);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_id, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_4 = (__Pyx_PySequence_Contains(__pyx_t_3, __pyx_v_self->crossref_set2, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5 = __pyx_t_4;
    } else {
      __pyx_t_5 = __pyx_v_self->crossref;
    }
    __pyx_t_4 = __pyx_t_5;
  } else {
    __pyx_t_4 = __pyx_t_1;
  }
  __pyx_r = __pyx_t_4;
  goto __pyx_L0;

  /* "axon/_dumper.py":513
 *     types.date_type, types.time_type, types.datetime_type}
 * 
 * def is_simple_type(self, o):             # <<<<<<<<<<<<<<
 *     return type(o) in _simple_types or (self.crossref and id(o) in self.crossref_set2)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_WriteUnraisable("axon._dumper.is_simple_type", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":522
 *     '''
 *     #
 *     def __init__(self, fd, pretty=0, braces=0, sorted=1, hsize=1, crossref=0):             # <<<<<<<<<<<<<<
 * 
 *         self.max_size = 65000
 */

/* Python wrapper */
static int __pyx_pw_4axon_7_dumper_6Dumper_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4axon_7_dumper_6Dumper_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fd = 0;
  PyObject *__pyx_v_pretty = 0;
  PyObject *__pyx_v_braces = 0;
  PyObject *__pyx_v_sorted = 0;
  PyObject *__pyx_v_hsize = 0;
  PyObject *__pyx_v_crossref = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fd,&__pyx_n_s_pretty,&__pyx_n_s_braces,&__pyx_n_s_sorted,&__pyx_n_s_hsize,&__pyx_n_s_crossref,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    values[1] = ((PyObject *)__pyx_int_0);
    values[2] = ((PyObject *)__pyx_int_0);
    values[3] = ((PyObject *)__pyx_int_1);
    values[4] = ((PyObject *)__pyx_int_1);
    values[5] = ((PyObject *)__pyx_int_0);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_fd)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pretty);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_braces);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sorted);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_hsize);
          if (value) { values[4] = value; kw_args--; }
        }
        case  5:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_crossref);
          if (value) { values[5] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 522; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_fd = values[0];
    __pyx_v_pretty = values[1];
    __pyx_v_braces = values[2];
    __pyx_v_sorted = values[3];
    __pyx_v_hsize = values[4];
    __pyx_v_crossref = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 6, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 522; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper___init__(((struct Dumper *)__pyx_v_self), __pyx_v_fd, __pyx_v_pretty, __pyx_v_braces, __pyx_v_sorted, __pyx_v_hsize, __pyx_v_crossref);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4axon_7_dumper_6Dumper___init__(struct Dumper *__pyx_v_self, PyObject *__pyx_v_fd, PyObject *__pyx_v_pretty, PyObject *__pyx_v_braces, PyObject *__pyx_v_sorted, PyObject *__pyx_v_hsize, PyObject *__pyx_v_crossref) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "axon/_dumper.py":524
 *     def __init__(self, fd, pretty=0, braces=0, sorted=1, hsize=1, crossref=0):
 * 
 *         self.max_size = 65000             # <<<<<<<<<<<<<<
 *         self.size = 0
 * 
 */
  __pyx_v_self->max_size = 65000;

  /* "axon/_dumper.py":525
 * 
 *         self.max_size = 65000
 *         self.size = 0             # <<<<<<<<<<<<<<
 * 
 *         self.crossref = 1 if crossref else 0
 */
  __pyx_v_self->size = 0;

  /* "axon/_dumper.py":527
 *         self.size = 0
 * 
 *         self.crossref = 1 if crossref else 0             # <<<<<<<<<<<<<<
 *         self.crossref_set = None
 *         self.crossref_set2 = None
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_crossref); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_2) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_v_self->crossref = __pyx_t_1;

  /* "axon/_dumper.py":528
 * 
 *         self.crossref = 1 if crossref else 0
 *         self.crossref_set = None             # <<<<<<<<<<<<<<
 *         self.crossref_set2 = None
 *         self.crossref_dict = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->crossref_set);
  __Pyx_DECREF(__pyx_v_self->crossref_set);
  __pyx_v_self->crossref_set = ((PyObject*)Py_None);

  /* "axon/_dumper.py":529
 *         self.crossref = 1 if crossref else 0
 *         self.crossref_set = None
 *         self.crossref_set2 = None             # <<<<<<<<<<<<<<
 *         self.crossref_dict = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->crossref_set2);
  __Pyx_DECREF(__pyx_v_self->crossref_set2);
  __pyx_v_self->crossref_set2 = ((PyObject*)Py_None);

  /* "axon/_dumper.py":530
 *         self.crossref_set = None
 *         self.crossref_set2 = None
 *         self.crossref_dict = None             # <<<<<<<<<<<<<<
 * 
 *         self.pretty = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->crossref_dict);
  __Pyx_DECREF(__pyx_v_self->crossref_dict);
  __pyx_v_self->crossref_dict = ((PyObject*)Py_None);

  /* "axon/_dumper.py":532
 *         self.crossref_dict = None
 * 
 *         self.pretty = 0             # <<<<<<<<<<<<<<
 *         if pretty:
 *             self.pretty = 1
 */
  __pyx_v_self->pretty = 0;

  /* "axon/_dumper.py":533
 * 
 *         self.pretty = 0
 *         if pretty:             # <<<<<<<<<<<<<<
 *             self.pretty = 1
 *             if braces:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_pretty); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 533; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_1) {

    /* "axon/_dumper.py":534
 *         self.pretty = 0
 *         if pretty:
 *             self.pretty = 1             # <<<<<<<<<<<<<<
 *             if braces:
 *                 self.pretty = 2
 */
    __pyx_v_self->pretty = 1;

    /* "axon/_dumper.py":535
 *         if pretty:
 *             self.pretty = 1
 *             if braces:             # <<<<<<<<<<<<<<
 *                 self.pretty = 2
 *         #self.offset = '  '
 */
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_braces); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 535; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_1) {

      /* "axon/_dumper.py":536
 *             self.pretty = 1
 *             if braces:
 *                 self.pretty = 2             # <<<<<<<<<<<<<<
 *         #self.offset = '  '
 *         self.hsize = hsize
 */
      __pyx_v_self->pretty = 2;
      goto __pyx_L4;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":538
 *                 self.pretty = 2
 *         #self.offset = '  '
 *         self.hsize = hsize             # <<<<<<<<<<<<<<
 * 
 *         self.sorted = sorted
 */
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_hsize); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 538; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->hsize = __pyx_t_3;

  /* "axon/_dumper.py":540
 *         self.hsize = hsize
 * 
 *         self.sorted = sorted             # <<<<<<<<<<<<<<
 * 
 *         self.c_simple_dumpers = c_simple_dumpers
 */
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_sorted); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 540; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->sorted = __pyx_t_3;

  /* "axon/_dumper.py":542
 *         self.sorted = sorted
 * 
 *         self.c_simple_dumpers = c_simple_dumpers             # <<<<<<<<<<<<<<
 *         self.c_type_reducers = c_reduce_dict
 * 
 */
  __Pyx_INCREF(__pyx_v_4axon_7_dumper_c_simple_dumpers);
  __Pyx_GIVEREF(__pyx_v_4axon_7_dumper_c_simple_dumpers);
  __Pyx_GOTREF(__pyx_v_self->c_simple_dumpers);
  __Pyx_DECREF(__pyx_v_self->c_simple_dumpers);
  __pyx_v_self->c_simple_dumpers = __pyx_v_4axon_7_dumper_c_simple_dumpers;

  /* "axon/_dumper.py":543
 * 
 *         self.c_simple_dumpers = c_simple_dumpers
 *         self.c_type_reducers = c_reduce_dict             # <<<<<<<<<<<<<<
 * 
 *         self.fd = fd
 */
  __Pyx_INCREF(c_reduce_dict);
  __Pyx_GIVEREF(c_reduce_dict);
  __Pyx_GOTREF(__pyx_v_self->c_type_reducers);
  __Pyx_DECREF(__pyx_v_self->c_type_reducers);
  __pyx_v_self->c_type_reducers = c_reduce_dict;

  /* "axon/_dumper.py":545
 *         self.c_type_reducers = c_reduce_dict
 * 
 *         self.fd = fd             # <<<<<<<<<<<<<<
 *         self.sfd = None
 *         if type(fd) is StringWriter:
 */
  __Pyx_INCREF(__pyx_v_fd);
  __Pyx_GIVEREF(__pyx_v_fd);
  __Pyx_GOTREF(__pyx_v_self->fd);
  __Pyx_DECREF(__pyx_v_self->fd);
  __pyx_v_self->fd = __pyx_v_fd;

  /* "axon/_dumper.py":546
 * 
 *         self.fd = fd
 *         self.sfd = None             # <<<<<<<<<<<<<<
 *         if type(fd) is StringWriter:
 *             self.sfd = self.fd
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sfd);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->sfd));
  __pyx_v_self->sfd = ((struct __pyx_obj_4axon_8_objects_StringWriter *)Py_None);

  /* "axon/_dumper.py":547
 *         self.fd = fd
 *         self.sfd = None
 *         if type(fd) is StringWriter:             # <<<<<<<<<<<<<<
 *             self.sfd = self.fd
 * 
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_fd)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_StringWriter)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":548
 *         self.sfd = None
 *         if type(fd) is StringWriter:
 *             self.sfd = self.fd             # <<<<<<<<<<<<<<
 * 
 *         self.sdumper = SimpleDumper()
 */
    if (!(likely(((__pyx_v_self->fd) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_self->fd, __pyx_ptype_4axon_8_objects_StringWriter))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_4 = __pyx_v_self->fd;
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_v_self->sfd);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->sfd));
    __pyx_v_self->sfd = ((struct __pyx_obj_4axon_8_objects_StringWriter *)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":550
 *             self.sfd = self.fd
 * 
 *         self.sdumper = SimpleDumper()             # <<<<<<<<<<<<<<
 *     #
 *     def write(self, sval):
 */
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_SimpleDumper)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 550; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->sdumper);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->sdumper));
  __pyx_v_self->sdumper = ((struct __pyx_obj_4axon_7_dumper_SimpleDumper *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "axon/_dumper.py":522
 *     '''
 *     #
 *     def __init__(self, fd, pretty=0, braces=0, sorted=1, hsize=1, crossref=0):             # <<<<<<<<<<<<<<
 * 
 *         self.max_size = 65000
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.Dumper.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":552
 *         self.sdumper = SimpleDumper()
 *     #
 *     def write(self, sval):             # <<<<<<<<<<<<<<
 *         if self.sfd is None:
 *             self.fd.write(sval)
 */

static CYTHON_INLINE void __pyx_f_4axon_7_dumper_6Dumper_write(struct Dumper *__pyx_v_self, PyObject *__pyx_v_sval) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("write", 0);

  /* "axon/_dumper.py":553
 *     #
 *     def write(self, sval):
 *         if self.sfd is None:             # <<<<<<<<<<<<<<
 *             self.fd.write(sval)
 *         else:
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->sfd) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":554
 *     def write(self, sval):
 *         if self.sfd is None:
 *             self.fd.write(sval)             # <<<<<<<<<<<<<<
 *         else:
 *             self.sfd.write(sval)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->fd, __pyx_n_s_write); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_sval);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_sval);
    __Pyx_GIVEREF(__pyx_v_sval);
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":556
 *             self.fd.write(sval)
 *         else:
 *             self.sfd.write(sval)             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_crossref(self, o):
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_4axon_8_objects_StringWriter *)__pyx_v_self->sfd->__pyx_vtab)->write(__pyx_v_self->sfd, __pyx_v_sval, 0); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":552
 *         self.sdumper = SimpleDumper()
 *     #
 *     def write(self, sval):             # <<<<<<<<<<<<<<
 *         if self.sfd is None:
 *             self.fd.write(sval)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_WriteUnraisable("axon._dumper.Dumper.write", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":558
 *             self.sfd.write(sval)
 *     #
 *     def _pretty_dump_crossref(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 */

static void __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_crossref(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_o_id = NULL;
  PyObject *__pyx_v_label = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_crossref", 0);

  /* "axon/_dumper.py":559
 *     #
 *     def _pretty_dump_crossref(self, o):
 *         o_id = id(o)             # <<<<<<<<<<<<<<
 *         if o_id in self.crossref_set:
 *             self.write(' &')
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 559; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_id, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 559; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_o_id = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":560
 *     def _pretty_dump_crossref(self, o):
 *         o_id = id(o)
 *         if o_id in self.crossref_set:             # <<<<<<<<<<<<<<
 *             self.write(' &')
 * 
 */
  __pyx_t_3 = (__Pyx_PySequence_Contains(__pyx_v_o_id, __pyx_v_self->crossref_set, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":561
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 *             self.write(' &')             # <<<<<<<<<<<<<<
 * 
 *             label = self.crossref_dict[o_id]
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__20);

    /* "axon/_dumper.py":563
 *             self.write(' &')
 * 
 *             label = self.crossref_dict[o_id]             # <<<<<<<<<<<<<<
 *             self.write(label)
 *             self.write(' ')
 */
    if (unlikely(__pyx_v_self->crossref_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 563; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_self->crossref_dict, __pyx_v_o_id); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 563; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_label = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":564
 * 
 *             label = self.crossref_dict[o_id]
 *             self.write(label)             # <<<<<<<<<<<<<<
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_label);

    /* "axon/_dumper.py":565
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *     #
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);

    /* "axon/_dumper.py":566
 *             self.write(label)
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_crossref(self, o):
 */
    if (unlikely(__pyx_v_self->crossref_set2 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 566; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = PySet_Add(__pyx_v_self->crossref_set2, __pyx_v_o_id); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 566; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":558
 *             self.sfd.write(sval)
 *     #
 *     def _pretty_dump_crossref(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("axon._dumper.Dumper._pretty_dump_crossref", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_o_id);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":568
 *             self.crossref_set2.add(o_id)
 *     #
 *     def _dump_crossref(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 */

static void __pyx_f_4axon_7_dumper_6Dumper__dump_crossref(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_o_id = NULL;
  PyObject *__pyx_v_label = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_crossref", 0);

  /* "axon/_dumper.py":569
 *     #
 *     def _dump_crossref(self, o):
 *         o_id = id(o)             # <<<<<<<<<<<<<<
 *         if o_id in self.crossref_set:
 *             self.write('&')
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 569; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_id, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 569; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_o_id = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":570
 *     def _dump_crossref(self, o):
 *         o_id = id(o)
 *         if o_id in self.crossref_set:             # <<<<<<<<<<<<<<
 *             self.write('&')
 * 
 */
  __pyx_t_3 = (__Pyx_PySequence_Contains(__pyx_v_o_id, __pyx_v_self->crossref_set, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 570; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":571
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 *             self.write('&')             # <<<<<<<<<<<<<<
 * 
 *             label = self.crossref_dict[o_id]
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__22);

    /* "axon/_dumper.py":573
 *             self.write('&')
 * 
 *             label = self.crossref_dict[o_id]             # <<<<<<<<<<<<<<
 *             self.write(label)
 *             self.write(' ')
 */
    if (unlikely(__pyx_v_self->crossref_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 573; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_self->crossref_dict, __pyx_v_o_id); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 573; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_label = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":574
 * 
 *             label = self.crossref_dict[o_id]
 *             self.write(label)             # <<<<<<<<<<<<<<
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_label);

    /* "axon/_dumper.py":575
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *     #
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);

    /* "axon/_dumper.py":576
 *             self.write(label)
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_label(self, o):
 */
    if (unlikely(__pyx_v_self->crossref_set2 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = PySet_Add(__pyx_v_self->crossref_set2, __pyx_v_o_id); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":568
 *             self.crossref_set2.add(o_id)
 *     #
 *     def _dump_crossref(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if o_id in self.crossref_set:
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("axon._dumper.Dumper._dump_crossref", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_o_id);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":578
 *             self.crossref_set2.add(o_id)
 *     #
 *     def _dump_label(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if  o_id in self.crossref_set2:
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_label(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_o_id = NULL;
  PyObject *__pyx_v_label = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_label", 0);

  /* "axon/_dumper.py":579
 *     #
 *     def _dump_label(self, o):
 *         o_id = id(o)             # <<<<<<<<<<<<<<
 *         if  o_id in self.crossref_set2:
 *             self.write('*')
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 579; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_id, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 579; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_o_id = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":580
 *     def _dump_label(self, o):
 *         o_id = id(o)
 *         if  o_id in self.crossref_set2:             # <<<<<<<<<<<<<<
 *             self.write('*')
 * #
 */
  __pyx_t_3 = (__Pyx_PySequence_Contains(__pyx_v_o_id, __pyx_v_self->crossref_set2, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 580; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":581
 *         o_id = id(o)
 *         if  o_id in self.crossref_set2:
 *             self.write('*')             # <<<<<<<<<<<<<<
 * #
 *             label = self.crossref_dict[o_id]
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__23);

    /* "axon/_dumper.py":583
 *             self.write('*')
 * #
 *             label = self.crossref_dict[o_id]             # <<<<<<<<<<<<<<
 *             self.write(label)
 *             return 1
 */
    if (unlikely(__pyx_v_self->crossref_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 583; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_self->crossref_dict, __pyx_v_o_id); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 583; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_label = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":584
 * #
 *             label = self.crossref_dict[o_id]
 *             self.write(label)             # <<<<<<<<<<<<<<
 *             return 1
 *         elif  o_id in self.crossref_set:
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_label);

    /* "axon/_dumper.py":585
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             return 1             # <<<<<<<<<<<<<<
 *         elif  o_id in self.crossref_set:
 *             self.write('&')
 */
    __pyx_r = 1;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":586
 *             self.write(label)
 *             return 1
 *         elif  o_id in self.crossref_set:             # <<<<<<<<<<<<<<
 *             self.write('&')
 * #
 */
  __pyx_t_4 = (__Pyx_PySequence_Contains(__pyx_v_o_id, __pyx_v_self->crossref_set, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 586; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "axon/_dumper.py":587
 *             return 1
 *         elif  o_id in self.crossref_set:
 *             self.write('&')             # <<<<<<<<<<<<<<
 * #
 *             label = self.crossref_dict[o_id]
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__22);

    /* "axon/_dumper.py":589
 *             self.write('&')
 * #
 *             label = self.crossref_dict[o_id]             # <<<<<<<<<<<<<<
 *             self.write(label)
 *             self.write(' ')
 */
    if (unlikely(__pyx_v_self->crossref_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 589; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_self->crossref_dict, __pyx_v_o_id); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 589; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_label = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":590
 * #
 *             label = self.crossref_dict[o_id]
 *             self.write(label)             # <<<<<<<<<<<<<<
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_label);

    /* "axon/_dumper.py":591
 *             label = self.crossref_dict[o_id]
 *             self.write(label)
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self.crossref_set2.add(o_id)
 *             self.crossref_set.remove(o_id)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);

    /* "axon/_dumper.py":592
 *             self.write(label)
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)             # <<<<<<<<<<<<<<
 *             self.crossref_set.remove(o_id)
 *             return 2
 */
    if (unlikely(__pyx_v_self->crossref_set2 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 592; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = PySet_Add(__pyx_v_self->crossref_set2, __pyx_v_o_id); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 592; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":593
 *             self.write(' ')
 *             self.crossref_set2.add(o_id)
 *             self.crossref_set.remove(o_id)             # <<<<<<<<<<<<<<
 *             return 2
 *         else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->crossref_set, __pyx_n_s_remove); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 593; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 593; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_o_id);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o_id);
    __Pyx_GIVEREF(__pyx_v_o_id);
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 593; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "axon/_dumper.py":594
 *             self.crossref_set2.add(o_id)
 *             self.crossref_set.remove(o_id)
 *             return 2             # <<<<<<<<<<<<<<
 *         else:
 *             return -1
 */
    __pyx_r = 2;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_dumper.py":596
 *             return 2
 *         else:
 *             return -1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump(self, o):
 */
    __pyx_r = -1;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":578
 *             self.crossref_set2.add(o_id)
 *     #
 *     def _dump_label(self, o):             # <<<<<<<<<<<<<<
 *         o_id = id(o)
 *         if  o_id in self.crossref_set2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("axon._dumper.Dumper._dump_label", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_o_id);
  __Pyx_XDECREF(__pyx_v_label);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":598
 *             return -1
 *     #
 *     def _dump(self, o):             # <<<<<<<<<<<<<<
 * 
 *         flag = self._dump_value(o)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  int __pyx_v_flag;
  PyObject *__pyx_v_otype = NULL;
  PyObject *__pyx_v_reducer = NULL;
  PyObject *__pyx_v_ob = NULL;
  PyObject *__pyx_v_obtype = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump", 0);

  /* "axon/_dumper.py":600
 *     def _dump(self, o):
 * 
 *         flag = self._dump_value(o)             # <<<<<<<<<<<<<<
 *         if not flag:
 *             if self.crossref:
 */
  __pyx_t_1 = __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_o); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 600; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_flag = __pyx_t_1;

  /* "axon/_dumper.py":601
 * 
 *         flag = self._dump_value(o)
 *         if not flag:             # <<<<<<<<<<<<<<
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:
 */
  __pyx_t_1 = ((!(__pyx_v_flag != 0)) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":602
 *         flag = self._dump_value(o)
 *         if not flag:
 *             if self.crossref:             # <<<<<<<<<<<<<<
 *                 if self._dump_label(o) == 1:
 *                     return 0
 */
    __pyx_t_1 = (__pyx_v_self->crossref != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":603
 *         if not flag:
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:             # <<<<<<<<<<<<<<
 *                     return 0
 * 
 */
      __pyx_t_1 = ((__pyx_f_4axon_7_dumper_6Dumper__dump_label(__pyx_v_self, __pyx_v_o) == 1) != 0);
      if (__pyx_t_1) {

        /* "axon/_dumper.py":604
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:
 *                     return 0             # <<<<<<<<<<<<<<
 * 
 *             #self.write('\n')
 */
        __pyx_r = 0;
        goto __pyx_L0;
      }
      goto __pyx_L4;
    }
    __pyx_L4:;

    /* "axon/_dumper.py":607
 * 
 *             #self.write('\n')
 *             otype = type(o)             # <<<<<<<<<<<<<<
 *             if otype is list:
 *                 self.dump_list(o)
 */
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
    __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

    /* "axon/_dumper.py":608
 *             #self.write('\n')
 *             otype = type(o)
 *             if otype is list:             # <<<<<<<<<<<<<<
 *                 self.dump_list(o)
 *             elif otype is dict:
 */
    __pyx_t_1 = (__pyx_v_otype == ((PyObject*)(&PyList_Type)));
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":609
 *             otype = type(o)
 *             if otype is list:
 *                 self.dump_list(o)             # <<<<<<<<<<<<<<
 *             elif otype is dict:
 *                 self.dump_dict(o)
 */
      if (!(likely(PyList_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_list(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":610
 *             if otype is list:
 *                 self.dump_list(o)
 *             elif otype is dict:             # <<<<<<<<<<<<<<
 *                 self.dump_dict(o)
 *             elif otype is tuple:
 */
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)(&PyDict_Type)));
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":611
 *                 self.dump_list(o)
 *             elif otype is dict:
 *                 self.dump_dict(o)             # <<<<<<<<<<<<<<
 *             elif otype is tuple:
 *                 self.dump_tuple(o)
 */
      if (!(likely(PyDict_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_dict(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":612
 *             elif otype is dict:
 *                 self.dump_dict(o)
 *             elif otype is tuple:             # <<<<<<<<<<<<<<
 *                 self.dump_tuple(o)
 *             #elif otype is set:
 */
    __pyx_t_1 = (__pyx_v_otype == ((PyObject*)(&PyTuple_Type)));
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":613
 *                 self.dump_dict(o)
 *             elif otype is tuple:
 *                 self.dump_tuple(o)             # <<<<<<<<<<<<<<
 *             #elif otype is set:
 *             #    self.dump_set(o)
 */
      if (!(likely(PyTuple_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_tuple(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":616
 *             #elif otype is set:
 *             #    self.dump_set(o)
 *             elif otype is Mapping:             # <<<<<<<<<<<<<<
 *                 self.dump_mapping(o)
 *             elif otype is Sequence:
 */
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Mapping));
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":617
 *             #    self.dump_set(o)
 *             elif otype is Mapping:
 *                 self.dump_mapping(o)             # <<<<<<<<<<<<<<
 *             elif otype is Sequence:
 *                 self.dump_sequence(o)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Mapping))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 617; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_mapping(__pyx_v_self, ((struct MappingObject *)__pyx_v_o)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 617; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":618
 *             elif otype is Mapping:
 *                 self.dump_mapping(o)
 *             elif otype is Sequence:             # <<<<<<<<<<<<<<
 *                 self.dump_sequence(o)
 *             elif otype is Element:
 */
    __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Sequence));
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":619
 *                 self.dump_mapping(o)
 *             elif otype is Sequence:
 *                 self.dump_sequence(o)             # <<<<<<<<<<<<<<
 *             elif otype is Element:
 *                 self.dump_element(o)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Sequence))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 619; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_sequence(__pyx_v_self, ((struct SequenceObject *)__pyx_v_o)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 619; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":620
 *             elif otype is Sequence:
 *                 self.dump_sequence(o)
 *             elif otype is Element:             # <<<<<<<<<<<<<<
 *                 self.dump_element(o)
 *             elif otype is Instance:
 */
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Element));
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":621
 *                 self.dump_sequence(o)
 *             elif otype is Element:
 *                 self.dump_element(o)             # <<<<<<<<<<<<<<
 *             elif otype is Instance:
 *                 self.dump_instance(o)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Element))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 621; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_element(__pyx_v_self, ((struct ElementObject *)__pyx_v_o)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 621; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":622
 *             elif otype is Element:
 *                 self.dump_element(o)
 *             elif otype is Instance:             # <<<<<<<<<<<<<<
 *                 self.dump_instance(o)
 *             elif otype is Empty:
 */
    __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Instance));
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":623
 *                 self.dump_element(o)
 *             elif otype is Instance:
 *                 self.dump_instance(o)             # <<<<<<<<<<<<<<
 *             elif otype is Empty:
 *                 self.dump_empty(o)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Instance))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 623; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_instance(__pyx_v_self, ((struct InstanceObject *)__pyx_v_o)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 623; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }

    /* "axon/_dumper.py":624
 *             elif otype is Instance:
 *                 self.dump_instance(o)
 *             elif otype is Empty:             # <<<<<<<<<<<<<<
 *                 self.dump_empty(o)
 *             else:
 */
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Empty));
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":625
 *                 self.dump_instance(o)
 *             elif otype is Empty:
 *                 self.dump_empty(o)             # <<<<<<<<<<<<<<
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Empty))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_empty(__pyx_v_self, ((struct EmptyObject *)__pyx_v_o)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }
    /*else*/ {

      /* "axon/_dumper.py":627
 *                 self.dump_empty(o)
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)             # <<<<<<<<<<<<<<
 *                 if reducer is None:
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 */
      if (unlikely(__pyx_v_self->c_type_reducers == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 627; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_4 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->c_type_reducers, ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 627; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_reducer = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "axon/_dumper.py":628
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)
 *                 if reducer is None:             # <<<<<<<<<<<<<<
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 *                 else:
 */
      __pyx_t_1 = (__pyx_v_reducer == Py_None);
      __pyx_t_2 = (__pyx_t_1 != 0);
      if (__pyx_t_2) {

        /* "axon/_dumper.py":629
 *                 reducer = self.c_type_reducers.get(otype, None)
 *                 if reducer is None:
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))             # <<<<<<<<<<<<<<
 *                 else:
 *                     ob = reducer(o)
 */
        __pyx_t_4 = PyObject_Repr(((PyObject *)__pyx_v_otype)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyUnicode_ConcatSafe(__pyx_kp_u_There_is_no_reducer_for_this_typ, __pyx_t_4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      /*else*/ {

        /* "axon/_dumper.py":631
 *                     raise TypeError('There is no reducer for this type: ' + repr(otype))
 *                 else:
 *                     ob = reducer(o)             # <<<<<<<<<<<<<<
 *                     obtype = type(ob)
 *                     if obtype is Mapping:
 */
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 631; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_o);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_o);
        __Pyx_GIVEREF(__pyx_v_o);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_reducer, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 631; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_v_ob = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "axon/_dumper.py":632
 *                 else:
 *                     ob = reducer(o)
 *                     obtype = type(ob)             # <<<<<<<<<<<<<<
 *                     if obtype is Mapping:
 *                         self.dump_mapping(ob)
 */
        __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_ob)));
        __pyx_v_obtype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_ob)));

        /* "axon/_dumper.py":633
 *                     ob = reducer(o)
 *                     obtype = type(ob)
 *                     if obtype is Mapping:             # <<<<<<<<<<<<<<
 *                         self.dump_mapping(ob)
 *                     elif obtype is Sequence:
 */
        __pyx_t_2 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Mapping));
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (__pyx_t_1) {

          /* "axon/_dumper.py":634
 *                     obtype = type(ob)
 *                     if obtype is Mapping:
 *                         self.dump_mapping(ob)             # <<<<<<<<<<<<<<
 *                     elif obtype is Sequence:
 *                         self.dump_sequence(ob)
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Mapping))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_mapping(__pyx_v_self, ((struct MappingObject *)__pyx_v_ob)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L8;
        }

        /* "axon/_dumper.py":635
 *                     if obtype is Mapping:
 *                         self.dump_mapping(ob)
 *                     elif obtype is Sequence:             # <<<<<<<<<<<<<<
 *                         self.dump_sequence(ob)
 *                     elif obtype is Element:
 */
        __pyx_t_1 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Sequence));
        __pyx_t_2 = (__pyx_t_1 != 0);
        if (__pyx_t_2) {

          /* "axon/_dumper.py":636
 *                         self.dump_mapping(ob)
 *                     elif obtype is Sequence:
 *                         self.dump_sequence(ob)             # <<<<<<<<<<<<<<
 *                     elif obtype is Element:
 *                         self.dump_element(ob)
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Sequence))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 636; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_sequence(__pyx_v_self, ((struct SequenceObject *)__pyx_v_ob)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 636; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L8;
        }

        /* "axon/_dumper.py":637
 *                     elif obtype is Sequence:
 *                         self.dump_sequence(ob)
 *                     elif obtype is Element:             # <<<<<<<<<<<<<<
 *                         self.dump_element(ob)
 *                     elif obtype is Instance:
 */
        __pyx_t_2 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Element));
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (__pyx_t_1) {

          /* "axon/_dumper.py":638
 *                         self.dump_sequence(ob)
 *                     elif obtype is Element:
 *                         self.dump_element(ob)             # <<<<<<<<<<<<<<
 *                     elif obtype is Instance:
 *                         self.dump_instance(ob)
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Element))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_element(__pyx_v_self, ((struct ElementObject *)__pyx_v_ob)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L8;
        }

        /* "axon/_dumper.py":639
 *                     elif obtype is Element:
 *                         self.dump_element(ob)
 *                     elif obtype is Instance:             # <<<<<<<<<<<<<<
 *                         self.dump_instance(ob)
 *                     elif obtype is Empty:
 */
        __pyx_t_1 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Instance));
        __pyx_t_2 = (__pyx_t_1 != 0);
        if (__pyx_t_2) {

          /* "axon/_dumper.py":640
 *                         self.dump_element(ob)
 *                     elif obtype is Instance:
 *                         self.dump_instance(ob)             # <<<<<<<<<<<<<<
 *                     elif obtype is Empty:
 *                         self.dump_empty(ob)
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Instance))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_instance(__pyx_v_self, ((struct InstanceObject *)__pyx_v_ob)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 640; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L8;
        }

        /* "axon/_dumper.py":641
 *                     elif obtype is Instance:
 *                         self.dump_instance(ob)
 *                     elif obtype is Empty:             # <<<<<<<<<<<<<<
 *                         self.dump_empty(ob)
 *                     else:
 */
        __pyx_t_2 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Empty));
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (__pyx_t_1) {

          /* "axon/_dumper.py":642
 *                         self.dump_instance(ob)
 *                     elif obtype is Empty:
 *                         self.dump_empty(ob)             # <<<<<<<<<<<<<<
 *                     else:
 *                         raise RuntimeError()
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Empty))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 642; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_dump_empty(__pyx_v_self, ((struct EmptyObject *)__pyx_v_ob)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 642; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L8;
        }
        /*else*/ {

          /* "axon/_dumper.py":644
 *                         self.dump_empty(ob)
 *                     else:
 *                         raise RuntimeError()             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump(self, o, offset, use_offset):
 */
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 644; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_Raise(__pyx_t_4, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 644; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_L8:;
      }
    }
    __pyx_L6:;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":598
 *             return -1
 *     #
 *     def _dump(self, o):             # <<<<<<<<<<<<<<
 * 
 *         flag = self._dump_value(o)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF(__pyx_v_reducer);
  __Pyx_XDECREF(__pyx_v_ob);
  __Pyx_XDECREF(__pyx_v_obtype);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":646
 *                         raise RuntimeError()
 *     #
 *     def _pretty_dump(self, o, offset, use_offset):             # <<<<<<<<<<<<<<
 *         new_offset = offset + '  '
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o, PyObject *__pyx_v_offset, int __pyx_v_use_offset) {
  int __pyx_v_flag;
  PyObject *__pyx_v_new_offset = 0;
  PyObject *__pyx_v_otype = NULL;
  PyObject *__pyx_v_reducer = NULL;
  PyObject *__pyx_v_ob = NULL;
  PyObject *__pyx_v_obtype = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump", 0);

  /* "axon/_dumper.py":647
 *     #
 *     def _pretty_dump(self, o, offset, use_offset):
 *         new_offset = offset + '  '             # <<<<<<<<<<<<<<
 * 
 *         if use_offset:
 */
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_offset, __pyx_kp_u__24); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 647; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_new_offset = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":649
 *         new_offset = offset + '  '
 * 
 *         if use_offset:             # <<<<<<<<<<<<<<
 *             self.write(offset)
 * 
 */
  __pyx_t_2 = (__pyx_v_use_offset != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":650
 * 
 *         if use_offset:
 *             self.write(offset)             # <<<<<<<<<<<<<<
 * 
 *         flag = self._dump_value(o)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_offset);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":652
 *             self.write(offset)
 * 
 *         flag = self._dump_value(o)             # <<<<<<<<<<<<<<
 *         if not flag:
 *             if self.crossref:
 */
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_o); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 652; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_flag = __pyx_t_2;

  /* "axon/_dumper.py":653
 * 
 *         flag = self._dump_value(o)
 *         if not flag:             # <<<<<<<<<<<<<<
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:
 */
  __pyx_t_2 = ((!(__pyx_v_flag != 0)) != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":654
 *         flag = self._dump_value(o)
 *         if not flag:
 *             if self.crossref:             # <<<<<<<<<<<<<<
 *                 if self._dump_label(o) == 1:
 *                     return 0
 */
    __pyx_t_2 = (__pyx_v_self->crossref != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":655
 *         if not flag:
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:             # <<<<<<<<<<<<<<
 *                     return 0
 * 
 */
      __pyx_t_2 = ((__pyx_f_4axon_7_dumper_6Dumper__dump_label(__pyx_v_self, __pyx_v_o) == 1) != 0);
      if (__pyx_t_2) {

        /* "axon/_dumper.py":656
 *             if self.crossref:
 *                 if self._dump_label(o) == 1:
 *                     return 0             # <<<<<<<<<<<<<<
 * 
 *             otype = type(o)
 */
        __pyx_r = 0;
        goto __pyx_L0;
      }
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":658
 *                     return 0
 * 
 *             otype = type(o)             # <<<<<<<<<<<<<<
 *             if otype is list:
 *                 self.pretty_dump_list(o, new_offset, not use_offset)
 */
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
    __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

    /* "axon/_dumper.py":659
 * 
 *             otype = type(o)
 *             if otype is list:             # <<<<<<<<<<<<<<
 *                 self.pretty_dump_list(o, new_offset, not use_offset)
 *             elif otype is dict:
 */
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)(&PyList_Type)));
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "axon/_dumper.py":660
 *             otype = type(o)
 *             if otype is list:
 *                 self.pretty_dump_list(o, new_offset, not use_offset)             # <<<<<<<<<<<<<<
 *             elif otype is dict:
 *                 self.pretty_dump_dict(o, new_offset, not use_offset)
 */
      if (!(likely(PyList_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_list(__pyx_v_self, ((PyObject*)__pyx_v_o), __pyx_v_new_offset, (!(__pyx_v_use_offset != 0))); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 660; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":661
 *             if otype is list:
 *                 self.pretty_dump_list(o, new_offset, not use_offset)
 *             elif otype is dict:             # <<<<<<<<<<<<<<
 *                 self.pretty_dump_dict(o, new_offset, not use_offset)
 *             elif otype is tuple:
 */
    __pyx_t_3 = (__pyx_v_otype == ((PyObject*)(&PyDict_Type)));
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":662
 *                 self.pretty_dump_list(o, new_offset, not use_offset)
 *             elif otype is dict:
 *                 self.pretty_dump_dict(o, new_offset, not use_offset)             # <<<<<<<<<<<<<<
 *             elif otype is tuple:
 *                 self.pretty_dump_tuple(o, new_offset, not use_offset)
 */
      if (!(likely(PyDict_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 662; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_dict(__pyx_v_self, ((PyObject*)__pyx_v_o), __pyx_v_new_offset, (!(__pyx_v_use_offset != 0))); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 662; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":663
 *             elif otype is dict:
 *                 self.pretty_dump_dict(o, new_offset, not use_offset)
 *             elif otype is tuple:             # <<<<<<<<<<<<<<
 *                 self.pretty_dump_tuple(o, new_offset, not use_offset)
 *             #elif otype is set:
 */
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)(&PyTuple_Type)));
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "axon/_dumper.py":664
 *                 self.pretty_dump_dict(o, new_offset, not use_offset)
 *             elif otype is tuple:
 *                 self.pretty_dump_tuple(o, new_offset, not use_offset)             # <<<<<<<<<<<<<<
 *             #elif otype is set:
 *             #    self.pretty_dump_set(o, new_offset, not use_offset)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pretty_dump_tuple); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyBool_FromLong((!(__pyx_v_use_offset != 0))); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_o);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_o);
      __Pyx_GIVEREF(__pyx_v_o);
      __Pyx_INCREF(__pyx_v_new_offset);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_new_offset);
      __Pyx_GIVEREF(__pyx_v_new_offset);
      PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":667
 *             #elif otype is set:
 *             #    self.pretty_dump_set(o, new_offset, not use_offset)
 *             elif otype is Mapping:             # <<<<<<<<<<<<<<
 *                 self.pretty_dump_mapping(o, new_offset, use_offset)
 *             elif otype is Sequence:
 */
    __pyx_t_3 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Mapping));
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":668
 *             #    self.pretty_dump_set(o, new_offset, not use_offset)
 *             elif otype is Mapping:
 *                 self.pretty_dump_mapping(o, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *             elif otype is Sequence:
 *                 self.pretty_dump_sequence(o, new_offset, use_offset)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Mapping))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 668; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_mapping(__pyx_v_self, ((struct MappingObject *)__pyx_v_o), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 668; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":669
 *             elif otype is Mapping:
 *                 self.pretty_dump_mapping(o, new_offset, use_offset)
 *             elif otype is Sequence:             # <<<<<<<<<<<<<<
 *                 self.pretty_dump_sequence(o, new_offset, use_offset)
 *             elif otype is Element:
 */
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Sequence));
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "axon/_dumper.py":670
 *                 self.pretty_dump_mapping(o, new_offset, use_offset)
 *             elif otype is Sequence:
 *                 self.pretty_dump_sequence(o, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *             elif otype is Element:
 *                 self.pretty_dump_element(o, new_offset, use_offset)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Sequence))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 670; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_sequence(__pyx_v_self, ((struct SequenceObject *)__pyx_v_o), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 670; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":671
 *             elif otype is Sequence:
 *                 self.pretty_dump_sequence(o, new_offset, use_offset)
 *             elif otype is Element:             # <<<<<<<<<<<<<<
 *                 self.pretty_dump_element(o, new_offset, use_offset)
 *             elif otype is Instance:
 */
    __pyx_t_3 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Element));
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":672
 *                 self.pretty_dump_sequence(o, new_offset, use_offset)
 *             elif otype is Element:
 *                 self.pretty_dump_element(o, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *             elif otype is Instance:
 *                 self.pretty_dump_instance(o, new_offset, use_offset)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Element))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 672; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_element(__pyx_v_self, ((struct ElementObject *)__pyx_v_o), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 672; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":673
 *             elif otype is Element:
 *                 self.pretty_dump_element(o, new_offset, use_offset)
 *             elif otype is Instance:             # <<<<<<<<<<<<<<
 *                 self.pretty_dump_instance(o, new_offset, use_offset)
 *             elif otype is Empty:
 */
    __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Instance));
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "axon/_dumper.py":674
 *                 self.pretty_dump_element(o, new_offset, use_offset)
 *             elif otype is Instance:
 *                 self.pretty_dump_instance(o, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *             elif otype is Empty:
 *                 self.pretty_dump_empty(o, new_offset, use_offset)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Instance))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 674; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_instance(__pyx_v_self, ((struct InstanceObject *)__pyx_v_o), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 674; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }

    /* "axon/_dumper.py":675
 *             elif otype is Instance:
 *                 self.pretty_dump_instance(o, new_offset, use_offset)
 *             elif otype is Empty:             # <<<<<<<<<<<<<<
 *                 self.pretty_dump_empty(o, new_offset, use_offset)
 *             else:
 */
    __pyx_t_3 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Empty));
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":676
 *                 self.pretty_dump_instance(o, new_offset, use_offset)
 *             elif otype is Empty:
 *                 self.pretty_dump_empty(o, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)
 */
      if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Empty))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 676; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_empty(__pyx_v_self, ((struct EmptyObject *)__pyx_v_o), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 676; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }
    /*else*/ {

      /* "axon/_dumper.py":678
 *                 self.pretty_dump_empty(o, new_offset, use_offset)
 *             else:
 *                 reducer = self.c_type_reducers.get(otype, None)             # <<<<<<<<<<<<<<
 *                 #print(repr(o))
 *                 if reducer is None:
 */
      if (unlikely(__pyx_v_self->c_type_reducers == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 678; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_5 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->c_type_reducers, ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 678; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_v_reducer = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "axon/_dumper.py":680
 *                 reducer = self.c_type_reducers.get(otype, None)
 *                 #print(repr(o))
 *                 if reducer is None:             # <<<<<<<<<<<<<<
 *                     raise TypeError('There is no reducer for this type: %r %r' % (otype, o))
 *                 else:
 */
      __pyx_t_2 = (__pyx_v_reducer == Py_None);
      __pyx_t_3 = (__pyx_t_2 != 0);
      if (__pyx_t_3) {

        /* "axon/_dumper.py":681
 *                 #print(repr(o))
 *                 if reducer is None:
 *                     raise TypeError('There is no reducer for this type: %r %r' % (otype, o))             # <<<<<<<<<<<<<<
 *                 else:
 *                     ob = reducer(o)
 */
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(((PyObject *)__pyx_v_otype));
        PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_otype));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_otype));
        __Pyx_INCREF(__pyx_v_o);
        PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_o);
        __Pyx_GIVEREF(__pyx_v_o);
        __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_There_is_no_reducer_for_this_typ_2, __pyx_t_5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 681; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      /*else*/ {

        /* "axon/_dumper.py":683
 *                     raise TypeError('There is no reducer for this type: %r %r' % (otype, o))
 *                 else:
 *                     ob = reducer(o)             # <<<<<<<<<<<<<<
 *                     obtype = type(ob)
 *                     #print(obtype)
 */
        __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 683; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_v_o);
        PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_o);
        __Pyx_GIVEREF(__pyx_v_o);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_reducer, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 683; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_ob = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "axon/_dumper.py":684
 *                 else:
 *                     ob = reducer(o)
 *                     obtype = type(ob)             # <<<<<<<<<<<<<<
 *                     #print(obtype)
 *                     if obtype is Mapping:
 */
        __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_ob)));
        __pyx_v_obtype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_ob)));

        /* "axon/_dumper.py":686
 *                     obtype = type(ob)
 *                     #print(obtype)
 *                     if obtype is Mapping:             # <<<<<<<<<<<<<<
 *                         self.pretty_dump_mapping(ob, new_offset, use_offset)
 *                     elif obtype is Sequence:
 */
        __pyx_t_3 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Mapping));
        __pyx_t_2 = (__pyx_t_3 != 0);
        if (__pyx_t_2) {

          /* "axon/_dumper.py":687
 *                     #print(obtype)
 *                     if obtype is Mapping:
 *                         self.pretty_dump_mapping(ob, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *                     elif obtype is Sequence:
 *                         self.pretty_dump_sequence(ob, new_offset, use_offset)
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Mapping))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_mapping(__pyx_v_self, ((struct MappingObject *)__pyx_v_ob), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L9;
        }

        /* "axon/_dumper.py":688
 *                     if obtype is Mapping:
 *                         self.pretty_dump_mapping(ob, new_offset, use_offset)
 *                     elif obtype is Sequence:             # <<<<<<<<<<<<<<
 *                         self.pretty_dump_sequence(ob, new_offset, use_offset)
 *                     elif obtype is Element:
 */
        __pyx_t_2 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Sequence));
        __pyx_t_3 = (__pyx_t_2 != 0);
        if (__pyx_t_3) {

          /* "axon/_dumper.py":689
 *                         self.pretty_dump_mapping(ob, new_offset, use_offset)
 *                     elif obtype is Sequence:
 *                         self.pretty_dump_sequence(ob, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *                     elif obtype is Element:
 *                         self.pretty_dump_element(ob, new_offset, use_offset)
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Sequence))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 689; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_sequence(__pyx_v_self, ((struct SequenceObject *)__pyx_v_ob), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 689; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L9;
        }

        /* "axon/_dumper.py":690
 *                     elif obtype is Sequence:
 *                         self.pretty_dump_sequence(ob, new_offset, use_offset)
 *                     elif obtype is Element:             # <<<<<<<<<<<<<<
 *                         self.pretty_dump_element(ob, new_offset, use_offset)
 *                     elif obtype is Instance:
 */
        __pyx_t_3 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Element));
        __pyx_t_2 = (__pyx_t_3 != 0);
        if (__pyx_t_2) {

          /* "axon/_dumper.py":691
 *                         self.pretty_dump_sequence(ob, new_offset, use_offset)
 *                     elif obtype is Element:
 *                         self.pretty_dump_element(ob, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *                     elif obtype is Instance:
 *                         self.pretty_dump_instance(ob, new_offset, use_offset)
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Element))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 691; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_element(__pyx_v_self, ((struct ElementObject *)__pyx_v_ob), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 691; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L9;
        }

        /* "axon/_dumper.py":692
 *                     elif obtype is Element:
 *                         self.pretty_dump_element(ob, new_offset, use_offset)
 *                     elif obtype is Instance:             # <<<<<<<<<<<<<<
 *                         self.pretty_dump_instance(ob, new_offset, use_offset)
 *                     elif obtype is Empty:
 */
        __pyx_t_2 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Instance));
        __pyx_t_3 = (__pyx_t_2 != 0);
        if (__pyx_t_3) {

          /* "axon/_dumper.py":693
 *                         self.pretty_dump_element(ob, new_offset, use_offset)
 *                     elif obtype is Instance:
 *                         self.pretty_dump_instance(ob, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *                     elif obtype is Empty:
 *                         self.pretty_dump_empty(ob, new_offset, use_offset)
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Instance))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_instance(__pyx_v_self, ((struct InstanceObject *)__pyx_v_ob), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L9;
        }

        /* "axon/_dumper.py":694
 *                     elif obtype is Instance:
 *                         self.pretty_dump_instance(ob, new_offset, use_offset)
 *                     elif obtype is Empty:             # <<<<<<<<<<<<<<
 *                         self.pretty_dump_empty(ob, new_offset, use_offset)
 *                     else:
 */
        __pyx_t_3 = (__pyx_v_obtype == ((PyObject*)__pyx_ptype_4axon_8_objects_Empty));
        __pyx_t_2 = (__pyx_t_3 != 0);
        if (__pyx_t_2) {

          /* "axon/_dumper.py":695
 *                         self.pretty_dump_instance(ob, new_offset, use_offset)
 *                     elif obtype is Empty:
 *                         self.pretty_dump_empty(ob, new_offset, use_offset)             # <<<<<<<<<<<<<<
 *                     else:
 *                         raise RuntimeError()
 */
          if (!(likely(((__pyx_v_ob) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_ob, __pyx_ptype_4axon_8_objects_Empty))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 695; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_empty(__pyx_v_self, ((struct EmptyObject *)__pyx_v_ob), __pyx_v_new_offset, __pyx_v_use_offset); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 695; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          goto __pyx_L9;
        }
        /*else*/ {

          /* "axon/_dumper.py":697
 *                         self.pretty_dump_empty(ob, new_offset, use_offset)
 *                     else:
 *                         raise RuntimeError()             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_value(self, o):
 */
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 697; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_Raise(__pyx_t_5, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 697; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_L9:;
      }
    }
    __pyx_L7:;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":646
 *                         raise RuntimeError()
 *     #
 *     def _pretty_dump(self, o, offset, use_offset):             # <<<<<<<<<<<<<<
 *         new_offset = offset + '  '
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF(__pyx_v_reducer);
  __Pyx_XDECREF(__pyx_v_ob);
  __Pyx_XDECREF(__pyx_v_obtype);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":699
 *                         raise RuntimeError()
 *     #
 *     def _dump_value(self, o):             # <<<<<<<<<<<<<<
 *         otype = type(o)
 *         #print(otype)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_value(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  PyObject *__pyx_v_text = 0;
  struct __pyx_obj_4axon_7_dumper_PyPointer *__pyx_v_ptr = 0;
  PyObject *__pyx_v_otype = NULL;
  struct __pyx_obj_4axon_7_dumper_SimpleDumper *__pyx_v_dumper = NULL;
  PyObject *__pyx_v__dumper = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_value", 0);

  /* "axon/_dumper.py":700
 *     #
 *     def _dump_value(self, o):
 *         otype = type(o)             # <<<<<<<<<<<<<<
 *         #print(otype)
 *         dumper = self.sdumper
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
  __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

  /* "axon/_dumper.py":702
 *         otype = type(o)
 *         #print(otype)
 *         dumper = self.sdumper             # <<<<<<<<<<<<<<
 *         if otype is unicode_type:
 *             self.write('"')
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->sdumper);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_dumper = ((struct __pyx_obj_4axon_7_dumper_SimpleDumper *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":703
 *         #print(otype)
 *         dumper = self.sdumper
 *         if otype is unicode_type:             # <<<<<<<<<<<<<<
 *             self.write('"')
 *             text = dumper.dump_unicode(o)
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_unicode_type));
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_dumper.py":704
 *         dumper = self.sdumper
 *         if otype is unicode_type:
 *             self.write('"')             # <<<<<<<<<<<<<<
 *             text = dumper.dump_unicode(o)
 *             self.write(text)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__4);

    /* "axon/_dumper.py":705
 *         if otype is unicode_type:
 *             self.write('"')
 *             text = dumper.dump_unicode(o)             # <<<<<<<<<<<<<<
 *             self.write(text)
 *             self.write('"')
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_unicode(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "axon/_dumper.py":706
 *             self.write('"')
 *             text = dumper.dump_unicode(o)
 *             self.write(text)             # <<<<<<<<<<<<<<
 *             self.write('"')
 *             return 1
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_text);

    /* "axon/_dumper.py":707
 *             text = dumper.dump_unicode(o)
 *             self.write(text)
 *             self.write('"')             # <<<<<<<<<<<<<<
 *             return 1
 *         elif otype is str_type:
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__4);

    /* "axon/_dumper.py":708
 *             self.write(text)
 *             self.write('"')
 *             return 1             # <<<<<<<<<<<<<<
 *         elif otype is str_type:
 *             self.write('"')
 */
    __pyx_r = 1;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":709
 *             self.write('"')
 *             return 1
 *         elif otype is str_type:             # <<<<<<<<<<<<<<
 *             self.write('"')
 *             text = dumper.dump_str(o)
 */
  __pyx_t_3 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_str_type));
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":710
 *             return 1
 *         elif otype is str_type:
 *             self.write('"')             # <<<<<<<<<<<<<<
 *             text = dumper.dump_str(o)
 *             self.write(text)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__4);

    /* "axon/_dumper.py":711
 *         elif otype is str_type:
 *             self.write('"')
 *             text = dumper.dump_str(o)             # <<<<<<<<<<<<<<
 *             self.write(text)
 *             self.write('"')
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_str(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "axon/_dumper.py":712
 *             self.write('"')
 *             text = dumper.dump_str(o)
 *             self.write(text)             # <<<<<<<<<<<<<<
 *             self.write('"')
 *             return 1
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_text);

    /* "axon/_dumper.py":713
 *             text = dumper.dump_str(o)
 *             self.write(text)
 *             self.write('"')             # <<<<<<<<<<<<<<
 *             return 1
 *         elif otype is long_type or otype is int_type:
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__4);

    /* "axon/_dumper.py":714
 *             self.write(text)
 *             self.write('"')
 *             return 1             # <<<<<<<<<<<<<<
 *         elif otype is long_type or otype is int_type:
 *             text = dumper.dump_int(o)
 */
    __pyx_r = 1;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":715
 *             self.write('"')
 *             return 1
 *         elif otype is long_type or otype is int_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_int(o)
 *         elif otype is float_type:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_long_type));
  if (!(__pyx_t_2 != 0)) {
    __pyx_t_3 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_int_type));
    __pyx_t_4 = (__pyx_t_3 != 0);
  } else {
    __pyx_t_4 = (__pyx_t_2 != 0);
  }
  if (__pyx_t_4) {

    /* "axon/_dumper.py":716
 *             return 1
 *         elif otype is long_type or otype is int_type:
 *             text = dumper.dump_int(o)             # <<<<<<<<<<<<<<
 *         elif otype is float_type:
 *             text = dumper.dump_float(o)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_int(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":717
 *         elif otype is long_type or otype is int_type:
 *             text = dumper.dump_int(o)
 *         elif otype is float_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_float(o)
 *         elif otype is decimal_type:
 */
  __pyx_t_4 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_float_type));
  __pyx_t_2 = (__pyx_t_4 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":718
 *             text = dumper.dump_int(o)
 *         elif otype is float_type:
 *             text = dumper.dump_float(o)             # <<<<<<<<<<<<<<
 *         elif otype is decimal_type:
 *             text = dumper.dump_decimal(o)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_float(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":719
 *         elif otype is float_type:
 *             text = dumper.dump_float(o)
 *         elif otype is decimal_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_decimal(o)
 *         elif otype is none_type:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_decimal_type));
  __pyx_t_4 = (__pyx_t_2 != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":720
 *             text = dumper.dump_float(o)
 *         elif otype is decimal_type:
 *             text = dumper.dump_decimal(o)             # <<<<<<<<<<<<<<
 *         elif otype is none_type:
 *             text = dumper.dump_none(o)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_decimal(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":721
 *         elif otype is decimal_type:
 *             text = dumper.dump_decimal(o)
 *         elif otype is none_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_none(o)
 *         elif otype is bytes_type or otype is bytearray_type:
 */
  __pyx_t_4 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_none_type));
  __pyx_t_2 = (__pyx_t_4 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":722
 *             text = dumper.dump_decimal(o)
 *         elif otype is none_type:
 *             text = dumper.dump_none(o)             # <<<<<<<<<<<<<<
 *         elif otype is bytes_type or otype is bytearray_type:
 *             text = dumper.dump_bytes(o)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_none(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 722; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":723
 *         elif otype is none_type:
 *             text = dumper.dump_none(o)
 *         elif otype is bytes_type or otype is bytearray_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_bytes(o)
 *         elif otype is date_type:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_bytes_type));
  if (!(__pyx_t_2 != 0)) {
    __pyx_t_4 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_bytearray_type));
    __pyx_t_3 = (__pyx_t_4 != 0);
  } else {
    __pyx_t_3 = (__pyx_t_2 != 0);
  }
  if (__pyx_t_3) {

    /* "axon/_dumper.py":724
 *             text = dumper.dump_none(o)
 *         elif otype is bytes_type or otype is bytearray_type:
 *             text = dumper.dump_bytes(o)             # <<<<<<<<<<<<<<
 *         elif otype is date_type:
 *             text = dumper.dump_date(o)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_bytes(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 724; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":725
 *         elif otype is bytes_type or otype is bytearray_type:
 *             text = dumper.dump_bytes(o)
 *         elif otype is date_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_date(o)
 *         elif otype is time_type:
 */
  __pyx_t_3 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_date_type));
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":726
 *             text = dumper.dump_bytes(o)
 *         elif otype is date_type:
 *             text = dumper.dump_date(o)             # <<<<<<<<<<<<<<
 *         elif otype is time_type:
 *             text = dumper.dump_time(o)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_date(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 726; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":727
 *         elif otype is date_type:
 *             text = dumper.dump_date(o)
 *         elif otype is time_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_time(o)
 *         elif otype is datetime_type:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_time_type));
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_dumper.py":728
 *             text = dumper.dump_date(o)
 *         elif otype is time_type:
 *             text = dumper.dump_time(o)             # <<<<<<<<<<<<<<
 *         elif otype is datetime_type:
 *             text = dumper.dump_datetime(o)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_time(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":729
 *         elif otype is time_type:
 *             text = dumper.dump_time(o)
 *         elif otype is datetime_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_datetime(o)
 *         elif otype is bool_type:
 */
  __pyx_t_3 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_datetime_type));
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":730
 *             text = dumper.dump_time(o)
 *         elif otype is datetime_type:
 *             text = dumper.dump_datetime(o)             # <<<<<<<<<<<<<<
 *         elif otype is bool_type:
 *             text = dumper.dump_bool(o)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_datetime(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }

  /* "axon/_dumper.py":731
 *         elif otype is datetime_type:
 *             text = dumper.dump_datetime(o)
 *         elif otype is bool_type:             # <<<<<<<<<<<<<<
 *             text = dumper.dump_bool(o)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_v_4axon_7_dumper_bool_type));
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_dumper.py":732
 *             text = dumper.dump_datetime(o)
 *         elif otype is bool_type:
 *             text = dumper.dump_bool(o)             # <<<<<<<<<<<<<<
 *         else:
 *             _dumper = c_simple_dumpers.get(otype, None)
 */
    __pyx_t_1 = __pyx_f_4axon_7_dumper_12SimpleDumper_dump_bool(__pyx_v_dumper, __pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_text = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":734
 *             text = dumper.dump_bool(o)
 *         else:
 *             _dumper = c_simple_dumpers.get(otype, None)             # <<<<<<<<<<<<<<
 *             if _dumper is None:
 *                 return 0
 */
    if (unlikely(__pyx_v_4axon_7_dumper_c_simple_dumpers == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 734; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_7_dumper_c_simple_dumpers, ((PyObject *)__pyx_v_otype), Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 734; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v__dumper = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_dumper.py":735
 *         else:
 *             _dumper = c_simple_dumpers.get(otype, None)
 *             if _dumper is None:             # <<<<<<<<<<<<<<
 *                 return 0
 *             else:
 */
    __pyx_t_3 = (__pyx_v__dumper == Py_None);
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "axon/_dumper.py":736
 *             _dumper = c_simple_dumpers.get(otype, None)
 *             if _dumper is None:
 *                 return 0             # <<<<<<<<<<<<<<
 *             else:
 *                 if type(_dumper) is PyPointer:
 */
      __pyx_r = 0;
      goto __pyx_L0;
    }
    /*else*/ {

      /* "axon/_dumper.py":738
 *                 return 0
 *             else:
 *                 if type(_dumper) is PyPointer:             # <<<<<<<<<<<<<<
 *                     ptr = _dumper
 *                     text = ptr.ptr(o)
 */
      __pyx_t_2 = (((PyObject *)Py_TYPE(__pyx_v__dumper)) == ((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_PyPointer)));
      __pyx_t_3 = (__pyx_t_2 != 0);
      if (__pyx_t_3) {

        /* "axon/_dumper.py":739
 *             else:
 *                 if type(_dumper) is PyPointer:
 *                     ptr = _dumper             # <<<<<<<<<<<<<<
 *                     text = ptr.ptr(o)
 *                 else:
 */
        if (!(likely(((__pyx_v__dumper) == Py_None) || likely(__Pyx_TypeTest(__pyx_v__dumper, __pyx_ptype_4axon_7_dumper_PyPointer))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 739; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_1 = __pyx_v__dumper;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_ptr = ((struct __pyx_obj_4axon_7_dumper_PyPointer *)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "axon/_dumper.py":740
 *                 if type(_dumper) is PyPointer:
 *                     ptr = _dumper
 *                     text = ptr.ptr(o)             # <<<<<<<<<<<<<<
 *                 else:
 *                     text = _dumper(o)
 */
        __pyx_t_1 = __pyx_v_ptr->ptr(__pyx_v_o); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 740; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_text = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;
        goto __pyx_L5;
      }
      /*else*/ {

        /* "axon/_dumper.py":742
 *                     text = ptr.ptr(o)
 *                 else:
 *                     text = _dumper(o)             # <<<<<<<<<<<<<<
 * 
 *         self.write(text)
 */
        __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_o);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_o);
        __Pyx_GIVEREF(__pyx_v_o);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v__dumper, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_5)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_v_text = ((PyObject*)__pyx_t_5);
        __pyx_t_5 = 0;
      }
      __pyx_L5:;
    }
  }
  __pyx_L3:;

  /* "axon/_dumper.py":744
 *                     text = _dumper(o)
 * 
 *         self.write(text)             # <<<<<<<<<<<<<<
 *         return 1
 *     #
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_text);

  /* "axon/_dumper.py":745
 * 
 *         self.write(text)
 *         return 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_dict_sequence(self, d):
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "axon/_dumper.py":699
 *                         raise RuntimeError()
 *     #
 *     def _dump_value(self, o):             # <<<<<<<<<<<<<<
 *         otype = type(o)
 *         #print(otype)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF((PyObject *)__pyx_v_ptr);
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_XDECREF((PyObject *)__pyx_v_dumper);
  __Pyx_XDECREF(__pyx_v__dumper);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":747
 *         return 1
 *     #
 *     def _dump_dict_sequence(self, d):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_dict_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  int __pyx_v_i;
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_dict_sequence", 0);

  /* "axon/_dumper.py":748
 *     #
 *     def _dump_dict_sequence(self, d):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         if self.sorted:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":750
 *         i = 0
 * 
 *         if self.sorted:             # <<<<<<<<<<<<<<
 *             items = sorted(d.items())
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->sorted != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":751
 * 
 *         if self.sorted:
 *             items = sorted(d.items())             # <<<<<<<<<<<<<<
 *         else:
 *             items = d.items()
 */
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_sorted, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":753
 *             items = sorted(d.items())
 *         else:
 *             items = d.items()             # <<<<<<<<<<<<<<
 * 
 *         for k,v in items:
 */
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 753; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 753; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":755
 *             items = d.items()
 * 
 *         for k,v in items:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 755; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":756
 * 
 *         for k,v in items:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 #self.size += 1
 */
    __pyx_t_1 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":757
 *         for k,v in items:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 #self.size += 1
 * 
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":760
 *                 #self.size += 1
 * 
 *             text = c_as_unicode(k)             # <<<<<<<<<<<<<<
 *             self.write(_dump_key(text))
 * 
 */
    __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_k); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 760; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":761
 * 
 *             text = c_as_unicode(k)
 *             self.write(_dump_key(text))             # <<<<<<<<<<<<<<
 * 
 *             self.write(':')
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper__dump_key(__pyx_v_text); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":763
 *             self.write(_dump_key(text))
 * 
 *             self.write(':')             # <<<<<<<<<<<<<<
 * 
 *             self._dump(v)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__25);

    /* "axon/_dumper.py":765
 *             self.write(':')
 * 
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":766
 * 
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_attr_sequence(self, d):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":747
 *         return 1
 *     #
 *     def _dump_dict_sequence(self, d):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_dict_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":768
 *             i += 1
 *     #
 *     def _dump_attr_sequence(self, d):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  int __pyx_v_i;
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_attr_sequence", 0);

  /* "axon/_dumper.py":769
 *     #
 *     def _dump_attr_sequence(self, d):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         if self.sorted:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":771
 *         i = 0
 * 
 *         if self.sorted:             # <<<<<<<<<<<<<<
 *             items = sorted(d.items())
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->sorted != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":772
 * 
 *         if self.sorted:
 *             items = sorted(d.items())             # <<<<<<<<<<<<<<
 *         else:
 *             items = d.items()
 */
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_sorted, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":774
 *             items = sorted(d.items())
 *         else:
 *             items = d.items()             # <<<<<<<<<<<<<<
 * 
 *         for k,v in items:
 */
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":776
 *             items = d.items()
 * 
 *         for k,v in items:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":777
 * 
 *         for k,v in items:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 #self.size += 1
 */
    __pyx_t_1 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":778
 *         for k,v in items:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 #self.size += 1
 * 
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":781
 *                 #self.size += 1
 * 
 *             text = c_as_unicode(k)             # <<<<<<<<<<<<<<
 *             self.write(_dump_name(text))
 *             #self.size += c_unicode_length(text)
 */
    __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_k); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 781; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":782
 * 
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text))             # <<<<<<<<<<<<<<
 *             #self.size += c_unicode_length(text)
 * 
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper__dump_name(__pyx_v_text); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 782; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":785
 *             #self.size += c_unicode_length(text)
 * 
 *             self.write(':')             # <<<<<<<<<<<<<<
 *             #self.size += 1
 *             self._dump(v)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__25);

    /* "axon/_dumper.py":787
 *             self.write(':')
 *             #self.size += 1
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 787; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":788
 *             #self.size += 1
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_list_sequence(self, l):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":768
 *             i += 1
 *     #
 *     def _dump_attr_sequence(self, d):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_attr_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":790
 *             i += 1
 *     #
 *     def _dump_list_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l) {
  int __pyx_v_i;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_list_sequence", 0);

  /* "axon/_dumper.py":791
 *     #
 *     def _dump_list_sequence(self, l):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         for v in l:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":793
 *         i = 0
 * 
 *         for v in l:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (unlikely(__pyx_v_l == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 793; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __pyx_v_l; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 793; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 793; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":794
 * 
 *         for v in l:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *             self._dump(v)
 */
    __pyx_t_4 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":795
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *             self._dump(v)
 *             i += 1
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":796
 *             if i > 0:
 *                 self.write(' ')
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":797
 *                 self.write(' ')
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_set_sequence(self, l):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":790
 *             i += 1
 *     #
 *     def _dump_list_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_list_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":799
 *             i += 1
 *     #
 *     def _dump_set_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_3_dump_set_sequence(PyObject *__pyx_v_self, PyObject *__pyx_v_l); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_3_dump_set_sequence(PyObject *__pyx_v_self, PyObject *__pyx_v_l) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_dump_set_sequence (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper_2_dump_set_sequence(((struct Dumper *)__pyx_v_self), ((PyObject *)__pyx_v_l));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_2_dump_set_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l) {
  long __pyx_v_i;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_set_sequence", 0);

  /* "axon/_dumper.py":800
 *     #
 *     def _dump_set_sequence(self, l):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         for v in l:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":802
 *         i = 0
 * 
 *         for v in l:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (PyList_CheckExact(__pyx_v_l) || PyTuple_CheckExact(__pyx_v_l)) {
    __pyx_t_1 = __pyx_v_l; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_l); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_3 && PyList_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_3 && PyTuple_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 802; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":803
 * 
 *         for v in l:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 #self.size += 1
 */
    __pyx_t_5 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":804
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 #self.size += 1
 *             self._dump(v)
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":806
 *                 self.write(' ')
 *                 #self.size += 1
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_6 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 806; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":807
 *                 #self.size += 1
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def _dump_tuple_sequence(self, l):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":799
 *             i += 1
 *     #
 *     def _dump_set_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_set_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":809
 *             i += 1
 *     #
 *     def _dump_tuple_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

static int __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l) {
  int __pyx_v_i;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump_tuple_sequence", 0);

  /* "axon/_dumper.py":810
 *     #
 *     def _dump_tuple_sequence(self, l):
 *         i = 0             # <<<<<<<<<<<<<<
 * 
 *         for v in l:
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":812
 *         i = 0
 * 
 *         for v in l:             # <<<<<<<<<<<<<<
 *             if i > 0:
 *                 self.write(' ')
 */
  if (unlikely(__pyx_v_l == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __pyx_v_l; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":813
 * 
 *         for v in l:
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 #self.size += 1
 */
    __pyx_t_4 = ((__pyx_v_i > 0) != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":814
 *         for v in l:
 *             if i > 0:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 #self.size += 1
 *             self._dump(v)
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":816
 *                 self.write(' ')
 *                 #self.size += 1
 *             self._dump(v)             # <<<<<<<<<<<<<<
 *             i += 1
 *     #
 */
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 816; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":817
 *                 #self.size += 1
 *             self._dump(v)
 *             i += 1             # <<<<<<<<<<<<<<
 *     #
 *     def dump_mapping(self, o):
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":809
 *             i += 1
 *     #
 *     def _dump_tuple_sequence(self, l):             # <<<<<<<<<<<<<<
 *         i = 0
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._dump_tuple_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":819
 *             i += 1
 *     #
 *     def dump_mapping(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_mapping(struct Dumper *__pyx_v_self, struct MappingObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_mapping", 0);

  /* "axon/_dumper.py":820
 *     #
 *     def dump_mapping(self, o):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{')
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":822
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *         self._dump_attr_sequence(o.mapping)
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__26);

  /* "axon/_dumper.py":824
 *         self.write('{')
 *         #self.size += 1
 *         self._dump_attr_sequence(o.mapping)             # <<<<<<<<<<<<<<
 *         self.write('}')
 *         #self.size += 1
 */
  __pyx_t_2 = __pyx_v_o->mapping;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 824; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":825
 *         #self.size += 1
 *         self._dump_attr_sequence(o.mapping)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *     #
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);

  /* "axon/_dumper.py":819
 *             i += 1
 *     #
 *     def dump_mapping(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":828
 *         #self.size += 1
 *     #
 *     def dump_element(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_element(struct Dumper *__pyx_v_self, struct ElementObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_element", 0);

  /* "axon/_dumper.py":829
 *     #
 *     def dump_element(self, o):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{')
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":831
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *         self._dump_attr_sequence(o.mapping)
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__26);

  /* "axon/_dumper.py":833
 *         self.write('{')
 *         #self.size += 1
 *         self._dump_attr_sequence(o.mapping)             # <<<<<<<<<<<<<<
 *         if o.sequence:
 *             self.write(' ')
 */
  __pyx_t_2 = __pyx_v_o->mapping;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":834
 *         #self.size += 1
 *         self._dump_attr_sequence(o.mapping)
 *         if o.sequence:             # <<<<<<<<<<<<<<
 *             self.write(' ')
 *             self._dump_list_sequence(o.sequence)
 */
  __pyx_t_4 = (__pyx_v_o->sequence != Py_None) && (PyList_GET_SIZE(__pyx_v_o->sequence) != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":835
 *         self._dump_attr_sequence(o.mapping)
 *         if o.sequence:
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             self._dump_list_sequence(o.sequence)
 *         self.write('}')
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);

    /* "axon/_dumper.py":836
 *         if o.sequence:
 *             self.write(' ')
 *             self._dump_list_sequence(o.sequence)             # <<<<<<<<<<<<<<
 *         self.write('}')
 *         #self.size += 1
 */
    __pyx_t_2 = __pyx_v_o->sequence;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":837
 *             self.write(' ')
 *             self._dump_list_sequence(o.sequence)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *     #
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);

  /* "axon/_dumper.py":828
 *         #self.size += 1
 *     #
 *     def dump_element(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":840
 *         #self.size += 1
 *     #
 *     def dump_sequence(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_sequence(struct Dumper *__pyx_v_self, struct SequenceObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_sequence", 0);

  /* "axon/_dumper.py":841
 *     #
 *     def dump_sequence(self, o):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{')
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":843
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *         self._dump_list_sequence(o.sequence)
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__26);

  /* "axon/_dumper.py":845
 *         self.write('{')
 *         #self.size += 1
 *         self._dump_list_sequence(o.sequence)             # <<<<<<<<<<<<<<
 *         self.write('}')
 *         #self.size += 1
 */
  __pyx_t_2 = __pyx_v_o->sequence;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":846
 *         #self.size += 1
 *         self._dump_list_sequence(o.sequence)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *     #
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);

  /* "axon/_dumper.py":840
 *         #self.size += 1
 *     #
 *     def dump_sequence(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":849
 *         #self.size += 1
 *     #
 *     def dump_instance(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_instance(struct Dumper *__pyx_v_self, struct InstanceObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_instance", 0);

  /* "axon/_dumper.py":850
 *     #
 *     def dump_instance(self, o):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{')
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":852
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *         self._dump_tuple_sequence(o.sequence)
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__26);

  /* "axon/_dumper.py":854
 *         self.write('{')
 *         #self.size += 1
 *         self._dump_tuple_sequence(o.sequence)             # <<<<<<<<<<<<<<
 *         if o.mapping:
 *             self.write(' ')
 */
  __pyx_t_2 = __pyx_v_o->sequence;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 854; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":855
 *         #self.size += 1
 *         self._dump_tuple_sequence(o.sequence)
 *         if o.mapping:             # <<<<<<<<<<<<<<
 *             self.write(' ')
 *             #self.size += 1
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_o->mapping); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 855; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_4) {

    /* "axon/_dumper.py":856
 *         self._dump_tuple_sequence(o.sequence)
 *         if o.mapping:
 *             self.write(' ')             # <<<<<<<<<<<<<<
 *             #self.size += 1
 *             self._dump_attr_sequence(o.mapping)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);

    /* "axon/_dumper.py":858
 *             self.write(' ')
 *             #self.size += 1
 *             self._dump_attr_sequence(o.mapping)             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *         self.write('}')
 */
    __pyx_t_2 = __pyx_v_o->mapping;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":860
 *             self._dump_attr_sequence(o.mapping)
 *         #self.size += 1
 *         self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def dump_empty(self, o):
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);

  /* "axon/_dumper.py":849
 *         #self.size += 1
 *     #
 *     def dump_instance(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":862
 *         self.write('}')
 *     #
 *     def dump_empty(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_empty(struct Dumper *__pyx_v_self, struct EmptyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_empty", 0);

  /* "axon/_dumper.py":863
 *     #
 *     def dump_empty(self, o):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{}')
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":865
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 *         self.write('{}')             # <<<<<<<<<<<<<<
 *         #self.size += 2
 *     #
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__28);

  /* "axon/_dumper.py":862
 *         self.write('}')
 *     #
 *     def dump_empty(self, o):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 *         #self.size += c_unicode_length(o.name)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":868
 *         #self.size += 2
 *     #
 *     def dump_list(self, l):             # <<<<<<<<<<<<<<
 *         self.write('[')
 *         #self.size += 1
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_list(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_list", 0);

  /* "axon/_dumper.py":869
 *     #
 *     def dump_list(self, l):
 *         self.write('[')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *         self._dump_list_sequence(l)
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__29);

  /* "axon/_dumper.py":871
 *         self.write('[')
 *         #self.size += 1
 *         self._dump_list_sequence(l)             # <<<<<<<<<<<<<<
 *         self.write(']')
 *         #self.size += 1
 */
  __pyx_t_1 = __pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence(__pyx_v_self, __pyx_v_l); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 871; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":872
 *         #self.size += 1
 *         self._dump_list_sequence(l)
 *         self.write(']')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *     #
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__30);

  /* "axon/_dumper.py":868
 *         #self.size += 2
 *     #
 *     def dump_list(self, l):             # <<<<<<<<<<<<<<
 *         self.write('[')
 *         #self.size += 1
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":875
 *         #self.size += 1
 *     #
 *     def dump_dict(self, d):             # <<<<<<<<<<<<<<
 *         self.write('{')
 *         #self.size += 1
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_dict(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_dict", 0);

  /* "axon/_dumper.py":876
 *     #
 *     def dump_dict(self, d):
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *         self._dump_dict_sequence(d)
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__26);

  /* "axon/_dumper.py":878
 *         self.write('{')
 *         #self.size += 1
 *         self._dump_dict_sequence(d)             # <<<<<<<<<<<<<<
 *         self.write('}')
 *         #self.size += 1
 */
  __pyx_t_1 = __pyx_f_4axon_7_dumper_6Dumper__dump_dict_sequence(__pyx_v_self, __pyx_v_d); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 878; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":879
 *         #self.size += 1
 *         self._dump_dict_sequence(d)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *     #
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);

  /* "axon/_dumper.py":875
 *         #self.size += 1
 *     #
 *     def dump_dict(self, d):             # <<<<<<<<<<<<<<
 *         self.write('{')
 *         #self.size += 1
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":882
 *         #self.size += 1
 *     #
 *     def dump_tuple(self, d):             # <<<<<<<<<<<<<<
 *         self.write('(')
 *         #self.size += 1
 */

static int __pyx_f_4axon_7_dumper_6Dumper_dump_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_tuple", 0);

  /* "axon/_dumper.py":883
 *     #
 *     def dump_tuple(self, d):
 *         self.write('(')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *         self._dump_tuple_sequence(d)
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__31);

  /* "axon/_dumper.py":885
 *         self.write('(')
 *         #self.size += 1
 *         self._dump_tuple_sequence(d)             # <<<<<<<<<<<<<<
 *         self.write(')')
 *         #self.size += 1
 */
  __pyx_t_1 = __pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence(__pyx_v_self, __pyx_v_d); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":886
 *         #self.size += 1
 *         self._dump_tuple_sequence(d)
 *         self.write(')')             # <<<<<<<<<<<<<<
 *         #self.size += 1
 *     #
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__32);

  /* "axon/_dumper.py":882
 *         #self.size += 1
 *     #
 *     def dump_tuple(self, d):             # <<<<<<<<<<<<<<
 *         self.write('(')
 *         #self.size += 1
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.dump_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":889
 *         #self.size += 1
 *     #
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         if self.sorted:
 *             items = sorted(d.items())
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_dict_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  PyObject *__pyx_v_text = 0;
  int __pyx_v_flag;
  int __pyx_v_j;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_dict_sequence", 0);

  /* "axon/_dumper.py":890
 *     #
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):
 *         if self.sorted:             # <<<<<<<<<<<<<<
 *             items = sorted(d.items())
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->sorted != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":891
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):
 *         if self.sorted:
 *             items = sorted(d.items())             # <<<<<<<<<<<<<<
 *         else:
 *             items = d.items()
 */
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 891; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 891; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 891; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_sorted, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 891; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":893
 *             items = sorted(d.items())
 *         else:
 *             items = d.items()             # <<<<<<<<<<<<<<
 * 
 *         j = 1
 */
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":895
 *             items = d.items()
 * 
 *         j = 1             # <<<<<<<<<<<<<<
 *         for k,v in items:
 *             flag = type(v) not in simple_types
 */
  __pyx_v_j = 1;

  /* "axon/_dumper.py":896
 * 
 *         j = 1
 *         for k,v in items:             # <<<<<<<<<<<<<<
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":897
 *         j = 1
 *         for k,v in items:
 *             flag = type(v) not in simple_types             # <<<<<<<<<<<<<<
 *             if not use_offset and flag:
 *                 use_offset = 1
 */
    __pyx_t_1 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_v)), __pyx_v_4axon_7_dumper_simple_types, Py_NE)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 897; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_flag = __pyx_t_1;

    /* "axon/_dumper.py":898
 *         for k,v in items:
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 *                 j = 1
 */
    __pyx_t_1 = ((!(__pyx_v_use_offset != 0)) != 0);
    if (__pyx_t_1) {
      __pyx_t_10 = (__pyx_v_flag != 0);
    } else {
      __pyx_t_10 = __pyx_t_1;
    }
    if (__pyx_t_10) {

      /* "axon/_dumper.py":899
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *                 j = 1
 * 
 */
      __pyx_v_use_offset = 1;

      /* "axon/_dumper.py":900
 *             if not use_offset and flag:
 *                 use_offset = 1
 *                 j = 1             # <<<<<<<<<<<<<<
 * 
 *             if use_offset:
 */
      __pyx_v_j = 1;
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":902
 *                 j = 1
 * 
 *             if use_offset:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self.write(w)
 */
    __pyx_t_10 = (__pyx_v_use_offset != 0);
    if (__pyx_t_10) {

      /* "axon/_dumper.py":903
 * 
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self.write(w)
 *             else:
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__33);

      /* "axon/_dumper.py":904
 *             if use_offset:
 *                 self.write('\n')
 *                 self.write(w)             # <<<<<<<<<<<<<<
 *             else:
 *                 use_offset = 0
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_w);
      goto __pyx_L9;
    }
    /*else*/ {

      /* "axon/_dumper.py":906
 *                 self.write(w)
 *             else:
 *                 use_offset = 0             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 use_offset = 1
 */
      __pyx_v_use_offset = 0;

      /* "axon/_dumper.py":907
 *             else:
 *                 use_offset = 0
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 * 
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);

      /* "axon/_dumper.py":908
 *                 use_offset = 0
 *                 self.write(' ')
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 * 
 *             text = c_as_unicode(k)
 */
      __pyx_v_use_offset = 1;
    }
    __pyx_L9:;

    /* "axon/_dumper.py":910
 *                 use_offset = 1
 * 
 *             text = c_as_unicode(k)             # <<<<<<<<<<<<<<
 *             self.write(_dump_key(text))
 *             self.write(': ')
 */
    __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_k); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 910; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":911
 * 
 *             text = c_as_unicode(k)
 *             self.write(_dump_key(text))             # <<<<<<<<<<<<<<
 *             self.write(': ')
 *             if flag:
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper__dump_key(__pyx_v_text); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 911; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":912
 *             text = c_as_unicode(k)
 *             self.write(_dump_key(text))
 *             self.write(': ')             # <<<<<<<<<<<<<<
 *             if flag:
 *                 self._pretty_dump(v, w, 0)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__34);

    /* "axon/_dumper.py":913
 *             self.write(_dump_key(text))
 *             self.write(': ')
 *             if flag:             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 0)
 *             else:
 */
    __pyx_t_10 = (__pyx_v_flag != 0);
    if (__pyx_t_10) {

      /* "axon/_dumper.py":914
 *             self.write(': ')
 *             if flag:
 *                 self._pretty_dump(v, w, 0)             # <<<<<<<<<<<<<<
 *             else:
 *                 self._dump_value(v)
 */
      __pyx_t_11 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 0); if (unlikely(__pyx_t_11 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 914; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L10;
    }
    /*else*/ {

      /* "axon/_dumper.py":916
 *                 self._pretty_dump(v, w, 0)
 *             else:
 *                 self._dump_value(v)             # <<<<<<<<<<<<<<
 * 
 *             if j < self.hsize:
 */
      __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L10:;

    /* "axon/_dumper.py":918
 *                 self._dump_value(v)
 * 
 *             if j < self.hsize:             # <<<<<<<<<<<<<<
 *                 if flag:
 *                     use_offset = 1
 */
    __pyx_t_10 = ((__pyx_v_j < __pyx_v_self->hsize) != 0);
    if (__pyx_t_10) {

      /* "axon/_dumper.py":919
 * 
 *             if j < self.hsize:
 *                 if flag:             # <<<<<<<<<<<<<<
 *                     use_offset = 1
 *                 else:
 */
      __pyx_t_10 = (__pyx_v_flag != 0);
      if (__pyx_t_10) {

        /* "axon/_dumper.py":920
 *             if j < self.hsize:
 *                 if flag:
 *                     use_offset = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     use_offset = 0
 */
        __pyx_v_use_offset = 1;
        goto __pyx_L12;
      }
      /*else*/ {

        /* "axon/_dumper.py":922
 *                     use_offset = 1
 *                 else:
 *                     use_offset = 0             # <<<<<<<<<<<<<<
 *                 j += 1
 *             else:
 */
        __pyx_v_use_offset = 0;
      }
      __pyx_L12:;

      /* "axon/_dumper.py":923
 *                 else:
 *                     use_offset = 0
 *                 j += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 use_offset = 1
 */
      __pyx_v_j = (__pyx_v_j + 1);
      goto __pyx_L11;
    }
    /*else*/ {

      /* "axon/_dumper.py":925
 *                 j += 1
 *             else:
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *                 j = 1
 *     #
 */
      __pyx_v_use_offset = 1;

      /* "axon/_dumper.py":926
 *             else:
 *                 use_offset = 1
 *                 j = 1             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):
 */
      __pyx_v_j = 1;
    }
    __pyx_L11:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":889
 *         #self.size += 1
 *     #
 *     def _pretty_dump_dict_sequence(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         if self.sorted:
 *             items = sorted(d.items())
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_dict_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":928
 *                 j = 1
 *     #
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         if self.sorted:
 *             items = sorted(d.items())
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  PyObject *__pyx_v_text = 0;
  int __pyx_v_flag;
  int __pyx_v_j;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_attr_sequence", 0);

  /* "axon/_dumper.py":929
 *     #
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):
 *         if self.sorted:             # <<<<<<<<<<<<<<
 *             items = sorted(d.items())
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->sorted != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":930
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):
 *         if self.sorted:
 *             items = sorted(d.items())             # <<<<<<<<<<<<<<
 *         else:
 *             items = d.items()
 */
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_sorted, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":932
 *             items = sorted(d.items())
 *         else:
 *             items = d.items()             # <<<<<<<<<<<<<<
 * 
 *         j = 1
 */
    if (unlikely(__pyx_v_d == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 932; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 932; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_items = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":934
 *             items = d.items()
 * 
 *         j = 1             # <<<<<<<<<<<<<<
 *         for k,v in items:
 *             flag = type(v) not in simple_types
 */
  __pyx_v_j = 1;

  /* "axon/_dumper.py":935
 * 
 *         j = 1
 *         for k,v in items:             # <<<<<<<<<<<<<<
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:
 */
  if (PyList_CheckExact(__pyx_v_items) || PyTuple_CheckExact(__pyx_v_items)) {
    __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_items); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "axon/_dumper.py":936
 *         j = 1
 *         for k,v in items:
 *             flag = type(v) not in simple_types             # <<<<<<<<<<<<<<
 *             if not use_offset and flag:
 *                 use_offset = 1
 */
    __pyx_t_1 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_v)), __pyx_v_4axon_7_dumper_simple_types, Py_NE)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_flag = __pyx_t_1;

    /* "axon/_dumper.py":937
 *         for k,v in items:
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 *                 j = 1
 */
    __pyx_t_1 = ((!(__pyx_v_use_offset != 0)) != 0);
    if (__pyx_t_1) {
      __pyx_t_10 = (__pyx_v_flag != 0);
    } else {
      __pyx_t_10 = __pyx_t_1;
    }
    if (__pyx_t_10) {

      /* "axon/_dumper.py":938
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *                 j = 1
 * 
 */
      __pyx_v_use_offset = 1;

      /* "axon/_dumper.py":939
 *             if not use_offset and flag:
 *                 use_offset = 1
 *                 j = 1             # <<<<<<<<<<<<<<
 * 
 *             if use_offset:
 */
      __pyx_v_j = 1;
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":941
 *                 j = 1
 * 
 *             if use_offset:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self.write(w)
 */
    __pyx_t_10 = (__pyx_v_use_offset != 0);
    if (__pyx_t_10) {

      /* "axon/_dumper.py":942
 * 
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self.write(w)
 *             else:
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__33);

      /* "axon/_dumper.py":943
 *             if use_offset:
 *                 self.write('\n')
 *                 self.write(w)             # <<<<<<<<<<<<<<
 *             else:
 *                 use_offset = 0
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_w);
      goto __pyx_L9;
    }
    /*else*/ {

      /* "axon/_dumper.py":945
 *                 self.write(w)
 *             else:
 *                 use_offset = 0             # <<<<<<<<<<<<<<
 *                 self.write(' ')
 *                 use_offset = 1
 */
      __pyx_v_use_offset = 0;

      /* "axon/_dumper.py":946
 *             else:
 *                 use_offset = 0
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 * 
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);

      /* "axon/_dumper.py":947
 *                 use_offset = 0
 *                 self.write(' ')
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 * 
 *             text = c_as_unicode(k)
 */
      __pyx_v_use_offset = 1;
    }
    __pyx_L9:;

    /* "axon/_dumper.py":949
 *                 use_offset = 1
 * 
 *             text = c_as_unicode(k)             # <<<<<<<<<<<<<<
 *             self.write(_dump_name(text))
 *             self.write(': ')
 */
    __pyx_t_3 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_k); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 949; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":950
 * 
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text))             # <<<<<<<<<<<<<<
 *             self.write(': ')
 *             if flag:
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper__dump_name(__pyx_v_text); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":951
 *             text = c_as_unicode(k)
 *             self.write(_dump_name(text))
 *             self.write(': ')             # <<<<<<<<<<<<<<
 *             if flag:
 *                 self._pretty_dump(v, w, 0)
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__34);

    /* "axon/_dumper.py":952
 *             self.write(_dump_name(text))
 *             self.write(': ')
 *             if flag:             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 0)
 *             else:
 */
    __pyx_t_10 = (__pyx_v_flag != 0);
    if (__pyx_t_10) {

      /* "axon/_dumper.py":953
 *             self.write(': ')
 *             if flag:
 *                 self._pretty_dump(v, w, 0)             # <<<<<<<<<<<<<<
 *             else:
 *                 self._dump_value(v)
 */
      __pyx_t_11 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 0); if (unlikely(__pyx_t_11 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 953; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L10;
    }
    /*else*/ {

      /* "axon/_dumper.py":955
 *                 self._pretty_dump(v, w, 0)
 *             else:
 *                 self._dump_value(v)             # <<<<<<<<<<<<<<
 * 
 *             if j < self.hsize:
 */
      __pyx_t_10 = __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 955; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L10:;

    /* "axon/_dumper.py":957
 *                 self._dump_value(v)
 * 
 *             if j < self.hsize:             # <<<<<<<<<<<<<<
 *                 if flag:
 *                     use_offset = 1
 */
    __pyx_t_10 = ((__pyx_v_j < __pyx_v_self->hsize) != 0);
    if (__pyx_t_10) {

      /* "axon/_dumper.py":958
 * 
 *             if j < self.hsize:
 *                 if flag:             # <<<<<<<<<<<<<<
 *                     use_offset = 1
 *                 else:
 */
      __pyx_t_10 = (__pyx_v_flag != 0);
      if (__pyx_t_10) {

        /* "axon/_dumper.py":959
 *             if j < self.hsize:
 *                 if flag:
 *                     use_offset = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     use_offset = 0
 */
        __pyx_v_use_offset = 1;
        goto __pyx_L12;
      }
      /*else*/ {

        /* "axon/_dumper.py":961
 *                     use_offset = 1
 *                 else:
 *                     use_offset = 0             # <<<<<<<<<<<<<<
 *                 j += 1
 *             else:
 */
        __pyx_v_use_offset = 0;
      }
      __pyx_L12:;

      /* "axon/_dumper.py":962
 *                 else:
 *                     use_offset = 0
 *                 j += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 use_offset = 1
 */
      __pyx_v_j = (__pyx_v_j + 1);
      goto __pyx_L11;
    }
    /*else*/ {

      /* "axon/_dumper.py":964
 *                 j += 1
 *             else:
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *                 j = 1
 *     #
 */
      __pyx_v_use_offset = 1;

      /* "axon/_dumper.py":965
 *             else:
 *                 use_offset = 1
 *                 j = 1             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_list_sequence(self, l, w, use_offset):
 */
      __pyx_v_j = 1;
    }
    __pyx_L11:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":928
 *                 j = 1
 *     #
 *     def _pretty_dump_attr_sequence(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         if self.sorted:
 *             items = sorted(d.items())
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_attr_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":967
 *                 j = 1
 *     #
 *     def _pretty_dump_list_sequence(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         #if  self.pretty == 2 and len(l) == 1 and not use_offset:
 *         #    v = l[0]
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  int __pyx_v_flag;
  int __pyx_v_j;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_list_sequence", 0);

  /* "axon/_dumper.py":973
 *         #        self._dump_value(v)
 *         #        return 0
 *         j = 1             # <<<<<<<<<<<<<<
 *         for v in l:
 *             flag = type(v) not in simple_types
 */
  __pyx_v_j = 1;

  /* "axon/_dumper.py":974
 *         #        return 0
 *         j = 1
 *         for v in l:             # <<<<<<<<<<<<<<
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:
 */
  if (unlikely(__pyx_v_l == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __pyx_v_l; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":975
 *         j = 1
 *         for v in l:
 *             flag = type(v) not in simple_types             # <<<<<<<<<<<<<<
 *             if not use_offset and flag:
 *                 use_offset = 1
 */
    __pyx_t_4 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_v)), __pyx_v_4axon_7_dumper_simple_types, Py_NE)); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 975; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_flag = __pyx_t_4;

    /* "axon/_dumper.py":976
 *         for v in l:
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 *                 j = 1
 */
    __pyx_t_4 = ((!(__pyx_v_use_offset != 0)) != 0);
    if (__pyx_t_4) {
      __pyx_t_5 = (__pyx_v_flag != 0);
    } else {
      __pyx_t_5 = __pyx_t_4;
    }
    if (__pyx_t_5) {

      /* "axon/_dumper.py":977
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *                 j = 1
 * 
 */
      __pyx_v_use_offset = 1;

      /* "axon/_dumper.py":978
 *             if not use_offset and flag:
 *                 use_offset = 1
 *                 j = 1             # <<<<<<<<<<<<<<
 * 
 *             if use_offset:
 */
      __pyx_v_j = 1;
      goto __pyx_L5;
    }
    __pyx_L5:;

    /* "axon/_dumper.py":980
 *                 j = 1
 * 
 *             if use_offset:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self._pretty_dump(v, w, 1)
 */
    __pyx_t_5 = (__pyx_v_use_offset != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":981
 * 
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 1)
 *             else:
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__33);

      /* "axon/_dumper.py":982
 *             if use_offset:
 *                 self.write('\n')
 *                 self._pretty_dump(v, w, 1)             # <<<<<<<<<<<<<<
 *             else:
 *                 if j > 1:
 */
      __pyx_t_6 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 1); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 982; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L6;
    }
    /*else*/ {

      /* "axon/_dumper.py":984
 *                 self._pretty_dump(v, w, 1)
 *             else:
 *                 if j > 1:             # <<<<<<<<<<<<<<
 *                     self.write(' ')
 *                 if flag:
 */
      __pyx_t_5 = ((__pyx_v_j > 1) != 0);
      if (__pyx_t_5) {

        /* "axon/_dumper.py":985
 *             else:
 *                 if j > 1:
 *                     self.write(' ')             # <<<<<<<<<<<<<<
 *                 if flag:
 *                     self._pretty_dump(v, w, 0)
 */
        __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);
        goto __pyx_L7;
      }
      __pyx_L7:;

      /* "axon/_dumper.py":986
 *                 if j > 1:
 *                     self.write(' ')
 *                 if flag:             # <<<<<<<<<<<<<<
 *                     self._pretty_dump(v, w, 0)
 *                 else:
 */
      __pyx_t_5 = (__pyx_v_flag != 0);
      if (__pyx_t_5) {

        /* "axon/_dumper.py":987
 *                     self.write(' ')
 *                 if flag:
 *                     self._pretty_dump(v, w, 0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._dump_value(v)
 */
        __pyx_t_6 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 0); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 987; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L8;
      }
      /*else*/ {

        /* "axon/_dumper.py":989
 *                     self._pretty_dump(v, w, 0)
 *                 else:
 *                     self._dump_value(v)             # <<<<<<<<<<<<<<
 * 
 *             if j < self.hsize:
 */
        __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 989; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L8:;
    }
    __pyx_L6:;

    /* "axon/_dumper.py":991
 *                     self._dump_value(v)
 * 
 *             if j < self.hsize:             # <<<<<<<<<<<<<<
 *                 if flag:
 *                     use_offset = 1
 */
    __pyx_t_5 = ((__pyx_v_j < __pyx_v_self->hsize) != 0);
    if (__pyx_t_5) {

      /* "axon/_dumper.py":992
 * 
 *             if j < self.hsize:
 *                 if flag:             # <<<<<<<<<<<<<<
 *                     use_offset = 1
 *                 else:
 */
      __pyx_t_5 = (__pyx_v_flag != 0);
      if (__pyx_t_5) {

        /* "axon/_dumper.py":993
 *             if j < self.hsize:
 *                 if flag:
 *                     use_offset = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     use_offset = 0
 */
        __pyx_v_use_offset = 1;
        goto __pyx_L10;
      }
      /*else*/ {

        /* "axon/_dumper.py":995
 *                     use_offset = 1
 *                 else:
 *                     use_offset = 0             # <<<<<<<<<<<<<<
 *                 j += 1
 *             else:
 */
        __pyx_v_use_offset = 0;
      }
      __pyx_L10:;

      /* "axon/_dumper.py":996
 *                 else:
 *                     use_offset = 0
 *                 j += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 use_offset = 1
 */
      __pyx_v_j = (__pyx_v_j + 1);
      goto __pyx_L9;
    }
    /*else*/ {

      /* "axon/_dumper.py":998
 *                 j += 1
 *             else:
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *                 j = 1
 *     #
 */
      __pyx_v_use_offset = 1;

      /* "axon/_dumper.py":999
 *             else:
 *                 use_offset = 1
 *                 j = 1             # <<<<<<<<<<<<<<
 *     #
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):
 */
      __pyx_v_j = 1;
    }
    __pyx_L9:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":967
 *                 j = 1
 *     #
 *     def _pretty_dump_list_sequence(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         #if  self.pretty == 2 and len(l) == 1 and not use_offset:
 *         #    v = l[0]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_list_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1001
 *                 j = 1
 *     #
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         if self.pretty == 2 and len(l) == 1:
 *             v = l[0]
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  int __pyx_v_flag;
  int __pyx_v_j;
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty_dump_tuple_sequence", 0);

  /* "axon/_dumper.py":1002
 *     #
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):
 *         if self.pretty == 2 and len(l) == 1:             # <<<<<<<<<<<<<<
 *             v = l[0]
 *             if type(v) in simple_types:
 */
  __pyx_t_1 = ((__pyx_v_self->pretty == 2) != 0);
  if (__pyx_t_1) {
    if (unlikely(__pyx_v_l == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = PyTuple_GET_SIZE(__pyx_v_l); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_3 = ((__pyx_t_2 == 1) != 0);
    __pyx_t_4 = __pyx_t_3;
  } else {
    __pyx_t_4 = __pyx_t_1;
  }
  if (__pyx_t_4) {

    /* "axon/_dumper.py":1003
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):
 *         if self.pretty == 2 and len(l) == 1:
 *             v = l[0]             # <<<<<<<<<<<<<<
 *             if type(v) in simple_types:
 *                 self._dump_value(v)
 */
    if (unlikely(__pyx_v_l == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1003; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_5 = PyTuple_GET_ITEM(__pyx_v_l, 0);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_v_v = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "axon/_dumper.py":1004
 *         if self.pretty == 2 and len(l) == 1:
 *             v = l[0]
 *             if type(v) in simple_types:             # <<<<<<<<<<<<<<
 *                 self._dump_value(v)
 *                 return 0
 */
    __pyx_t_4 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_v)), __pyx_v_4axon_7_dumper_simple_types, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = (__pyx_t_4 != 0);
    if (__pyx_t_1) {

      /* "axon/_dumper.py":1005
 *             v = l[0]
 *             if type(v) in simple_types:
 *                 self._dump_value(v)             # <<<<<<<<<<<<<<
 *                 return 0
 * 
 */
      __pyx_t_1 = __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1005; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "axon/_dumper.py":1006
 *             if type(v) in simple_types:
 *                 self._dump_value(v)
 *                 return 0             # <<<<<<<<<<<<<<
 * 
 *         j = 1
 */
      __pyx_r = 0;
      goto __pyx_L0;
    }
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":1008
 *                 return 0
 * 
 *         j = 1             # <<<<<<<<<<<<<<
 *         for v in l:
 *             flag = type(v) not in simple_types
 */
  __pyx_v_j = 1;

  /* "axon/_dumper.py":1009
 * 
 *         j = 1
 *         for v in l:             # <<<<<<<<<<<<<<
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:
 */
  if (unlikely(__pyx_v_l == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1009; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __pyx_v_l; __Pyx_INCREF(__pyx_t_5); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_2); __Pyx_INCREF(__pyx_t_6); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1009; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1009; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "axon/_dumper.py":1010
 *         j = 1
 *         for v in l:
 *             flag = type(v) not in simple_types             # <<<<<<<<<<<<<<
 *             if not use_offset and flag:
 *                 use_offset = 1
 */
    __pyx_t_1 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_v)), __pyx_v_4axon_7_dumper_simple_types, Py_NE)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1010; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_flag = __pyx_t_1;

    /* "axon/_dumper.py":1011
 *         for v in l:
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:             # <<<<<<<<<<<<<<
 *                 use_offset = 1
 *                 j = 1
 */
    __pyx_t_1 = ((!(__pyx_v_use_offset != 0)) != 0);
    if (__pyx_t_1) {
      __pyx_t_4 = (__pyx_v_flag != 0);
    } else {
      __pyx_t_4 = __pyx_t_1;
    }
    if (__pyx_t_4) {

      /* "axon/_dumper.py":1012
 *             flag = type(v) not in simple_types
 *             if not use_offset and flag:
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *                 j = 1
 * 
 */
      __pyx_v_use_offset = 1;

      /* "axon/_dumper.py":1013
 *             if not use_offset and flag:
 *                 use_offset = 1
 *                 j = 1             # <<<<<<<<<<<<<<
 * 
 *             if use_offset:
 */
      __pyx_v_j = 1;
      goto __pyx_L7;
    }
    __pyx_L7:;

    /* "axon/_dumper.py":1015
 *                 j = 1
 * 
 *             if use_offset:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self._pretty_dump(v, w, 1)
 */
    __pyx_t_4 = (__pyx_v_use_offset != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":1016
 * 
 *             if use_offset:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, w, 1)
 *             else:
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__33);

      /* "axon/_dumper.py":1017
 *             if use_offset:
 *                 self.write('\n')
 *                 self._pretty_dump(v, w, 1)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.write(' ')
 */
      __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 1); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1017; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L8;
    }
    /*else*/ {

      /* "axon/_dumper.py":1019
 *                 self._pretty_dump(v, w, 1)
 *             else:
 *                 self.write(' ')             # <<<<<<<<<<<<<<
 *                 if flag:
 *                     self._pretty_dump(v, w, 0)
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__21);

      /* "axon/_dumper.py":1020
 *             else:
 *                 self.write(' ')
 *                 if flag:             # <<<<<<<<<<<<<<
 *                     self._pretty_dump(v, w, 0)
 *                 else:
 */
      __pyx_t_4 = (__pyx_v_flag != 0);
      if (__pyx_t_4) {

        /* "axon/_dumper.py":1021
 *                 self.write(' ')
 *                 if flag:
 *                     self._pretty_dump(v, w, 0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._dump_value(v)
 */
        __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_v_w, 0); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1021; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L9;
      }
      /*else*/ {

        /* "axon/_dumper.py":1023
 *                     self._pretty_dump(v, w, 0)
 *                 else:
 *                     self._dump_value(v)             # <<<<<<<<<<<<<<
 * 
 *             if j < self.hsize:
 */
        __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper__dump_value(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L9:;
    }
    __pyx_L8:;

    /* "axon/_dumper.py":1025
 *                     self._dump_value(v)
 * 
 *             if j < self.hsize:             # <<<<<<<<<<<<<<
 *                 if flag:
 *                     use_offset = 1
 */
    __pyx_t_4 = ((__pyx_v_j < __pyx_v_self->hsize) != 0);
    if (__pyx_t_4) {

      /* "axon/_dumper.py":1026
 * 
 *             if j < self.hsize:
 *                 if flag:             # <<<<<<<<<<<<<<
 *                     use_offset = 1
 *                 else:
 */
      __pyx_t_4 = (__pyx_v_flag != 0);
      if (__pyx_t_4) {

        /* "axon/_dumper.py":1027
 *             if j < self.hsize:
 *                 if flag:
 *                     use_offset = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     use_offset = 0
 */
        __pyx_v_use_offset = 1;
        goto __pyx_L11;
      }
      /*else*/ {

        /* "axon/_dumper.py":1029
 *                     use_offset = 1
 *                 else:
 *                     use_offset = 0             # <<<<<<<<<<<<<<
 *                 j += 1
 *             else:
 */
        __pyx_v_use_offset = 0;
      }
      __pyx_L11:;

      /* "axon/_dumper.py":1030
 *                 else:
 *                     use_offset = 0
 *                 j += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 use_offset = 1
 */
      __pyx_v_j = (__pyx_v_j + 1);
      goto __pyx_L10;
    }
    /*else*/ {

      /* "axon/_dumper.py":1032
 *                 j += 1
 *             else:
 *                 use_offset = 1             # <<<<<<<<<<<<<<
 *                 j = 1
 *     #
 */
      __pyx_v_use_offset = 1;

      /* "axon/_dumper.py":1033
 *             else:
 *                 use_offset = 1
 *                 j = 1             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_mapping(self, o, w, use_offset):
 */
      __pyx_v_j = 1;
    }
    __pyx_L10:;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "axon/_dumper.py":1001
 *                 j = 1
 *     #
 *     def _pretty_dump_tuple_sequence(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         if self.pretty == 2 and len(l) == 1:
 *             v = l[0]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._dumper.Dumper._pretty_dump_tuple_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1035
 *                 j = 1
 *     #
 *     def pretty_dump_mapping(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_mapping(struct Dumper *__pyx_v_self, struct MappingObject *__pyx_v_o, PyObject *__pyx_v_w, CYTHON_UNUSED int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_mapping", 0);

  /* "axon/_dumper.py":1036
 *     #
 *     def pretty_dump_mapping(self, o, w, use_offset):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 * 
 *         #w1 = w + '  '
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1036; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":1042
 *         if self.pretty == 1:
 *             self.write(':')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 * 
 */
  switch (__pyx_v_self->pretty) {

    /* "axon/_dumper.py":1040
 *         #w1 = w + '  '
 * 
 *         if self.pretty == 1:             # <<<<<<<<<<<<<<
 *             self.write(':')
 *         elif self.pretty == 2:
 */
    case 1:

    /* "axon/_dumper.py":1041
 * 
 *         if self.pretty == 1:
 *             self.write(':')             # <<<<<<<<<<<<<<
 *         elif self.pretty == 2:
 *             self.write(' {')
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__25);
    break;

    /* "axon/_dumper.py":1042
 *         if self.pretty == 1:
 *             self.write(':')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 * 
 */
    case 2:

    /* "axon/_dumper.py":1043
 *             self.write(':')
 *         elif self.pretty == 2:
 *             self.write(' {')             # <<<<<<<<<<<<<<
 * 
 *         #self.write('\n')
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__35);
    break;
    default: break;
  }

  /* "axon/_dumper.py":1048
 *         #self.write(w1)
 * 
 *         self._pretty_dump_attr_sequence(o.mapping, w, 1)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 2:
 */
  __pyx_t_2 = __pyx_v_o->mapping;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2), __pyx_v_w, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1048; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":1050
 *         self._pretty_dump_attr_sequence(o.mapping, w, 1)
 * 
 *         if self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write('}')
 *     #
 */
  __pyx_t_4 = ((__pyx_v_self->pretty == 2) != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":1051
 * 
 *         if self.pretty == 2:
 *             self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_element(self, o, w, use_offset):
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":1035
 *                 j = 1
 *     #
 *     def pretty_dump_mapping(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1053
 *             self.write('}')
 *     #
 *     def pretty_dump_element(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_element(struct Dumper *__pyx_v_self, struct ElementObject *__pyx_v_o, PyObject *__pyx_v_w, CYTHON_UNUSED int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_element", 0);

  /* "axon/_dumper.py":1054
 *     #
 *     def pretty_dump_element(self, o, w, use_offset):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 1:
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1054; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":1058
 *         if self.pretty == 1:
 *             self.write(':')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 * 
 */
  switch (__pyx_v_self->pretty) {

    /* "axon/_dumper.py":1056
 *         self.write(_dump_name(o.name))
 * 
 *         if self.pretty == 1:             # <<<<<<<<<<<<<<
 *             self.write(':')
 *         elif self.pretty == 2:
 */
    case 1:

    /* "axon/_dumper.py":1057
 * 
 *         if self.pretty == 1:
 *             self.write(':')             # <<<<<<<<<<<<<<
 *         elif self.pretty == 2:
 *             self.write(' {')
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__25);
    break;

    /* "axon/_dumper.py":1058
 *         if self.pretty == 1:
 *             self.write(':')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 * 
 */
    case 2:

    /* "axon/_dumper.py":1059
 *             self.write(':')
 *         elif self.pretty == 2:
 *             self.write(' {')             # <<<<<<<<<<<<<<
 * 
 *         #w1 = w + '  '
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__35);
    break;
    default: break;
  }

  /* "axon/_dumper.py":1066
 *         #self.write(w1)
 * 
 *         self._pretty_dump_attr_sequence(o.mapping, w, 1)             # <<<<<<<<<<<<<<
 *         if o.sequence:
 *             #self.write(' ')
 */
  __pyx_t_2 = __pyx_v_o->mapping;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2), __pyx_v_w, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1066; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":1067
 * 
 *         self._pretty_dump_attr_sequence(o.mapping, w, 1)
 *         if o.sequence:             # <<<<<<<<<<<<<<
 *             #self.write(' ')
 *             self._pretty_dump_list_sequence(o.sequence, w, 1)
 */
  __pyx_t_4 = (__pyx_v_o->sequence != Py_None) && (PyList_GET_SIZE(__pyx_v_o->sequence) != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":1069
 *         if o.sequence:
 *             #self.write(' ')
 *             self._pretty_dump_list_sequence(o.sequence, w, 1)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 2:
 */
    __pyx_t_2 = __pyx_v_o->sequence;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2), __pyx_v_w, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1069; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":1071
 *             self._pretty_dump_list_sequence(o.sequence, w, 1)
 * 
 *         if self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write('}')
 *     #
 */
  __pyx_t_4 = ((__pyx_v_self->pretty == 2) != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":1072
 * 
 *         if self.pretty == 2:
 *             self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_sequence(self, o, w, use_offset):
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":1053
 *             self.write('}')
 *     #
 *     def pretty_dump_element(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1074
 *             self.write('}')
 *     #
 *     def pretty_dump_sequence(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_sequence(struct Dumper *__pyx_v_self, struct SequenceObject *__pyx_v_o, PyObject *__pyx_v_w, CYTHON_UNUSED int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_sequence", 0);

  /* "axon/_dumper.py":1075
 *     #
 *     def pretty_dump_sequence(self, o, w, use_offset):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 1:
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1075; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":1079
 *         if self.pretty == 1:
 *             self.write(':')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 * 
 */
  switch (__pyx_v_self->pretty) {

    /* "axon/_dumper.py":1077
 *         self.write(_dump_name(o.name))
 * 
 *         if self.pretty == 1:             # <<<<<<<<<<<<<<
 *             self.write(':')
 *         elif self.pretty == 2:
 */
    case 1:

    /* "axon/_dumper.py":1078
 * 
 *         if self.pretty == 1:
 *             self.write(':')             # <<<<<<<<<<<<<<
 *         elif self.pretty == 2:
 *             self.write(' {')
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__25);
    break;

    /* "axon/_dumper.py":1079
 *         if self.pretty == 1:
 *             self.write(':')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 * 
 */
    case 2:

    /* "axon/_dumper.py":1080
 *             self.write(':')
 *         elif self.pretty == 2:
 *             self.write(' {')             # <<<<<<<<<<<<<<
 * 
 *         #w1 = w + '  '
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__35);
    break;
    default: break;
  }

  /* "axon/_dumper.py":1087
 *         #self.write(w1)
 * 
 *         if self.pretty == 2 and len(o.sequence) == 1:             # <<<<<<<<<<<<<<
 *             self._pretty_dump_list_sequence(o.sequence, w, 0)
 *         else:
 */
  __pyx_t_3 = ((__pyx_v_self->pretty == 2) != 0);
  if (__pyx_t_3) {
    __pyx_t_2 = __pyx_v_o->sequence;
    __Pyx_INCREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1087; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_4 = PyList_GET_SIZE(__pyx_t_2); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1087; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = ((__pyx_t_4 == 1) != 0);
    __pyx_t_6 = __pyx_t_5;
  } else {
    __pyx_t_6 = __pyx_t_3;
  }
  if (__pyx_t_6) {

    /* "axon/_dumper.py":1088
 * 
 *         if self.pretty == 2 and len(o.sequence) == 1:
 *             self._pretty_dump_list_sequence(o.sequence, w, 0)             # <<<<<<<<<<<<<<
 *         else:
 *             self._pretty_dump_list_sequence(o.sequence, w, 1)
 */
    __pyx_t_2 = __pyx_v_o->sequence;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2), __pyx_v_w, 0); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1088; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_dumper.py":1090
 *             self._pretty_dump_list_sequence(o.sequence, w, 0)
 *         else:
 *             self._pretty_dump_list_sequence(o.sequence, w, 1)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 2:
 */
    __pyx_t_2 = __pyx_v_o->sequence;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2), __pyx_v_w, 1); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1090; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":1092
 *             self._pretty_dump_list_sequence(o.sequence, w, 1)
 * 
 *         if self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write('}')
 *     #
 */
  __pyx_t_6 = ((__pyx_v_self->pretty == 2) != 0);
  if (__pyx_t_6) {

    /* "axon/_dumper.py":1093
 * 
 *         if self.pretty == 2:
 *             self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_instance(self, o, w, use_offset):
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":1074
 *             self.write('}')
 *     #
 *     def pretty_dump_sequence(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1095
 *             self.write('}')
 *     #
 *     def pretty_dump_instance(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_instance(struct Dumper *__pyx_v_self, struct InstanceObject *__pyx_v_o, PyObject *__pyx_v_w, CYTHON_UNUSED int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_instance", 0);

  /* "axon/_dumper.py":1096
 *     #
 *     def pretty_dump_instance(self, o, w, use_offset):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 1:
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1096; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":1100
 *         if self.pretty == 1:
 *             self.write(':')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 * 
 */
  switch (__pyx_v_self->pretty) {

    /* "axon/_dumper.py":1098
 *         self.write(_dump_name(o.name))
 * 
 *         if self.pretty == 1:             # <<<<<<<<<<<<<<
 *             self.write(':')
 *         elif self.pretty == 2:
 */
    case 1:

    /* "axon/_dumper.py":1099
 * 
 *         if self.pretty == 1:
 *             self.write(':')             # <<<<<<<<<<<<<<
 *         elif self.pretty == 2:
 *             self.write(' {')
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__25);
    break;

    /* "axon/_dumper.py":1100
 *         if self.pretty == 1:
 *             self.write(':')
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {')
 * 
 */
    case 2:

    /* "axon/_dumper.py":1101
 *             self.write(':')
 *         elif self.pretty == 2:
 *             self.write(' {')             # <<<<<<<<<<<<<<
 * 
 *         #w1 = w + '  '
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__35);
    break;
    default: break;
  }

  /* "axon/_dumper.py":1108
 *         #self.write(w1)
 * 
 *         self._pretty_dump_tuple_sequence(o.sequence, w, 1)             # <<<<<<<<<<<<<<
 *         if o.mapping:
 *             #self.write(' ')
 */
  __pyx_t_2 = __pyx_v_o->sequence;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2), __pyx_v_w, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":1109
 * 
 *         self._pretty_dump_tuple_sequence(o.sequence, w, 1)
 *         if o.mapping:             # <<<<<<<<<<<<<<
 *             #self.write(' ')
 *             self._pretty_dump_attr_sequence(o.mapping, w, 1)
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_o->mapping); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_4) {

    /* "axon/_dumper.py":1111
 *         if o.mapping:
 *             #self.write(' ')
 *             self._pretty_dump_attr_sequence(o.mapping, w, 1)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 2:
 */
    __pyx_t_2 = __pyx_v_o->mapping;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence(__pyx_v_self, ((PyObject*)__pyx_t_2), __pyx_v_w, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":1113
 *             self._pretty_dump_attr_sequence(o.mapping, w, 1)
 * 
 *         if self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write('}')
 *     #
 */
  __pyx_t_4 = ((__pyx_v_self->pretty == 2) != 0);
  if (__pyx_t_4) {

    /* "axon/_dumper.py":1114
 * 
 *         if self.pretty == 2:
 *             self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_empty(self, o, w, use_offset):
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":1095
 *             self.write('}')
 *     #
 *     def pretty_dump_instance(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1116
 *             self.write('}')
 *     #
 *     def pretty_dump_empty(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_empty(struct Dumper *__pyx_v_self, struct EmptyObject *__pyx_v_o, PyObject *__pyx_v_w, CYTHON_UNUSED int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_empty", 0);

  /* "axon/_dumper.py":1117
 *     #
 *     def pretty_dump_empty(self, o, w, use_offset):
 *         self.write(_dump_name(o.name))             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty == 1:
 */
  __pyx_t_1 = __pyx_v_o->name;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper__dump_name(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":1122
 *             self.write(':\n')
 *             self.write(w)
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {}')
 * 
 */
  switch (__pyx_v_self->pretty) {

    /* "axon/_dumper.py":1119
 *         self.write(_dump_name(o.name))
 * 
 *         if self.pretty == 1:             # <<<<<<<<<<<<<<
 *             self.write(':\n')
 *             self.write(w)
 */
    case 1:

    /* "axon/_dumper.py":1120
 * 
 *         if self.pretty == 1:
 *             self.write(':\n')             # <<<<<<<<<<<<<<
 *             self.write(w)
 *         elif self.pretty == 2:
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__36);

    /* "axon/_dumper.py":1121
 *         if self.pretty == 1:
 *             self.write(':\n')
 *             self.write(w)             # <<<<<<<<<<<<<<
 *         elif self.pretty == 2:
 *             self.write(' {}')
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_v_w);
    break;

    /* "axon/_dumper.py":1122
 *             self.write(':\n')
 *             self.write(w)
 *         elif self.pretty == 2:             # <<<<<<<<<<<<<<
 *             self.write(' {}')
 * 
 */
    case 2:

    /* "axon/_dumper.py":1123
 *             self.write(w)
 *         elif self.pretty == 2:
 *             self.write(' {}')             # <<<<<<<<<<<<<<
 * 
 *     #
 */
    __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__37);
    break;
    default: break;
  }

  /* "axon/_dumper.py":1116
 *             self.write('}')
 *     #
 *     def pretty_dump_empty(self, o, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write(_dump_name(o.name))
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1126
 * 
 *     #
 *     def pretty_dump_list(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('[')
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_list(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_list", 0);

  /* "axon/_dumper.py":1127
 *     #
 *     def pretty_dump_list(self, l, w, use_offset):
 *         self.write('[')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 *         self.write(']')
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__29);

  /* "axon/_dumper.py":1128
 *     def pretty_dump_list(self, l, w, use_offset):
 *         self.write('[')
 *         self._pretty_dump_list_sequence(l, w, use_offset)             # <<<<<<<<<<<<<<
 *         self.write(']')
 *     #
 */
  __pyx_t_1 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence(__pyx_v_self, __pyx_v_l, __pyx_v_w, __pyx_v_use_offset); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":1129
 *         self.write('[')
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 *         self.write(']')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_dict(self, d, w, use_offset):
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__30);

  /* "axon/_dumper.py":1126
 * 
 *     #
 *     def pretty_dump_list(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('[')
 *         self._pretty_dump_list_sequence(l, w, use_offset)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1131
 *         self.write(']')
 *     #
 *     def pretty_dump_dict(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('{')
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 */

static CYTHON_INLINE int __pyx_f_4axon_7_dumper_6Dumper_pretty_dump_dict(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d, PyObject *__pyx_v_w, int __pyx_v_use_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_dict", 0);

  /* "axon/_dumper.py":1132
 *     #
 *     def pretty_dump_dict(self, d, w, use_offset):
 *         self.write('{')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 *         self.write('}')
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__26);

  /* "axon/_dumper.py":1133
 *     def pretty_dump_dict(self, d, w, use_offset):
 *         self.write('{')
 *         self._pretty_dump_dict_sequence(d, w, use_offset)             # <<<<<<<<<<<<<<
 *         self.write('}')
 *     #
 */
  __pyx_t_1 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_dict_sequence(__pyx_v_self, __pyx_v_d, __pyx_v_w, __pyx_v_use_offset); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":1134
 *         self.write('{')
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 *         self.write('}')             # <<<<<<<<<<<<<<
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__27);

  /* "axon/_dumper.py":1131
 *         self.write(']')
 *     #
 *     def pretty_dump_dict(self, d, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('{')
 *         self._pretty_dump_dict_sequence(d, w, use_offset)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1136
 *         self.write('}')
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('(')
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_5pretty_dump_tuple(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_5pretty_dump_tuple(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_w = 0;
  CYTHON_UNUSED PyObject *__pyx_v_use_offset = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pretty_dump_tuple (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_l,&__pyx_n_s_w,&__pyx_n_s_use_offset,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_w)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pretty_dump_tuple", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1136; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_use_offset)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pretty_dump_tuple", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1136; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pretty_dump_tuple") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1136; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_l = values[0];
    __pyx_v_w = values[1];
    __pyx_v_use_offset = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pretty_dump_tuple", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1136; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper_4pretty_dump_tuple(((struct Dumper *)__pyx_v_self), __pyx_v_l, __pyx_v_w, __pyx_v_use_offset);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_4pretty_dump_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_w, CYTHON_UNUSED PyObject *__pyx_v_use_offset) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty_dump_tuple", 0);

  /* "axon/_dumper.py":1137
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):
 *         self.write('(')             # <<<<<<<<<<<<<<
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 *         self.write(')')
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__31);

  /* "axon/_dumper.py":1138
 *     def pretty_dump_tuple(self, l, w, use_offset):
 *         self.write('(')
 *         self._pretty_dump_tuple_sequence(l, w, 0)             # <<<<<<<<<<<<<<
 *         self.write(')')
 *     #
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v_l))||((__pyx_v_l) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v_l)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!(likely(PyUnicode_CheckExact(__pyx_v_w))||((__pyx_v_w) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_w)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence(__pyx_v_self, ((PyObject*)__pyx_v_l), ((PyObject*)__pyx_v_w), 0); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":1139
 *         self.write('(')
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 *         self.write(')')             # <<<<<<<<<<<<<<
 *     #
 *     def dump(self, seq):
 */
  __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__32);

  /* "axon/_dumper.py":1136
 *         self.write('}')
 *     #
 *     def pretty_dump_tuple(self, l, w, use_offset):             # <<<<<<<<<<<<<<
 *         self.write('(')
 *         self._pretty_dump_tuple_sequence(l, w, 0)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("axon._dumper.Dumper.pretty_dump_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1141
 *         self.write(')')
 *     #
 *     def dump(self, seq):             # <<<<<<<<<<<<<<
 *         '''
 *         Main dumping method.
 */

/* Python wrapper */
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_7dump(PyObject *__pyx_v_self, PyObject *__pyx_v_seq); /*proto*/
static char __pyx_doc_4axon_7_dumper_6Dumper_6dump[] = "\n        Main dumping method.\n\n        :param seq:\n\n            Sequence of values to dump\n\n        :param pretty:\n\n            Flag indicates whether to use pretty dumping mode. Default is `False` (i.e. no pretty dumping)\n\n        ";
static PyObject *__pyx_pw_4axon_7_dumper_6Dumper_7dump(PyObject *__pyx_v_self, PyObject *__pyx_v_seq) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  __pyx_r = __pyx_pf_4axon_7_dumper_6Dumper_6dump(((struct Dumper *)__pyx_v_self), ((PyObject *)__pyx_v_seq));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4axon_7_dumper_6Dumper_6dump(struct Dumper *__pyx_v_self, PyObject *__pyx_v_seq) {
  PyObject *__pyx_v_iterseq = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "axon/_dumper.py":1155
 *         '''
 * 
 *         if self.crossref:             # <<<<<<<<<<<<<<
 *             self.crossref_dict = {}
 *             self.collect(seq)
 */
  __pyx_t_1 = (__pyx_v_self->crossref != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":1156
 * 
 *         if self.crossref:
 *             self.crossref_dict = {}             # <<<<<<<<<<<<<<
 *             self.collect(seq)
 *             self.apply_crossref()
 */
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->crossref_dict);
    __Pyx_DECREF(__pyx_v_self->crossref_dict);
    __pyx_v_self->crossref_dict = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "axon/_dumper.py":1157
 *         if self.crossref:
 *             self.crossref_dict = {}
 *             self.collect(seq)             # <<<<<<<<<<<<<<
 *             self.apply_crossref()
 * 
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper_collect(__pyx_v_self, __pyx_v_seq); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":1158
 *             self.crossref_dict = {}
 *             self.collect(seq)
 *             self.apply_crossref()             # <<<<<<<<<<<<<<
 * 
 *         iterseq = iter(seq)
 */
    __pyx_f_4axon_7_dumper_6Dumper_apply_crossref(__pyx_v_self);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "axon/_dumper.py":1160
 *             self.apply_crossref()
 * 
 *         iterseq = iter(seq)             # <<<<<<<<<<<<<<
 *         v = next(iterseq)
 * 
 */
  __pyx_t_2 = PyObject_GetIter(__pyx_v_seq); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_iterseq = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":1161
 * 
 *         iterseq = iter(seq)
 *         v = next(iterseq)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty:
 */
  __pyx_t_2 = __Pyx_PyIter_Next(__pyx_v_iterseq); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_v = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":1163
 *         v = next(iterseq)
 * 
 *         if self.pretty:             # <<<<<<<<<<<<<<
 *             self._pretty_dump(v, '', 1)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->pretty != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":1164
 * 
 *         if self.pretty:
 *             self._pretty_dump(v, '', 1)             # <<<<<<<<<<<<<<
 *         else:
 *             self._dump(v)
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_kp_u__10, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_dumper.py":1166
 *             self._pretty_dump(v, '', 1)
 *         else:
 *             self._dump(v)             # <<<<<<<<<<<<<<
 * 
 *         if self.pretty:
 */
    __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L4:;

  /* "axon/_dumper.py":1168
 *             self._dump(v)
 * 
 *         if self.pretty:             # <<<<<<<<<<<<<<
 *             for v in iterseq:
 *                 self.write('\n')
 */
  __pyx_t_1 = (__pyx_v_self->pretty != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":1169
 * 
 *         if self.pretty:
 *             for v in iterseq:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self._pretty_dump(v, '', 1)
 */
    if (PyList_CheckExact(__pyx_v_iterseq) || PyTuple_CheckExact(__pyx_v_iterseq)) {
      __pyx_t_2 = __pyx_v_iterseq; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_iterseq); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
    }
    for (;;) {
      if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        __pyx_t_6 = __pyx_t_5(__pyx_t_2);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF_SET(__pyx_v_v, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "axon/_dumper.py":1170
 *         if self.pretty:
 *             for v in iterseq:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._pretty_dump(v, '', 1)
 *         else:
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__33);

      /* "axon/_dumper.py":1171
 *             for v in iterseq:
 *                 self.write('\n')
 *                 self._pretty_dump(v, '', 1)             # <<<<<<<<<<<<<<
 *         else:
 *             for v in iterseq:
 */
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__pretty_dump(__pyx_v_self, __pyx_v_v, __pyx_kp_u__10, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1171; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "axon/_dumper.py":1173
 *                 self._pretty_dump(v, '', 1)
 *         else:
 *             for v in iterseq:             # <<<<<<<<<<<<<<
 *                 self.write('\n')
 *                 self._dump(v)
 */
    if (PyList_CheckExact(__pyx_v_iterseq) || PyTuple_CheckExact(__pyx_v_iterseq)) {
      __pyx_t_2 = __pyx_v_iterseq; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_iterseq); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
    }
    for (;;) {
      if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_2)) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_2)) {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        __pyx_t_6 = __pyx_t_5(__pyx_t_2);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF_SET(__pyx_v_v, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "axon/_dumper.py":1174
 *         else:
 *             for v in iterseq:
 *                 self.write('\n')             # <<<<<<<<<<<<<<
 *                 self._dump(v)
 *     #
 */
      __pyx_f_4axon_7_dumper_6Dumper_write(__pyx_v_self, __pyx_kp_u__33);

      /* "axon/_dumper.py":1175
 *             for v in iterseq:
 *                 self.write('\n')
 *                 self._dump(v)             # <<<<<<<<<<<<<<
 *     #
 *     def apply_crossref(self):
 */
      __pyx_t_3 = __pyx_f_4axon_7_dumper_6Dumper__dump(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1175; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":1141
 *         self.write(')')
 *     #
 *     def dump(self, seq):             # <<<<<<<<<<<<<<
 *         '''
 *         Main dumping method.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("axon._dumper.Dumper.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_iterseq);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1177
 *                 self._dump(v)
 *     #
 *     def apply_crossref(self):             # <<<<<<<<<<<<<<
 *         crossref_set = set()
 *         crossref_set2 = set()
 */

static void __pyx_f_4axon_7_dumper_6Dumper_apply_crossref(struct Dumper *__pyx_v_self) {
  struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_count = 0;
  int __pyx_v_i;
  PyObject *__pyx_v_crossref_dict = 0;
  PyObject *__pyx_v_crossref_set = 0;
  PyObject *__pyx_v_crossref_set2 = NULL;
  PyObject *__pyx_v_o_ref = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply_crossref", 0);

  /* "axon/_dumper.py":1178
 *     #
 *     def apply_crossref(self):
 *         crossref_set = set()             # <<<<<<<<<<<<<<
 *         crossref_set2 = set()
 *         for o_ref, count in self.crossref_dict.items():
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_crossref_set = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":1179
 *     def apply_crossref(self):
 *         crossref_set = set()
 *         crossref_set2 = set()             # <<<<<<<<<<<<<<
 *         for o_ref, count in self.crossref_dict.items():
 *             if count.val > 1:
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_crossref_set2 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":1180
 *         crossref_set = set()
 *         crossref_set2 = set()
 *         for o_ref, count in self.crossref_dict.items():             # <<<<<<<<<<<<<<
 *             if count.val > 1:
 *                 crossref_set.add(o_ref)
 */
  __pyx_t_2 = 0;
  if (unlikely(__pyx_v_self->crossref_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_self->crossref_dict, 1, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_4axon_7_dumper_PyInt))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF_SET(__pyx_v_o_ref, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_count, ((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "axon/_dumper.py":1181
 *         crossref_set2 = set()
 *         for o_ref, count in self.crossref_dict.items():
 *             if count.val > 1:             # <<<<<<<<<<<<<<
 *                 crossref_set.add(o_ref)
 * 
 */
    __pyx_t_8 = ((__pyx_v_count->val > 1) != 0);
    if (__pyx_t_8) {

      /* "axon/_dumper.py":1182
 *         for o_ref, count in self.crossref_dict.items():
 *             if count.val > 1:
 *                 crossref_set.add(o_ref)             # <<<<<<<<<<<<<<
 * 
 *         crossref_dict = {}
 */
      __pyx_t_9 = PySet_Add(__pyx_v_crossref_set, __pyx_v_o_ref); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L5;
    }
    __pyx_L5:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1184
 *                 crossref_set.add(o_ref)
 * 
 *         crossref_dict = {}             # <<<<<<<<<<<<<<
 *         i = 0
 *         for o_ref in crossref_set:
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_crossref_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":1185
 * 
 *         crossref_dict = {}
 *         i = 0             # <<<<<<<<<<<<<<
 *         for o_ref in crossref_set:
 *             i += 1
 */
  __pyx_v_i = 0;

  /* "axon/_dumper.py":1186
 *         crossref_dict = {}
 *         i = 0
 *         for o_ref in crossref_set:             # <<<<<<<<<<<<<<
 *             i += 1
 *             crossref_dict[o_ref] = unicode(i)
 */
  __pyx_t_1 = PyObject_GetIter(__pyx_v_crossref_set); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_10 = Py_TYPE(__pyx_t_1)->tp_iternext;
  for (;;) {
    {
      __pyx_t_6 = __pyx_t_10(__pyx_t_1);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF_SET(__pyx_v_o_ref, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "axon/_dumper.py":1187
 *         i = 0
 *         for o_ref in crossref_set:
 *             i += 1             # <<<<<<<<<<<<<<
 *             crossref_dict[o_ref] = unicode(i)
 * 
 */
    __pyx_v_i = (__pyx_v_i + 1);

    /* "axon/_dumper.py":1188
 *         for o_ref in crossref_set:
 *             i += 1
 *             crossref_dict[o_ref] = unicode(i)             # <<<<<<<<<<<<<<
 * 
 *         self.crossref_set = crossref_set
 */
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyUnicode_Type))), __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(PyDict_SetItem(__pyx_v_crossref_dict, __pyx_v_o_ref, __pyx_t_6) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1190
 *             crossref_dict[o_ref] = unicode(i)
 * 
 *         self.crossref_set = crossref_set             # <<<<<<<<<<<<<<
 *         self.crossref_set2 = crossref_set2
 *         self.crossref_dict = crossref_dict
 */
  __Pyx_INCREF(__pyx_v_crossref_set);
  __Pyx_GIVEREF(__pyx_v_crossref_set);
  __Pyx_GOTREF(__pyx_v_self->crossref_set);
  __Pyx_DECREF(__pyx_v_self->crossref_set);
  __pyx_v_self->crossref_set = __pyx_v_crossref_set;

  /* "axon/_dumper.py":1191
 * 
 *         self.crossref_set = crossref_set
 *         self.crossref_set2 = crossref_set2             # <<<<<<<<<<<<<<
 *         self.crossref_dict = crossref_dict
 *         crossref_dict = None
 */
  if (!(likely(PySet_CheckExact(__pyx_v_crossref_set2))||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "set", Py_TYPE(__pyx_v_crossref_set2)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_crossref_set2;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->crossref_set2);
  __Pyx_DECREF(__pyx_v_self->crossref_set2);
  __pyx_v_self->crossref_set2 = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "axon/_dumper.py":1192
 *         self.crossref_set = crossref_set
 *         self.crossref_set2 = crossref_set2
 *         self.crossref_dict = crossref_dict             # <<<<<<<<<<<<<<
 *         crossref_dict = None
 *         crossref_set = None
 */
  __Pyx_INCREF(__pyx_v_crossref_dict);
  __Pyx_GIVEREF(__pyx_v_crossref_dict);
  __Pyx_GOTREF(__pyx_v_self->crossref_dict);
  __Pyx_DECREF(__pyx_v_self->crossref_dict);
  __pyx_v_self->crossref_dict = __pyx_v_crossref_dict;

  /* "axon/_dumper.py":1193
 *         self.crossref_set2 = crossref_set2
 *         self.crossref_dict = crossref_dict
 *         crossref_dict = None             # <<<<<<<<<<<<<<
 *         crossref_set = None
 *         crossref_set2 = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_DECREF_SET(__pyx_v_crossref_dict, ((PyObject*)Py_None));

  /* "axon/_dumper.py":1194
 *         self.crossref_dict = crossref_dict
 *         crossref_dict = None
 *         crossref_set = None             # <<<<<<<<<<<<<<
 *         crossref_set2 = None
 *     #
 */
  __Pyx_INCREF(Py_None);
  __Pyx_DECREF_SET(__pyx_v_crossref_set, ((PyObject*)Py_None));

  /* "axon/_dumper.py":1195
 *         crossref_dict = None
 *         crossref_set = None
 *         crossref_set2 = None             # <<<<<<<<<<<<<<
 *     #
 *     def _collect(self, o):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_DECREF_SET(__pyx_v_crossref_set2, Py_None);

  /* "axon/_dumper.py":1177
 *                 self._dump(v)
 *     #
 *     def apply_crossref(self):             # <<<<<<<<<<<<<<
 *         crossref_set = set()
 *         crossref_set2 = set()
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("axon._dumper.Dumper.apply_crossref", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_crossref_dict);
  __Pyx_XDECREF(__pyx_v_crossref_set);
  __Pyx_XDECREF(__pyx_v_crossref_set2);
  __Pyx_XDECREF(__pyx_v_o_ref);
  __Pyx_RefNannyFinishContext();
}

/* "axon/_dumper.py":1197
 *         crossref_set2 = None
 *     #
 *     def _collect(self, o):             # <<<<<<<<<<<<<<
 * 
 *         if type(o) in simple_types:
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect(struct Dumper *__pyx_v_self, PyObject *__pyx_v_o) {
  struct __pyx_obj_4axon_7_dumper_PyInt *__pyx_v_count = 0;
  PyObject *__pyx_v_ref_o = NULL;
  PyObject *__pyx_v_otype = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect", 0);

  /* "axon/_dumper.py":1199
 *     def _collect(self, o):
 * 
 *         if type(o) in simple_types:             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
  __pyx_t_1 = (__Pyx_PySequence_Contains(((PyObject *)Py_TYPE(__pyx_v_o)), __pyx_v_4axon_7_dumper_simple_types, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":1200
 * 
 *         if type(o) in simple_types:
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         ref_o = id(o)
 */
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "axon/_dumper.py":1202
 *             return 0
 * 
 *         ref_o = id(o)             # <<<<<<<<<<<<<<
 *         count = self.crossref_dict.get(ref_o, None)
 *         if count is None:
 */
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_o);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_id, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_ref_o = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "axon/_dumper.py":1203
 * 
 *         ref_o = id(o)
 *         count = self.crossref_dict.get(ref_o, None)             # <<<<<<<<<<<<<<
 *         if count is None:
 *             count = PyInt(1)
 */
  if (unlikely(__pyx_v_self->crossref_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1203; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_4 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->crossref_dict, __pyx_v_ref_o, Py_None); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1203; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_4axon_7_dumper_PyInt))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1203; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_count = ((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "axon/_dumper.py":1204
 *         ref_o = id(o)
 *         count = self.crossref_dict.get(ref_o, None)
 *         if count is None:             # <<<<<<<<<<<<<<
 *             count = PyInt(1)
 *             self.crossref_dict[ref_o] = count
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_count) == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":1205
 *         count = self.crossref_dict.get(ref_o, None)
 *         if count is None:
 *             count = PyInt(1)             # <<<<<<<<<<<<<<
 *             self.crossref_dict[ref_o] = count
 *         else:
 */
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_PyInt)), __pyx_tuple__38, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_count, ((struct __pyx_obj_4axon_7_dumper_PyInt *)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":1206
 *         if count is None:
 *             count = PyInt(1)
 *             self.crossref_dict[ref_o] = count             # <<<<<<<<<<<<<<
 *         else:
 *             count.val += 1
 */
    if (unlikely(__pyx_v_self->crossref_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1206; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(__pyx_v_self->crossref_dict, __pyx_v_ref_o, ((PyObject *)__pyx_v_count)) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1206; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  /*else*/ {

    /* "axon/_dumper.py":1208
 *             self.crossref_dict[ref_o] = count
 *         else:
 *             count.val += 1             # <<<<<<<<<<<<<<
 *             self.crossref_dict[ref_o] = count
 *             return 0
 */
    __pyx_v_count->val = (__pyx_v_count->val + 1);

    /* "axon/_dumper.py":1209
 *         else:
 *             count.val += 1
 *             self.crossref_dict[ref_o] = count             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
    if (unlikely(__pyx_v_self->crossref_dict == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(__pyx_v_self->crossref_dict, __pyx_v_ref_o, ((PyObject *)__pyx_v_count)) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "axon/_dumper.py":1210
 *             count.val += 1
 *             self.crossref_dict[ref_o] = count
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         otype = type(o)
 */
    __pyx_r = 0;
    goto __pyx_L0;
  }
  __pyx_L4:;

  /* "axon/_dumper.py":1212
 *             return 0
 * 
 *         otype = type(o)             # <<<<<<<<<<<<<<
 *         if otype is list:
 *             self._collect_list(o)
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_o)));
  __pyx_v_otype = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_o)));

  /* "axon/_dumper.py":1213
 * 
 *         otype = type(o)
 *         if otype is list:             # <<<<<<<<<<<<<<
 *             self._collect_list(o)
 *         elif otype is dict:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)(&PyList_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":1214
 *         otype = type(o)
 *         if otype is list:
 *             self._collect_list(o)             # <<<<<<<<<<<<<<
 *         elif otype is dict:
 *             self._collect_dict(o)
 */
    if (!(likely(PyList_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_list(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":1215
 *         if otype is list:
 *             self._collect_list(o)
 *         elif otype is dict:             # <<<<<<<<<<<<<<
 *             self._collect_dict(o)
 *         elif otype is tuple:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)(&PyDict_Type)));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":1216
 *             self._collect_list(o)
 *         elif otype is dict:
 *             self._collect_dict(o)             # <<<<<<<<<<<<<<
 *         elif otype is tuple:
 *             self._collect_tuple(o)
 */
    if (!(likely(PyDict_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_dict(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":1217
 *         elif otype is dict:
 *             self._collect_dict(o)
 *         elif otype is tuple:             # <<<<<<<<<<<<<<
 *             self._collect_tuple(o)
 *         elif otype is set:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)(&PyTuple_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":1218
 *             self._collect_dict(o)
 *         elif otype is tuple:
 *             self._collect_tuple(o)             # <<<<<<<<<<<<<<
 *         elif otype is set:
 *             self._collect_set(o)
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_tuple(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":1219
 *         elif otype is tuple:
 *             self._collect_tuple(o)
 *         elif otype is set:             # <<<<<<<<<<<<<<
 *             self._collect_set(o)
 *         elif otype is Element:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)(&PySet_Type)));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":1220
 *             self._collect_tuple(o)
 *         elif otype is set:
 *             self._collect_set(o)             # <<<<<<<<<<<<<<
 *         elif otype is Element:
 *             self._collect_element(o)
 */
    if (!(likely(PySet_CheckExact(__pyx_v_o))||((__pyx_v_o) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "set", Py_TYPE(__pyx_v_o)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_set(__pyx_v_self, ((PyObject*)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":1221
 *         elif otype is set:
 *             self._collect_set(o)
 *         elif otype is Element:             # <<<<<<<<<<<<<<
 *             self._collect_element(o)
 *         elif otype is Mapping:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Element));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":1222
 *             self._collect_set(o)
 *         elif otype is Element:
 *             self._collect_element(o)             # <<<<<<<<<<<<<<
 *         elif otype is Mapping:
 *             self._collect_mapping(o)
 */
    if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Element))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1222; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_element(__pyx_v_self, ((struct ElementObject *)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1222; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":1223
 *         elif otype is Element:
 *             self._collect_element(o)
 *         elif otype is Mapping:             # <<<<<<<<<<<<<<
 *             self._collect_mapping(o)
 *         elif otype is Sequence:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Mapping));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":1224
 *             self._collect_element(o)
 *         elif otype is Mapping:
 *             self._collect_mapping(o)             # <<<<<<<<<<<<<<
 *         elif otype is Sequence:
 *             self._collect_sequence(o)
 */
    if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Mapping))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1224; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_mapping(__pyx_v_self, ((struct MappingObject *)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1224; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":1225
 *         elif otype is Mapping:
 *             self._collect_mapping(o)
 *         elif otype is Sequence:             # <<<<<<<<<<<<<<
 *             self._collect_sequence(o)
 *         elif otype is Instance:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Sequence));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":1226
 *             self._collect_mapping(o)
 *         elif otype is Sequence:
 *             self._collect_sequence(o)             # <<<<<<<<<<<<<<
 *         elif otype is Instance:
 *             self._collect_instance(o)
 */
    if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Sequence))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1226; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_sequence(__pyx_v_self, ((struct SequenceObject *)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1226; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":1227
 *         elif otype is Sequence:
 *             self._collect_sequence(o)
 *         elif otype is Instance:             # <<<<<<<<<<<<<<
 *             self._collect_instance(o)
 *         elif otype is Empty:
 */
  __pyx_t_2 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Instance));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.py":1228
 *             self._collect_sequence(o)
 *         elif otype is Instance:
 *             self._collect_instance(o)             # <<<<<<<<<<<<<<
 *         elif otype is Empty:
 *             self._collect_instance(o)
 */
    if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Instance))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_instance(__pyx_v_self, ((struct InstanceObject *)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }

  /* "axon/_dumper.py":1229
 *         elif otype is Instance:
 *             self._collect_instance(o)
 *         elif otype is Empty:             # <<<<<<<<<<<<<<
 *             self._collect_instance(o)
 *         #else:
 */
  __pyx_t_1 = (__pyx_v_otype == ((PyObject*)__pyx_ptype_4axon_8_objects_Empty));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_dumper.py":1230
 *             self._collect_instance(o)
 *         elif otype is Empty:
 *             self._collect_instance(o)             # <<<<<<<<<<<<<<
 *         #else:
 *         #    reducer = self.c_type_reducers.get(otype, None)
 */
    if (!(likely(((__pyx_v_o) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_o, __pyx_ptype_4axon_8_objects_Instance))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1230; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect_instance(__pyx_v_self, ((struct InstanceObject *)__pyx_v_o)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1230; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "axon/_dumper.py":1197
 *         crossref_set2 = None
 *     #
 *     def _collect(self, o):             # <<<<<<<<<<<<<<
 * 
 *         if type(o) in simple_types:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_ref_o);
  __Pyx_XDECREF(__pyx_v_otype);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1238
 *         #        self._collect_with_reducer(reducer, o)
 *     #
 *     def _collect_list(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_list(struct Dumper *__pyx_v_self, PyObject *__pyx_v_lst) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_list", 0);

  /* "axon/_dumper.py":1239
 *     #
 *     def _collect_list(self, lst):
 *         for v in lst:             # <<<<<<<<<<<<<<
 *             self._collect(v)
 *     #
 */
  if (unlikely(__pyx_v_lst == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __pyx_v_lst; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":1240
 *     def _collect_list(self, lst):
 *         for v in lst:
 *             self._collect(v)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_tuple(self, lst):
 */
    __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1240; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1238
 *         #        self._collect_with_reducer(reducer, o)
 *     #
 *     def _collect_list(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1242
 *             self._collect(v)
 *     #
 *     def _collect_tuple(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_tuple(struct Dumper *__pyx_v_self, PyObject *__pyx_v_lst) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_tuple", 0);

  /* "axon/_dumper.py":1243
 *     #
 *     def _collect_tuple(self, lst):
 *         for v in lst:             # <<<<<<<<<<<<<<
 *             self._collect(v)
 *     #
 */
  if (unlikely(__pyx_v_lst == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1243; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __pyx_v_lst; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1243; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1243; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":1244
 *     def _collect_tuple(self, lst):
 *         for v in lst:
 *             self._collect(v)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_set(self, lst):
 */
    __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1244; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1242
 *             self._collect(v)
 *     #
 *     def _collect_tuple(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1246
 *             self._collect(v)
 *     #
 *     def _collect_set(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_set(struct Dumper *__pyx_v_self, PyObject *__pyx_v_lst) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *(*__pyx_t_2)(PyObject *);
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_set", 0);

  /* "axon/_dumper.py":1247
 *     #
 *     def _collect_set(self, lst):
 *         for v in lst:             # <<<<<<<<<<<<<<
 *             self._collect(v)
 *     #
 */
  __pyx_t_1 = PyObject_GetIter(__pyx_v_lst); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = Py_TYPE(__pyx_t_1)->tp_iternext;
  for (;;) {
    {
      __pyx_t_3 = __pyx_t_2(__pyx_t_1);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "axon/_dumper.py":1248
 *     def _collect_set(self, lst):
 *         for v in lst:
 *             self._collect(v)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_dict(self, d):
 */
    __pyx_t_4 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1246
 *             self._collect(v)
 *     #
 *     def _collect_set(self, lst):             # <<<<<<<<<<<<<<
 *         for v in lst:
 *             self._collect(v)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1250
 *             self._collect(v)
 *     #
 *     def _collect_dict(self, d):             # <<<<<<<<<<<<<<
 *         for v in d.values():
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_dict(struct Dumper *__pyx_v_self, PyObject *__pyx_v_d) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_dict", 0);

  /* "axon/_dumper.py":1251
 *     #
 *     def _collect_dict(self, d):
 *         for v in d.values():             # <<<<<<<<<<<<<<
 *             self._collect(v)
 *     #
 */
  __pyx_t_2 = 0;
  if (unlikely(__pyx_v_d == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "values");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_d, 1, __pyx_n_s_values, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, NULL, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "axon/_dumper.py":1252
 *     def _collect_dict(self, d):
 *         for v in d.values():
 *             self._collect(v)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_element(self, ob):
 */
    __pyx_t_6 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1252; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1250
 *             self._collect(v)
 *     #
 *     def _collect_dict(self, d):             # <<<<<<<<<<<<<<
 *         for v in d.values():
 *             self._collect(v)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1254
 *             self._collect(v)
 *     #
 *     def _collect_element(self, ob):             # <<<<<<<<<<<<<<
 *         self._collect_dict(ob.mapping)
 *         self._collect_list(ob.sequence)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_element(struct Dumper *__pyx_v_self, struct ElementObject *__pyx_v_ob) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_element", 0);

  /* "axon/_dumper.py":1255
 *     #
 *     def _collect_element(self, ob):
 *         self._collect_dict(ob.mapping)             # <<<<<<<<<<<<<<
 *         self._collect_list(ob.sequence)
 *     #
 */
  __pyx_t_1 = __pyx_v_ob->mapping;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__collect_dict(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1255; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1256
 *     def _collect_element(self, ob):
 *         self._collect_dict(ob.mapping)
 *         self._collect_list(ob.sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_instance(self, ob):
 */
  __pyx_t_1 = __pyx_v_ob->sequence;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__collect_list(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1254
 *             self._collect(v)
 *     #
 *     def _collect_element(self, ob):             # <<<<<<<<<<<<<<
 *         self._collect_dict(ob.mapping)
 *         self._collect_list(ob.sequence)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1258
 *         self._collect_list(ob.sequence)
 *     #
 *     def _collect_instance(self, ob):             # <<<<<<<<<<<<<<
 *         self._collect_dict(ob.mapping)
 *         self._collect_tuple(ob.sequence)
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_instance(struct Dumper *__pyx_v_self, struct InstanceObject *__pyx_v_ob) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_instance", 0);

  /* "axon/_dumper.py":1259
 *     #
 *     def _collect_instance(self, ob):
 *         self._collect_dict(ob.mapping)             # <<<<<<<<<<<<<<
 *         self._collect_tuple(ob.sequence)
 *     #
 */
  __pyx_t_1 = __pyx_v_ob->mapping;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__collect_dict(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1260
 *     def _collect_instance(self, ob):
 *         self._collect_dict(ob.mapping)
 *         self._collect_tuple(ob.sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_mapping(self, ob):
 */
  __pyx_t_1 = __pyx_v_ob->sequence;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__collect_tuple(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1258
 *         self._collect_list(ob.sequence)
 *     #
 *     def _collect_instance(self, ob):             # <<<<<<<<<<<<<<
 *         self._collect_dict(ob.mapping)
 *         self._collect_tuple(ob.sequence)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_instance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1262
 *         self._collect_tuple(ob.sequence)
 *     #
 *     def _collect_mapping(self, ob):             # <<<<<<<<<<<<<<
 *         self._collect_dict(ob.mapping)
 *     #
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_mapping(struct Dumper *__pyx_v_self, struct MappingObject *__pyx_v_ob) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_mapping", 0);

  /* "axon/_dumper.py":1263
 *     #
 *     def _collect_mapping(self, ob):
 *         self._collect_dict(ob.mapping)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_sequence(self, ob):
 */
  __pyx_t_1 = __pyx_v_ob->mapping;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__collect_dict(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1262
 *         self._collect_tuple(ob.sequence)
 *     #
 *     def _collect_mapping(self, ob):             # <<<<<<<<<<<<<<
 *         self._collect_dict(ob.mapping)
 *     #
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_mapping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1265
 *         self._collect_dict(ob.mapping)
 *     #
 *     def _collect_sequence(self, ob):             # <<<<<<<<<<<<<<
 *         self._collect_list(ob.sequence)
 *     #
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_sequence(struct Dumper *__pyx_v_self, struct SequenceObject *__pyx_v_ob) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_collect_sequence", 0);

  /* "axon/_dumper.py":1266
 *     #
 *     def _collect_sequence(self, ob):
 *         self._collect_list(ob.sequence)             # <<<<<<<<<<<<<<
 *     #
 *     def _collect_empty(self, ob):
 */
  __pyx_t_1 = __pyx_v_ob->sequence;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_4axon_7_dumper_6Dumper__collect_list(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1265
 *         self._collect_dict(ob.mapping)
 *     #
 *     def _collect_sequence(self, ob):             # <<<<<<<<<<<<<<
 *         self._collect_list(ob.sequence)
 *     #
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._dumper.Dumper._collect_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1268
 *         self._collect_list(ob.sequence)
 *     #
 *     def _collect_empty(self, ob):             # <<<<<<<<<<<<<<
 *         pass
 *     #
 */

static int __pyx_f_4axon_7_dumper_6Dumper__collect_empty(CYTHON_UNUSED struct Dumper *__pyx_v_self, CYTHON_UNUSED struct EmptyObject *__pyx_v_ob) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_collect_empty", 0);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.py":1291
 *     #            self._collect_set(results_i)
 *     #
 *     def collect(self, values):             # <<<<<<<<<<<<<<
 *         for v in values:
 *             self._collect(v)
 */

static int __pyx_f_4axon_7_dumper_6Dumper_collect(struct Dumper *__pyx_v_self, PyObject *__pyx_v_values) {
  PyObject *__pyx_v_v = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("collect", 0);

  /* "axon/_dumper.py":1292
 *     #
 *     def collect(self, values):
 *         for v in values:             # <<<<<<<<<<<<<<
 *             self._collect(v)
 * 
 */
  if (PyList_CheckExact(__pyx_v_values) || PyTuple_CheckExact(__pyx_v_values)) {
    __pyx_t_1 = __pyx_v_values; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_values); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_3 && PyList_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_3 && PyTuple_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "axon/_dumper.py":1293
 *     def collect(self, values):
 *         for v in values:
 *             self._collect(v)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_5 = __pyx_f_4axon_7_dumper_6Dumper__collect(__pyx_v_self, __pyx_v_v); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "axon/_dumper.py":1291
 *     #            self._collect_set(results_i)
 *     #
 *     def collect(self, values):             # <<<<<<<<<<<<<<
 *         for v in values:
 *             self._collect(v)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._dumper.Dumper.collect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.pxd":62
 * from cpython.unicode cimport PyUnicode_FromEncodedObject
 * 
 * cdef inline object dict_get(object op, object key, object default):             # <<<<<<<<<<<<<<
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)
 *     if val == NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_7_dumper_dict_get(PyObject *__pyx_v_op, PyObject *__pyx_v_key, PyObject *__pyx_v_default) {
  PyObject *__pyx_v_val;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("dict_get", 0);

  /* "axon/_dumper.pxd":63
 * 
 * cdef inline object dict_get(object op, object key, object default):
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)             # <<<<<<<<<<<<<<
 *     if val == NULL:
 *         return default
 */
  __pyx_v_val = ((PyObject *)PyDict_GetItem(__pyx_v_op, __pyx_v_key));

  /* "axon/_dumper.pxd":64
 * cdef inline object dict_get(object op, object key, object default):
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)
 *     if val == NULL:             # <<<<<<<<<<<<<<
 *         return default
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_val == NULL) != 0);
  if (__pyx_t_1) {

    /* "axon/_dumper.pxd":65
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)
 *     if val == NULL:
 *         return default             # <<<<<<<<<<<<<<
 *     else:
 *         return <object>val
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_default);
    __pyx_r = __pyx_v_default;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_dumper.pxd":67
 *         return default
 *     else:
 *         return <object>val             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_val));
    __pyx_r = ((PyObject *)__pyx_v_val);
    goto __pyx_L0;
  }

  /* "axon/_dumper.pxd":62
 * from cpython.unicode cimport PyUnicode_FromEncodedObject
 * 
 * cdef inline object dict_get(object op, object key, object default):             # <<<<<<<<<<<<<<
 *     cdef PyObject* val = <PyObject*>PyDict_GetItem(op, key)
 *     if val == NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.pxd":102
 * #     return uname
 * 
 * cdef inline Mapping as_mapping(object ob):             # <<<<<<<<<<<<<<
 *     return <Mapping>ob
 * 
 */

static CYTHON_INLINE struct MappingObject *__pyx_f_4axon_7_dumper_as_mapping(PyObject *__pyx_v_ob) {
  struct MappingObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_mapping", 0);

  /* "axon/_dumper.pxd":103
 * 
 * cdef inline Mapping as_mapping(object ob):
 *     return <Mapping>ob             # <<<<<<<<<<<<<<
 * 
 * cdef inline Element as_element(object ob):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)((struct MappingObject *)__pyx_v_ob)));
  __pyx_r = ((struct MappingObject *)__pyx_v_ob);
  goto __pyx_L0;

  /* "axon/_dumper.pxd":102
 * #     return uname
 * 
 * cdef inline Mapping as_mapping(object ob):             # <<<<<<<<<<<<<<
 *     return <Mapping>ob
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.pxd":105
 *     return <Mapping>ob
 * 
 * cdef inline Element as_element(object ob):             # <<<<<<<<<<<<<<
 *     return <Element>ob
 * 
 */

static CYTHON_INLINE struct ElementObject *__pyx_f_4axon_7_dumper_as_element(PyObject *__pyx_v_ob) {
  struct ElementObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_element", 0);

  /* "axon/_dumper.pxd":106
 * 
 * cdef inline Element as_element(object ob):
 *     return <Element>ob             # <<<<<<<<<<<<<<
 * 
 * cdef inline Sequence as_sequence(object ob):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)((struct ElementObject *)__pyx_v_ob)));
  __pyx_r = ((struct ElementObject *)__pyx_v_ob);
  goto __pyx_L0;

  /* "axon/_dumper.pxd":105
 *     return <Mapping>ob
 * 
 * cdef inline Element as_element(object ob):             # <<<<<<<<<<<<<<
 *     return <Element>ob
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.pxd":108
 *     return <Element>ob
 * 
 * cdef inline Sequence as_sequence(object ob):             # <<<<<<<<<<<<<<
 *     return <Sequence>ob
 * 
 */

static CYTHON_INLINE struct SequenceObject *__pyx_f_4axon_7_dumper_as_sequence(PyObject *__pyx_v_ob) {
  struct SequenceObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_sequence", 0);

  /* "axon/_dumper.pxd":109
 * 
 * cdef inline Sequence as_sequence(object ob):
 *     return <Sequence>ob             # <<<<<<<<<<<<<<
 * 
 * cdef inline Instance as_instance(object ob):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)((struct SequenceObject *)__pyx_v_ob)));
  __pyx_r = ((struct SequenceObject *)__pyx_v_ob);
  goto __pyx_L0;

  /* "axon/_dumper.pxd":108
 *     return <Element>ob
 * 
 * cdef inline Sequence as_sequence(object ob):             # <<<<<<<<<<<<<<
 *     return <Sequence>ob
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.pxd":111
 *     return <Sequence>ob
 * 
 * cdef inline Instance as_instance(object ob):             # <<<<<<<<<<<<<<
 *     return <Instance>ob
 * 
 */

static CYTHON_INLINE struct InstanceObject *__pyx_f_4axon_7_dumper_as_instance(PyObject *__pyx_v_ob) {
  struct InstanceObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_instance", 0);

  /* "axon/_dumper.pxd":112
 * 
 * cdef inline Instance as_instance(object ob):
 *     return <Instance>ob             # <<<<<<<<<<<<<<
 * 
 * cdef inline Empty as_empty(object ob):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)((struct InstanceObject *)__pyx_v_ob)));
  __pyx_r = ((struct InstanceObject *)__pyx_v_ob);
  goto __pyx_L0;

  /* "axon/_dumper.pxd":111
 *     return <Sequence>ob
 * 
 * cdef inline Instance as_instance(object ob):             # <<<<<<<<<<<<<<
 *     return <Instance>ob
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_dumper.pxd":114
 *     return <Instance>ob
 * 
 * cdef inline Empty as_empty(object ob):             # <<<<<<<<<<<<<<
 *     return <Empty>ob
 * 
 */

static CYTHON_INLINE struct EmptyObject *__pyx_f_4axon_7_dumper_as_empty(PyObject *__pyx_v_ob) {
  struct EmptyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_empty", 0);

  /* "axon/_dumper.pxd":115
 * 
 * cdef inline Empty as_empty(object ob):
 *     return <Empty>ob             # <<<<<<<<<<<<<<
 * 
 * cdef class PyInt:
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)((struct EmptyObject *)__pyx_v_ob)));
  __pyx_r = ((struct EmptyObject *)__pyx_v_ob);
  goto __pyx_L0;

  /* "axon/_dumper.pxd":114
 *     return <Instance>ob
 * 
 * cdef inline Empty as_empty(object ob):             # <<<<<<<<<<<<<<
 *     return <Empty>ob
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":104
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("import_datetime", 0);

  /* "cpython/datetime.pxd":105
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():
 *     PyDateTime_IMPORT             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DateTime CAPI factory function.
 */
  PyDateTime_IMPORT;

  /* "cpython/datetime.pxd":104
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "cpython/datetime.pxd":109
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_date_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_new", 0);

  /* "cpython/datetime.pxd":110
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object date_new(int year, int month, int day):
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)             # <<<<<<<<<<<<<<
 * 
 * # Create time object using DateTime CAPI factory function
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Date_FromDate(__pyx_v_year, __pyx_v_month, __pyx_v_day, PyDateTimeAPI->DateType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":109
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.date_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":114
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object time_new(int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI.TimeType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_new(int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("time_new", 0);

  /* "cpython/datetime.pxd":115
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object time_new(int hour, int minute, int second, int microsecond, object tz):
 *     return PyDateTimeAPI.Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI.TimeType)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Time_FromTime(__pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, PyDateTimeAPI->TimeType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":114
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object time_new(int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI.TimeType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.time_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":119
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromDateAndTime(year, month, day, hour, minute, second, microsecond, tz, PyDateTimeAPI.DateTimeType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day, int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_new", 0);

  /* "cpython/datetime.pxd":120
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz):
 *     return PyDateTimeAPI.DateTime_FromDateAndTime(year, month, day, hour, minute, second, microsecond, tz, PyDateTimeAPI.DateTimeType)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->DateTime_FromDateAndTime(__pyx_v_year, __pyx_v_month, __pyx_v_day, __pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, PyDateTimeAPI->DateTimeType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":119
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromDateAndTime(year, month, day, hour, minute, second, microsecond, tz, PyDateTimeAPI.DateTimeType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.datetime_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":124
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timedelta_new(int __pyx_v_days, int __pyx_v_seconds, int __pyx_v_useconds) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timedelta_new", 0);

  /* "cpython/datetime.pxd":125
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object timedelta_new(int days, int seconds, int useconds):
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)             # <<<<<<<<<<<<<<
 * 
 * # More recognizable getters for date/time/datetime/timedelta.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTimeAPI->Delta_FromDelta(__pyx_v_days, __pyx_v_seconds, __pyx_v_useconds, 1, PyDateTimeAPI->DeltaType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":124
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline object timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.timedelta_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":133
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_Time*>o).hastzinfo:
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("time_tzinfo", 0);

  /* "cpython/datetime.pxd":134
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):
 *     if (<PyDateTime_Time*>o).hastzinfo:             # <<<<<<<<<<<<<<
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 *     else:
 */
  __pyx_t_1 = (((PyDateTime_Time *)__pyx_v_o)->hastzinfo != 0);
  if (__pyx_t_1) {

    /* "cpython/datetime.pxd":135
 * cdef inline object time_tzinfo(object o):
 *     if (<PyDateTime_Time*>o).hastzinfo:
 *         return <object>(<PyDateTime_Time*>o).tzinfo             # <<<<<<<<<<<<<<
 *     else:
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)((PyDateTime_Time *)__pyx_v_o)->tzinfo));
    __pyx_r = ((PyObject *)((PyDateTime_Time *)__pyx_v_o)->tzinfo);
    goto __pyx_L0;
  }
  /*else*/ {

    /* "cpython/datetime.pxd":137
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of datetime
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }

  /* "cpython/datetime.pxd":133
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_Time*>o).hastzinfo:
 *         return <object>(<PyDateTime_Time*>o).tzinfo
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":140
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_DateTime*>o).hastzinfo:
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("datetime_tzinfo", 0);

  /* "cpython/datetime.pxd":141
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):
 *     if (<PyDateTime_DateTime*>o).hastzinfo:             # <<<<<<<<<<<<<<
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 *     else:
 */
  __pyx_t_1 = (((PyDateTime_DateTime *)__pyx_v_o)->hastzinfo != 0);
  if (__pyx_t_1) {

    /* "cpython/datetime.pxd":142
 * cdef inline object datetime_tzinfo(object o):
 *     if (<PyDateTime_DateTime*>o).hastzinfo:
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo             # <<<<<<<<<<<<<<
 *     else:
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)((PyDateTime_DateTime *)__pyx_v_o)->tzinfo));
    __pyx_r = ((PyObject *)((PyDateTime_DateTime *)__pyx_v_o)->tzinfo);
    goto __pyx_L0;
  }
  /*else*/ {

    /* "cpython/datetime.pxd":144
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * # Get year of date
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }

  /* "cpython/datetime.pxd":140
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     if (<PyDateTime_DateTime*>o).hastzinfo:
 *         return <object>(<PyDateTime_DateTime*>o).tzinfo
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":147
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_year(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_year", 0);

  /* "cpython/datetime.pxd":148
 * # Get year of date
 * cdef inline int date_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of date
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":147
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":151
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_month(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_month", 0);

  /* "cpython/datetime.pxd":152
 * # Get month of date
 * cdef inline int date_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of date
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":151
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":155
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_day(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("date_day", 0);

  /* "cpython/datetime.pxd":156
 * # Get day of date
 * cdef inline int date_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of datetime
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":155
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":159
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_year(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_year", 0);

  /* "cpython/datetime.pxd":160
 * # Get year of datetime
 * cdef inline int datetime_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of datetime
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":159
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":163
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_month(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_month", 0);

  /* "cpython/datetime.pxd":164
 * # Get month of datetime
 * cdef inline int datetime_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of datetime
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":163
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":167
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_day(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_day", 0);

  /* "cpython/datetime.pxd":168
 * # Get day of datetime
 * cdef inline int datetime_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of time
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":167
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":171
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_hour(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_hour", 0);

  /* "cpython/datetime.pxd":172
 * # Get hour of time
 * cdef inline int time_hour(object o):
 *     return PyDateTime_TIME_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of time
 */
  __pyx_r = PyDateTime_TIME_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":171
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":175
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_minute(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_minute", 0);

  /* "cpython/datetime.pxd":176
 * # Get minute of time
 * cdef inline int time_minute(object o):
 *     return PyDateTime_TIME_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of time
 */
  __pyx_r = PyDateTime_TIME_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":175
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":179
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_second(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_second", 0);

  /* "cpython/datetime.pxd":180
 * # Get second of time
 * cdef inline int time_second(object o):
 *     return PyDateTime_TIME_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of time
 */
  __pyx_r = PyDateTime_TIME_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":179
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":183
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time_microsecond", 0);

  /* "cpython/datetime.pxd":184
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):
 *     return PyDateTime_TIME_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of datetime
 */
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":183
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":187
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_hour(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_hour", 0);

  /* "cpython/datetime.pxd":188
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):
 *     return PyDateTime_DATE_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":187
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":191
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_minute(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_minute", 0);

  /* "cpython/datetime.pxd":192
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):
 *     return PyDateTime_DATE_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":191
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":195
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_second(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_second", 0);

  /* "cpython/datetime.pxd":196
 * # Get second of datetime
 * cdef inline int datetime_second(object o):
 *     return PyDateTime_DATE_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":195
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":199
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("datetime_microsecond", 0);

  /* "cpython/datetime.pxd":200
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):
 *     return PyDateTime_DATE_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get days of timedelta
 */
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":199
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":203
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_days(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_days", 0);

  /* "cpython/datetime.pxd":204
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):
 *     return (<PyDateTime_Delta*>o).days             # <<<<<<<<<<<<<<
 * 
 * # Get seconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->days;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":203
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":207
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_seconds(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_seconds", 0);

  /* "cpython/datetime.pxd":208
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):
 *     return (<PyDateTime_Delta*>o).seconds             # <<<<<<<<<<<<<<
 * 
 * # Get microseconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->seconds;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":207
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":211
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_microseconds(PyObject *__pyx_v_o) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("timedelta_microseconds", 0);

  /* "cpython/datetime.pxd":212
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):
 *     return (<PyDateTime_Delta*>o).microseconds             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->microseconds;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":211
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":80
 * #        return <object>val
 * 
 * cdef inline dict c_as_dict(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is dict:
 *         return <dict>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_dict(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_dict", 0);

  /* "axon/_objects.pxd":81
 * 
 * cdef inline dict c_as_dict(object ob):
 *     if type(ob) is dict:             # <<<<<<<<<<<<<<
 *         return <dict>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyDict_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":82
 * cdef inline dict c_as_dict(object ob):
 *     if type(ob) is dict:
 *         return <dict>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return {}
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_ob));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":83
 *     if type(ob) is dict:
 *         return <dict>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return {}
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":84
 *         return <dict>ob
 *     elif ob is None:
 *         return {}             # <<<<<<<<<<<<<<
 *     else:
 *         return dict(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.pxd":86
 *         return {}
 *     else:
 *         return dict(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline list c_as_list(object ob):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyDict_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":80
 * #        return <object>val
 * 
 * cdef inline dict c_as_dict(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is dict:
 *         return <dict>ob
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":88
 *         return dict(ob)
 * 
 * cdef inline list c_as_list(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is list:
 *         return <list>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_list(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_list", 0);

  /* "axon/_objects.pxd":89
 * 
 * cdef inline list c_as_list(object ob):
 *     if type(ob) is list:             # <<<<<<<<<<<<<<
 *         return <list>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyList_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":90
 * cdef inline list c_as_list(object ob):
 *     if type(ob) is list:
 *         return <list>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return []
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_ob));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":91
 *     if type(ob) is list:
 *         return <list>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return []
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":92
 *         return <list>ob
 *     elif ob is None:
 *         return []             # <<<<<<<<<<<<<<
 *     else:
 *         return list(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.pxd":94
 *         return []
 *     else:
 *         return list(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple c_as_tuple(object ob):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyList_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":88
 *         return dict(ob)
 * 
 * cdef inline list c_as_list(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is list:
 *         return <list>ob
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":96
 *         return list(ob)
 * 
 * cdef inline tuple c_as_tuple(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is tuple:
 *         return <tuple>ob
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_tuple(PyObject *__pyx_v_ob) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_tuple", 0);

  /* "axon/_objects.pxd":97
 * 
 * cdef inline tuple c_as_tuple(object ob):
 *     if type(ob) is tuple:             # <<<<<<<<<<<<<<
 *         return <tuple>ob
 *     elif ob is None:
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_ob)) == ((PyObject *)((PyObject*)(&PyTuple_Type))));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":98
 * cdef inline tuple c_as_tuple(object ob):
 *     if type(ob) is tuple:
 *         return <tuple>ob             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_ob));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":99
 *     if type(ob) is tuple:
 *         return <tuple>ob
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return ()
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":100
 *         return <tuple>ob
 *     elif ob is None:
 *         return ()             # <<<<<<<<<<<<<<
 *     else:
 *         return tuple(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.pxd":102
 *         return ()
 *     else:
 *         return tuple(ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline unicode c_as_unicode(object ob):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_ob);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ob);
    __Pyx_GIVEREF(__pyx_v_ob);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)(&PyTuple_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":96
 *         return list(ob)
 * 
 * cdef inline tuple c_as_tuple(object ob):             # <<<<<<<<<<<<<<
 *     if type(ob) is tuple:
 *         return <tuple>ob
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_tuple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":104
 *         return tuple(ob)
 * 
 * cdef inline unicode c_as_unicode(object ob):             # <<<<<<<<<<<<<<
 *     tp = type(ob)
 *     if tp is unicode:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_unicode(PyObject *__pyx_v_ob) {
  PyObject *__pyx_v_tp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_unicode", 0);

  /* "axon/_objects.pxd":105
 * 
 * cdef inline unicode c_as_unicode(object ob):
 *     tp = type(ob)             # <<<<<<<<<<<<<<
 *     if tp is unicode:
 *         return <unicode>ob
 */
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_ob)));
  __pyx_v_tp = ((PyObject*)((PyObject *)Py_TYPE(__pyx_v_ob)));

  /* "axon/_objects.pxd":106
 * cdef inline unicode c_as_unicode(object ob):
 *     tp = type(ob)
 *     if tp is unicode:             # <<<<<<<<<<<<<<
 *         return <unicode>ob
 *     elif tp == c_str_type:
 */
  __pyx_t_1 = (__pyx_v_tp == ((PyObject*)(&PyUnicode_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":107
 *     tp = type(ob)
 *     if tp is unicode:
 *         return <unicode>ob             # <<<<<<<<<<<<<<
 *     elif tp == c_str_type:
 *         return c_object_to_unicode(ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_ob));
    __pyx_r = ((PyObject*)__pyx_v_ob);
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":108
 *     if tp is unicode:
 *         return <unicode>ob
 *     elif tp == c_str_type:             # <<<<<<<<<<<<<<
 *         return c_object_to_unicode(ob)
 *     elif ob is None:
 */
  __pyx_t_3 = PyObject_RichCompare(((PyObject *)__pyx_v_tp), __pyx_v_4axon_8_objects_c_str_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":109
 *         return <unicode>ob
 *     elif tp == c_str_type:
 *         return c_object_to_unicode(ob)             # <<<<<<<<<<<<<<
 *     elif ob is None:
 *         return c_object_to_unicode('')
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = c_object_to_unicode(__pyx_v_ob); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "axon/_objects.pxd":110
 *     elif tp == c_str_type:
 *         return c_object_to_unicode(ob)
 *     elif ob is None:             # <<<<<<<<<<<<<<
 *         return c_object_to_unicode('')
 *     else:
 */
  __pyx_t_2 = (__pyx_v_ob == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "axon/_objects.pxd":111
 *         return c_object_to_unicode(ob)
 *     elif ob is None:
 *         return c_object_to_unicode('')             # <<<<<<<<<<<<<<
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = c_object_to_unicode(__pyx_kp_s__10); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "axon/_objects.pxd":113
 *         return c_object_to_unicode('')
 *     else:
 *         raise TypeError('This object %r is not unicode compatible' % ob)             # <<<<<<<<<<<<<<
 * 
 * cdef inline unicode c_as_name(object name):
 */
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_This_object_r_is_not_unicode_com, __pyx_v_ob); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[3]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "axon/_objects.pxd":104
 *         return tuple(ob)
 * 
 * cdef inline unicode c_as_unicode(object ob):             # <<<<<<<<<<<<<<
 *     tp = type(ob)
 *     if tp is unicode:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("axon._objects.c_as_unicode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":115
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 * 
 * cdef inline unicode c_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_c_as_name(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_uname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_as_name", 0);

  /* "axon/_objects.pxd":116
 * 
 * cdef inline unicode c_as_name(object name):
 *     n = name_cache.get(name, None)             # <<<<<<<<<<<<<<
 *     if n is None:
 *         uname = c_as_unicode(name)
 */
  if (unlikely(__pyx_v_4axon_8_objects_name_cache == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[3]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_name_cache, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.pxd":117
 * cdef inline unicode c_as_name(object name):
 *     n = name_cache.get(name, None)
 *     if n is None:             # <<<<<<<<<<<<<<
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 */
  __pyx_t_2 = (__pyx_v_n == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.pxd":118
 *     n = name_cache.get(name, None)
 *     if n is None:
 *         uname = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *         name_cache[name] = uname
 *     elif name is None:
 */
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.pxd":119
 *     if n is None:
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname             # <<<<<<<<<<<<<<
 *     elif name is None:
 *         uname = empty_name
 */
    if (unlikely(__pyx_v_4axon_8_objects_name_cache == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[3]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(__pyx_v_4axon_8_objects_name_cache, __pyx_v_name, __pyx_v_uname) < 0)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":120
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 *     elif name is None:             # <<<<<<<<<<<<<<
 *         uname = empty_name
 *     else:
 */
  __pyx_t_3 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":121
 *         name_cache[name] = uname
 *     elif name is None:
 *         uname = empty_name             # <<<<<<<<<<<<<<
 *     else:
 *         uname = n
 */
    __Pyx_INCREF(__pyx_v_4axon_8_objects_empty_name);
    __pyx_v_uname = __pyx_v_4axon_8_objects_empty_name;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":123
 *         uname = empty_name
 *     else:
 *         uname = n             # <<<<<<<<<<<<<<
 *     return uname
 * 
 */
    __Pyx_INCREF(__pyx_v_n);
    __pyx_v_uname = __pyx_v_n;
  }
  __pyx_L3:;

  /* "axon/_objects.pxd":124
 *     else:
 *         uname = n
 *     return uname             # <<<<<<<<<<<<<<
 * 
 * cdef inline object py_as_name(object name):
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_uname))||((__pyx_v_uname) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_uname)->tp_name), 0))) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_uname);
  __pyx_r = ((PyObject*)__pyx_v_uname);
  goto __pyx_L0;

  /* "axon/_objects.pxd":115
 *         raise TypeError('This object %r is not unicode compatible' % ob)
 * 
 * cdef inline unicode c_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_uname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":126
 *     return uname
 * 
 * cdef inline object py_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_4axon_8_objects_py_as_name(PyObject *__pyx_v_name) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_uname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_as_name", 0);

  /* "axon/_objects.pxd":127
 * 
 * cdef inline object py_as_name(object name):
 *     n = name_cache.get(name, None)             # <<<<<<<<<<<<<<
 *     if n is None:
 *         uname = c_as_unicode(name)
 */
  if (unlikely(__pyx_v_4axon_8_objects_name_cache == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[3]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_name_cache, __pyx_v_name, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "axon/_objects.pxd":128
 * cdef inline object py_as_name(object name):
 *     n = name_cache.get(name, None)
 *     if n is None:             # <<<<<<<<<<<<<<
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 */
  __pyx_t_2 = (__pyx_v_n == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "axon/_objects.pxd":129
 *     n = name_cache.get(name, None)
 *     if n is None:
 *         uname = c_as_unicode(name)             # <<<<<<<<<<<<<<
 *         name_cache[name] = uname
 *     elif name is None:
 */
    __pyx_t_1 = __pyx_f_4axon_8_objects_c_as_unicode(__pyx_v_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "axon/_objects.pxd":130
 *     if n is None:
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname             # <<<<<<<<<<<<<<
 *     elif name is None:
 *         uname = empty_name
 */
    if (unlikely(__pyx_v_4axon_8_objects_name_cache == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[3]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (unlikely(PyDict_SetItem(__pyx_v_4axon_8_objects_name_cache, __pyx_v_name, __pyx_v_uname) < 0)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "axon/_objects.pxd":131
 *         uname = c_as_unicode(name)
 *         name_cache[name] = uname
 *     elif name is None:             # <<<<<<<<<<<<<<
 *         uname = empty_name
 *     else:
 */
  __pyx_t_3 = (__pyx_v_name == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "axon/_objects.pxd":132
 *         name_cache[name] = uname
 *     elif name is None:
 *         uname = empty_name             # <<<<<<<<<<<<<<
 *     else:
 *         uname = n
 */
    __Pyx_INCREF(__pyx_v_4axon_8_objects_empty_name);
    __pyx_v_uname = __pyx_v_4axon_8_objects_empty_name;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "axon/_objects.pxd":134
 *         uname = empty_name
 *     else:
 *         uname = n             # <<<<<<<<<<<<<<
 *     return uname
 * 
 */
    __Pyx_INCREF(__pyx_v_n);
    __pyx_v_uname = __pyx_v_n;
  }
  __pyx_L3:;

  /* "axon/_objects.pxd":135
 *     else:
 *         uname = n
 *     return uname             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_uname);
  __pyx_r = __pyx_v_uname;
  goto __pyx_L0;

  /* "axon/_objects.pxd":126
 *     return uname
 * 
 * cdef inline object py_as_name(object name):             # <<<<<<<<<<<<<<
 *     n = name_cache.get(name, None)
 *     if n is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.py_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_uname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "axon/_objects.pxd":351
 * cdef dict c_builder_dict
 * 
 * cdef inline Builder c_get_builder(object mode):             # <<<<<<<<<<<<<<
 *     return <Builder>c_builder_dict.get(mode, None)
 * 
 */

static CYTHON_INLINE struct __pyx_obj_4axon_8_objects_Builder *__pyx_f_4axon_8_objects_c_get_builder(PyObject *__pyx_v_mode) {
  struct __pyx_obj_4axon_8_objects_Builder *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_get_builder", 0);

  /* "axon/_objects.pxd":352
 * 
 * cdef inline Builder c_get_builder(object mode):
 *     return <Builder>c_builder_dict.get(mode, None)             # <<<<<<<<<<<<<<
 * 
 * cpdef Builder get_builder(object)
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_4axon_8_objects_c_builder_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    {__pyx_filename = __pyx_f[3]; __pyx_lineno = 352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_4axon_8_objects_c_builder_dict, __pyx_v_mode, Py_None); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)((struct __pyx_obj_4axon_8_objects_Builder *)__pyx_t_1)));
  __pyx_r = ((struct __pyx_obj_4axon_8_objects_Builder *)__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "axon/_objects.pxd":351
 * cdef dict c_builder_dict
 * 
 * cdef inline Builder c_get_builder(object mode):             # <<<<<<<<<<<<<<
 *     return <Builder>c_builder_dict.get(mode, None)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("axon._objects.c_get_builder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_4axon_7_dumper_PyInt(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_PyInt(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_4axon_7_dumper_PyInt[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper_PyInt = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.PyInt"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper_PyInt), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_PyInt, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_4axon_7_dumper_5PyInt_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper_PyInt, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_dumper_5PyInt_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_PyInt, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_4axon_7_dumper_PyPointer(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_PyPointer(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyTypeObject __pyx_type_4axon_7_dumper_PyPointer = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.PyPointer"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper_PyPointer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_PyPointer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_PyPointer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumper __pyx_vtable_4axon_7_dumper_SimpleDumper;

static PyObject *__pyx_tp_new_4axon_7_dumper_SimpleDumper(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4axon_7_dumper_SimpleDumper *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_4axon_7_dumper_SimpleDumper *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_7_dumper_SimpleDumper;
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_SimpleDumper(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_4axon_7_dumper_SimpleDumper[] = {
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_4axon_7_dumper_SimpleDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.SimpleDumper"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper_SimpleDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_SimpleDumper, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_4axon_7_dumper_12SimpleDumper_1__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper_SimpleDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_SimpleDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_7_dumper_SimpleDumpers __pyx_vtable_4axon_7_dumper_SimpleDumpers;

static PyObject *__pyx_tp_new_4axon_7_dumper_SimpleDumpers(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct SimpleDumpers *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct SimpleDumpers *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_7_dumper_SimpleDumpers;
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_SimpleDumpers(PyObject *o) {
  struct SimpleDumpers *p = (struct SimpleDumpers *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->mapping);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_7_dumper_SimpleDumpers(PyObject *o, visitproc v, void *a) {
  int e;
  struct SimpleDumpers *p = (struct SimpleDumpers *)o;
  if (p->mapping) {
    e = (*v)(p->mapping, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper_SimpleDumpers(PyObject *o) {
  PyObject* tmp;
  struct SimpleDumpers *p = (struct SimpleDumpers *)o;
  tmp = ((PyObject*)p->mapping);
  p->mapping = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_4axon_7_dumper_13SimpleDumpers_mapping(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_1__get__(o);
}

static int __pyx_setprop_4axon_7_dumper_13SimpleDumpers_mapping(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_3__set__(o, v);
  }
  else {
    return __pyx_pw_4axon_7_dumper_13SimpleDumpers_7mapping_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_4axon_7_dumper_SimpleDumpers[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4axon_7_dumper_SimpleDumpers[] = {
  {(char *)"mapping", __pyx_getprop_4axon_7_dumper_13SimpleDumpers_mapping, __pyx_setprop_4axon_7_dumper_13SimpleDumpers_mapping, 0, 0},
  {0, 0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) SimpleDumpersType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.SimpleDumpers"), /*tp_name*/
  sizeof(struct SimpleDumpers), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_SimpleDumpers, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper_SimpleDumpers, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper_SimpleDumpers, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper_SimpleDumpers, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4axon_7_dumper_SimpleDumpers, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_dumper_13SimpleDumpers_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_SimpleDumpers, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_4axon_7_dumper_Dumper __pyx_vtable_4axon_7_dumper_Dumper;

static PyObject *__pyx_tp_new_4axon_7_dumper_Dumper(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct Dumper *p;
  PyObject *o;
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct Dumper *)o);
  p->__pyx_vtab = __pyx_vtabptr_4axon_7_dumper_Dumper;
  p->c_simple_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->c_type_reducers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->fd = Py_None; Py_INCREF(Py_None);
  p->sfd = ((struct __pyx_obj_4axon_8_objects_StringWriter *)Py_None); Py_INCREF(Py_None);
  p->sdumper = ((struct __pyx_obj_4axon_7_dumper_SimpleDumper *)Py_None); Py_INCREF(Py_None);
  p->crossref_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->crossref_set = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->crossref_set2 = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper_Dumper(PyObject *o) {
  struct Dumper *p = (struct Dumper *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->c_simple_dumpers);
  Py_CLEAR(p->c_type_reducers);
  Py_CLEAR(p->fd);
  Py_CLEAR(p->sfd);
  Py_CLEAR(p->sdumper);
  Py_CLEAR(p->crossref_dict);
  Py_CLEAR(p->crossref_set);
  Py_CLEAR(p->crossref_set2);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_4axon_7_dumper_Dumper(PyObject *o, visitproc v, void *a) {
  int e;
  struct Dumper *p = (struct Dumper *)o;
  if (p->c_simple_dumpers) {
    e = (*v)(p->c_simple_dumpers, a); if (e) return e;
  }
  if (p->c_type_reducers) {
    e = (*v)(p->c_type_reducers, a); if (e) return e;
  }
  if (p->fd) {
    e = (*v)(p->fd, a); if (e) return e;
  }
  if (p->sfd) {
    e = (*v)(((PyObject*)p->sfd), a); if (e) return e;
  }
  if (p->sdumper) {
    e = (*v)(((PyObject*)p->sdumper), a); if (e) return e;
  }
  if (p->crossref_dict) {
    e = (*v)(p->crossref_dict, a); if (e) return e;
  }
  if (p->crossref_set) {
    e = (*v)(p->crossref_set, a); if (e) return e;
  }
  if (p->crossref_set2) {
    e = (*v)(p->crossref_set2, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper_Dumper(PyObject *o) {
  PyObject* tmp;
  struct Dumper *p = (struct Dumper *)o;
  tmp = ((PyObject*)p->c_simple_dumpers);
  p->c_simple_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->c_type_reducers);
  p->c_type_reducers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->fd);
  p->fd = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sfd);
  p->sfd = ((struct __pyx_obj_4axon_8_objects_StringWriter *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->sdumper);
  p->sdumper = ((struct __pyx_obj_4axon_7_dumper_SimpleDumper *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->crossref_dict);
  p->crossref_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->crossref_set);
  p->crossref_set = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->crossref_set2);
  p->crossref_set2 = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4axon_7_dumper_Dumper[] = {
  {__Pyx_NAMESTR("_dump_set_sequence"), (PyCFunction)__pyx_pw_4axon_7_dumper_6Dumper_3_dump_set_sequence, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("pretty_dump_tuple"), (PyCFunction)__pyx_pw_4axon_7_dumper_6Dumper_5pretty_dump_tuple, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("dump"), (PyCFunction)__pyx_pw_4axon_7_dumper_6Dumper_7dump, METH_O, __Pyx_DOCSTR(__pyx_doc_4axon_7_dumper_6Dumper_6dump)},
  {0, 0, 0, 0}
};

DL_EXPORT(PyTypeObject) DumperType = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.Dumper"), /*tp_name*/
  sizeof(struct Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper_Dumper, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    Dumper class\n    "), /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper_Dumper, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper_Dumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4axon_7_dumper_Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_4axon_7_dumper_6Dumper_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper_Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *__pyx_freelist_4axon_7_dumper___pyx_scope_struct__reduce[8];
static int __pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce = 0;

static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct__reduce(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_dumper___pyx_scope_struct__reduce[--__pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct__reduce(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_type_);
  if ((__pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce))) {
    __pyx_freelist_4axon_7_dumper___pyx_scope_struct__reduce[__pyx_freecount_4axon_7_dumper___pyx_scope_struct__reduce++] = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct__reduce(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o;
  if (p->__pyx_v_type_) {
    e = (*v)(p->__pyx_v_type_, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct__reduce(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce *)o;
  tmp = ((PyObject*)p->__pyx_v_type_);
  p->__pyx_v_type_ = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_4axon_7_dumper___pyx_scope_struct__reduce = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.__pyx_scope_struct__reduce"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct__reduce), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper___pyx_scope_struct__reduce, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *__pyx_freelist_4axon_7_dumper___pyx_scope_struct_1_dump_as_str[8];
static int __pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str = 0;

static PyObject *__pyx_tp_new_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str)))) {
    o = (PyObject*)__pyx_freelist_4axon_7_dumper___pyx_scope_struct_1_dump_as_str[--__pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str];
    memset(o, 0, sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyObject *o) {
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_tp);
  if ((__pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str))) {
    __pyx_freelist_4axon_7_dumper___pyx_scope_struct_1_dump_as_str[__pyx_freecount_4axon_7_dumper___pyx_scope_struct_1_dump_as_str++] = ((struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o;
  if (p->__pyx_v_tp) {
    e = (*v)(p->__pyx_v_tp, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_1_dump_as_str(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *p = (struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str *)o;
  tmp = ((PyObject*)p->__pyx_v_tp);
  p->__pyx_v_tp = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_4axon_7_dumper___pyx_scope_struct_1_dump_as_str = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("axon._dumper.__pyx_scope_struct_1_dump_as_str"), /*tp_name*/
  sizeof(struct __pyx_obj_4axon_7_dumper___pyx_scope_struct_1_dump_as_str), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_traverse*/
  __pyx_tp_clear_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4axon_7_dumper___pyx_scope_struct_1_dump_as_str, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {__Pyx_NAMESTR("mapping_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_1mapping_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("element_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_3element_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("sequence_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_5sequence_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("instance_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_7instance_reduce, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("empty_reduce"), (PyCFunction)__pyx_pw_4axon_7_dumper_9empty_reduce, METH_O, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    __Pyx_NAMESTR("_dumper"),
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_0, __pyx_k_0, sizeof(__pyx_k_0), 0, 1, 0, 0},
  {&__pyx_kp_u_02d_02d, __pyx_k_02d_02d, sizeof(__pyx_k_02d_02d), 0, 1, 0, 0},
  {&__pyx_kp_u_02d_02d_02d, __pyx_k_02d_02d_02d, sizeof(__pyx_k_02d_02d_02d), 0, 1, 0, 0},
  {&__pyx_kp_u_02d_02d_02d_06d, __pyx_k_02d_02d_02d_06d, sizeof(__pyx_k_02d_02d_02d_06d), 0, 1, 0, 0},
  {&__pyx_kp_u_0_2, __pyx_k_0_2, sizeof(__pyx_k_0_2), 0, 1, 0, 0},
  {&__pyx_n_u_D, __pyx_k_D, sizeof(__pyx_k_D), 0, 1, 0, 1},
  {&__pyx_kp_u_Empty_name, __pyx_k_Empty_name, sizeof(__pyx_k_Empty_name), 0, 1, 0, 0},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_kp_u_There_is_no_reducer_for_this_typ, __pyx_k_There_is_no_reducer_for_this_typ, sizeof(__pyx_k_There_is_no_reducer_for_this_typ), 0, 1, 0, 0},
  {&__pyx_kp_u_There_is_no_reducer_for_this_typ_2, __pyx_k_There_is_no_reducer_for_this_typ_2, sizeof(__pyx_k_There_is_no_reducer_for_this_typ_2), 0, 1, 0, 0},
  {&__pyx_kp_s_This_object_r_is_not_unicode_com, __pyx_k_This_object_r_is_not_unicode_com, sizeof(__pyx_k_This_object_r_is_not_unicode_com), 0, 0, 1, 0},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_k_Users_sz_repos_pyaxon_lib_axon, sizeof(__pyx_k_Users_sz_repos_pyaxon_lib_axon), 0, 0, 1, 0},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_kp_s__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 0, 1, 0},
  {&__pyx_kp_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 0},
  {&__pyx_kp_u__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 1, 0, 0},
  {&__pyx_kp_u__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 1, 0, 0},
  {&__pyx_kp_u__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 1, 0, 0},
  {&__pyx_kp_u__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 1, 0, 0},
  {&__pyx_kp_u__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 1, 0, 0},
  {&__pyx_kp_u__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 1, 0, 0},
  {&__pyx_kp_u__21, __pyx_k__21, sizeof(__pyx_k__21), 0, 1, 0, 0},
  {&__pyx_kp_u__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 1, 0, 0},
  {&__pyx_n_s__23, __pyx_k__23, sizeof(__pyx_k__23), 0, 0, 1, 1},
  {&__pyx_kp_u__23, __pyx_k__23, sizeof(__pyx_k__23), 0, 1, 0, 0},
  {&__pyx_kp_u__24, __pyx_k__24, sizeof(__pyx_k__24), 0, 1, 0, 0},
  {&__pyx_kp_u__25, __pyx_k__25, sizeof(__pyx_k__25), 0, 1, 0, 0},
  {&__pyx_kp_u__26, __pyx_k__26, sizeof(__pyx_k__26), 0, 1, 0, 0},
  {&__pyx_kp_u__27, __pyx_k__27, sizeof(__pyx_k__27), 0, 1, 0, 0},
  {&__pyx_kp_u__28, __pyx_k__28, sizeof(__pyx_k__28), 0, 1, 0, 0},
  {&__pyx_kp_u__29, __pyx_k__29, sizeof(__pyx_k__29), 0, 1, 0, 0},
  {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
  {&__pyx_kp_u__30, __pyx_k__30, sizeof(__pyx_k__30), 0, 1, 0, 0},
  {&__pyx_kp_u__31, __pyx_k__31, sizeof(__pyx_k__31), 0, 1, 0, 0},
  {&__pyx_kp_u__32, __pyx_k__32, sizeof(__pyx_k__32), 0, 1, 0, 0},
  {&__pyx_kp_u__33, __pyx_k__33, sizeof(__pyx_k__33), 0, 1, 0, 0},
  {&__pyx_kp_u__34, __pyx_k__34, sizeof(__pyx_k__34), 0, 1, 0, 0},
  {&__pyx_kp_u__35, __pyx_k__35, sizeof(__pyx_k__35), 0, 1, 0, 0},
  {&__pyx_kp_u__36, __pyx_k__36, sizeof(__pyx_k__36), 0, 1, 0, 0},
  {&__pyx_kp_u__37, __pyx_k__37, sizeof(__pyx_k__37), 0, 1, 0, 0},
  {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
  {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
  {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
  {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
  {&__pyx_kp_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 0},
  {&__pyx_kp_u__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 1, 0, 0},
  {&__pyx_n_s_axon__dumper, __pyx_k_axon__dumper, sizeof(__pyx_k_axon__dumper), 0, 0, 1, 1},
  {&__pyx_n_s_axon_types, __pyx_k_axon_types, sizeof(__pyx_k_axon_types), 0, 0, 1, 1},
  {&__pyx_n_s_base64, __pyx_k_base64, sizeof(__pyx_k_base64), 0, 0, 1, 1},
  {&__pyx_n_s_bool_type, __pyx_k_bool_type, sizeof(__pyx_k_bool_type), 0, 0, 1, 1},
  {&__pyx_n_s_braces, __pyx_k_braces, sizeof(__pyx_k_braces), 0, 0, 1, 1},
  {&__pyx_n_s_builtins, __pyx_k_builtins, sizeof(__pyx_k_builtins), 0, 0, 1, 1},
  {&__pyx_n_s_bytearray_type, __pyx_k_bytearray_type, sizeof(__pyx_k_bytearray_type), 0, 0, 1, 1},
  {&__pyx_n_s_bytes_type, __pyx_k_bytes_type, sizeof(__pyx_k_bytes_type), 0, 0, 1, 1},
  {&__pyx_n_s_c_all_names, __pyx_k_c_all_names, sizeof(__pyx_k_c_all_names), 0, 0, 1, 1},
  {&__pyx_n_s_c_factory_dict, __pyx_k_c_factory_dict, sizeof(__pyx_k_c_factory_dict), 0, 0, 1, 1},
  {&__pyx_n_s_c_reduce_dict, __pyx_k_c_reduce_dict, sizeof(__pyx_k_c_reduce_dict), 0, 0, 1, 1},
  {&__pyx_n_s_c_simple_dumpers, __pyx_k_c_simple_dumpers, sizeof(__pyx_k_c_simple_dumpers), 0, 0, 1, 1},
  {&__pyx_n_s_c_type_reducers, __pyx_k_c_type_reducers, sizeof(__pyx_k_c_type_reducers), 0, 0, 1, 1},
  {&__pyx_n_s_cdecimal, __pyx_k_cdecimal, sizeof(__pyx_k_cdecimal), 0, 0, 1, 1},
  {&__pyx_n_s_crossref, __pyx_k_crossref, sizeof(__pyx_k_crossref), 0, 0, 1, 1},
  {&__pyx_kp_u_d_02d_02d, __pyx_k_d_02d_02d, sizeof(__pyx_k_d_02d_02d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_02d_02dT_02d_02d, __pyx_k_d_02d_02dT_02d_02d, sizeof(__pyx_k_d_02d_02dT_02d_02d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_02d_02dT_02d_02d_02d, __pyx_k_d_02d_02dT_02d_02d_02d, sizeof(__pyx_k_d_02d_02dT_02d_02d_02d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_02d_02dT_02d_02d_02d_06d, __pyx_k_d_02d_02dT_02d_02d_02d_06d, sizeof(__pyx_k_d_02d_02dT_02d_02d_02d_06d), 0, 1, 0, 0},
  {&__pyx_n_s_date_type, __pyx_k_date_type, sizeof(__pyx_k_date_type), 0, 0, 1, 1},
  {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
  {&__pyx_n_s_datetime_type, __pyx_k_datetime_type, sizeof(__pyx_k_datetime_type), 0, 0, 1, 1},
  {&__pyx_n_s_day, __pyx_k_day, sizeof(__pyx_k_day), 0, 0, 1, 1},
  {&__pyx_n_s_days, __pyx_k_days, sizeof(__pyx_k_days), 0, 0, 1, 1},
  {&__pyx_n_s_decimal, __pyx_k_decimal, sizeof(__pyx_k_decimal), 0, 0, 1, 1},
  {&__pyx_n_s_decimal2str, __pyx_k_decimal2str, sizeof(__pyx_k_decimal2str), 0, 0, 1, 1},
  {&__pyx_n_s_decimal_2, __pyx_k_decimal_2, sizeof(__pyx_k_decimal_2), 0, 0, 1, 1},
  {&__pyx_n_s_decimal_type, __pyx_k_decimal_type, sizeof(__pyx_k_decimal_type), 0, 0, 1, 1},
  {&__pyx_n_s_decodebytes, __pyx_k_decodebytes, sizeof(__pyx_k_decodebytes), 0, 0, 1, 1},
  {&__pyx_n_s_decodestring, __pyx_k_decodestring, sizeof(__pyx_k_decodestring), 0, 0, 1, 1},
  {&__pyx_n_s_default_decimal_context, __pyx_k_default_decimal_context, sizeof(__pyx_k_default_decimal_context), 0, 0, 1, 1},
  {&__pyx_n_s_divmod, __pyx_k_divmod, sizeof(__pyx_k_divmod), 0, 0, 1, 1},
  {&__pyx_n_s_dump_as_str, __pyx_k_dump_as_str, sizeof(__pyx_k_dump_as_str), 0, 0, 1, 1},
  {&__pyx_n_s_dump_as_str_2, __pyx_k_dump_as_str_2, sizeof(__pyx_k_dump_as_str_2), 0, 0, 1, 1},
  {&__pyx_n_s_dump_as_str_locals__dump_as_str, __pyx_k_dump_as_str_locals__dump_as_str, sizeof(__pyx_k_dump_as_str_locals__dump_as_str), 0, 0, 1, 1},
  {&__pyx_n_s_dump_undef, __pyx_k_dump_undef, sizeof(__pyx_k_dump_undef), 0, 0, 1, 1},
  {&__pyx_n_s_element_reduce, __pyx_k_element_reduce, sizeof(__pyx_k_element_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_empty_reduce, __pyx_k_empty_reduce, sizeof(__pyx_k_empty_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_encodebytes, __pyx_k_encodebytes, sizeof(__pyx_k_encodebytes), 0, 0, 1, 1},
  {&__pyx_n_s_encodestring, __pyx_k_encodestring, sizeof(__pyx_k_encodestring), 0, 0, 1, 1},
  {&__pyx_n_s_factory, __pyx_k_factory, sizeof(__pyx_k_factory), 0, 0, 1, 1},
  {&__pyx_n_s_factory_func, __pyx_k_factory_func, sizeof(__pyx_k_factory_func), 0, 0, 1, 1},
  {&__pyx_n_u_false, __pyx_k_false, sizeof(__pyx_k_false), 0, 1, 0, 1},
  {&__pyx_n_s_fd, __pyx_k_fd, sizeof(__pyx_k_fd), 0, 0, 1, 1},
  {&__pyx_n_s_float_type, __pyx_k_float_type, sizeof(__pyx_k_float_type), 0, 0, 1, 1},
  {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_getcontext, __pyx_k_getcontext, sizeof(__pyx_k_getcontext), 0, 0, 1, 1},
  {&__pyx_n_s_hour, __pyx_k_hour, sizeof(__pyx_k_hour), 0, 0, 1, 1},
  {&__pyx_n_s_hsize, __pyx_k_hsize, sizeof(__pyx_k_hsize), 0, 0, 1, 1},
  {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_instance_reduce, __pyx_k_instance_reduce, sizeof(__pyx_k_instance_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_int_type, __pyx_k_int_type, sizeof(__pyx_k_int_type), 0, 0, 1, 1},
  {&__pyx_n_s_is_finite, __pyx_k_is_finite, sizeof(__pyx_k_is_finite), 0, 0, 1, 1},
  {&__pyx_n_s_is_infinite, __pyx_k_is_infinite, sizeof(__pyx_k_is_infinite), 0, 0, 1, 1},
  {&__pyx_n_s_is_nan, __pyx_k_is_nan, sizeof(__pyx_k_is_nan), 0, 0, 1, 1},
  {&__pyx_n_s_is_signed, __pyx_k_is_signed, sizeof(__pyx_k_is_signed), 0, 0, 1, 1},
  {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {&__pyx_n_s_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 0, 1, 1},
  {&__pyx_n_s_long_type, __pyx_k_long_type, sizeof(__pyx_k_long_type), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_mapping_reduce, __pyx_k_mapping_reduce, sizeof(__pyx_k_mapping_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_microsecond, __pyx_k_microsecond, sizeof(__pyx_k_microsecond), 0, 0, 1, 1},
  {&__pyx_n_s_minute, __pyx_k_minute, sizeof(__pyx_k_minute), 0, 0, 1, 1},
  {&__pyx_n_s_month, __pyx_k_month, sizeof(__pyx_k_month), 0, 0, 1, 1},
  {&__pyx_n_s_none_type, __pyx_k_none_type, sizeof(__pyx_k_none_type), 0, 0, 1, 1},
  {&__pyx_n_u_null, __pyx_k_null, sizeof(__pyx_k_null), 0, 1, 0, 1},
  {&__pyx_n_s_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 0, 1, 1},
  {&__pyx_n_s_pretty, __pyx_k_pretty, sizeof(__pyx_k_pretty), 0, 0, 1, 1},
  {&__pyx_n_s_pretty_dump_tuple, __pyx_k_pretty_dump_tuple, sizeof(__pyx_k_pretty_dump_tuple), 0, 0, 1, 1},
  {&__pyx_n_s_ptr, __pyx_k_ptr, sizeof(__pyx_k_ptr), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_capi, __pyx_k_pyx_capi, sizeof(__pyx_k_pyx_capi), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_dict, __pyx_k_reduce_dict, sizeof(__pyx_k_reduce_dict), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_func, __pyx_k_reduce_func, sizeof(__pyx_k_reduce_func), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_locals__factory, __pyx_k_reduce_locals__factory, sizeof(__pyx_k_reduce_locals__factory), 0, 0, 1, 1},
  {&__pyx_n_s_remove, __pyx_k_remove, sizeof(__pyx_k_remove), 0, 0, 1, 1},
  {&__pyx_n_s_reset_reduce, __pyx_k_reset_reduce, sizeof(__pyx_k_reset_reduce), 0, 0, 1, 1},
  {&__pyx_kp_u_s_02d, __pyx_k_s_02d, sizeof(__pyx_k_s_02d), 0, 1, 0, 0},
  {&__pyx_kp_u_s_02d_02d, __pyx_k_s_02d_02d, sizeof(__pyx_k_s_02d_02d), 0, 1, 0, 0},
  {&__pyx_n_s_second, __pyx_k_second, sizeof(__pyx_k_second), 0, 0, 1, 1},
  {&__pyx_n_s_seconds, __pyx_k_seconds, sizeof(__pyx_k_seconds), 0, 0, 1, 1},
  {&__pyx_n_s_sequence_reduce, __pyx_k_sequence_reduce, sizeof(__pyx_k_sequence_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_simple_dumper, __pyx_k_simple_dumper, sizeof(__pyx_k_simple_dumper), 0, 0, 1, 1},
  {&__pyx_n_s_simple_types, __pyx_k_simple_types, sizeof(__pyx_k_simple_types), 0, 0, 1, 1},
  {&__pyx_n_s_simple_types_2, __pyx_k_simple_types_2, sizeof(__pyx_k_simple_types_2), 0, 0, 1, 1},
  {&__pyx_n_s_sorted, __pyx_k_sorted, sizeof(__pyx_k_sorted), 0, 0, 1, 1},
  {&__pyx_n_s_str_type, __pyx_k_str_type, sizeof(__pyx_k_str_type), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_time_type, __pyx_k_time_type, sizeof(__pyx_k_time_type), 0, 0, 1, 1},
  {&__pyx_n_s_to_eng_string, __pyx_k_to_eng_string, sizeof(__pyx_k_to_eng_string), 0, 0, 1, 1},
  {&__pyx_n_s_tp, __pyx_k_tp, sizeof(__pyx_k_tp), 0, 0, 1, 1},
  {&__pyx_n_u_true, __pyx_k_true, sizeof(__pyx_k_true), 0, 1, 0, 1},
  {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
  {&__pyx_n_s_types, __pyx_k_types, sizeof(__pyx_k_types), 0, 0, 1, 1},
  {&__pyx_n_s_tzinfo, __pyx_k_tzinfo, sizeof(__pyx_k_tzinfo), 0, 0, 1, 1},
  {&__pyx_n_s_unicode_type, __pyx_k_unicode_type, sizeof(__pyx_k_unicode_type), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_use_offset, __pyx_k_use_offset, sizeof(__pyx_k_use_offset), 0, 0, 1, 1},
  {&__pyx_n_s_utcoffset, __pyx_k_utcoffset, sizeof(__pyx_k_utcoffset), 0, 0, 1, 1},
  {&__pyx_n_s_val, __pyx_k_val, sizeof(__pyx_k_val), 0, 0, 1, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {&__pyx_n_s_w, __pyx_k_w, sizeof(__pyx_k_w), 0, 0, 1, 1},
  {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
  {&__pyx_n_s_year, __pyx_k_year, sizeof(__pyx_k_year), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 644; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_sorted = __Pyx_GetBuiltinName(__pyx_n_s_sorted); if (!__pyx_builtin_sorted) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "axon/_dumper.py":152
 * def reduce(type_, reduce_func = None):
 *     if reduce_func is None:
 *         def _factory(factory_func):             # <<<<<<<<<<<<<<
 *             c_reduce_dict[type_] = factory_func
 *             return factory_func
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_n_s_factory_func); if (unlikely(!__pyx_tuple_)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);
  __pyx_codeobj__2 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple_, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_factory, 152, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":350
 * 
 *     def _dump_tzinfo(self, o):
 *         offset = o.utcoffset(None)             # <<<<<<<<<<<<<<
 *         seconds = offset.seconds + offset.days * 86400 # 24 * 60 * 60
 * 
 */
  __pyx_tuple__12 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 350; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "axon/_dumper.py":420
 * def dump_as_str(tp=None):
 *     if tp is None:
 *         def _dump_as_str(func):             # <<<<<<<<<<<<<<
 *             c_simple_dumpers[tp] = func
 *             return func
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_n_s_func); if (unlikely(!__pyx_tuple__15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_dump_as_str, 420, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":441
 *     n = len(name)
 *     if n == 0:
 *         raise ValueError('Empty name')             # <<<<<<<<<<<<<<
 * 
 *     ch = name[pos]
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_Empty_name); if (unlikely(!__pyx_tuple__17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "axon/_dumper.py":1205
 *         count = self.crossref_dict.get(ref_o, None)
 *         if count is None:
 *             count = PyInt(1)             # <<<<<<<<<<<<<<
 *             self.crossref_dict[ref_o] = count
 *         else:
 */
  __pyx_tuple__38 = PyTuple_Pack(1, __pyx_int_1); if (unlikely(!__pyx_tuple__38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "axon/_dumper.py":143
 * c_reduce_dict = _c_type_reducers.copy()
 * 
 * def reset_reduce():             # <<<<<<<<<<<<<<
 *     c_reduce_dict = _c_type_reducers.copy()
 * 
 */
  __pyx_tuple__39 = PyTuple_Pack(1, __pyx_n_s_c_reduce_dict); if (unlikely(!__pyx_tuple__39)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);
  __pyx_codeobj__40 = (PyObject*)__Pyx_PyCode_New(0, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__39, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_reset_reduce, 143, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__40)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":150
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */
  __pyx_tuple__41 = PyTuple_Pack(4, __pyx_n_s_type, __pyx_n_s_reduce_func, __pyx_n_s_factory, __pyx_n_s_factory); if (unlikely(!__pyx_tuple__41)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);
  __pyx_codeobj__42 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__41, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_reduce, 150, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__42)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_tuple__43 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__43)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "axon/_dumper.py":177
 *     return pyptr
 * 
 * def _dump_undef(o):             # <<<<<<<<<<<<<<
 *     return '??'
 * 
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_n_s_o); if (unlikely(!__pyx_tuple__44)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__44, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_dump_undef, 177, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":418
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */
  __pyx_tuple__46 = PyTuple_Pack(3, __pyx_n_s_tp, __pyx_n_s_dump_as_str, __pyx_n_s_dump_as_str); if (unlikely(!__pyx_tuple__46)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__46, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_sz_repos_pyaxon_lib_axon, __pyx_n_s_dump_as_str_2, 418, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_tuple__48 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__48)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_60 = PyInt_FromLong(60); if (unlikely(!__pyx_int_60)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_86400 = PyInt_FromLong(86400L); if (unlikely(!__pyx_int_86400)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_dumper(void); /*proto*/
PyMODINIT_FUNC init_dumper(void)
#else
PyMODINIT_FUNC PyInit__dumper(void); /*proto*/
PyMODINIT_FUNC PyInit__dumper(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__dumper(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("_dumper"), __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_axon___dumper) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "axon._dumper")) {
      if (unlikely(PyDict_SetItemString(modules, "axon._dumper", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  __pyx_v_4axon_7_dumper_unicode_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_str_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_int_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_long_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_decimal_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_bool_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_float_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_bytes_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_bytearray_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_none_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_date_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_time_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_datetime_type = Py_None; Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_simple_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  c_reduce_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_c_all_names = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__c_type_reducers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_c_factory_dict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__simple_dumper = ((struct __pyx_obj_4axon_7_dumper_SimpleDumper *)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper_c_simple_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_4axon_7_dumper__simple_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  /*--- Variable export code ---*/
  if (__Pyx_ExportVoidPtr(__pyx_n_s_unicode_type, (void *)&__pyx_v_4axon_7_dumper_unicode_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_str_type, (void *)&__pyx_v_4axon_7_dumper_str_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_int_type, (void *)&__pyx_v_4axon_7_dumper_int_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_long_type, (void *)&__pyx_v_4axon_7_dumper_long_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_decimal_type, (void *)&__pyx_v_4axon_7_dumper_decimal_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_bool_type, (void *)&__pyx_v_4axon_7_dumper_bool_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_float_type, (void *)&__pyx_v_4axon_7_dumper_float_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_bytes_type, (void *)&__pyx_v_4axon_7_dumper_bytes_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_bytearray_type, (void *)&__pyx_v_4axon_7_dumper_bytearray_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_none_type, (void *)&__pyx_v_4axon_7_dumper_none_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_date_type, (void *)&__pyx_v_4axon_7_dumper_date_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_time_type, (void *)&__pyx_v_4axon_7_dumper_time_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_datetime_type, (void *)&__pyx_v_4axon_7_dumper_datetime_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_simple_types, (void *)&__pyx_v_4axon_7_dumper_simple_types, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_reduce_dict, (void *)&c_reduce_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_all_names, (void *)&__pyx_v_4axon_7_dumper_c_all_names, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_type_reducers, (void *)&__pyx_v_4axon_7_dumper__c_type_reducers, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_factory_dict, (void *)&__pyx_v_4axon_7_dumper_c_factory_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_simple_dumper, (void *)&__pyx_v_4axon_7_dumper__simple_dumper, "struct __pyx_obj_4axon_7_dumper_SimpleDumper *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_c_simple_dumpers, (void *)&__pyx_v_4axon_7_dumper_c_simple_dumpers, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportVoidPtr(__pyx_n_s_simple_types_2, (void *)&__pyx_v_4axon_7_dumper__simple_types, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("mapping_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_mapping_reduce, "PyObject *(struct MappingObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("element_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_element_reduce, "PyObject *(struct ElementObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("sequence_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_sequence_reduce, "PyObject *(struct SequenceObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("instance_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_instance_reduce, "PyObject *(struct InstanceObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("empty_reduce", (void (*)(void))__pyx_f_4axon_7_dumper_empty_reduce, "PyObject *(struct EmptyObject *, int __pyx_skip_dispatch)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("c_new_pyptr", (void (*)(void))__pyx_f_4axon_7_dumper_c_new_pyptr, "struct __pyx_obj_4axon_7_dumper_PyPointer *(PyObject *(*)(PyObject *))") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("dump_default", (void (*)(void))__pyx_f_4axon_7_dumper_dump_default, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_name", (void (*)(void))__pyx_f_4axon_7_dumper__dump_name, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("_dump_key", (void (*)(void))__pyx_f_4axon_7_dumper__dump_key, "PyObject *(PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ExportFunction("is_simple_type", (void (*)(void))__pyx_f_4axon_7_dumper_is_simple_type, "int (struct Dumper *, PyObject *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_4axon_7_dumper_PyInt) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_7_dumper_PyInt.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "PyInt", (PyObject *)&__pyx_type_4axon_7_dumper_PyInt) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_PyInt = &__pyx_type_4axon_7_dumper_PyInt;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper_PyPointer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_7_dumper_PyPointer.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "PyPointer", (PyObject *)&__pyx_type_4axon_7_dumper_PyPointer) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_PyPointer = &__pyx_type_4axon_7_dumper_PyPointer;
  __pyx_vtabptr_4axon_7_dumper_SimpleDumper = &__pyx_vtable_4axon_7_dumper_SimpleDumper;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_int = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_int;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_float = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_float;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_decimal = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_decimal;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_str = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_str;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_bytes = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_bytes;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_unicode = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_unicode;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_bool = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_bool;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_date = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_date;
  __pyx_vtable_4axon_7_dumper_SimpleDumper._dump_tzinfo = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper__dump_tzinfo;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_time = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_time;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_datetime = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_datetime;
  __pyx_vtable_4axon_7_dumper_SimpleDumper.dump_none = (PyObject *(*)(struct __pyx_obj_4axon_7_dumper_SimpleDumper *, PyObject *))__pyx_f_4axon_7_dumper_12SimpleDumper_dump_none;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper_SimpleDumper) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_7_dumper_SimpleDumper.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_4axon_7_dumper_SimpleDumper.tp_dict, __pyx_vtabptr_4axon_7_dumper_SimpleDumper) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "SimpleDumper", (PyObject *)&__pyx_type_4axon_7_dumper_SimpleDumper) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 228; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_SimpleDumper = &__pyx_type_4axon_7_dumper_SimpleDumper;
  __pyx_vtabptr_4axon_7_dumper_SimpleDumpers = &__pyx_vtable_4axon_7_dumper_SimpleDumpers;
  __pyx_vtable_4axon_7_dumper_SimpleDumpers.add = (void (*)(struct SimpleDumpers *, PyObject *, PyObject *(*)(PyObject *)))__pyx_f_4axon_7_dumper_13SimpleDumpers_add;
  __pyx_vtable_4axon_7_dumper_SimpleDumpers.update = (void (*)(struct SimpleDumpers *, PyObject *))__pyx_f_4axon_7_dumper_13SimpleDumpers_update;
  if (PyType_Ready(&SimpleDumpersType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  SimpleDumpersType.tp_print = 0;
  if (__Pyx_SetVtable(SimpleDumpersType.tp_dict, __pyx_vtabptr_4axon_7_dumper_SimpleDumpers) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "SimpleDumpers", (PyObject *)&SimpleDumpersType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_SimpleDumpers = &SimpleDumpersType;
  __pyx_vtabptr_4axon_7_dumper_Dumper = &__pyx_vtable_4axon_7_dumper_Dumper;
  __pyx_vtable_4axon_7_dumper_Dumper.write = (void (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_write;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_crossref = (void (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_crossref;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_crossref = (void (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_crossref;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_label = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_label;
  __pyx_vtable_4axon_7_dumper_Dumper._dump = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_value = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_value;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_dict_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_dict_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_attr_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_attr_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_list_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_list_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._dump_tuple_sequence = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__dump_tuple_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_list = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_list;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_dict = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_dict;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_tuple = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_tuple;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_mapping = (int (*)(struct Dumper *, struct MappingObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_mapping;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_element = (int (*)(struct Dumper *, struct ElementObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_element;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_sequence = (int (*)(struct Dumper *, struct SequenceObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_instance = (int (*)(struct Dumper *, struct InstanceObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_instance;
  __pyx_vtable_4axon_7_dumper_Dumper.dump_empty = (int (*)(struct Dumper *, struct EmptyObject *))__pyx_f_4axon_7_dumper_6Dumper_dump_empty;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_dict_sequence = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_dict_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_attr_sequence = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_attr_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_list_sequence = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_list_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._pretty_dump_tuple_sequence = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper__pretty_dump_tuple_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_list = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_list;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_dict = (int (*)(struct Dumper *, PyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_dict;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_mapping = (int (*)(struct Dumper *, struct MappingObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_mapping;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_element = (int (*)(struct Dumper *, struct ElementObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_element;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_sequence = (int (*)(struct Dumper *, struct SequenceObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_instance = (int (*)(struct Dumper *, struct InstanceObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_instance;
  __pyx_vtable_4axon_7_dumper_Dumper.pretty_dump_empty = (int (*)(struct Dumper *, struct EmptyObject *, PyObject *, int))__pyx_f_4axon_7_dumper_6Dumper_pretty_dump_empty;
  __pyx_vtable_4axon_7_dumper_Dumper.apply_crossref = (void (*)(struct Dumper *))__pyx_f_4axon_7_dumper_6Dumper_apply_crossref;
  __pyx_vtable_4axon_7_dumper_Dumper._collect = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_list = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_list;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_tuple = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_tuple;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_set = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_set;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_dict = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_dict;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_mapping = (int (*)(struct Dumper *, struct MappingObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_mapping;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_sequence = (int (*)(struct Dumper *, struct SequenceObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_sequence;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_element = (int (*)(struct Dumper *, struct ElementObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_element;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_instance = (int (*)(struct Dumper *, struct InstanceObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_instance;
  __pyx_vtable_4axon_7_dumper_Dumper._collect_empty = (int (*)(struct Dumper *, struct EmptyObject *))__pyx_f_4axon_7_dumper_6Dumper__collect_empty;
  __pyx_vtable_4axon_7_dumper_Dumper.collect = (int (*)(struct Dumper *, PyObject *))__pyx_f_4axon_7_dumper_6Dumper_collect;
  if (PyType_Ready(&DumperType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  DumperType.tp_print = 0;
  if (__Pyx_SetVtable(DumperType.tp_dict, __pyx_vtabptr_4axon_7_dumper_Dumper) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Dumper", (PyObject *)&DumperType) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_7_dumper_Dumper = &DumperType;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper___pyx_scope_struct__reduce) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_7_dumper___pyx_scope_struct__reduce.tp_print = 0;
  __pyx_ptype_4axon_7_dumper___pyx_scope_struct__reduce = &__pyx_type_4axon_7_dumper___pyx_scope_struct__reduce;
  if (PyType_Ready(&__pyx_type_4axon_7_dumper___pyx_scope_struct_1_dump_as_str) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_4axon_7_dumper___pyx_scope_struct_1_dump_as_str.tp_print = 0;
  __pyx_ptype_4axon_7_dumper___pyx_scope_struct_1_dump_as_str = &__pyx_type_4axon_7_dumper___pyx_scope_struct_1_dump_as_str;
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_8datetime_date = __Pyx_ImportType("datetime", "date", sizeof(PyDateTime_Date), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_date)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_time = __Pyx_ImportType("datetime", "time", sizeof(PyDateTime_Time), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_time)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_datetime = __Pyx_ImportType("datetime", "datetime", sizeof(PyDateTime_DateTime), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_datetime)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_timedelta = __Pyx_ImportType("datetime", "timedelta", sizeof(PyDateTime_Delta), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_timedelta)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cpython_8datetime_tzinfo = __Pyx_ImportType("datetime", "tzinfo", sizeof(PyDateTime_TZInfo), 0); if (unlikely(!__pyx_ptype_7cpython_8datetime_tzinfo)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 21; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Undefined = __Pyx_ImportType("axon._objects", "Undefined", sizeof(struct UndefinedObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Undefined)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 193; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_rdict = __Pyx_ImportType("axon._objects", "rdict", sizeof(struct ReadonlyDict), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_rdict)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_rlist = __Pyx_ImportType("axon._objects", "rlist", sizeof(struct ReadonlyList), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_rlist)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 207; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_NamedValue = __Pyx_ImportType("axon._objects", "NamedValue", sizeof(struct __pyx_obj_4axon_8_objects_NamedValue), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_NamedValue)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Attribute = __Pyx_ImportType("axon._objects", "Attribute", sizeof(struct Attribute), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Attribute)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 223; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Attrs = __Pyx_ImportType("axon._objects", "Attrs", sizeof(struct __pyx_obj_4axon_8_objects_Attrs), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Attrs)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Empty = __Pyx_ImportType("axon._objects", "Empty", sizeof(struct EmptyObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Empty)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 244; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Sequence = __Pyx_ImportType("axon._objects", "Sequence", sizeof(struct SequenceObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Sequence)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 252; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Mapping = __Pyx_ImportType("axon._objects", "Mapping", sizeof(struct MappingObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Mapping)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Element = __Pyx_ImportType("axon._objects", "Element", sizeof(struct ElementObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Element)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Instance = __Pyx_ImportType("axon._objects", "Instance", sizeof(struct InstanceObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Instance)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_Builder = __Pyx_ImportType("axon._objects", "Builder", sizeof(struct __pyx_obj_4axon_8_objects_Builder), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_Builder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 308; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_Builder = (struct __pyx_vtabstruct_4axon_8_objects_Builder*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_Builder->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_Builder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 308; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_SafeBuilder = __Pyx_ImportType("axon._objects", "SafeBuilder", sizeof(struct __pyx_obj_4axon_8_objects_SafeBuilder), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_SafeBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_SafeBuilder = (struct __pyx_vtabstruct_4axon_8_objects_SafeBuilder*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_SafeBuilder->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_SafeBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_StrictBuilder = __Pyx_ImportType("axon._objects", "StrictBuilder", sizeof(struct __pyx_obj_4axon_8_objects_StrictBuilder), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_StrictBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_StrictBuilder = (struct __pyx_vtabstruct_4axon_8_objects_StrictBuilder*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_StrictBuilder->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_StrictBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_MixedBuilder = __Pyx_ImportType("axon._objects", "MixedBuilder", sizeof(struct __pyx_obj_4axon_8_objects_MixedBuilder), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_MixedBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_MixedBuilder = (struct __pyx_vtabstruct_4axon_8_objects_MixedBuilder*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_MixedBuilder->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_MixedBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_GenericBuilder = __Pyx_ImportType("axon._objects", "GenericBuilder", sizeof(struct GenericBuilderObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_GenericBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_GenericBuilder = (struct __pyx_vtabstruct_4axon_8_objects_GenericBuilder*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_GenericBuilder->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_GenericBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_SimpleBuilder = __Pyx_ImportType("axon._objects", "SimpleBuilder", sizeof(struct SimpleBuilder), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_SimpleBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_SimpleBuilder = (struct __pyx_vtabstruct_4axon_8_objects_SimpleBuilder*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_SimpleBuilder->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_SimpleBuilder)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_StringReader = __Pyx_ImportType("axon._objects", "StringReader", sizeof(struct __pyx_obj_4axon_8_objects_StringReader), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_StringReader)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_StringReader = (struct __pyx_vtabstruct_4axon_8_objects_StringReader*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_StringReader->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_StringReader)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_StringWriter = __Pyx_ImportType("axon._objects", "StringWriter", sizeof(struct __pyx_obj_4axon_8_objects_StringWriter), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_StringWriter)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 404; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_vtabptr_4axon_8_objects_StringWriter = (struct __pyx_vtabstruct_4axon_8_objects_StringWriter*)__Pyx_GetVtable(__pyx_ptype_4axon_8_objects_StringWriter->tp_dict); if (unlikely(!__pyx_vtabptr_4axon_8_objects_StringWriter)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 404; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4axon_8_objects_timezone = __Pyx_ImportType("axon._objects", "timezone", sizeof(struct TimeZoneUTCObject), 1); if (unlikely(!__pyx_ptype_4axon_8_objects_timezone)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  __pyx_t_1 = __Pyx_ImportModule("axon._objects"); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_decimal2str", (void **)&__pyx_vp_4axon_8_objects__decimal2str, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "empty_name", (void **)&__pyx_vp_4axon_8_objects_empty_name, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_undescore", (void **)&__pyx_vp_4axon_8_objects_c_undescore, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_undefined", (void **)&__pyx_vp_4axon_8_objects_c_undefined, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "name_cache", (void **)&__pyx_vp_4axon_8_objects_name_cache, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_str_type", (void **)&__pyx_vp_4axon_8_objects_c_str_type, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_empty_dict", (void **)&__pyx_vp_4axon_8_objects_c_empty_dict, "struct ReadonlyDict *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_empty_list", (void **)&__pyx_vp_4axon_8_objects_c_empty_list, "struct ReadonlyList *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_factory_dict", (void **)&__pyx_vp_4axon_8_objects_c_factory_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "c_builder_dict", (void **)&__pyx_vp_4axon_8_objects_c_builder_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_str2decimal", (void **)&__pyx_vp_4axon_8_objects__str2decimal, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_inf", (void **)&__pyx_vp_4axon_8_objects__inf, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_ninf", (void **)&__pyx_vp_4axon_8_objects__ninf, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_nan", (void **)&__pyx_vp_4axon_8_objects__nan, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_decimal_inf", (void **)&__pyx_vp_4axon_8_objects__decimal_inf, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_decimal_ninf", (void **)&__pyx_vp_4axon_8_objects__decimal_ninf, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "_decimal_nan", (void **)&__pyx_vp_4axon_8_objects__decimal_nan, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "tz_dict", (void **)&__pyx_vp_4axon_8_objects_tz_dict, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "timezone_cls", (void **)&__pyx_vp_4axon_8_objects_timezone_cls, "PyObject *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "axon/_dumper.py":31
 * # THE SOFTWARE.
 * 
 * import axon.types as types             # <<<<<<<<<<<<<<
 * # from axon.types import unicode_type, str_type, int_type, long_type, decimal_type
 * # from axon.types import bool_type, float_type, bytes_type, bytearray_type, none_type
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 31; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s__23);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s__23);
  __Pyx_GIVEREF(__pyx_n_s__23);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_axon_types, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 31; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_types, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 31; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":35
 * # from axon.types import bool_type, float_type, bytes_type, bytearray_type, none_type
 * # from axon.types import date_type, time_type, datetime_type
 * from axon.types import builtins             # <<<<<<<<<<<<<<
 * 
 * unicode_type = types.unicode_type
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_builtins);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_builtins);
  __Pyx_GIVEREF(__pyx_n_s_builtins);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_axon_types, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_builtins); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_builtins, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":37
 * from axon.types import builtins
 * 
 * unicode_type = types.unicode_type             # <<<<<<<<<<<<<<
 * str_type = types.str_type
 * int_type = types.int_type
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_unicode_type); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_unicode_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_unicode_type, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":38
 * 
 * unicode_type = types.unicode_type
 * str_type = types.str_type             # <<<<<<<<<<<<<<
 * int_type = types.int_type
 * long_type = types.long_type
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_str_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_str_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_str_type, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":39
 * unicode_type = types.unicode_type
 * str_type = types.str_type
 * int_type = types.int_type             # <<<<<<<<<<<<<<
 * long_type = types.long_type
 * decimal_type = types.decimal_type
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_int_type); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_int_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_int_type, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":40
 * str_type = types.str_type
 * int_type = types.int_type
 * long_type = types.long_type             # <<<<<<<<<<<<<<
 * decimal_type = types.decimal_type
 * bool_type = types.bool_type
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_long_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_long_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_long_type, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":41
 * int_type = types.int_type
 * long_type = types.long_type
 * decimal_type = types.decimal_type             # <<<<<<<<<<<<<<
 * bool_type = types.bool_type
 * float_type = types.float_type
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_decimal_type); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_decimal_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_decimal_type, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":42
 * long_type = types.long_type
 * decimal_type = types.decimal_type
 * bool_type = types.bool_type             # <<<<<<<<<<<<<<
 * float_type = types.float_type
 * bytes_type = types.bytes_type
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_bool_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_bool_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_bool_type, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":43
 * decimal_type = types.decimal_type
 * bool_type = types.bool_type
 * float_type = types.float_type             # <<<<<<<<<<<<<<
 * bytes_type = types.bytes_type
 * bytearray_type = types.bytearray_type
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float_type); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_float_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_float_type, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":44
 * bool_type = types.bool_type
 * float_type = types.float_type
 * bytes_type = types.bytes_type             # <<<<<<<<<<<<<<
 * bytearray_type = types.bytearray_type
 * none_type = types.none_type
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_bytes_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_bytes_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_bytes_type, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":45
 * float_type = types.float_type
 * bytes_type = types.bytes_type
 * bytearray_type = types.bytearray_type             # <<<<<<<<<<<<<<
 * none_type = types.none_type
 * date_type = types.date_type
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_bytearray_type); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_bytearray_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_bytearray_type, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":46
 * bytes_type = types.bytes_type
 * bytearray_type = types.bytearray_type
 * none_type = types.none_type             # <<<<<<<<<<<<<<
 * date_type = types.date_type
 * time_type = types.time_type
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_none_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_none_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_none_type, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":47
 * bytearray_type = types.bytearray_type
 * none_type = types.none_type
 * date_type = types.date_type             # <<<<<<<<<<<<<<
 * time_type = types.time_type
 * datetime_type = types.datetime_type
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_date_type); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_date_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_date_type, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":48
 * none_type = types.none_type
 * date_type = types.date_type
 * time_type = types.time_type             # <<<<<<<<<<<<<<
 * datetime_type = types.datetime_type
 * 
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_time_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_time_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_time_type, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "axon/_dumper.py":49
 * date_type = types.date_type
 * time_type = types.time_type
 * datetime_type = types.datetime_type             # <<<<<<<<<<<<<<
 * 
 * simple_types = {
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_datetime_type); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_datetime_type);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_datetime_type, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":51
 * datetime_type = types.datetime_type
 * 
 * simple_types = {             # <<<<<<<<<<<<<<
 *     unicode_type,
 *     str_type,
 */
  __pyx_t_3 = PySet_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);

  /* "axon/_dumper.py":52
 * 
 * simple_types = {
 *     unicode_type,             # <<<<<<<<<<<<<<
 *     str_type,
 *     int_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_unicode_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":53
 * simple_types = {
 *     unicode_type,
 *     str_type,             # <<<<<<<<<<<<<<
 *     int_type,
 *     long_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_str_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":54
 *     unicode_type,
 *     str_type,
 *     int_type,             # <<<<<<<<<<<<<<
 *     long_type,
 *     decimal_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_int_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":55
 *     str_type,
 *     int_type,
 *     long_type,             # <<<<<<<<<<<<<<
 *     decimal_type,
 *     bool_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_long_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":56
 *     int_type,
 *     long_type,
 *     decimal_type,             # <<<<<<<<<<<<<<
 *     bool_type,
 *     float_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_decimal_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":57
 *     long_type,
 *     decimal_type,
 *     bool_type,             # <<<<<<<<<<<<<<
 *     float_type,
 *     bytes_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_bool_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":58
 *     decimal_type,
 *     bool_type,
 *     float_type,             # <<<<<<<<<<<<<<
 *     bytes_type,
 *     bytearray_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_float_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":59
 *     bool_type,
 *     float_type,
 *     bytes_type,             # <<<<<<<<<<<<<<
 *     bytearray_type,
 *     none_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_bytes_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":60
 *     float_type,
 *     bytes_type,
 *     bytearray_type,             # <<<<<<<<<<<<<<
 *     none_type,
 *     date_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_bytearray_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":61
 *     bytes_type,
 *     bytearray_type,
 *     none_type,             # <<<<<<<<<<<<<<
 *     date_type,
 *     time_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_none_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":62
 *     bytearray_type,
 *     none_type,
 *     date_type,             # <<<<<<<<<<<<<<
 *     time_type,
 *     datetime_type,
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_date_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":63
 *     none_type,
 *     date_type,
 *     time_type,             # <<<<<<<<<<<<<<
 *     datetime_type,
 * }
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_time_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":64
 *     date_type,
 *     time_type,
 *     datetime_type,             # <<<<<<<<<<<<<<
 * }
 * 
 */
  if (PySet_Add(__pyx_t_3, __pyx_v_4axon_7_dumper_datetime_type) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_simple_types);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_simple_types, ((PyObject*)__pyx_t_3));
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":67
 * }
 * 
 * try:             # <<<<<<<<<<<<<<
 *     import cdecimal as _decimal
 * 
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "axon/_dumper.py":68
 * 
 * try:
 *     import cdecimal as _decimal             # <<<<<<<<<<<<<<
 * 
 * except:
 */
      __pyx_t_3 = __Pyx_Import(__pyx_n_s_cdecimal, 0, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_decimal, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L2_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L2_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "axon/_dumper.py":70
 *     import cdecimal as _decimal
 * 
 * except:             # <<<<<<<<<<<<<<
 *     import decimal as _decimal
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_2, &__pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_7);

      /* "axon/_dumper.py":71
 * 
 * except:
 *     import decimal as _decimal             # <<<<<<<<<<<<<<
 * 
 * default_decimal_context = _decimal.getcontext()
 */
      __pyx_t_8 = __Pyx_Import(__pyx_n_s_decimal_2, 0, 0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_decimal, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L4_except_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L3_exception_handled;
    }
    __pyx_L4_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L9_try_end:;
  }

  /* "axon/_dumper.py":73
 *     import decimal as _decimal
 * 
 * default_decimal_context = _decimal.getcontext()             # <<<<<<<<<<<<<<
 * _decimal2str = default_decimal_context.to_eng_string
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_decimal); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_getcontext); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_default_decimal_context, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "axon/_dumper.py":74
 * 
 * default_decimal_context = _decimal.getcontext()
 * _decimal2str = default_decimal_context.to_eng_string             # <<<<<<<<<<<<<<
 * 
 * import datetime
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_default_decimal_context); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_to_eng_string); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_decimal2str, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":76
 * _decimal2str = default_decimal_context.to_eng_string
 * 
 * import datetime             # <<<<<<<<<<<<<<
 * 
 * try:
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_datetime, 0, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":78
 * import datetime
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from base64 import encodebytes, decodebytes
 * except:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "axon/_dumper.py":79
 * 
 * try:
 *     from base64 import encodebytes, decodebytes             # <<<<<<<<<<<<<<
 * except:
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes
 */
      __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_n_s_encodebytes);
      PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_encodebytes);
      __Pyx_GIVEREF(__pyx_n_s_encodebytes);
      __Pyx_INCREF(__pyx_n_s_decodebytes);
      PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_decodebytes);
      __Pyx_GIVEREF(__pyx_n_s_decodebytes);
      __pyx_t_7 = __Pyx_Import(__pyx_n_s_base64, __pyx_t_2, 0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s_encodebytes); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_encodebytes, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s_decodebytes); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_decodebytes, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L12_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L19_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "axon/_dumper.py":80
 * try:
 *     from base64 import encodebytes, decodebytes
 * except:             # <<<<<<<<<<<<<<
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("axon._dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_2, &__pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);

      /* "axon/_dumper.py":81
 *     from base64 import encodebytes, decodebytes
 * except:
 *     from base64 import encodestring as encodebytes, decodestring as decodebytes             # <<<<<<<<<<<<<<
 * 
 * class PyInt:
 */
      __pyx_t_8 = PyList_New(2); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_n_s_encodestring);
      PyList_SET_ITEM(__pyx_t_8, 0, __pyx_n_s_encodestring);
      __Pyx_GIVEREF(__pyx_n_s_encodestring);
      __Pyx_INCREF(__pyx_n_s_decodestring);
      PyList_SET_ITEM(__pyx_t_8, 1, __pyx_n_s_decodestring);
      __Pyx_GIVEREF(__pyx_n_s_decodestring);
      __pyx_t_9 = __Pyx_Import(__pyx_n_s_base64, __pyx_t_8, 0); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_ImportFrom(__pyx_t_9, __pyx_n_s_encodestring); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_encodebytes, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_ImportFrom(__pyx_t_9, __pyx_n_s_decodestring); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_decodebytes, __pyx_t_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L14_except_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L13_exception_handled;
    }
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L13_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
    __pyx_L19_try_end:;
  }

  /* "axon/_dumper.py":128
 * #     return _list_name, o
 * 
 * _c_type_reducers = {             # <<<<<<<<<<<<<<
 *     Mapping: mapping_reduce,
 *     Element: element_reduce,
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);

  /* "axon/_dumper.py":129
 * 
 * _c_type_reducers = {
 *     Mapping: mapping_reduce,             # <<<<<<<<<<<<<<
 *     Element: element_reduce,
 *     Sequence: sequence_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_mapping_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Mapping)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":130
 * _c_type_reducers = {
 *     Mapping: mapping_reduce,
 *     Element: element_reduce,             # <<<<<<<<<<<<<<
 *     Sequence: sequence_reduce,
 *     Instance: instance_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_element_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Element)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":131
 *     Mapping: mapping_reduce,
 *     Element: element_reduce,
 *     Sequence: sequence_reduce,             # <<<<<<<<<<<<<<
 *     Instance: instance_reduce,
 *     Empty: empty_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sequence_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Sequence)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":132
 *     Element: element_reduce,
 *     Sequence: sequence_reduce,
 *     Instance: instance_reduce,             # <<<<<<<<<<<<<<
 *     Empty: empty_reduce,
 *     #Collection: collection_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_instance_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Instance)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":133
 *     Sequence: sequence_reduce,
 *     Instance: instance_reduce,
 *     Empty: empty_reduce,             # <<<<<<<<<<<<<<
 *     #Collection: collection_reduce,
 *     #set: set_reduce,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_empty_reduce); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)((PyObject*)__pyx_ptype_4axon_8_objects_Empty)), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper__c_type_reducers);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper__c_type_reducers, ((PyObject*)__pyx_t_3));
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":141
 * }
 * 
 * c_reduce_dict = _c_type_reducers.copy()             # <<<<<<<<<<<<<<
 * 
 * def reset_reduce():
 */
  if (unlikely(__pyx_v_4axon_7_dumper__c_type_reducers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "copy");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_3 = PyDict_Copy(__pyx_v_4axon_7_dumper__c_type_reducers); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XGOTREF(c_reduce_dict);
  __Pyx_DECREF_SET(c_reduce_dict, ((PyObject*)__pyx_t_3));
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":143
 * c_reduce_dict = _c_type_reducers.copy()
 * 
 * def reset_reduce():             # <<<<<<<<<<<<<<
 *     c_reduce_dict = _c_type_reducers.copy()
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_11reset_reduce, 0, __pyx_n_s_reset_reduce, NULL, __pyx_n_s_axon__dumper, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__40)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reset_reduce, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":150
 * #        self.__dict__.update(kw)
 * 
 * def reduce(type_, reduce_func = None):             # <<<<<<<<<<<<<<
 *     if reduce_func is None:
 *         def _factory(factory_func):
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_13reduce, 0, __pyx_n_s_reduce, NULL, __pyx_n_s_axon__dumper, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__42)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__43);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":159
 *         c_reduce_dict[type_] = reduce_func
 * 
 * reduce_dict = c_reduce_dict             # <<<<<<<<<<<<<<
 * 
 * #
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_dict, c_reduce_dict) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "axon/_dumper.py":177
 *     return pyptr
 * 
 * def _dump_undef(o):             # <<<<<<<<<<<<<<
 *     return '??'
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_15_dump_undef, 0, __pyx_n_s_dump_undef, NULL, __pyx_n_s_axon__dumper, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dump_undef, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":196
 *     return c_object_to_unicode(v)
 * 
 * c_simple_dumpers = {}             # <<<<<<<<<<<<<<
 * 
 * #    ###types.int_type: c_new_pyptr(_dump_int),
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper_c_simple_dumpers);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper_c_simple_dumpers, ((PyObject*)__pyx_t_3));
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":400
 *         return 'null'
 * 
 * _simple_dumper = SimpleDumper()             # <<<<<<<<<<<<<<
 * 
 * class SimpleDumpers:
 */
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_4axon_7_dumper_SimpleDumper)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 400; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XGOTREF(((PyObject *)__pyx_v_4axon_7_dumper__simple_dumper));
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper__simple_dumper, ((struct __pyx_obj_4axon_7_dumper_SimpleDumper *)__pyx_t_3));
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":418
 *             self.mapping.update(sd.mapping)
 * 
 * def dump_as_str(tp=None):             # <<<<<<<<<<<<<<
 *     if tp is None:
 *         def _dump_as_str(func):
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_4axon_7_dumper_17dump_as_str, 0, __pyx_n_s_dump_as_str_2, NULL, __pyx_n_s_axon__dumper, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__47)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__48);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dump_as_str_2, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 418; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_dumper.py":508
 *         return text
 * 
 * _simple_types = {             # <<<<<<<<<<<<<<
 *     types.unicode_type, types.str_type, types.int_type, types.long_type,
 *     types.float_type, types.decimal_type, types.bool_type,
 */
  __pyx_t_3 = PySet_New(0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);

  /* "axon/_dumper.py":509
 * 
 * _simple_types = {
 *     types.unicode_type, types.str_type, types.int_type, types.long_type,             # <<<<<<<<<<<<<<
 *     types.float_type, types.decimal_type, types.bool_type,
 *     types.date_type, types.time_type, types.datetime_type}
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_unicode_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_int_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_long_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "axon/_dumper.py":510
 * _simple_types = {
 *     types.unicode_type, types.str_type, types.int_type, types.long_type,
 *     types.float_type, types.decimal_type, types.bool_type,             # <<<<<<<<<<<<<<
 *     types.date_type, types.time_type, types.datetime_type}
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_decimal_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_bool_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "axon/_dumper.py":511
 *     types.unicode_type, types.str_type, types.int_type, types.long_type,
 *     types.float_type, types.decimal_type, types.bool_type,
 *     types.date_type, types.time_type, types.datetime_type}             # <<<<<<<<<<<<<<
 * 
 * def is_simple_type(self, o):
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_date_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_time_type); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_datetime_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PySet_Add(__pyx_t_3, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_4axon_7_dumper__simple_types);
  __Pyx_DECREF_SET(__pyx_v_4axon_7_dumper__simple_types, ((PyObject*)__pyx_t_3));
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "axon/_dumper.py":1
 * # coding: utf-8             # <<<<<<<<<<<<<<
 * 
 * #cython: boundscheck=False
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "axon/_objects.pxd":351
 * cdef dict c_builder_dict
 * 
 * cdef inline Builder c_get_builder(object mode):             # <<<<<<<<<<<<<<
 *     return <Builder>c_builder_dict.get(mode, None)
 * 
 */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  if (__pyx_m) {
    __Pyx_AddTraceback("init axon._dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init axon._dumper");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
#if PY_VERSION_HEX >= 0x02060000
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
#endif
    result = (*call)(func, arg, kw);
#if PY_VERSION_HEX >= 0x02060000
    Py_LeaveRecursiveCall();
#endif
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

static void __Pyx_RaiseArgumentTypeInvalid(const char* name, PyObject *obj, PyTypeObject *type) {
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
}
static CYTHON_INLINE int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (none_allowed && obj == Py_None) return 1;
    else if (exact) {
        if (likely(Py_TYPE(obj) == type)) return 1;
        #if PY_MAJOR_VERSION == 2
        else if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(PyObject_TypeCheck(obj, type))) return 1;
    }
    __Pyx_RaiseArgumentTypeInvalid(name, obj, type);
    return 0;
}

static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL)
        value = Py_None; /* Mark as deleted */
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    Py_DECREF(res);
    return 0;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
#ifndef PY_WRITE_RESTRICTED /* < Py2.5 */
#define PY_WRITE_RESTRICTED WRITE_RESTRICTED
#endif
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CyFunctionObject, func.m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {__Pyx_NAMESTR("__reduce__"), (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    op->func_weakreflist = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyMem_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    if (m->func_weakreflist != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return PyMethod_New(func,
                            type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
#if CYTHON_COMPILING_IN_PYPY
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    Py_ssize_t size;
    switch (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)) {
    case METH_VARARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0)
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 0)
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 1)
                return (*meth)(self, PyTuple_GET_ITEM(arg, 0));
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
#else
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
	return PyCFunction_Call(func, arg, kw);
}
#endif
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __Pyx_NAMESTR("cython_function_or_method"), /*tp_name*/
    sizeof(__pyx_CyFunctionObject),   /*tp_basicsize*/
    0,                                  /*tp_itemsize*/
    (destructor) __Pyx_CyFunction_dealloc, /*tp_dealloc*/
    0,                                  /*tp_print*/
    0,                                  /*tp_getattr*/
    0,                                  /*tp_setattr*/
#if PY_MAJOR_VERSION < 3
    0,                                  /*tp_compare*/
#else
    0,                                  /*reserved*/
#endif
    (reprfunc) __Pyx_CyFunction_repr,   /*tp_repr*/
    0,                                  /*tp_as_number*/
    0,                                  /*tp_as_sequence*/
    0,                                  /*tp_as_mapping*/
    0,                                  /*tp_hash*/
    __Pyx_CyFunction_Call,              /*tp_call*/
    0,                                  /*tp_str*/
    0,                                  /*tp_getattro*/
    0,                                  /*tp_setattro*/
    0,                                  /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC, /* tp_flags*/
    0,                                  /*tp_doc*/
    (traverseproc) __Pyx_CyFunction_traverse,   /*tp_traverse*/
    (inquiry) __Pyx_CyFunction_clear,   /*tp_clear*/
    0,                                  /*tp_richcompare*/
    offsetof(__pyx_CyFunctionObject, func_weakreflist), /* tp_weaklistoffse */
    0,                                  /*tp_iter*/
    0,                                  /*tp_iternext*/
    __pyx_CyFunction_methods,           /*tp_methods*/
    __pyx_CyFunction_members,           /*tp_members*/
    __pyx_CyFunction_getsets,           /*tp_getset*/
    0,                                  /*tp_base*/
    0,                                  /*tp_dict*/
    __Pyx_CyFunction_descr_get,         /*tp_descr_get*/
    0,                                  /*tp_descr_set*/
    offsetof(__pyx_CyFunctionObject, func_dict),/*tp_dictoffset*/
    0,                                  /*tp_init*/
    0,                                  /*tp_alloc*/
    0,                                  /*tp_new*/
    0,                                  /*tp_free*/
    0,                                  /*tp_is_gc*/
    0,                                  /*tp_bases*/
    0,                                  /*tp_mro*/
    0,                                  /*tp_cache*/
    0,                                  /*tp_subclasses*/
    0,                                  /*tp_weaklist*/
    0,                                  /*tp_del*/
#if PY_VERSION_HEX >= 0x02060000
    0,                                  /*tp_version_tag*/
#endif
#if PY_VERSION_HEX >= 0x030400a1
    0,                                  /*tp_finalize*/
#endif
};
static int __Pyx_CyFunction_init(void) {
#if !CYTHON_COMPILING_IN_PYPY
    __pyx_CyFunctionType_type.tp_call = PyCFunction_Call;
#endif
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (__pyx_CyFunctionType == NULL) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyMem_Malloc(size);
    if (!m->defaults)
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    } else {
        if (default_value == Py_None)
            default_value = NULL;
        value = PyObject_CallMethodObjArgs(
            d, __pyx_n_s_get, key, default_value, NULL);
    }
#endif
    return value;
}

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON
    result = PyDict_GetItem(__pyx_d, name);
    if (result) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    #if PY_VERSION_HEX < 0x02050000
    if (PyClass_Check(type)) {
    #else
    if (PyType_Check(type)) {
    #endif
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        #if PY_VERSION_HEX < 0x02050000
        if (PyInstance_Check(type)) {
            type = (PyObject*) ((PyInstanceObject*)type)->in_class;
            Py_INCREF(type);
        } else {
            type = 0;
            PyErr_SetString(PyExc_TypeError,
                "raise: exception must be an old-style class or instance");
            goto raise_error;
        }
        #else
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
        #endif
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else /* Python 3+ */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                if (PyObject_IsSubclass(instance_class, type)) {
                    type = instance_class;
                } else {
                    instance_class = NULL;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck) {
    Py_ssize_t length;
#if CYTHON_PEP393_ENABLED
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return (Py_UCS4)-1;
#endif
    if (wraparound | boundscheck) {
        length = __Pyx_PyUnicode_GET_LENGTH(ustring);
        if (wraparound & unlikely(i < 0)) i += length;
        if ((!boundscheck) || likely((0 <= i) & (i < length))) {
            return __Pyx_PyUnicode_READ_CHAR(ustring, i);
        } else {
            PyErr_SetString(PyExc_IndexError, "string index out of range");
            return (Py_UCS4)-1;
        }
    } else {
        return __Pyx_PyUnicode_READ_CHAR(ustring, i);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
#if CYTHON_PEP393_ENABLED
    if (unlikely(PyUnicode_READY(text) == -1)) return NULL;
    length = PyUnicode_GET_LENGTH(text);
#else
    length = PyUnicode_GET_SIZE(text);
#endif
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    length = stop - start;
    if (length <= 0)
        return PyUnicode_FromUnicode(NULL, 0);
#if CYTHON_PEP393_ENABLED
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#else
    return PyUnicode_FromUnicode(PyUnicode_AS_UNICODE(text)+start, stop-start);
#endif
}

static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_PyObject_CallMethod1((PyObject*)&PyDict_Type, __pyx_n_s_items, d);
    else
        return PyDict_Items(d);
}

static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject* iterator, PyObject* defval) {
    PyObject* next;
    iternextfunc iternext = Py_TYPE(iterator)->tp_iternext;
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(!iternext)) {
#else
    if (unlikely(!iternext) || unlikely(!PyIter_Check(iterator))) {
#endif
        PyErr_Format(PyExc_TypeError,
            "%.200s object is not an iterator", Py_TYPE(iterator)->tp_name);
        return NULL;
    }
    next = iternext(iterator);
    if (likely(next))
        return next;
#if CYTHON_COMPILING_IN_CPYTHON
#if PY_VERSION_HEX >= 0x03010000 || (PY_MAJOR_VERSION < 3 && PY_VERSION_HEX >= 0x02070000)
    if (unlikely(iternext == &_PyObject_NextNotImplemented))
        return NULL;
#endif
#endif
    if (defval) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
            if (unlikely(exc_type != PyExc_StopIteration) &&
                    !PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))
                return NULL;
            PyErr_Clear();
        }
        Py_INCREF(defval);
        return defval;
    }
    if (!PyErr_Occurred())
        PyErr_SetNone(PyExc_StopIteration);
    return NULL;
}

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

static CYTHON_INLINE int __Pyx_unpack_tuple2(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                             int is_tuple, int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    if (!is_tuple && unlikely(!PyTuple_Check(tuple))) {
        iternextfunc iternext;
        iter = PyObject_GetIter(tuple);
        if (unlikely(!iter)) goto bad;
        if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
        iternext = Py_TYPE(iter)->tp_iternext;
        value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
        value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
        if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
        Py_DECREF(iter);
    } else {
        if (!has_known_size && unlikely(PyTuple_GET_SIZE(tuple) != 2)) {
            __Pyx_UnpackTupleError(tuple, 2);
            goto bad;
        }
#if CYTHON_COMPILING_IN_PYPY
        value1 = PySequence_ITEM(tuple, 0);
        if (unlikely(!value1)) goto bad;
        value2 = PySequence_ITEM(tuple, 1);
        if (unlikely(!value2)) goto bad;
#else
        value1 = PyTuple_GET_ITEM(tuple, 0);
        value2 = PyTuple_GET_ITEM(tuple, 1);
        Py_INCREF(value1);
        Py_INCREF(value2);
#endif
        if (decref_tuple) { Py_DECREF(tuple); }
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
#if !CYTHON_COMPILING_IN_PYPY
    if (is_dict) {
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#endif
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* iter_obj, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
#else
    PyErr_GetExcInfo(type, value, tb);
#endif
}
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(type, value, tb);
#endif
}

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func)             \
    {                                                                     \
        func_type value = func(x);                                        \
        if (sizeof(target_type) < sizeof(func_type)) {                    \
            if (unlikely(value != (func_type) (target_type) value)) {     \
                func_type zero = 0;                                       \
                PyErr_SetString(PyExc_OverflowError,                      \
                    (is_unsigned && unlikely(value < zero)) ?             \
                    "can't convert negative value to " #target_type :     \
                    "value too large to convert to " #target_type);       \
                return (target_type) -1;                                  \
            }                                                             \
        }                                                                 \
        return (target_type) value;                                       \
    }

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG)
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long) -1;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long) -1;
            }
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long, PyLong_AsUnsignedLong)
            } else if (sizeof(long) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long long, PyLong_AsUnsignedLongLong)
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(long, long, PyLong_AsLong)
            } else if (sizeof(long) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(long, long long, PyLong_AsLongLong)
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(long) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(int) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG)
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to int");
                return (int) -1;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(int)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (int) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to int");
                return (int) -1;
            }
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long, PyLong_AsUnsignedLong)
            } else if (sizeof(int) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long long, PyLong_AsUnsignedLongLong)
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(int)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(int) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(int) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(int, long, PyLong_AsLong)
            } else if (sizeof(int) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(int, long long, PyLong_AsLongLong)
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig) {
    PyObject *d;
    PyObject *cobj = 0;
    d = PyDict_GetItem(__pyx_d, __pyx_n_s_pyx_capi);
    Py_XINCREF(d);
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (__Pyx_PyObject_SetAttrStr(__pyx_m, __pyx_n_s_pyx_capi, d) < 0)
            goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    cobj = PyCapsule_New(p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItem(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    cobj = PyCapsule_New(tmp.p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(tmp.p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        #if PY_VERSION_HEX < 0x02050000
        if (PyErr_Warn(NULL, warning) < 0) goto bad;
        #else
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
        #endif
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

#ifndef __PYX_HAVE_RT_ImportVoidPtr
#define __PYX_HAVE_RT_ImportVoidPtr
static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, name);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C variable %.200s",
                PyModule_GetName(module), name);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C variable %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C variable %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), name, sig, desc);
        goto bad;
    }
    *p = PyCObject_AsVoidPtr(cobj);}
#endif
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif /*__PYX_DEFAULT_STRING_ENCODING_IS_ASCII*/
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else /* PY_VERSION_HEX < 0x03030000 */
        if (PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_DATA_SIZE(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
        return PyUnicode_AsUTF8AndSize(o, length);
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
#endif /* PY_VERSION_HEX < 0x03030000 */
    } else
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII  || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT */
#if !CYTHON_COMPILING_IN_PYPY
#if PY_VERSION_HEX >= 0x02060000
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b)))
      return PyInt_AS_LONG(b);
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
     #if CYTHON_USE_PYLONG_INTERNALS
       switch (Py_SIZE(b)) {
       case -1: return -(sdigit)((PyLongObject*)b)->ob_digit[0];
       case  0: return 0;
       case  1: return ((PyLongObject*)b)->ob_digit[0];
       }
     #endif
    #endif
  #if PY_VERSION_HEX < 0x02060000
    return PyInt_AsSsize_t(b);
  #else
    return PyLong_AsSsize_t(b);
  #endif
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}


#endif /* Py_PYTHON_H */
